@@ -1,4 +1,4 @@
-<?PHP //$Id: backup_scheduled.php,v 1.16.2.4 2005/01/10 21:46:21 mjollnir_ Exp $
+<?php //$Id: backup_scheduled.php,v 1.36 2006/10/07 20:47:56 skodak Exp $
     //This file contains all the code needed to execute scheduled backups
 
 //This function is executed via moodle cron
@@ -98,9 +98,17 @@ function schedule_backup_cron() {
                 if (!$backup_course) {
                     mtrace("            ERROR (in backup_courses detection)");
                     $status = false;
+                    continue;
                 }
-                //Now we backup every course with nextstarttime < now
-                if ($backup_course->nextstarttime > 0 && $backup_course->nextstarttime < $now) {
+                // Skip backup of unavailable courses that have remained unmodified in a month
+                $skipped = false;
+                if (!$course->visible && ($now - $course->timemodified) > 31*24*60*60) {  //Hidden + unmodified last month
+                    mtrace("            SKIPPING - hidden+unmodified");
+                    set_field("backup_courses","laststatus","3","courseid",$backup_course->courseid);
+                    $skipped = true;
+                } 
+                //Now we backup every non skipped course with nextstarttime < now
+                if (!$skipped  && $backup_course->nextstarttime > 0 && $backup_course->nextstarttime < $now) {
                     //We have to send a email because we have included at least one backup
                     $emailpending = true;
                     //Only make the backup if laststatus isn't 2-UNFINISHED (uncontrolled error)
@@ -154,6 +162,7 @@ function schedule_backup_cron() {
         $count_ok = count_records('backup_courses','laststatus','1');
         $count_error = count_records('backup_courses','laststatus','0');
         $count_unfinished = count_records('backup_courses','laststatus','2');
+        $count_skipped = count_records('backup_courses','laststatus','3');
 
         //Build the message text
         //Summary
@@ -161,6 +170,7 @@ function schedule_backup_cron() {
         $message .= "==================================================\n";
         $message .= "  ".get_string('courses').": ".$count_all."\n";
         $message .= "  ".get_string('ok').": ".$count_ok."\n";
+        $message .= "  ".get_string('skipped').": ".$count_skipped."\n";
         $message .= "  ".get_string('error').": ".$count_error."\n";
         $message .= "  ".get_string('unfinished').": ".$count_unfinished."\n\n";
 
@@ -169,6 +179,8 @@ function schedule_backup_cron() {
             $message .= "  ".get_string('backupfailed')."\n\n";
             $dest_url = $CFG->wwwroot.'/backup/log.php';
             $message .= "  ".get_string('backuptakealook','',$dest_url)."\n\n";
+            //Set message priority
+            $admin->priority = 1;
             //Reset unfinished to error
             set_field('backup_courses','laststatus','0','laststatus','2');
         } else {
@@ -307,6 +319,9 @@ function schedule_backup_course_configure($course,$starttime = 0) {
         if (!isset($backup_config->backup_sche_withuserdata)) {
             $backup_config->backup_sche_withuserdata = 1;
         }
+        if (!isset($backup_config->backup_sche_metacourse)) {
+            $backup_config->backup_sche_metacourse = 1;
+        }
         if (!isset($backup_config->backup_sche_users)) {
             $backup_config->backup_sche_users = 1;
         }
@@ -319,6 +334,9 @@ function schedule_backup_course_configure($course,$starttime = 0) {
         if (!isset($backup_config->backup_sche_coursefiles)) {
             $backup_config->backup_sche_coursefiles = 1;
         }
+        if (!isset($backup_config->backup_sche_messages)) {
+            $backup_config->backup_sche_messages = 0;
+        }
         if (!isset($backup_config->backup_sche_active)) {
             $backup_config->backup_sche_active = 0;
         }
@@ -355,36 +373,58 @@ function schedule_backup_course_configure($course,$starttime = 0) {
                        $var = "exists_".$modname;
                        $$var = true;
                        $count++;
+                       
+                       // PENNY NOTES: I have moved from here to the closing brace inside 
+                       // by two sets of ifs()
+                       // to avoid the backup failing on a non existant backup.
+                       // If the file/function/whatever doesn't exist, we don't want to set this
+                       // this module in backup preferences at all.
+                       //Check data
+                       //Check module info
+                       $var = "backup_".$modname;
+                       if (!isset($$var)) {
+                           $$var = $backup_config->backup_sche_modules;
+                       }
+                       //Now stores all the mods preferences into an array into preferences
+                       $preferences->mods[$modname]->backup = $$var;
+                       
+                       //Check include user info
+                       $var = "backup_user_info_".$modname;
+                       if (!isset($$var)) {
+                           $$var = $backup_config->backup_sche_withuserdata;
+                       }
+                       //Now stores all the mods preferences into an array into preferences
+                       $preferences->mods[$modname]->userinfo = $$var;
+                       //And the name of the mod
+                       $preferences->mods[$modname]->name = $modname;
                    }
                 }
-                //Check data
-                //Check module info
-                $var = "backup_".$modname;
-                if (!isset($$var)) {
-                    $$var = $backup_config->backup_sche_modules;
+            }
+        }
+        // now set instances
+        if ($coursemods = get_course_mods($course->id)) {
+            foreach ($coursemods as $mod) {
+                if (array_key_exists($mod->modname,$preferences->mods)) { // we are to backup this module
+                    if (empty($preferences->mods[$mod->modname]->instances)) {
+                        $preferences->mods[$mod->modname]->instances = array(); // avoid warnings
+                    }
+                    $preferences->mods[$mod->modname]->instances[$mod->instance]->backup = $preferences->mods[$mod->modname]->backup;
+                    $preferences->mods[$mod->modname]->instances[$mod->instance]->userinfo = $preferences->mods[$mod->modname]->userinfo;
+                    // there isn't really a nice way to do this...
+                    $preferences->mods[$mod->modname]->instances[$mod->instance]->name = get_field($mod->modname,'name','id',$mod->instance);
                 }
-                //Now stores all the mods preferences into an array into preferences
-                $preferences->mods[$modname]->backup = $$var;
-
-                //Check include user info
-                $var = "backup_user_info_".$modname;
-                if (!isset($$var)) {
-                    $$var = $backup_config->backup_sche_withuserdata;
-                }
-                //Now stores all the mods preferences into an array into preferences
-                $preferences->mods[$modname]->userinfo = $$var;
-                //And the name of the mod
-                $preferences->mods[$modname]->name = $modname;
             }
         }
     }
     
     //Convert other parameters
     if ($status) {
+        $preferences->backup_metacourse = $backup_config->backup_sche_metacourse;
         $preferences->backup_users = $backup_config->backup_sche_users;
         $preferences->backup_logs = $backup_config->backup_sche_logs;
         $preferences->backup_user_files = $backup_config->backup_sche_userfiles;
         $preferences->backup_course_files = $backup_config->backup_sche_coursefiles;
+        $preferences->backup_messages = $backup_config->backup_sche_messages;
         $preferences->backup_course = $course->id;
         $preferences->backup_destination = $backup_config->backup_sche_destination;
         $preferences->backup_keep = $backup_config->backup_sche_keep;
@@ -397,7 +437,7 @@ function schedule_backup_course_configure($course,$starttime = 0) {
         //Calculate the backup word
         //Take off some characters in the filename !!
         $takeoff = array(" ", ":", "/", "\\", "|");
-        $backup_word = str_replace($takeoff,"_",strtolower(get_string("backupfilename")));
+        $backup_word = str_replace($takeoff,"_",moodle_strtolower(get_string("backupfilename")));
         //If non-translated, use "backup"
         if (substr($backup_word,0,1) == "[") {
             $backup_word= "backup";
@@ -420,7 +460,7 @@ function schedule_backup_course_configure($course,$starttime = 0) {
         //The backup word
         $backup_name = $backup_word."-";
         //The shortname
-        $backup_name .= strtolower($backup_shortname)."-";
+        $backup_name .= moodle_strtolower($backup_shortname)."-";
         //The date format
         $backup_name .= userdate(time(),$backup_date_format,99,false);
         //The extension
@@ -431,7 +471,7 @@ function schedule_backup_course_configure($course,$starttime = 0) {
         //Calculate the string to match the keep preference
         $keep_name = $backup_word."-";
         //The shortname
-        $keep_name .= strtolower($backup_shortname)."-";
+        $keep_name .= moodle_strtolower($backup_shortname)."-";
         //And finally, clean everything
         $keep_name = clean_filename($keep_name);
  
@@ -474,7 +514,13 @@ function schedule_backup_course_configure($course,$starttime = 0) {
     //Now calculate the users
     if ($status) {
         schedule_backup_log($starttime,$course->id,"    calculating users");
-        user_check_backup($course->id,$backup_unique_code,$preferences->backup_users);  
+        //Decide about include users with messages, based on SITEID
+        if ($preferences->backup_messages && $preferences->backup_course == SITEID) {
+            $include_message_users = true;
+        } else {
+            $include_message_users = false;
+        }
+        user_check_backup($course->id,$backup_unique_code,$preferences->backup_users,$include_message_users);  
     }
 
     //Now calculate the logs
@@ -558,6 +604,18 @@ function schedule_backup_course_execute($preferences,$starttime = 0) {
             $status = backup_course_start($backup_file,$preferences);
         }
 
+        //Metacourse information
+        if ($status && $preferences->backup_metacourse) {
+            schedule_backup_log($starttime,$preferences->backup_course,"      metacourse info");
+            $status = backup_course_metacourse($backup_file,$preferences);
+        }
+
+        //Block info
+        if ($status) {
+            schedule_backup_log($starttime,$preferences->backup_course,"      blocks info");
+            $status = backup_course_blocks($backup_file,$preferences);
+        }
+
         //Section info
         if ($status) {
             schedule_backup_log($starttime,$preferences->backup_course,"      sections info");
@@ -570,11 +628,20 @@ function schedule_backup_course_execute($preferences,$starttime = 0) {
             $status = backup_user_info($backup_file,$preferences);
         }
 
+        //If we have selected to backup messages and we are
+        //doing a SITE backup, let's do it
+        if ($status && $preferences->backup_messages && $preferences->backup_course == SITEID) {
+            schedule_backup_log($starttime,$preferences->backup_course,"      messages");
+            if (!$status = backup_messages($backup_file,$preferences)) {
+                notify("An error occurred while backing up messages");
+            }
+        }
+
         //If we have selected to backup quizzes, backup categories and
         //questions structure (step 1). See notes on mod/quiz/backuplib.php
         if ($status and $preferences->mods['quiz']->backup) {
             schedule_backup_log($starttime,$preferences->backup_course,"      categories & questions");
-            $status = quiz_backup_question_categories($backup_file,$preferences);
+            $status = backup_question_categories($backup_file,$preferences);
         }
         
         //Print logs if selected
@@ -603,6 +670,12 @@ function schedule_backup_course_execute($preferences,$starttime = 0) {
             $status = backup_events_info($backup_file,$preferences);
         }
 
+        //Print gradebook info
+        if ($status) {
+            schedule_backup_log($starttime,$preferences->backup_course,"      gradebook");
+            $status = backup_gradebook_info($backup_file,$preferences);
+        }
+
         //Module info, this unique function makes all the work!!
         //db export and module fileis copy
         if ($status) {
@@ -699,7 +772,9 @@ function schedule_backup_course_delete_old_files($preferences,$starttime=0) {
         $dirtocheck = $CFG->dataroot."/".$preferences->backup_course."/backupdata";
     }
     schedule_backup_log($starttime,$preferences->backup_course,"    checking $dirtocheck");
-    mtrace("            Keeping backup files in $dirtocheck");
+    if ($CFG->debug > 7) {
+        mtrace("            Keeping backup files in $dirtocheck");
+    }
 
     //Get all the files in $dirtocheck
     $files = get_directory_list($dirtocheck,"",false);
