@@ -1,14 +1,17 @@
-<?PHP //$Id: lib.php,v 1.51.4.1 2004/09/24 11:47:03 stronk7 Exp $
+<?php //$Id: lib.php,v 1.78.2.3 2007/02/15 09:45:37 skodak Exp $
     //This file contains all the general function needed (file manipulation...)
     //not directly part of the backup/restore utility
 
+    require_once($CFG->dirroot.'/lib/uploadlib.php');
+
     //Sets a name/value pair in backup_config table
     function backup_set_config($name, $value) {
         if (get_field("backup_config", "name", "name", $name)) {
-            return set_field("backup_config", "value", $value, "name", $name);
+            return set_field("backup_config", "value", addslashes($value), "name", $name);
         } else {
+            $config = new object();
             $config->name = $name;
-            $config->value = $value;
+            $config->value = addslashes($value);
             return insert_record("backup_config", $config);
         }
     }
@@ -79,24 +82,6 @@
         return $status;
     }
 
-    //Function to check if a directory exists
-    //and, optionally, create it
-    function check_dir_exists($dir,$create=false) {
-
-        global $CFG; 
-
-        $status = true;
-        if(!is_dir($dir)) {
-            if (!$create) {
-                $status = false;
-            } else {
-                umask(0000);
-                $status = mkdir ($dir,$CFG->directorypermissions);
-            }
-        }
-        return $status;
-    }
-
     //Function to check and create the needed dir to 
     //save all the backup
     function check_and_create_backup_dir($backup_unique_code) {
@@ -278,22 +263,29 @@
     //I've copied it from: http://www.php.net/manual/en/function.copy.php
     //Little modifications done
   
-    function backup_copy_file ($from_file,$to_file) {
+    function backup_copy_file ($from_file,$to_file,$log_clam=false) {
 
         global $CFG;
 
         if (is_file($from_file)) {
-            //echo "<br>Copying ".$from_file." to ".$to_file;              //Debug
+            //echo "<br />Copying ".$from_file." to ".$to_file;              //Debug
             //$perms=fileperms($from_file);
             //return copy($from_file,$to_file) && chmod($to_file,$perms);
             umask(0000);
-            return copy($from_file,$to_file) && chmod($to_file,$CFG->directorypermissions);
+            if (copy($from_file,$to_file)) {
+                chmod($to_file,$CFG->directorypermissions);
+                if (!empty($log_clam)) {
+                    clam_log_upload($to_file,null,true);
+                }
+                return true;
+            }
+            return false;
         }
         else if (is_dir($from_file)) {
             return backup_copy_dir($from_file,$to_file);
         }
         else{
-            //echo "<br>Error: not file or dir ".$from_file;               //Debug
+            //echo "<br />Error: not file or dir ".$from_file;               //Debug
             return false;
         }
     }
@@ -302,8 +294,10 @@
 
         global $CFG;
 
+        $status = true; // Initialize this, next code will change its value if needed
+
         if (!is_dir($to_file)) {
-            //echo "<br>Creating ".$to_file;                                //Debug
+            //echo "<br />Creating ".$to_file;                                //Debug
             umask(0000);
             $status = mkdir($to_file,$CFG->directorypermissions);
         }
@@ -332,16 +326,32 @@
 
         if (empty($CFG->backup_version)) {                  // Backup has never been installed.
             $strdatabaseupgrades = get_string("databaseupgrades");
-            print_header($strdatabaseupgrades, $strdatabaseupgrades, $strdatabaseupgrades, 
-                         "", "", false, "&nbsp;", "&nbsp;");
+            print_header($strdatabaseupgrades, $strdatabaseupgrades, $strdatabaseupgrades, "", 
+                    upgrade_get_javascript(), false, "&nbsp;", "&nbsp;");
 
+            upgrade_log_start();
+            print_heading('backup');
             $db->debug=true;
-            if (modify_database("$CFG->dirroot/backup/db/$CFG->dbtype.sql")) {
-                $db->debug = false;
+
+        /// Both old .sql files and new install.xml are supported
+        /// but we priorize install.xml (XMLDB) if present
+            $status = false;
+            if (file_exists($CFG->dirroot . '/backup/db/install.xml')) {
+                $status = install_from_xmldb_file($CFG->dirroot . '/backup/db/install.xml'); //New method
+            } else if (file_exists($CFG->dirroot . '/backup/db/' . $CFG->dbtype . '.sql')) {
+                $status = modify_database($CFG->dirroot . '/backup/db/' . $CFG->dbtype . '.sql'); //Old method
+            }
+ 
+            $db->debug = false;
+            if ($status) {
                 if (set_config("backup_version", $backup_version) and set_config("backup_release", $backup_release)) {
+                    //initialize default backup settings now
+                    $adminroot = admin_get_root();
+                    apply_default_settings($adminroot->locate('backups'));
                     notify(get_string("databasesuccess"), "green");
-                    notify(get_string("databaseupgradebackups", "", $backup_version));
+                    notify(get_string("databaseupgradebackups", "", $backup_version), "green");
                     print_continue($continueto);
+                    print_footer('none');
                     exit;
                 } else {
                     error("Upgrade of backup system failed! (Could not update version in config table)");
@@ -351,32 +361,70 @@
             }
         }
 
+    /// Upgrading code starts here
+        $oldupgrade = false;
+        $newupgrade = false;
+        if (is_readable($CFG->dirroot . '/backup/db/' . $CFG->dbtype . '.php')) {
+            include_once($CFG->dirroot . '/backup/db/' . $CFG->dbtype . '.php');  // defines old upgrading function
+            $oldupgrade = true;
+        }
+        if (is_readable($CFG->dirroot . '/backup/db/upgrade.php')) {
+            include_once($CFG->dirroot . '/backup/db/upgrade.php');  // defines new upgrading function
+            $newupgrade = true;
+        }
 
         if ($backup_version > $CFG->backup_version) {       // Upgrade tables
             $strdatabaseupgrades = get_string("databaseupgrades");
-            print_header($strdatabaseupgrades, $strdatabaseupgrades, $strdatabaseupgrades);
+            print_header($strdatabaseupgrades, $strdatabaseupgrades, $strdatabaseupgrades, '', upgrade_get_javascript());
 
-            require_once ("$CFG->dirroot/backup/db/$CFG->dbtype.php");
+            upgrade_log_start();
+            print_heading('backup');
 
-            $db->debug=true;
-            if (backup_upgrade($CFG->backup_version)) {
-                $db->debug=false;
+        /// Run de old and new upgrade functions for the module
+            $oldupgrade_function = 'backup_upgrade';
+            $newupgrade_function = 'xmldb_backup_upgrade';
+
+        /// First, the old function if exists
+            $oldupgrade_status = true;
+            if ($oldupgrade && function_exists($oldupgrade_function)) {
+                $db->debug = true;
+                $oldupgrade_status = $oldupgrade_function($CFG->backup_version);
+            } else if ($oldupgrade) {
+                notify ('Upgrade function ' . $oldupgrade_function . ' was not available in ' .
+                        '/backup/db/' . $CFG->dbtype . '.php');
+            }
+
+        /// Then, the new function if exists and the old one was ok
+            $newupgrade_status = true;
+            if ($newupgrade && function_exists($newupgrade_function) && $oldupgrade_status) {
+                $db->debug = true;
+                $newupgrade_status = $newupgrade_function($CFG->backup_version);
+            } else if ($newupgrade) {
+                notify ('Upgrade function ' . $newupgrade_function . ' was not available in ' .
+                        '/backup/db/upgrade.php');
+            }
+
+            $db->debug=false;
+        /// Now analyze upgrade results
+            if ($oldupgrade_status && $newupgrade_status) {    // No upgrading failed
                 if (set_config("backup_version", $backup_version) and set_config("backup_release", $backup_release)) {
                     notify(get_string("databasesuccess"), "green");
-                    notify(get_string("databaseupgradebackups", "", $backup_version));
+                    notify(get_string("databaseupgradebackups", "", $backup_version), "green");
                     print_continue($continueto);
+                    print_footer('none');
                     exit;
                 } else {
                     error("Upgrade of backup system failed! (Could not update version in config table)");
                 }
             } else {
-                $db->debug=false;
                 error("Upgrade failed!  See backup/version.php");
             }
 
         } else if ($backup_version < $CFG->backup_version) {
+            upgrade_log_start();
             notify("WARNING!!!  The code you are using is OLDER than the version that made these databases!");
         }
+        upgrade_log_finish();
     }
 
  
@@ -418,10 +466,12 @@
             $rec->backup_code = $backup_unique_code;
             $rec->table_name = $table;
             $rec->old_id = $old_id;
-            $rec->new_id =$new_id;
+            $rec->new_id = ($new_id === null? 0 : $new_id);
             $rec->info = $info_to_save;
-            
-            $status = insert_record ("backup_ids", $rec, false,"backup_code");
+
+            if (!insert_record('backup_ids', $rec, false)) {
+                $status = false;
+            }
         }
         return $status;
     }
@@ -456,7 +506,7 @@
                                            "old_id", $old_id);
 
         //If info field = "infile", get file contents
-        if ($status->info == "infile") {
+        if (!empty($status->info) && $status->info == "infile") {
             $filename = $CFG->dataroot."/temp/backup/".$backup_unique_code."/".$backup_unique_code."_".$table."_".$old_id.".info";
             //Read data from file
             $status2 = backup_file2data($filename,$info);
@@ -479,26 +529,34 @@
         return $status;
     }
 
-    //This function is used to add slashes and decode from UTF-8
+    //This function is used to add slashes (and decode from UTF-8 if needed)
     //It's used intensivelly when restoring modules and saving them in db
     function backup_todb ($data) {
-        return restore_decode_absolute_links(addslashes(utf8_decode($data)));
+        return restore_decode_absolute_links(addslashes($data));
     }
 
     //This function is used to check that every necessary function to 
     //backup/restore exists in the current php installation. Thanks to
     //gregb@crowncollege.edu by the idea.
-    function backup_required_functions() {
+    function backup_required_functions($justcheck=false) {
 
         if(!function_exists('utf8_encode')) {
-            error('You need to add XML support to your PHP installation');  
+            if (empty($justcheck)) {
+                error('You need to add XML support to your PHP installation');  
+            } else {
+                return false;
+            }
         }
 
+        return true;
     }
 
     //This function send n white characters to the browser and flush the
     //output buffer. Used to avoid browser timeouts and to show the progress.
     function backup_flush($n=0,$time=false) {
+        if (defined('RESTORE_SILENTLY_NOFLUSH')) {
+            return;
+        }
         if ($time) {
             $ti = strftime("%X",time());
         } else {
@@ -534,4 +592,108 @@
 
         return ($status && $status2);
     }
+
+    /** this function will restore an entire backup.zip into the specified course
+     * using standard moodle backup/restore functions, but silently.
+     * @param string $pathtofile the absolute path to the backup file.
+     * @param int $destinationcourse the course id to restore to.
+     * @param boolean $emptyfirst whether to delete all coursedata first.
+     * @param boolean $userdata whether to include any userdata that may be in the backup file.
+     */
+    function import_backup_file_silently($pathtofile,$destinationcourse,$emptyfirst=false,$userdata=false) {
+        global $CFG,$SESSION,$USER; // is there such a thing on cron? I guess so..
+
+        if (empty($USER)) {
+            $USER = get_admin();
+            $USER->admin = 1; // not sure why, but this doesn't get set
+        }
+
+        define('RESTORE_SILENTLY',true); // don't output all the stuff to us.
+        
+        $debuginfo = 'import_backup_file_silently: ';
+        $cleanupafter = false;
+        $errorstr = ''; // passed by reference to restore_precheck to get errors from.
+
+        if (!$course = get_record('course','id',$destinationcourse)) {
+            mtrace($debuginfo.'Course with id $destinationcourse was not a valid course!');
+            return false;
+        }
+
+        // first check we have a valid file.
+        if (!file_exists($pathtofile) || !is_readable($pathtofile)) {
+            mtrace($debuginfo.'File '.$pathtofile.' either didn\'t exist or wasn\'t readable');
+            return false;
+        }
+
+        // now make sure it's a zip file
+        require_once($CFG->dirroot.'/lib/filelib.php');
+        $filename = substr($pathtofile,strrpos($pathtofile,'/')+1);
+        $mimetype = mimeinfo("type", $filename);
+        if ($mimetype != 'application/zip') {
+            mtrace($debuginfo.'File '.$pathtofile.' was of wrong mimetype ('.$mimetype.')' );
+            return false;
+        }
+
+        // restore_precheck wants this within dataroot, so lets put it there if it's not already..
+        if (strstr($pathtofile,$CFG->dataroot) === false) {
+            // first try and actually move it..
+            if (!check_dir_exists($CFG->dataroot.'/temp/backup/',true)) {
+                mtrace($debuginfo.'File '.$pathtofile.' outside of dataroot and couldn\'t move it! ');
+                return false;
+            }
+            if (!copy($pathtofile,$CFG->dataroot.'/temp/backup/'.$filename)) {
+                mtrace($debuginfo.'File '.$pathtofile.' outside of dataroot and couldn\'t move it! ');
+                return false;
+            } else {
+                $pathtofile = 'temp/backup/'.$filename;
+                $cleanupafter = true;
+            }
+        } else {
+            // it is within dataroot, so take it off the path for restore_precheck.
+            $pathtofile = substr($pathtofile,strlen($CFG->dataroot.'/'));
+        }
+
+        if (!backup_required_functions()) {
+            mtrace($debuginfo.'Required function check failed (see backup_required_functions)');
+            return false;
+        }
+        
+        @ini_set("max_execution_time","3000");
+        raise_memory_limit("192M");
+            
+        if (!$backup_unique_code = restore_precheck($destinationcourse,$pathtofile,$errorstr,true)) {
+            mtrace($debuginfo.'Failed restore_precheck (error was '.$errorstr.')');
+            return false;
+        }
+        
+        restore_setup_for_check($SESSION->restore,$backup_unique_code);
+
+        // add on some extra stuff we need...
+        $SESSION->restore->restoreto = 1;
+        $SESSION->restore->course_id = $destinationcourse; 
+        $SESSION->restore->deleting  = $emptyfirst;
+
+        // maybe we need users (defaults to 2 in restore_setup_for_check)
+        if (!empty($userdata)) {
+            $SESSION->restore->users = 1;
+        }
+
+        // we also need modules...
+        if ($allmods = get_records("modules")) {
+            foreach ($allmods as $mod) {
+                $modname = $mod->name;
+                //Now check that we have that module info in the backup file
+                if (isset($SESSION->info->mods[$modname]) && $SESSION->info->mods[$modname]->backup == "true") {
+                    $SESSION->restore->mods[$modname]->restore = true;
+                    $SESSION->restore->mods[$modname]->userinfo = $userdata;
+                }
+            }
+        }
+        if (!restore_execute($SESSION->restore,$SESSION->info,$SESSION->course_header,$errorstr)) {
+            mtrace($debuginfo.'Failed restore_execute (error was '.$errorstr.')');
+            return false;
+        }
+        return true;
+    }
+
 ?>
