@@ -1,14 +1,13 @@
-<?php
+<?PHP //$Id: try.php,v 1.5.6.3 2007/02/28 05:36:21 nicolasconnault Exp $
     require_once ("../config.php");
     require_once ("backup_scheduled.php");
     require_once ("lib.php");
     require_once ("backuplib.php");
+    require_once ("$CFG->libdir/blocklib.php");
 
     require_login();
 
-    if (!isadmin()) {
-        error("You need to be an admin user to use this page.", "$CFG->wwwroot/login/index.php");
-    }
+    require_capability('moodle/site:restore', get_context_instance(CONTEXT_SYSTEM, SITEID));
 
     //Check site
     if (!$site = get_site()) {
@@ -19,8 +18,8 @@
     backup_required_functions();
 
     //Adjust some php variables to the execution of this script
-    ini_set("max_execution_time","3000");
-    ini_set("memory_limit","56M");
+    @ini_set("max_execution_time","3000");
+    raise_memory_limit("192M");
 
     echo "<pre>\n";
 
@@ -28,15 +27,15 @@
 
     $courses = get_records("course");
     foreach ($courses as $course) {
-        echo "Start course ".$course->fullname;
+        echo "Start course ". format_string($course->fullname);
         $preferences = schedule_backup_course_configure($course);
         if ($preferences && $status) {
             $status = schedule_backup_course_execute($preferences);
         }
         if ($status && $preferences) {
-            echo "End course ".$course->fullname." OK\n\n";
+            echo "End course ". format_string($course->fullname)." OK\n\n";
         } else {
-            echo "End course ".$course->fullname." FAIL\n\n";
+            echo "End course ". format_string($course->fullname)." FAIL\n\n";
         }
     }
 ?>
