@@ -1,31 +1,38 @@
-<?PHP //$Id: block_recent_activity.php,v 1.2 2004/04/29 10:29:23 defacer Exp $
+<?PHP //$Id: block_recent_activity.php,v 1.9 2006/05/29 08:17:57 moodler Exp $
 
-class CourseBlock_recent_activity extends MoodleBlock {
-    function CourseBlock_recent_activity ($course) {
+class block_recent_activity extends block_base {
+    function init() {
         $this->title = get_string('recentactivity');
-        $this->content_type = BLOCK_TYPE_TEXT;
-        $this->course = $course;
         $this->version = 2004042900;
     }
 
     function get_content() {
+        global $COURSE;
 
-        if($this->content !== NULL) {
+        if ($this->content !== NULL) {
             return $this->content;
         }
 
-        $this->content = New object;
+        if (empty($this->instance)) {
+            $this->content = '';
+            return $this->content;
+        }
+
+        $this->content = new stdClass;
         $this->content->text = '';
         $this->content->footer = '';
 
         // Slightly hacky way to do it but...
         ob_start();
-        print_recent_activity($this->course);
+        print_recent_activity($COURSE);
         $this->content->text = ob_get_contents();
         ob_end_clean();
 
         return $this->content;
     }
-}
 
+    function applicable_formats() {
+        return array('all' => true, 'my' => false);
+    }
+}
 ?>
