@@ -1,4 +1,4 @@
-<?php //$Id: block_rss_client.php,v 1.56.2.1 2006/05/29 08:15:23 moodler Exp $
+<?php //$Id: block_rss_client.php,v 1.69.2.3 2007/03/26 03:04:33 nicolasconnault Exp $
 
 /*******************************************************************
 * This file contains one class which defines a block for display on
@@ -6,7 +6,7 @@
 * of a remote RSS news feed in your web site.
 *
 * @author Daryl Hawes
-* @version  $Id: block_rss_client.php,v 1.56.2.1 2006/05/29 08:15:23 moodler Exp $
+* @version  $Id: block_rss_client.php,v 1.69.2.3 2007/03/26 03:04:33 nicolasconnault Exp $
 * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
 * @package base
 ******************************************************************/
@@ -19,7 +19,7 @@
 
     function init() {
         $this->title = get_string('feedstitle', 'block_rss_client');
-        $this->version = 2005111400;
+        $this->version = 2006100102;
     }
 
     function preferred_width() {
@@ -42,7 +42,11 @@
     }
 
     function get_content() {
-        global $CFG, $editing, $COURSE;
+        global $CFG, $editing, $COURSE, $USER;
+        
+        if (!empty($COURSE)) {
+            $this->courseid = $COURSE->id;
+        }
 
         require_once($CFG->libdir .'/rsslib.php');
 
@@ -65,14 +69,14 @@
         if (isset($CFG->block_rss_client_num_entries) && is_numeric($CFG->block_rss_client_num_entries) ) {
             $shownumentries = intval($CFG->block_rss_client_num_entries);
         } else {
-            $shownumentries = 5; //default to 5 entries is not specified by admin or instance
+            $shownumentries = 5; //default to 5 entries is not specified in admin section or instance
         }
 
         if (!empty($this->config)) {
             if (!empty($this->config->rssid)) {
                 if (is_array($this->config->rssid)) { 
                     $rssidarray = $this->config->rssid;
-                } else {     // Make an array of the single value 
+                } else {     // Make an array of the single value
                     $rssidarray = array($this->config->rssid);
                 }
             }
@@ -83,37 +87,40 @@
                 $shownumentries = intval($this->config->shownumentries);
             }
         }
-
-        $submitters = $CFG->block_rss_client_submitters;
-
-        $isteacher = false;
-        $this->courseid = SITEID;
-        if ($this->instance->pagetype == PAGE_COURSE_VIEW) {
-            $this->courseid = $COURSE->id;
-            $isteacher = isteacher($this->courseid);
-        }
-
-        //if the user is an admin, course teacher, or all users are allowed
-        // then allow the user to add rss feeds
-        global $USER;
-        $userisloggedin = false;
-        if (isset($USER) && isset($USER->id) && $USER->id && !isguest()) {
-            $userisloggedin = true;
-        }
-        if ( $userisloggedin && ($submitters == SUBMITTERS_ALL_ACCOUNT_HOLDERS || ($submitters == SUBMITTERS_ADMIN_AND_TEACHER && $isteacher)) ) {
+        
+        $context = get_context_instance(CONTEXT_BLOCK, $this->instance->id);
+        
+        if (has_capability('block/rss_client:createsharedfeeds', $context)
+                    || has_capability('block/rss_client:createprivatefeeds', $context)) {
 
             $page = page_create_object($this->instance->pagetype, $this->instance->pageid);
-            if ($page->user_allowed_editing()) { // for SUBMITTERS_ALL_ACCOUNT_HOLDERS we're going to run into trouble later if we show it and then they don't have write access to the page.
-                if (isset($this->config)) {
-                    // this instance is configured - show Add/Edit feeds link
-                    $script = $page->url_get_full(array('instanceid' => $this->instance->id, 'sesskey' => $USER->sesskey, 'blockaction' => 'config', 'currentaction' => 'managefeeds', 'id' => $this->courseid));
-                    $output .= '<div align="center"><a title="'. get_string('feedsaddedit', 'block_rss_client') .'" href="'. $script .'">'. get_string('feedsaddedit', 'block_rss_client') .'</a></div>';
-                } else {
-                    // this instance has not been configured yet - show configure link
-                    $script = $page->url_get_full(array('instanceid' => $this->instance->id, 'sesskey' => $USER->sesskey, 'blockaction' => 'config', 'currentaction' => 'configblock', 'id' => $this->courseid));
-                    $output .= '<div align="center"><a title="'. get_string('feedsconfigurenewinstance', 'block_rss_client') .'" href="'. $script.'">'. get_string('feedsconfigurenewinstance', 'block_rss_client') .'</a></div>';
+            //if ($page->user_allowed_editing()) { // for SUBMITTERS_ALL_ACCOUNT_HOLDERS we're going to run into trouble later if we show it and then they don't have write access to the page.
+            if (isset($this->config)) {
+                // This instance is configured - show Add/Edit feeds link.
+                $script = $page->url_get_full(
+                                    array('instanceid' => $this->instance->id,
+                                          'sesskey' => $USER->sesskey,
+                                          'blockaction' => 'config',
+                                          'currentaction' => 'managefeeds',
+                                          'id' => $this->courseid,
+                                          'section' => 'rss'
+                                          ));
+                $output .= '<div class="info"><a title="'. get_string('feedsaddedit', 'block_rss_client') .'" href="'. $script .'">'. get_string('feedsaddedit', 'block_rss_client') .'</a></div>';
+            } else {
+                // This instance has not been configured yet - show configure link?
+                if (has_capability('block/rss_client:manageanyfeeds', $context)) {
+                    $script = $page->url_get_full(
+                                    array('instanceid' => $this->instance->id,
+                                          'sesskey' => $USER->sesskey,
+                                          'blockaction' => 'config',
+                                          'currentaction' => 'configblock',
+                                          'id' => $this->courseid,
+                                          'section' => 'rss'
+                                          ));
+                    $output .= '<div class="info"><a title="'. get_string('feedsconfigurenewinstance', 'block_rss_client') .'" href="'. $script.'">'. get_string('feedsconfigurenewinstance', 'block_rss_client') .'</a></div>';
                 }
             }
+            //}
         }
 
         // Daryl Hawes note: if count of rssidarray is greater than 1 
@@ -123,9 +130,9 @@
             $numids = count($rssidarray);
             $count = 0;
             foreach ($rssidarray as $rssid) {
-                $output .=  $this->get_rss_by_id($rssid, $display_description, $shownumentries, ($numids > 1) ? true : false);
+                $output .=  clean_text($this->get_rss_by_id($rssid, $display_description, $shownumentries, ($numids > 1) ? true : false), FORMAT_HTML);
                 if ($numids > 1 && $count != $numids -1 && !empty($rssfeedstring)) {
-                    $output .= '<hr width="80%" />';
+                    $output .= '<hr style="width=:80%" />';
                 }
                 $count ++;
             }
@@ -161,7 +168,7 @@
         require_once($CFG->libdir .'/rsslib.php');
         require_once(MAGPIE_DIR .'rss_fetch.inc');
         if (!defined('MAGPIE_OUTPUT_ENCODING')) {
-            define('MAGPIE_OUTPUT_ENCODING', current_charset());  // see bug 3107
+            define('MAGPIE_OUTPUT_ENCODING', 'utf-8');  // see bug 3107
         }
 
         $rss_record = get_record('block_rss_client', 'id', $rssid);
@@ -175,12 +182,12 @@
             ob_end_clean();
 
             if ($rss === false) {
-                if ($CFG->debug && !empty($rsserror)) {
+                if (debugging() && !empty($rsserror)) {
                     // There was a failure in loading the rss feed, print link to full error text
                     return '<a href="'. $CFG->wwwroot .'/blocks/rss_client/block_rss_client_error.php?error='. urlencode($rsserror) .'">Error loading a feed.</a><br />'; //Daryl Hawes note: localize this line
                 }
             }
-
+            
             if ($shownumentries > 0 && $shownumentries < count($rss->items) ) {
                 $rss->items = array_slice($rss->items, 0, $shownumentries);
             }
@@ -195,12 +202,12 @@
                     isset($this->config->block_rss_client_show_channel_image) && 
                         $this->config->block_rss_client_show_channel_image &&
                             isset($rss->image) && isset($rss->image['link']) && isset($rss->image['title']) && isset($rss->image['url']) ) {
-                $returnstring .= '<div class="image"><a href="'. $rss->image['link'] .'"><img src="'. $rss->image['url'] .'" title="'. $rss->image['title'] .'" alt="'. $rss->image['title'] .'"/></a></div>';
+                $returnstring .= "\n".'<div class="image" title="'. $rss->image['title'] .'"><a href="'. $rss->image['link'] .'"><img src="'. $rss->image['url'] .'" alt="'. $rss->image['title'] .'" /></a></div>';
             }
 
             if ($showtitle) {
                 $returnstring .= '<div class="title">'. $feedtitle .'</div>';
-            } 
+            }
 
             $formatoptions->para = false;
 
@@ -210,6 +217,9 @@
                 return '';
             }
 
+            /// Accessibility: markup as a list.
+            $returnstring .= '<ul class="list">'."\n";
+
             foreach ($rss->items as $item) {
                 if ($item['title'] == '') {
                     // no title present, use portion of description
@@ -221,20 +231,25 @@
                 if ($item['link'] == '') {
                     $item['link'] = $item['guid'];
                 }
+                $item['title'] = s($item['title']);
 
                 $item['link'] = str_replace('&', '&amp;', $item['link']);
 
-                $returnstring .= '<div class="link"><a href="'. $item['link'] .'" target="_blank">'. $item['title'] . '</a></div>' ."\n";
+                $returnstring .= '<li><div class="link"><a href="'. $item['link'] .'">'. $item['title'] . "</a></div>\n";
 
                 if ($display_description && !empty($item['description'])) {
                     $item['description'] = break_up_long_words($item['description'], 30);
                     $returnstring .= '<div class="description">'.
                                      format_text($item['description'], FORMAT_MOODLE, $formatoptions, $this->courseid) . 
-                                     '</div>' ."\n";
+                                     '</div>';
                 }
+                $returnstring .= "</li>\n";
             }
+            $returnstring .= "</ul>\n";
 
             if (!empty($rss->channel['link'])) {
+                $rss->channel['link'] = str_replace('&', '&amp;', $rss->channel['link']);
+            
                 if (!empty($this->config) && isset($this->config->block_rss_client_show_channel_link) && $this->config->block_rss_client_show_channel_link) {
                     $this->content->footer =  '<a href="'. $rss->channel['link'] .'">'. get_string('clientchannellink', 'block_rss_client') .'</a>';
                 } 
@@ -261,12 +276,13 @@
      /// Loading the textlib singleton instance. We are going to need it.
          $textlib = textlib_get_instance();
 
-         if ($textlib->strlen($title,current_charset()) <= $max) {
-             return $title;
+         if ($textlib->strlen($title) <= $max) {
+             return s($title);
          }
          else {
-             return $textlib->substr($title,0,$max-3,current_charset()).'...';
+             return s($textlib->substr($title,0,$max-3).'...');
          }
      }
 }
+
 ?>
