@@ -1,4 +1,4 @@
-<?php // $Id: event.php,v 1.50.2.4 2006/07/17 07:29:46 skodak Exp $
+<?php // $Id: event.php,v 1.63.2.4 2007/06/28 03:58:39 toyomoyo Exp $
 
 /////////////////////////////////////////////////////////////////////////////
 //                                                                         //
@@ -9,14 +9,14 @@
 // Copyright (C) 2003-2004  Greek School Network            www.sch.gr     //
 //                                                                         //
 // Designed by:                                                            //
-//     Avgoustos Tsinakos (tsinakos@uom.gr)                                //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Avgoustos Tsinakos (tsinakos@teikav.edu.gr)                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // Programming and development:                                            //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // For bugs, suggestions, etc contact:                                     //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // The current module was developed at the University of Macedonia         //
 // (www.uom.gr) under the funding of the Greek School Network (www.sch.gr) //
@@ -58,12 +58,17 @@
     $cal_m = optional_param('cal_m');
     $cal_d = optional_param('cal_d');
 
+    $focus = '';
+
     if(!$site = get_site()) {
         redirect($CFG->wwwroot.'/'.$CFG->admin.'/index.php');
     }
 
     $strcalendar = get_string('calendar', 'calendar');
 
+    // Initialize the session variables
+    calendar_session_vars();
+
     $now = usergetdate(time());
     $nav = calendar_get_link_tag($strcalendar, CALENDAR_URL.'view.php?view=upcoming&amp;', $now['mday'], $now['mon'], $now['year']);
     $day = intval($now['mday']);
@@ -78,6 +83,8 @@
 
     // If a course has been supplied in the URL, change the filters to show that one
     if($urlcourse > 0 && record_exists('course', 'id', $urlcourse)) {
+        require_login($urlcourse, false);
+
         if($urlcourse == SITEID) {
             // If coming from the site page, show all courses
             $SESSION->cal_courses_shown = calendar_get_default_courses(true);
@@ -181,7 +188,7 @@
         case 'new':
             $title = get_string('newevent', 'calendar');
             $form = data_submitted();
-            if(!empty($form) && $form->type == 'defined') {
+            if(!empty($form) && !empty($form->name)) {
 
                 $form->name = clean_text(strip_tags($form->name, '<lang><span>'));
 
@@ -198,7 +205,7 @@
                 else {
                     $form->timeduration = 0;
                 }
-                if(!calendar_add_event_allowed($form->courseid, $form->groupid, $form->userid)) {
+                if(!calendar_add_event_allowed($form)) {
                     error('You are not authorized to do this');
                 }
                 validate_form($form, $err);
@@ -243,8 +250,10 @@
                 }
             }
         break;
+        default: // no action
+            $title='';
+        break;
     }
-    if(empty($focus)) $focus = '';
 
     // Let's see if we are supposed to provide a referring course link
     // but NOT for the "main page" course
@@ -260,9 +269,10 @@
     } else {
         $course = $site;
     }
+    require_login($course, false);
 
     print_header($site->shortname.': '.$strcalendar.': '.$title, $strcalendar, $nav.' -> '.$title,
-                 $focus, '', true, '', user_login_string($site));
+                 'eventform.name', '', true, '', user_login_string($site));
 
     echo calendar_overlib_html();
 
@@ -378,7 +388,7 @@
                     $form->timestart = make_timestamp($cal_y, $cal_m, 1, 0, 0, 0);
                 }
             }
-            if($form->timestart < 0) {
+            if(!isset($form->timestart) or $form->timestart < 0) {
                 $form->timestart = time();
             }
 
@@ -405,11 +415,12 @@
                     $form->repeat = 0;
                     $form->repeats = '';
                     $form->minutes = '';
+                    $form->type = 'user';
                     $header = get_string('typeuser', 'calendar');
                 break;
                 case 'group':
                     $groupid = optional_param('groupid', 0, PARAM_INT);
-                    if(!($group = get_record('groups', 'id', $groupid) )) {
+                    if (! ($group = groups_get_group($groupid))) { //TODO:check.
                         calendar_get_allowed_types($allowed);
                         $eventtype = 'select';
                     }
@@ -427,6 +438,7 @@
                         $form->repeat = 0;
                         $form->repeats = '';
                         $form->minutes = '';
+                        $form->type = 'group';
                         $header = get_string('typegroup', 'calendar');
                     }
                 break;
@@ -450,6 +462,7 @@
                         $form->repeat = 0;
                         $form->repeats = '';
                         $form->minutes = '';
+                        $form->type = 'course';
                         $header = get_string('typecourse', 'calendar');
                     }
                 break;
@@ -467,9 +480,9 @@
                     $form->repeat = 0;
                     $form->repeats = '';
                     $form->minutes = '';
+                    $form->type = 'site';
                     $header = get_string('typesite', 'calendar');
                 break;
-                case 'defined':
                 case 'select':
                 break;
                 default:
@@ -579,46 +592,45 @@ function validate_form(&$form, &$err) {
     }
 }
 
-function calendar_add_event_allowed($courseid, $groupid, $userid) {
+function calendar_add_event_allowed($event) {
     global $USER;
 
-    if(isadmin()) {
+    // can not be using guest account
+    if (empty($USER->id) or $USER->username == 'guest') {
+        return false;  
+    }
+
+    $sitecontext = get_context_instance(CONTEXT_SYSTEM);
+    // if user has manageentries at site level, always return true
+    if (has_capability('moodle/calendar:manageentries', $sitecontext)) {
         return true;
     }
-    else if($courseid == 0 && $groupid == 0 && $userid == $USER->id) {
-        return true;
-    }
-    else if($courseid == 0 && $groupid != 0) {
-        $group = get_record('groups', 'id', $groupid);
-        if($group === false) {
+
+    switch ($event->type) {
+        case 'course':
+            return has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_COURSE, $event->courseid));
+
+        case 'group':
+            if (! groups_group_exists($event->groupid)) { //TODO:check.
+                return false;
+            } 
+            // this is ok because if you have this capability at course level, you should be able 
+            // to edit group calendar too
+            // there is no need to check membership, because if you have this capability
+            // you will have a role in this group context
+            return has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_GROUP, $event->groupid));
+
+        case 'user':
+            if ($event->userid == $USER->id) {
+                return (has_capability('moodle/calendar:manageownentries', $sitecontext));
+            }
+            //there is no 'break;' intentionally
+
+        case 'site':
+            return has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_COURSE, SITEID));
+
+        default:
             return false;
-        }
-        return isteacheredit($group->courseid) || isteacher($group->courseid) && ismember($groupid);
-    }
-    else if($courseid != 0 && isteacher($courseid)) {
-        return true;
-    }
-
-    return false;
-}
-
-function calendar_get_allowed_types(&$allowed) {
-    global $USER, $CFG, $SESSION;
-
-    $allowed->user = true; // User events always allowed
-    $allowed->groups = false; // This may change just below
-    $allowed->courses = false; // This may change just below
-    $allowed->site = isteacher(SITEID);
-
-    if(!empty($SESSION->cal_course_referer) && $SESSION->cal_course_referer != SITEID && isteacher($SESSION->cal_course_referer, $USER->id)) {
-        $course = get_record('course', 'id', $SESSION->cal_course_referer);
-
-        $allowed->courses = array($course->id => 1);
-
-        if($course->groupmode != NOGROUPS || !$course->groupmodeforce) {
-            $allowed->groups = get_groups($SESSION->cal_course_referer);
-        }
     }
 }
-
 ?>
