@@ -1,4 +1,4 @@
-<?php // $Id: lib.php,v 1.142.2.3 2006/07/24 00:14:07 danmarsden Exp $
+<?php // $Id: lib.php,v 1.164.2.18 2007/06/28 03:58:41 toyomoyo Exp $
 
 /////////////////////////////////////////////////////////////////////////////
 //                                                                         //
@@ -9,14 +9,14 @@
 // Copyright (C) 2003-2004  Greek School Network            www.sch.gr     //
 //                                                                         //
 // Designed by:                                                            //
-//     Avgoustos Tsinakos (tsinakos@uom.gr)                                //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Avgoustos Tsinakos (tsinakos@teikav.edu.gr)                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // Programming and development:                                            //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // For bugs, suggestions, etc contact:                                     //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // The current module was developed at the University of Macedonia         //
 // (www.uom.gr) under the funding of the Greek School Network (www.sch.gr) //
@@ -64,8 +64,7 @@ define ('CALENDAR_TF_12', '%I:%M %p');
 
 $CALENDARDAYS = array('sunday','monday','tuesday','wednesday','thursday','friday','saturday');
 
-// Initialize the session variables here to be sure
-calendar_session_vars();
+
 
 function calendar_get_mini($courses, $groups, $users, $cal_month = false, $cal_year = false) {
     global $CFG, $USER;
@@ -106,12 +105,12 @@ function calendar_get_mini($courses, $groups, $users, $cal_month = false, $cal_y
 
     if (get_user_timezone_offset() < 99) {
         // We 'll keep these values as GMT here, and offset them when the time comes to query the db
-	    $display->tstart = gmmktime(0, 0, 0, $m, 1, $y); // This is GMT
-	    $display->tend = gmmktime(23, 59, 59, $m, $display->maxdays, $y); // GMT
+        $display->tstart = gmmktime(0, 0, 0, $m, 1, $y); // This is GMT
+        $display->tend = gmmktime(23, 59, 59, $m, $display->maxdays, $y); // GMT
     } else {
         // no timezone info specified
-	    $display->tstart = mktime(0, 0, 0, $m, 1, $y);
-	    $display->tend = mktime(23, 59, 59, $m, $display->maxdays, $y);
+        $display->tstart = mktime(0, 0, 0, $m, 1, $y);
+        $display->tend = mktime(23, 59, 59, $m, $display->maxdays, $y);
     }
 
     $startwday = dayofweek(1, $m, $y);
@@ -242,7 +241,7 @@ function calendar_get_mini($courses, $groups, $users, $cal_month = false, $cal_y
                     $popupicon = $CFG->pixpath.'/c/user.gif';
                     $popupalt  = '';
                 }
-                $popupcontent .= '<div><img height="16" width="16" src="'.$popupicon.'" style="vertical-align: middle; margin-right: 4px;" alt="'.$popupalt.'" /><a href="'.$dayhref.'">'.format_string($event->name,true).'</a></div>';
+                $popupcontent .= '<div><img class="icon" src="'.$popupicon.'" alt="'.$popupalt.'" /><a href="'.$dayhref.'#event_'.$event->id.'">'.format_string($event->name, true).'</a></div>';
             }
             
             //Accessibility: functionality moved to calendar_get_popup.
@@ -338,6 +337,7 @@ function calendar_get_popup($is_today, $event_timestart, $popupcontent='') {
         $popupcaption .= get_string('eventsfor', 'calendar', userdate($event_timestart, get_string('strftimedayshort')));
     }
     $popupcontent = str_replace("'", "\'", htmlspecialchars($popupcontent));
+    $popupcaption = str_replace("'", "\'", htmlspecialchars($popupcaption)); 
     $popup = 'onmouseover="return overlib(\''.$popupcontent.'\', CAPTION, \''.$popupcaption.'\');" onmouseout="return nd();"';
     return $popup;
 }
@@ -425,27 +425,27 @@ function calendar_add_event_metadata($event) {
         $eventtype = get_string($event->eventtype, $event->modulename);
         $icon = $CFG->modpixpath.'/'.$event->modulename.'/icon.gif';
 
-        $event->icon = '<img height="16" width="16" src="'.$icon.'" alt="" title="'.$modulename.'" style="vertical-align: middle;" />';
+        $event->icon = '<img height="16" width="16" src="'.$icon.'" alt="'.$eventtype.'" title="'.$modulename.'" style="vertical-align: middle;" />';
         $event->referer = '<a href="'.$CFG->wwwroot.'/mod/'.$event->modulename.'/view.php?id='.$module->id.'">'.$event->name.'</a>';
         $event->courselink = '<a href="'.$CFG->wwwroot.'/course/view.php?id='.$module->course.'">'.$coursecache[$module->course]->fullname.'</a>';
         $event->cmid = $module->id;
 
 
     } else if($event->courseid == SITEID) {                              // Site event
-        $event->icon = '<img height="16" width="16" src="'.$CFG->pixpath.'/c/site.gif" alt="" style="vertical-align: middle;" />';
-
+        $event->icon = '<img height="16" width="16" src="'.$CFG->pixpath.'/c/site.gif" alt="'.get_string('globalevent', 'calendar').'" style="vertical-align: middle;" />';
+        $event->cssclass = 'event_global';
     } else if($event->courseid != 0 && $event->courseid != SITEID && $event->groupid == 0) {          // Course event
         calendar_get_course_cached($coursecache, $event->courseid);
-        $event->icon = '<img height="16" width="16" src="'.$CFG->pixpath.'/c/course.gif" alt="" style="vertical-align: middle;" />';
+        $event->icon = '<img height="16" width="16" src="'.$CFG->pixpath.'/c/course.gif" alt="'.get_string('courseevent', 'calendar').'" style="vertical-align: middle;" />';
         $event->courselink = '<a href="'.$CFG->wwwroot.'/course/view.php?id='.$event->courseid.'">'.$coursecache[$event->courseid]->fullname.'</a>';
-
+        $event->cssclass = 'event_course';
     } else if ($event->groupid) {                                    // Group event
-        $event->icon = '<img height="16" width="16" src="'.$CFG->pixpath.'/c/group.gif" alt="" style="vertical-align: middle;" />';
-
+        $event->icon = '<img height="16" width="16" src="'.$CFG->pixpath.'/c/group.gif" alt="'.get_string('groupevent', 'calendar').'" style="vertical-align: middle;" />';
+        $event->cssclass = 'event_group';
     } else if($event->userid) {                                      // User event
-        $event->icon = '<img height="16" width="16" src="'.$CFG->pixpath.'/c/user.gif" alt="" style="vertical-align: middle;" />';
+        $event->icon = '<img height="16" width="16" src="'.$CFG->pixpath.'/c/user.gif" alt="'.get_string('userevent', 'calendar').'" style="vertical-align: middle;" />';
+        $event->cssclass = 'event_user';
     }
-
     return $event;
 }    
 
@@ -455,7 +455,7 @@ function calendar_print_event($event) {
     static $strftimetime;
 
     $event = calendar_add_event_metadata($event);
-    echo '<table class="event" cellspacing="0">';
+    echo '<a name="event_'.$event->id.'"></a><table class="event" cellspacing="0">';
     echo '<tr><td class="picture">';
     if (!empty($event->icon)) {
         echo $event->icon;
@@ -481,7 +481,7 @@ function calendar_print_event($event) {
 
     echo '</td></tr>';
     echo '<tr><td class="side">&nbsp;</td>';
-    echo '<td class="description">';
+    echo '<td class="description '.$event->cssclass.'">';
     echo format_text($event->description, FORMAT_HTML);
     if (calendar_edit_event_allowed($event)) {
         echo '<div class="commands">';
@@ -602,7 +602,7 @@ function calendar_sql_where($tstart, $tend, $users, $groups, $courses, $withdura
 }
 
 function calendar_top_controls($type, $data) {
-    global $CFG, $CALENDARDAYS;
+    global $CFG, $CALENDARDAYS, $THEME;
     $content = '';
     if(!isset($data['d'])) {
         $data['d'] = 1;
@@ -620,31 +620,29 @@ function calendar_top_controls($type, $data) {
     $data['y'] = $date['year'];
 
     //Accessibility: calendar block controls, replaced <table> with <div>.
-    $nexttext = '<img src="'. $CFG->pixpath .'/a/r_next.gif" alt="'.get_string('monthnext','access').'" class="resize" />';
-    $prevtext = '<img src="'. $CFG->pixpath .'/a/r_previous.gif" alt="'.get_string('monthprev','access').'" class="resize" />';
+    //$nexttext = link_arrow_right(get_string('monthnext', 'access'), $url='', $accesshide=true);
+    //$prevtext = link_arrow_left(get_string('monthprev', 'access'), $url='', $accesshide=true);
 
     switch($type) {
         case 'frontpage':
             list($prevmonth, $prevyear) = calendar_sub_month($data['m'], $data['y']);
             list($nextmonth, $nextyear) = calendar_add_month($data['m'], $data['y']);
-            $nextlink = calendar_get_link_tag($nexttext, 'index.php?', 0, $nextmonth, $nextyear);
-            $prevlink = calendar_get_link_tag($prevtext, 'index.php?', 0, $prevmonth, $prevyear);
-            $content .= '<div class="calendar-controls">';
-            $content .= '<span class="previous" title="'.get_string('monthprev','access').'">'.$prevlink."</span>\n";
+            $nextlink = calendar_get_link_next(get_string('monthnext', 'access'), 'index.php?', 0, $nextmonth, $nextyear, $accesshide=true);
+            $prevlink = calendar_get_link_previous(get_string('monthprev', 'access'), 'index.php?', 0, $prevmonth, $prevyear, true);
+            $content .= "\n".'<div class="calendar-controls">'. $prevlink;
             $content .= '<span class="hide"> | </span><span class="current"><a href="'.calendar_get_link_href(CALENDAR_URL.'view.php?view=month&amp;', 1, $data['m'], $data['y']).'">'.userdate($time, get_string('strftimemonthyear')).'</a></span>';
-            $content .= '<span class="hide"> | </span><span class="next" title="'.get_string('monthnext','access').'">'.$nextlink."</span>\n";
-            $content .= "<span class=\"clearer\"></span></div>\n";
+            $content .= '<span class="hide"> | </span>'. $nextlink ."\n";
+            $content .= "<span class=\"clearer\"><!-- --></span></div>\n";
         break;
         case 'course':
             list($prevmonth, $prevyear) = calendar_sub_month($data['m'], $data['y']);
             list($nextmonth, $nextyear) = calendar_add_month($data['m'], $data['y']);
-            $nextlink = calendar_get_link_tag($nexttext, 'view.php?id='.$data['id'].'&amp;', 0, $nextmonth, $nextyear);
-            $prevlink = calendar_get_link_tag($prevtext, 'view.php?id='.$data['id'].'&amp;', 0, $prevmonth, $prevyear);
-            $content .= '<div class="calendar-controls">';
-            $content .= '<span class="previous" title="'.get_string('monthprev','access').'">'.$prevlink."</span>\n";
+            $nextlink = calendar_get_link_next(get_string('monthnext', 'access'), 'view.php?id='.$data['id'].'&amp;', 0, $nextmonth, $nextyear, $accesshide=true);
+            $prevlink = calendar_get_link_previous(get_string('monthprev', 'access'), 'view.php?id='.$data['id'].'&amp;', 0, $prevmonth, $prevyear, true);
+            $content .= "\n".'<div class="calendar-controls">'. $prevlink;
             $content .= '<span class="hide"> | </span><span class="current"><a href="'.calendar_get_link_href(CALENDAR_URL.'view.php?view=month&amp;course='.$data['id'].'&amp;', 1, $data['m'], $data['y']).'">'.userdate($time, get_string('strftimemonthyear')).'</a></span>';
-            $content .= '<span class="hide"> | </span><span class="next" title="'.get_string('monthnext','access').'">'.$nextlink."</span>\n";
-            $content .= "<span class=\"clearer\"></span></div>\n";
+            $content .= '<span class="hide"> | </span>'. $nextlink ."\n";
+            $content .= "<span class=\"clearer\"><!-- --></span></div>\n";
         break;
         case 'upcoming':
             $content .= '<div style="text-align: center;"><a href="'.CALENDAR_URL.'view.php?view=upcoming">'.userdate($time, get_string('strftimemonthyear'))."</a></div>\n";
@@ -657,11 +655,11 @@ function calendar_top_controls($type, $data) {
             list($nextmonth, $nextyear) = calendar_add_month($data['m'], $data['y']);
             $prevdate = make_timestamp($prevyear, $prevmonth, 1);
             $nextdate = make_timestamp($nextyear, $nextmonth, 1);
-            $content .= '<div class="calendar-controls">';
-            $content .= '<span class="previous"><a href="'.calendar_get_link_href('view.php?view=month&amp;', 1, $prevmonth, $prevyear).'">&lt; '.userdate($prevdate, get_string('strftimemonthyear')).'</a></span>';
+            $content .= "\n".'<div class="calendar-controls">';
+            $content .= calendar_get_link_previous(userdate($prevdate, get_string('strftimemonthyear')), 'view.php?view=month&amp;', 1, $prevmonth, $prevyear);
             $content .= '<span class="hide"> | </span><span class="current">'.userdate($time, get_string('strftimemonthyear'))."</span>\n";
-            $content .= '<span class="hide"> | </span><span class="next"><a href="'.calendar_get_link_href('view.php?view=month&amp;', 1, $nextmonth, $nextyear).'">'.userdate($nextdate, get_string('strftimemonthyear'))." &gt;</a></span>\n";
-            $content .= "<span class=\"clearer\"></span></div>\n";
+            $content .= '<span class="hide"> | </span>'.calendar_get_link_next(userdate($nextdate, get_string('strftimemonthyear')), 'view.php?view=month&amp;', 1, $nextmonth, $nextyear);
+            $content .= "<span class=\"clearer\"><!-- --></span></div>\n";
         break;
         case 'day':
             $data['d'] = $date['mday']; // Just for convenience
@@ -669,9 +667,9 @@ function calendar_top_controls($type, $data) {
             $nextdate = usergetdate(make_timestamp($data['y'], $data['m'], $data['d'] + 1));
             $prevname = calendar_wday_name($CALENDARDAYS[$prevdate['wday']]);
             $nextname = calendar_wday_name($CALENDARDAYS[$nextdate['wday']]);
-            $content .= '<div class="calendar-controls">';
-            $content .= '<span class="previous"><a href="'.calendar_get_link_href('view.php?view=day&amp;', $prevdate['mday'], $prevdate['mon'], $prevdate['year']).'">&lt; '.$prevname."</a></span>\n";
-
+            $content .= "\n".'<div class="calendar-controls">';
+            $content .= calendar_get_link_previous($prevname, 'view.php?view=day&amp;', $prevdate['mday'], $prevdate['mon'], $prevdate['year']);
+ 
             // Get the format string
             $text = get_string('strftimedaydate');
             /*
@@ -684,8 +682,8 @@ function calendar_top_controls($type, $data) {
             // Print the actual thing
             $content .= '<span class="hide"> | </span><span class="current">'.$text.'</span>';
 
-            $content .= '<span class="hide"> | </span><span class="next"><a href="'.calendar_get_link_href('view.php?view=day&amp;', $nextdate['mday'], $nextdate['mon'], $nextdate['year']).'">'.$nextname." &gt;</a></span>\n";
-            $content .= "<span class=\"clearer\"></span></div>\n";
+            $content .= '<span class="hide"> | </span>'. calendar_get_link_next($nextname, 'view.php?view=day&amp;', $nextdate['mday'], $nextdate['mon'], $nextdate['year']);
+            $content .= "<span class=\"clearer\"><!-- --></span></div>\n";
         break;
     }
     return $content;
@@ -726,16 +724,20 @@ function calendar_filter_controls($type, $vars = NULL, $course = NULL) {
 
     $content .= '<tr>';
     if($SESSION->cal_show_global) {
-        $content .= '<td class="event_global" style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showglobal'.$getvars.'" title="'.get_string('tt_hideglobal', 'calendar').'">'.get_string('globalevents', 'calendar').'</a></td>'."\n";
+        $content .= '<td class="event_global" style="width: 11px;"><img src="'.$CFG->pixpath.'/t/hide.gif" class="iconsmall" alt="'.get_string('hide').'" /></td>';
+        $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showglobal'.$getvars.'" title="'.get_string('tt_hideglobal', 'calendar').'">'.get_string('globalevents', 'calendar').'</a></td>'."\n";
     }
     else {
-        $content .= '<td style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showglobal'.$getvars.'" title="'.get_string('tt_showglobal', 'calendar').'">'.get_string('globalevents', 'calendar').'</a></td>'."\n";
+        $content .= '<td style="width: 11px;"><img src="'.$CFG->pixpath.'/t/show.gif" class="iconsmall" alt="'.get_string('show').'" /></td>';
+        $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showglobal'.$getvars.'" title="'.get_string('tt_showglobal', 'calendar').'">'.get_string('globalevents', 'calendar').'</a></td>'."\n";
     }
     if($SESSION->cal_show_course) {
-        $content .= '<td class="event_course" style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showcourses'.$getvars.'" title="'.get_string('tt_hidecourse', 'calendar').'">'.get_string('courseevents', 'calendar').'</a></td>'."\n";
+        $content .= '<td class="event_course" style="width: 11px;"><img src="'.$CFG->pixpath.'/t/hide.gif" class="iconsmall" alt="'.get_string('hide').'" /></td>';
+        $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showcourses'.$getvars.'" title="'.get_string('tt_hidecourse', 'calendar').'">'.get_string('courseevents', 'calendar').'</a></td>'."\n";
     }
     else {
-        $content .= '<td style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showcourses'.$getvars.'" title="'.get_string('tt_showcourse', 'calendar').'">'.get_string('courseevents', 'calendar').'</a></td>'."\n";
+        $content .= '<td style="width: 11px;"><img src="'.$CFG->pixpath.'/t/show.gif" class="iconsmall" alt="'.get_string('hide').'" /></td>';
+        $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showcourses'.$getvars.'" title="'.get_string('tt_showcourse', 'calendar').'">'.get_string('courseevents', 'calendar').'</a></td>'."\n";
     }
 
     if(!empty($USER->id) && !isguest()) {
@@ -744,24 +746,30 @@ function calendar_filter_controls($type, $vars = NULL, $course = NULL) {
         if($groupevents) {
             // This course MIGHT have group events defined, so show the filter
             if($SESSION->cal_show_groups) {
-                $content .= '<td class="event_group" style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showgroups'.$getvars.'" title="'.get_string('tt_hidegroups', 'calendar').'">'.get_string('groupevents', 'calendar').'</a></td>'."\n";
+                $content .= '<td class="event_group" style="width: 11px;"><img src="'.$CFG->pixpath.'/t/hide.gif" class="iconsmall" alt="'.get_string('hide').'" /></td>';
+                $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showgroups'.$getvars.'" title="'.get_string('tt_hidegroups', 'calendar').'">'.get_string('groupevents', 'calendar').'</a></td>'."\n";
             } else {
-                $content .= '<td style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showgroups'.$getvars.'" title="'.get_string('tt_showgroups', 'calendar').'">'.get_string('groupevents', 'calendar').'</a></td>'."\n";
+                $content .= '<td style="width: 11px;"><img src="'.$CFG->pixpath.'/t/show.gif" class="iconsmall" alt="'.get_string('show').'" /></td>';
+                $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showgroups'.$getvars.'" title="'.get_string('tt_showgroups', 'calendar').'">'.get_string('groupevents', 'calendar').'</a></td>'."\n";
             }
             if ($SESSION->cal_show_user) {
-                $content .= '<td class="event_user" style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showuser'.$getvars.'" title="'.get_string('tt_hideuser', 'calendar').'">'.get_string('userevents', 'calendar').'</a></td>'."\n";
+                $content .= '<td class="event_user" style="width: 11px;"><img src="'.$CFG->pixpath.'/t/hide.gif" class="iconsmall" alt="'.get_string('hide').'" /></td>';
+                $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showuser'.$getvars.'" title="'.get_string('tt_hideuser', 'calendar').'">'.get_string('userevents', 'calendar').'</a></td>'."\n";
             } else {
-                $content .= '<td style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showuser'.$getvars.'" title="'.get_string('tt_showuser', 'calendar').'">'.get_string('userevents', 'calendar').'</a></td>'."\n";
+                $content .= '<td style="width: 11px;"><img src="'.$CFG->pixpath.'/t/show.gif" class="iconsmall" alt="'.get_string('show').'" /></td>';
+                $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showuser'.$getvars.'" title="'.get_string('tt_showuser', 'calendar').'">'.get_string('userevents', 'calendar').'</a></td>'."\n";
             }
 
         } else {
             // This course CANNOT have group events, so lose the filter
-            $content .= '<td style="width: 8px;"></td><td>&nbsp;</td>'."\n";
+            $content .= '<td style="width: 11px;"></td><td>&nbsp;</td>'."\n";
 
             if($SESSION->cal_show_user) {
-                $content .= '<td class="event_user" style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showuser'.$getvars.'" title="'.get_string('tt_hideuser', 'calendar').'">'.get_string('userevents', 'calendar').'</a></td>'."\n";
+                $content .= '<td class="event_user" style="width: 11px;"><img src="'.$CFG->pixpath.'/t/hide.gif" class="iconsmall" alt="'.get_string('hide').'" /></td>';
+                $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showuser'.$getvars.'" title="'.get_string('tt_hideuser', 'calendar').'">'.get_string('userevents', 'calendar').'</a></td>'."\n";
             } else {
-                $content .= '<td style="width: 8px;"></td><td><a href="'.CALENDAR_URL.'set.php?var=showuser'.$getvars.'" title="'.get_string('tt_showuser', 'calendar').'">'.get_string('userevents', 'calendar').'</a></td>'."\n";
+                $content .= '<td style="width: 11px;"><img src="'.$CFG->pixpath.'/t/show.gif" class="iconsmall" alt="'.get_string('show').'" /></td>';
+                $content .= '<td><a href="'.CALENDAR_URL.'set.php?var=showuser'.$getvars.'" title="'.get_string('tt_showuser', 'calendar').'">'.get_string('userevents', 'calendar').'</a></td>'."\n";
             }
         }
     }
@@ -820,6 +828,9 @@ function calendar_time_representation($time) {
         $langtimeformat = get_string('strftimetime');
     }
     $timeformat = get_user_preferences('calendar_timeformat');
+    if(empty($timeformat)){
+        $timeformat = get_config(NULL,'calendar_site_timeformat');
+    }
     // The ? is needed because the preference might be present, but empty
     return userdate($time, empty($timeformat) ? $langtimeformat : $timeformat);
 }
@@ -840,6 +851,34 @@ function calendar_get_link_tag($text, $linkbase, $d, $m, $y) {
     return '<a href="'.$href.'">'.$text.'</a>';
 }
 
+/**
+ * Build and return a previous month HTML link, with an arrow.
+ * @param string $text The text label.
+ * @param string $linkbase The URL stub.
+ * @param int $d $m $y Day of month, month and year numbers.
+ * @param bool $accesshide Default visible, or hide from all except screenreaders.
+ * @return string HTML string.
+ */
+function calendar_get_link_previous($text, $linkbase, $d, $m, $y, $accesshide=false) {
+    $href = calendar_get_link_href($linkbase, $d, $m, $y);
+    if(empty($href)) return $text;
+    return link_arrow_left($text, $href, $accesshide, 'previous');
+}
+
+/**
+ * Build and return a next month HTML link, with an arrow.
+ * @param string $text The text label.
+ * @param string $linkbase The URL stub.
+ * @param int $d $m $y Day of month, month and year numbers.
+ * @param bool $accesshide Default visible, or hide from all except screenreaders.
+ * @return string HTML string.
+ */
+function calendar_get_link_next($text, $linkbase, $d, $m, $y, $accesshide=false) {
+    $href = calendar_get_link_href($linkbase, $d, $m, $y);
+    if(empty($href)) return $text;
+    return link_arrow_right($text, $href, $accesshide, 'next');
+}
+
 function calendar_wday_name($englishname) {
     return get_string(strtolower($englishname), 'calendar');
 }
@@ -868,7 +907,7 @@ function calendar_get_sideblock_upcoming($events, $linkhref = NULL) {
             if(!empty($linkhref)) {
                 $ed = usergetdate($events[$i]->timestart);
                 $href = calendar_get_link_href(CALENDAR_URL.$linkhref, $ed['mday'], $ed['mon'], $ed['year']);
-                $content .= '<a href="'.$href.'">'.$events[$i]->name.'</a>';
+                $content .= '<a href="'.$href.'#event_'.$events[$i]->id.'">'.$events[$i]->name.'</a>';
             }
             else {
                 $content .= $events[$i]->name;
@@ -1027,14 +1066,14 @@ function calendar_session_vars() {
     if(!isset($SESSION->cal_show_user)) {
         $SESSION->cal_show_user = true;
     }
-    if(empty($SESSION->cal_courses_shown)) {
+   // if(empty($SESSION->cal_courses_shown)) {
         $SESSION->cal_courses_shown = calendar_get_default_courses(true);
-    }
+    //}
     if(empty($SESSION->cal_users_shown)) {
         // The empty() instead of !isset() here makes a whole world of difference,
         // as it will automatically change to the user's id when the user first logs
         // in. With !isset(), it would never do that.
-        $SESSION->cal_users_shown = isset($USER->id) ? $USER->id : false;
+        $SESSION->cal_users_shown = !empty($USER->id) ? $USER->id : false;
     }
     else if(is_numeric($SESSION->cal_users_shown) && !empty($USER->id) && $SESSION->cal_users_shown != $USER->id) {
         // Follow the white rabbit, for example if a teacher logs in as a student
@@ -1093,10 +1132,13 @@ function calendar_set_filters(&$courses, &$group, &$user, $courseeventsfrom = NU
     else {
         $courses = false;
     }
-   //BUG 6130 clean $courses array as SESSION has bad entries. 
-   foreach ($courses as $index => $value) {
-       if (empty($value)) unset($courses[$index]);
-   }
+    //BUG 6130 clean $courses array as SESSION has bad entries. 
+    // [pj] TODO: See if this has to do with my new change in get_default_courses and can be taken out
+    if (is_array($courses)) {
+        foreach ($courses as $index => $value) {
+            if (empty($value)) unset($courses[$index]);
+        }
+    }
 
     if($SESSION->cal_show_user || $ignorefilters) {
         // This doesn't work for arrays yet (maybe someday it will)
@@ -1113,28 +1155,29 @@ function calendar_set_filters(&$courses, &$group, &$user, $courseeventsfrom = NU
             $groupcourses = array_keys($groupeventsfrom);
         }
 
-        if(isadmin() && !empty($CFG->calendar_adminseesall)) {
+        // XXX TODO: not sure how to replace $CFG->calendar_adminseesall
+        if(has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_SYSTEM, SITEID)) && !empty($CFG->calendar_adminseesall)) {
             $group = true;
         }
         else {
             $grouparray = array();
-            $groupmodes = NULL;
 
             // We already have the courses to examine in $courses
             // For each course...
+
             foreach($groupcourses as $courseid) {
 
                 // If the user is an editing teacher in there,
-                if(!empty($USER->id) && isteacheredit($courseid, $USER->id)) {
-
-                    // The first time we get in here, retrieve all groupmodes at once
-                    if($groupmodes === NULL) {
-                        $groupmodes = get_records_list('course', 'id', implode(',', $groupcourses), '', 'id, groupmode, groupmodeforce');
-                    }
-
+                if(!empty($USER->id) && has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_COURSE, $courseid))) {
                     // If this course has groups, show events from all of them
-                    if(isset($groupmodes[$courseid]) && ($groupmodes[$courseid]->groupmode != NOGROUPS || !$groupmodes[$courseid]->groupmodeforce) && ($grouprecords = get_groups($courseid)) !== false) {
-                        $grouparray = array_merge($grouparray, array_keys($grouprecords));
+                    if(is_int($groupeventsfrom)) {
+                        $courserecord = get_record('course', 'id', $courseid);
+                        if ($courserecord->groupmode != NOGROUPS || !$courserecord->groupmodeforce) {
+                            $groupids[] = $courseid;
+                        }
+                    }
+                    else if(isset($SESSION->cal_courses_shown[$courseid]) && ($SESSION->cal_courses_shown[$courseid]->groupmode != NOGROUPS || !$SESSION->cal_courses_shown[$courseid]->groupmodeforce)) {
+                        $groupids[] = $courseid;
                     }
                 }
 
@@ -1146,6 +1189,17 @@ function calendar_set_filters(&$courses, &$group, &$user, $courseeventsfrom = NU
                     }
                 }
             }
+            
+            if (!empty($groupids)) {
+                $sql = "SELECT id, groupid 
+                        FROM {$CFG->prefix}groups_courses_groups
+                        WHERE courseid IN (".implode(',', $groupids).')';
+    
+                if ($grouprecords= get_records_sql($sql)) {
+                    $grouparray = array_merge($grouparray, array_keys($grouprecords));
+                }
+            }
+            
             if(empty($grouparray)) {
                 $group = false;
             }
@@ -1161,28 +1215,40 @@ function calendar_set_filters(&$courses, &$group, &$user, $courseeventsfrom = NU
 }
 
 function calendar_edit_event_allowed($event) {
+    
     global $USER;
 
-    if(empty($USER->id) || isguest($USER->id)) {
-        return false;
+    // can not be using guest account
+    if ($USER->username == "guest") {
+        return false;  
     }
-
-    if (isadmin($USER->id)) return true; // Admins are allowed anything
-
-    if ($event->courseid != 0 && isteacher($event->courseid)) {
+    
+    $sitecontext = get_context_instance(CONTEXT_SYSTEM, SITEID);
+    // if user has manageentries at site level, return true
+    if (has_capability('moodle/calendar:manageentries', $sitecontext)) {
         return true;
-    } else if($event->courseid == 0 && $event->groupid != 0) {
-        // Group event
-        $group = get_record('groups', 'id', $event->groupid);
-        if($group === false) {
+    }
+    
+    // if groupid is set, it's definitely a group event
+    if ($event->groupid) {
+        //TODO:check.
+        if (! groups_group_exists($event->groupid)) {
             return false;
-        }
-        return isteacheredit($group->courseid) || isteacher($group->courseid) && ismember($event->groupid);
-    } else if($event->courseid == 0 && $event->groupid == 0 && $event->userid == $USER->id) {
-        // User event, owned by this user
-        return true;
-    }
-
+        } 
+        
+        // this is ok because if you have this capability at course level, you should be able 
+        // to edit group calendar too
+        // there is no need to check membership, because if you have this capability
+        // you will have a role in this group context
+        return has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_GROUP, $event->groupid)); 
+    } else if ($event->courseid) {
+    // if groupid is not set, but course is set,
+    // it's definiely a course event
+        return has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_COURSE, $event->courseid));  
+    } else if ($event->userid && $event->userid == $USER->id) {  
+    // if course is not set, but userid id set, it's a user event
+        return (has_capability('moodle/calendar:manageownentries', $sitecontext));
+    } 
     return false;
 }
 
@@ -1198,18 +1264,20 @@ function calendar_get_default_courses($ignoreref = false) {
     }
 
     $courses = array();
-    if(isadmin($USER->id)) {
-        if(!empty($CFG->calendar_adminseesall)) {
+    if (has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_SYSTEM, SITEID))) {
+        if (!empty($CFG->calendar_adminseesall)) {
             $courses = get_records_sql('SELECT id, 1 FROM '.$CFG->prefix.'course');
             return $courses;
         }
     }
-    if(isset($USER->student) && is_array($USER->student)) {
-        $courses = $courses + $USER->student;
+    
+    if (isset($CFG->adminseesall)) {
+        $courses = get_my_courses($USER->id, 'visible DESC', null, $CFG->adminseesall);
     }
-    if(isset($USER->teacher) && is_array($USER->teacher)) {
-        $courses = $courses + $USER->teacher;
+    else {
+        $courses = get_my_courses($USER->id, 'visible DESC', null, false);
     }
+
     return $courses;
 }
 
@@ -1221,9 +1289,9 @@ function calendar_preferences_button() {
         return '';
     }
 
-    return "<form target=\"$CFG->framename\" method=\"get\" ".
+    return "<form $CFG->frametarget method=\"get\" ".
            " action=\"$CFG->wwwroot/calendar/preferences.php\">".
-           "<input type=\"submit\" value=\"".get_string("preferences", "calendar")." ...\" /></form>";
+           "<div><input type=\"submit\" value=\"".get_string("preferences", "calendar")." ...\" /></div></form>";
 }
 
 function calendar_format_event_time($event, $now, $morehref, $usecommonwords = true) {
@@ -1293,7 +1361,7 @@ function calendar_print_month_selector($name, $selected) {
     $months = array();
 
     for ($i=1; $i<=12; $i++) {
-        $months[$i] = userdate(gmmktime(12, 0, 0, $i, 1, 2000), '%B');
+        $months[$i] = userdate(gmmktime(12, 0, 0, $i, 15, 2000), '%B');
     }
 
     choose_from_menu($months, $name, $selected, '');
@@ -1333,4 +1401,32 @@ function calendar_set_filters_status($packed_bitfield) {
     return true;
 }
 
+function calendar_get_allowed_types(&$allowed) {
+    global $USER, $CFG, $SESSION;
+    $sitecontext = get_context_instance(CONTEXT_SYSTEM);
+    $allowed->user = has_capability('moodle/calendar:manageownentries', $sitecontext);
+    $allowed->groups = false; // This may change just below
+    $allowed->courses = false; // This may change just below
+    $allowed->site = has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_COURSE, SITEID));
+
+    if(!empty($SESSION->cal_course_referer) && $SESSION->cal_course_referer != SITEID && has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_COURSE, $SESSION->cal_course_referer))) {
+        $course = get_record('course', 'id', $SESSION->cal_course_referer);
+
+        $allowed->courses = array($course->id => 1);
+
+        if($course->groupmode != NOGROUPS || !$course->groupmodeforce) {
+            $allowed->groups = get_groups($SESSION->cal_course_referer);
+        }
+    }
+}
+
+/**
+ * see if user can add calendar entries at all
+ * used to print the "New Event" button
+ * @return bool
+ */
+function calendar_user_can_add_event() {
+    calendar_get_allowed_types($allowed);
+    return (bool)($allowed->user || $allowed->groups || $allowed->courses || $allowed->site); 
+}
 ?>
