@@ -1,23 +1,24 @@
-<?PHP  // $Id: preferences.php,v 1.7 2004/08/12 07:48:00 moodler Exp $
+<?PHP  // $Id: preferences.php,v 1.16.4.1 2007/05/06 04:26:39 martinlanghoff Exp $
        // preferences.php - user prefs for calendar
 
     require_once('../config.php');
     require_once($CFG->dirroot.'/calendar/lib.php');
 
     if (isset($SESSION->cal_course_referer)) {
-        if (! $course = get_record("course", "id", $SESSION->cal_course_referer)) {
+        if (! $course = get_record('course', 'id', $SESSION->cal_course_referer)) {
             $course = get_site();
         }
     }
 
-    if ($course->category) {
+    if ($course->id != SITEID) {
         require_login($course->id);
     }
-
+    // Initialize the session variables
+    calendar_session_vars();
+    
 /// If data submitted, then process and store.
 
-	if ($form = data_submitted()) {
-        print_header();
+    if ($form = data_submitted()) {
         foreach ($form as $preference => $value) {
             switch ($preference) {
                 case 'timeformat':
@@ -34,18 +35,21 @@
                     set_user_preference('calendar_startwday', $value);
                 break;
                 case 'maxevents':
-                    if ((int)$value >= 1) {
+                    if (intval($value) >= 1) {
                         set_user_preference('calendar_maxevents', $value);
                     }
                 break;
                 case 'lookahead':
-                    if ((int)$value >= 1) {
+                    if (intval($value) >= 1) {
                         set_user_preference('calendar_lookahead', $value);
                     }
                 break;
+                case 'persistflt':
+                    set_user_preference('calendar_persistflt', intval($value));
+                break;
             }
         }
-        redirect("view.php", get_string("changessaved"), 1);
+        redirect('view.php', get_string('changessaved'), 1);
         exit;
     }
 
@@ -54,7 +58,7 @@
     $strcalendar = get_string('calendar', 'calendar');
     $strpreferences = get_string('preferences', 'calendar');
 
-    if ($course->category) {
+    if ($course->id != SITEID) {
         $navigation = "<a href=\"$CFG->wwwroot/course/view.php?id=$course->id\">$course->shortname</a> ->
                        <a href=\"view.php\">$strcalendar</a> -> $strpreferences";
     } else {
@@ -63,19 +67,20 @@
 
 
     print_header("$site->shortname: $strcalendar: $strpreferences", $strcalendar, $navigation,
-                 '', '', true, '', '<p class="logininfo">'.user_login_string($site).'</p>');
+                 '', '', true, '', user_login_string($site));
 
 
     print_heading($strpreferences);
 
-    print_simple_box_start("center", "", "$THEME->cellheading");
+    print_simple_box_start("center");
 
     $prefs->timeformat = get_user_preferences('calendar_timeformat', '');
-    $prefs->startwday = get_user_preferences('calendar_startwday', CALENDAR_STARTING_WEEKDAY);
-    $prefs->maxevents = get_user_preferences('calendar_maxevents', CALENDAR_UPCOMING_MAXEVENTS);
-    $prefs->lookahead = get_user_preferences('calendar_lookahead', CALENDAR_UPCOMING_DAYS);
+    $prefs->startwday  = get_user_preferences('calendar_startwday', CALENDAR_STARTING_WEEKDAY);
+    $prefs->maxevents  = get_user_preferences('calendar_maxevents', CALENDAR_UPCOMING_MAXEVENTS);
+    $prefs->lookahead  = get_user_preferences('calendar_lookahead', CALENDAR_UPCOMING_DAYS);
+    $prefs->persistflt = get_user_preferences('calendar_persistflt', 0);
 
-	include("preferences.html");
+    include('./preferences.html');
     print_simple_box_end();
 
     print_footer($course);
