@@ -1,4 +1,4 @@
-<?php // $Id: view.php,v 1.30 2004/05/25 06:36:09 moodler Exp $
+<?php // $Id: view.php,v 1.77.2.8 2007/06/28 03:58:41 toyomoyo Exp $
 
 /////////////////////////////////////////////////////////////////////////////
 //                                                                         //
@@ -9,14 +9,14 @@
 // Copyright (C) 2003-2004  Greek School Network            www.sch.gr     //
 //                                                                         //
 // Designed by:                                                            //
-//     Avgoustos Tsinakos (tsinakos@uom.gr)                                //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Avgoustos Tsinakos (tsinakos@teikav.edu.gr)                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // Programming and development:                                            //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // For bugs, suggestions, etc contact:                                     //
-//     Jon Papaioannou (pj@uom.gr)                                         //
+//     Jon Papaioannou (pj@moodle.org)                                     //
 //                                                                         //
 // The current module was developed at the University of Macedonia         //
 // (www.uom.gr) under the funding of the Greek School Network (www.sch.gr) //
@@ -41,50 +41,49 @@
 //  Display the calendar page.
 
     require_once('../config.php');
-    require_once('../course/lib.php');
+    require_once($CFG->dirroot.'/course/lib.php');
+    require_once($CFG->dirroot.'/calendar/lib.php');
 
-    require_login();
-
-    require_once('lib.php');
-
-    optional_variable($_GET['view'], 'upcoming');
-    optional_variable($_GET['course'], 0);
-    optional_variable($_GET['cal_d']);
-    optional_variable($_GET['cal_m']);
-    optional_variable($_GET['cal_y']);
+    $courseid = optional_param('course', 0, PARAM_INT);
+    $view = optional_param('view', 'upcoming', PARAM_ALPHA);
+    $day  = optional_param('cal_d', 0, PARAM_INT);
+    $mon  = optional_param('cal_m', 0, PARAM_INT);
+    $yr   = optional_param('cal_y', 0, PARAM_INT);
 
     if(!$site = get_site()) {
         redirect($CFG->wwwroot.'/'.$CFG->admin.'/index.php');
     }
 
+    if ($courseid) {
+        require_login($courseid);
+    } else if ($CFG->forcelogin) {
+        require_login();
+    }
+
+    // Initialize the session variables
+    calendar_session_vars();
+
     //add_to_log($course->id, "course", "view", "view.php?id=$course->id", "$course->id");
     $now = usergetdate(time());
     $pagetitle = '';
 
     $nav = calendar_get_link_tag(get_string('calendar', 'calendar'), CALENDAR_URL.'view.php?view=upcoming&amp;', $now['mday'], $now['mon'], $now['year']);
 
-    // Make sure that the GET variables are correct
-    $day = intval($_GET['cal_d']);
-    $mon = intval($_GET['cal_m']);
-    $yr = intval($_GET['cal_y']);
+    
     if(!checkdate($mon, $day, $yr)) {
         $day = intval($now['mday']);
         $mon = intval($now['mon']);
         $yr = intval($now['year']);
     }
-    $time = mktime(0, 0, 0, $mon, $day, $yr);
+    $time = make_timestamp($yr, $mon, $day);
 
-    switch($_GET['view']) {
+    switch($view) {
         case 'day':
-            $text = strftime(get_string('strftimedate'), $time);
-            if($text[0] == '0') {
-                $text = substr($text, 1);
-            }
-            $nav .= ' -> '.$text;
+            $nav .= ' -> '.userdate($time, get_string('strftimedate'));
             $pagetitle = get_string('dayview', 'calendar');
         break;
         case 'month':
-            $nav .= ' -> '.strftime(get_string('strftimemonthyear'), $time);
+            $nav .= ' -> '.userdate($time, get_string('strftimemonthyear'));
             $pagetitle = get_string('detailedmonthview', 'calendar');
         break;
         case 'upcoming':
@@ -93,27 +92,41 @@
     }
 
     // If a course has been supplied in the URL, change the filters to show that one
-    if(!empty($_GET['course'])) {
-        if(is_numeric($_GET['course']) && $_GET['course'] > 0 && record_exists('course', 'id', $_GET['course'])) {
-            $SESSION->cal_courses_shown = intval($_GET['course']);
-            calendar_set_referring_course($SESSION->cal_courses_shown);
+    if (!empty($courseid)) {
+        if ($course = get_record('course', 'id', $courseid)) {
+            if ($course->id == SITEID) {
+                // If coming from the home page, show all courses
+                $SESSION->cal_courses_shown = calendar_get_default_courses(true);
+                calendar_set_referring_course(0);
+
+            } else {
+                // Otherwise show just this one
+                $SESSION->cal_courses_shown = $course->id;
+                calendar_set_referring_course($SESSION->cal_courses_shown);
+            }
         }
+    } else {
+        $course = null;
     }
 
-    if(isguest($USER->id)) {
+    if (empty($USER->id) or isguest()) {
         $defaultcourses = calendar_get_default_courses();
         calendar_set_filters($courses, $groups, $users, $defaultcourses, $defaultcourses);
-    }
-    else {
+
+    } else {
         calendar_set_filters($courses, $groups, $users);
     }
 
     // Let's see if we are supposed to provide a referring course link
     // but NOT for the "main page" course
-    if($SESSION->cal_course_referer > 1 &&
-      ($shortname = get_field('course', 'shortname', 'id', $SESSION->cal_course_referer)) !== false) {
-        // If we know about the referring course, show a return link
+    if ($SESSION->cal_course_referer != SITEID &&
+       ($shortname = get_field('course', 'shortname', 'id', $SESSION->cal_course_referer)) !== false) {
+        // If we know about the referring course, show a return link and ALSO require login!
+        require_login();
         $nav = '<a href="'.$CFG->wwwroot.'/course/view.php?id='.$SESSION->cal_course_referer.'">'.$shortname.'</a> -> '.$nav;
+        if (empty($course)) {
+            $course = get_record('course', 'id', $SESSION->cal_course_referer); // Useful to have around
+        }
     }
 
     $strcalendar = get_string('calendar', 'calendar');
@@ -121,19 +134,20 @@
 
     // Print title and header
     print_header("$site->shortname: $strcalendar: $pagetitle", $strcalendar, $nav,
-                 '', '', true, $prefsbutton, '<p class="logininfo">'.user_login_string($site).'</p>');
+                 '', '', true, $prefsbutton, user_login_string($site));
 
     echo calendar_overlib_html();
 
     // Layout the whole page as three big columns.
-    echo '<table border="0" cellpadding="3" cellspacing="0" width="100%">';
-    echo '<tr style="vertical-align: top;">';
+    echo '<table id="calendar" style="height:100%;">';
+    echo '<tr>';
 
     // START: Main column
 
-    echo '<td style="vertical-align: top; width: 100%;">';
+    echo '<td class="maincalendar">';
+    echo '<div class="heightcontainer">';
 
-    switch($_GET['view']) {
+    switch($view) {
         case 'day':
             calendar_show_day($day, $mon, $yr, $courses, $groups, $users);
         break;
@@ -145,29 +159,50 @@
         break;
     }
 
+    //Link to calendar export page
+    echo '<div class="bottom">';
+    print_single_button('export.php', false, get_string('exportcalendar', 'calendar'));
+
+    if (!empty($USER->id)) {
+        $authtoken = sha1($USER->username . $USER->password);
+        $usernameencoded = urlencode($USER->username);
+
+        echo "<a href=\"export_execute.php?preset_what=all&amp;preset_time=recentupcoming&amp;username=$usernameencoded&amp;authtoken=$authtoken\">"
+             .'<img src="'.$CFG->pixpath.'/i/ical.gif" height="14" width="36" '
+             .'alt="'.get_string('ical', 'calendar').'" '
+             .'title="'.get_string('quickdownloadcalendar', 'calendar').'" />'
+             .'</a>';
+    }
+
+    echo '</div>';
+    echo '</div>';
     echo '</td>';
 
     // END: Main column
 
     // START: Last column (3-month display)
-    echo '<td style="vertical-align: top; width: 180px;">';
-    print_side_block_start(get_string('monthlyview', 'calendar'), '', 'sideblockmain');
+    echo '<td class="sidecalendar">';
+    echo '<div class="header">'.get_string('monthlyview', 'calendar').'</div>';
+
     list($prevmon, $prevyr) = calendar_sub_month($mon, $yr);
     list($nextmon, $nextyr) = calendar_add_month($mon, $yr);
     $getvars = 'cal_d='.$day.'&amp;cal_m='.$mon.'&amp;cal_y='.$yr; // For filtering
-    echo calendar_filter_controls($_GET['view'], $getvars);
-    echo '<p>';
+
+    echo '<div class="filters">';
+    echo calendar_filter_controls($view, $getvars);
+    echo '</div>';
+
+    echo '<div class="minicalendarblock">';
     echo calendar_top_controls('display', array('m' => $prevmon, 'y' => $prevyr));
     echo calendar_get_mini($courses, $groups, $users, $prevmon, $prevyr);
-    echo '</p><p>';
+    echo '</div><div class="minicalendarblock">';
     echo calendar_top_controls('display', array('m' => $mon, 'y' => $yr));
     echo calendar_get_mini($courses, $groups, $users, $mon, $yr);
-    echo '</p><p>';
+    echo '</div><div class="minicalendarblock">';
     echo calendar_top_controls('display', array('m' => $nextmon, 'y' => $nextyr));
     echo calendar_get_mini($courses, $groups, $users, $nextmon, $nextyr);
-    echo '</p>';
-    print_side_block_end();
-    print_spacer(1, 180);
+    echo '</div>';
+
     echo '</td>';
 
     echo '</tr></table>';
@@ -177,7 +212,7 @@
 
 
 function calendar_show_day($d, $m, $y, $courses, $groups, $users) {
-    global $CFG, $THEME, $db;
+    global $CFG, $USER;
 
     if (!checkdate($m, $d, $y)) {
         $now = usergetdate(time());
@@ -187,41 +222,53 @@ function calendar_show_day($d, $m, $y, $courses, $groups, $users) {
     $getvars = 'from=day&amp;cal_d='.$d.'&amp;cal_m='.$m.'&amp;cal_y='.$y; // For filtering
 
     $starttime = make_timestamp($y, $m, $d);
-    $endtime   = $starttime + SECS_IN_DAY - 1;
+    $endtime   = make_timestamp($y, $m, $d + 1) - 1;
 
     $events = calendar_get_upcoming($courses, $groups, $users, 1, 100, $starttime);
 
-    // New event button
-    if (isguest()) {
-        $text = get_string('dayview', 'calendar').': '.calendar_course_filter_selector($getvars);
-
-    } else {
-        $text = '<div style="float: left;">'.get_string('dayview', 'calendar').': '.
-                calendar_course_filter_selector($getvars).'</div><div style="float: right;">';
-        $text.= '<form style="display: inline;" action="'.CALENDAR_URL.'event.php" method="get">';
+    $text = '';
+    if (!isguest() && !empty($USER->id) && calendar_user_can_add_event()) {
+        $text.= '<div class="buttons">';
+        $text.= '<form action="'.CALENDAR_URL.'event.php" method="get">';
+        $text.= '<div>';
         $text.= '<input type="hidden" name="action" value="new" />';
         $text.= '<input type="hidden" name="cal_d" value="'.$d.'" />';
         $text.= '<input type="hidden" name="cal_m" value="'.$m.'" />';
         $text.= '<input type="hidden" name="cal_y" value="'.$y.'" />';
         $text.= '<input type="submit" value="'.get_string('newevent', 'calendar').'" />';
-        $text.= '</form></div>';
+        $text.= '</div></form></div>';
     }
 
-    print_side_block_start($text, '', 'mycalendar');
-    echo '<p>'.calendar_top_controls('day', array('d' => $d, 'm' => $m, 'y' => $y)).'</p>';
+    $text .= get_string('dayview', 'calendar').': '.calendar_course_filter_selector($getvars);
+
+    echo '<div class="header">'.$text.'</div>';
+
+    echo '<div class="controls">'.calendar_top_controls('day', array('d' => $d, 'm' => $m, 'y' => $y)).'</div>';
 
     if (empty($events)) {
         // There is nothing to display today.
-        echo '<p style="text-align: center;">'.get_string('daywithnoevents', 'calendar').'</p>';
+        echo '<h3>'.get_string('daywithnoevents', 'calendar').'</h3>';
 
     } else {
 
+        echo '<div class="eventlist">';
+
         $underway = array();
 
         // First, print details about events that start today
         foreach ($events as $event) {
             if ($event->timestart >= $starttime && $event->timestart <= $endtime) {  // Print it now
-                unset($event->time);
+
+
+/*
+                $dayend = calendar_day_representation($event->timestart + $event->timeduration);
+                $timeend = calendar_time_representation($event->timestart + $event->timeduration);
+                $enddate = usergetdate($event->timestart + $event->timeduration);
+                // Set printable representation
+                echo calendar_get_link_tag($dayend, CALENDAR_URL.'view.php?view=day'.$morehref.'&amp;', $enddate['mday'], $enddate['mon'], $enddate['year']).' ('.$timeend.')';
+*/
+                //unset($event->time);
+                $event->time = calendar_format_event_time($event, time(), '', false);
                 calendar_print_event($event);
 
             } else {                                                                 // Save this for later
@@ -231,18 +278,20 @@ function calendar_show_day($d, $m, $y, $courses, $groups, $users) {
 
         // Then, show a list of all events that just span this day
         if (!empty($underway)) {
-            echo '<p style="text-align: center;"><strong>'.get_string('spanningevents', 'calendar').':</strong></p>';
+            echo '<h3>'.get_string('spanningevents', 'calendar').':</h3>';
             foreach ($underway as $event) {
+                $event->time = calendar_format_event_time($event, time(), '', false);
                 calendar_print_event($event);
             }
         }
-    }
 
-    print_side_block_end();
+        echo '</div>';
+
+    }
 }
 
 function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
-    global $CFG, $SESSION, $USER;
+    global $CFG, $SESSION, $USER, $CALENDARDAYS;
     global $day, $mon, $yr;
 
     $getvars = 'from=month&amp;cal_d='.$day.'&amp;cal_m='.$mon.'&amp;cal_y='.$yr; // For filtering
@@ -279,11 +328,18 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
     list($d, $m, $y) = array($date['mday'], $date['mon'], $date['year']); // This is what we want to display
     $display->maxdays = calendar_days_in_month($m, $y);
 
-    // We 'll keep these values as GMT here, and offset them when the time comes to query the db
-    $display->tstart = gmmktime(0, 0, 0, $m, 1, $y); // This is GMT
-    $display->tend = gmmktime(23, 59, 59, $m, $display->maxdays, $y); // GMT
-
-    $startwday = gmdate('w', $display->tstart); // $display->tstart is already GMT, so don't use date(): messes with server's TZ
+    $startwday = 0;
+    if (get_user_timezone_offset() < 99) {
+        // We 'll keep these values as GMT here, and offset them when the time comes to query the db
+        $display->tstart = gmmktime(0, 0, 0, $m, 1, $y); // This is GMT
+        $display->tend = gmmktime(23, 59, 59, $m, $display->maxdays, $y); // GMT
+        $startwday = gmdate('w', $display->tstart); // $display->tstart is already GMT, so don't use date(): messes with server's TZ
+    } else {
+        // no timezone info specified
+        $display->tstart = mktime(0, 0, 0, $m, 1, $y);
+        $display->tend = mktime(23, 59, 59, $m, $display->maxdays, $y);
+        $startwday = date('w', $display->tstart); // $display->tstart not necessarily GMT, so use date()
+    }
 
     // Align the starting weekday to fall in our display range
     if($startwday < $display->minwday) {
@@ -296,42 +352,42 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         $events = array();
     }
     else {
-        $events = get_records_select('event', $whereclause);
+        $events = get_records_select('event', $whereclause, 'timestart');
     }
 
     // Extract information: events vs. time
-    calendar_events_by_day($events, $display->tstart, $eventsbyday, $durationbyday, $typesbyday);
+    calendar_events_by_day($events, $m, $y, $eventsbyday, $durationbyday, $typesbyday);
 
-    // New event button
-    if(isguest()) {
-        $text = get_string('detailedmonthview', 'calendar').': '.calendar_course_filter_selector($getvars);
-    }
-    else {
-        $text = '<div style="float: left;">'.get_string('detailedmonthview', 'calendar').': '.calendar_course_filter_selector($getvars).'</div><div style="float: right;">';
-        $text.= '<form style="display: inline;" action="'.CALENDAR_URL.'event.php" method="get">';
+    $text = '';
+    if(!isguest() && !empty($USER->id) && calendar_user_can_add_event()) {
+        $text.= '<div class="buttons"><form action="'.CALENDAR_URL.'event.php" method="get">';
+        $text.= '<div>';
         $text.= '<input type="hidden" name="action" value="new" />';
         $text.= '<input type="hidden" name="cal_m" value="'.$m.'" />';
         $text.= '<input type="hidden" name="cal_y" value="'.$y.'" />';
         $text.= '<input type="submit" value="'.get_string('newevent', 'calendar').'" />';
-        $text.= '</form></div>';
+        $text.= '</div></form></div>';
     }
 
-    print_side_block_start($text, '', 'mycalendar');
+    $text .= get_string('detailedmonthview', 'calendar').': '.calendar_course_filter_selector($getvars);
 
+    echo '<div class="header">'.$text.'</div>';
+
+    echo '<div class="controls">';
     echo calendar_top_controls('month', array('m' => $m, 'y' => $y));
+    echo '</div>';
 
     // Start calendar display
-    echo '<table class="calendarmonth"><thead><tr>'; // Begin table. First row: day names
+    echo '<table class="calendarmonth"><tr class="weekdays">'; // Begin table. First row: day names
 
     // Print out the names of the weekdays
-    $days = array('sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday');
     for($i = $display->minwday; $i <= $display->maxwday; ++$i) {
         // This uses the % operator to get the correct weekday no matter what shift we have
         // applied to the $display->minwday : $display->maxwday range from the default 0 : 6
-        echo '<td class="calendarheader">'.get_string($days[$i % 7], 'calendar').'</td>';
+        echo '<th scope="col">'.get_string($CALENDARDAYS[$i % 7], 'calendar').'</th>';
     }
 
-    echo '</tr></thead><tbody><tr>'; // End of day names; prepare for day numbers
+    echo '</tr><tr>'; // End of day names; prepare for day numbers
 
     // For the table display. $week is the row; $dayweek is the column.
     $week = 1;
@@ -355,9 +411,9 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         $cell = '';
         $dayhref = calendar_get_link_href(CALENDAR_URL.'view.php?view=day&amp;', $day, $m, $y);
 
-        if($dayweek % 7 == 0 || $dayweek % 7 == 6) {
+        if(CALENDAR_WEEKEND & (1 << ($dayweek % 7))) {
             // Weekend. This is true no matter what the exact range is.
-            $class = 'cal_weekend';
+            $class = 'weekend';
         }
         else {
             // Normal working day.
@@ -367,16 +423,16 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         // Special visual fx if an event is defined
         if(isset($eventsbyday[$day])) {
             if(isset($typesbyday[$day]['startglobal'])) {
-                $class .= ' cal_event_global';
+                $class .= ' event_global';
             }
             else if(isset($typesbyday[$day]['startcourse'])) {
-                $class .= ' cal_event_course';
+                $class .= ' event_course';
             }
             else if(isset($typesbyday[$day]['startgroup'])) {
-                $class .= ' cal_event_group';
+                $class .= ' event_group';
             }
             else if(isset($typesbyday[$day]['startuser'])) {
-                $class .= ' cal_event_user';
+                $class .= ' event_user';
             }
             if(count($eventsbyday[$day]) == 1) {
                 $title = get_string('oneevent', 'calendar');
@@ -384,29 +440,29 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
             else {
                 $title = get_string('manyevents', 'calendar', count($eventsbyday[$day]));
             }
-            $cell = '<strong><a href="'.$dayhref.'" title="'.$title.'">'.$day.'</a></strong>';
+            $cell = '<div class="day"><a href="'.$dayhref.'" title="'.$title.'">'.$day.'</a></div>';
         }
         else {
-            $cell = $day;
+            $cell = '<div class="day">'.$day.'</div>';
         }
 
         // Special visual fx if an event spans many days
         if(isset($typesbyday[$day]['durationglobal'])) {
-            $class .= ' cal_duration_global';
+            $class .= ' duration_global';
         }
         else if(isset($typesbyday[$day]['durationcourse'])) {
-            $class .= ' cal_duration_course';
+            $class .= ' duration_course';
         }
         else if(isset($typesbyday[$day]['durationgroup'])) {
-            $class .= ' cal_duration_group';
+            $class .= ' duration_group';
         }
         else if(isset($typesbyday[$day]['durationuser'])) {
-            $class .= ' cal_duration_user';
+            $class .= ' duration_user';
         }
 
         // Special visual fx for today
         if($display->thismonth && $day == $d) {
-            $class .= ' cal_today';
+            $class .= ' today';
         }
 
         // Just display it
@@ -416,17 +472,18 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         echo '<td'.$class.'>'.$cell;
 
         if(isset($eventsbyday[$day])) {
-            echo '<table>';
+            echo '<ul class="events-new">';
             foreach($eventsbyday[$day] as $eventindex) {
-                echo '<tr><td style="vertical-align: top; width: 10px;"><strong>&middot;</strong></td>';
-                echo '<td style="width: 100%;"><a href="'.$dayhref.'">'.$events[$eventindex]->name.'</a></td></tr>';
+                echo '<li><a href="'.$dayhref.'#event_'.$events[$eventindex]->id.'">'.format_string($events[$eventindex]->name, true).'</a></li>';
             }
-            echo '</table>';
+            echo '</ul>';
         }
         if(isset($durationbyday[$day])) {
+            echo '<ul class="events-underway">';
             foreach($durationbyday[$day] as $eventindex) {
-                echo '<div class="dimmed_text">('.$events[$eventindex]->name.')</div>';
+                echo '<li>['.format_string($events[$eventindex]->name,true).']</li>';
             }
+            echo '</ul>';
         }
         echo "</td>\n";
     }
@@ -435,18 +492,16 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
     for($i = $dayweek; $i <= $display->maxwday; ++$i) {
         echo '<td>&nbsp;</td>';
     }
-    echo "</tr>\n</tbody>\n"; // Last row ends
+    echo "</tr>\n"; // Last row ends
 
-    echo "</table>\n<br />\n"; // Tabular display of days ends
+    echo "</table>\n"; // Tabular display of days ends
 
     // OK, now for the filtering display
-    echo '<table class="cal_filters">';
-    echo '<tbody>';
-    echo '<tr>';
+    echo '<div class="filters"><table><tr>';
 
     // Global events
     if($SESSION->cal_show_global) {
-        echo '<td class="cal_event_global" style="width: 8px;"></td><td><strong>'.get_string('globalevents', 'calendar').':</strong> ';
+        echo '<td class="event_global" style="width: 8px;"></td><td><strong>'.get_string('globalevents', 'calendar').':</strong> ';
         echo get_string('shown', 'calendar').' (<a href="'.CALENDAR_URL.'set.php?var=showglobal&amp;'.$getvars.'">'.get_string('clickhide', 'calendar').'</a>)</td>'."\n";
     }
     else {
@@ -456,7 +511,7 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
 
     // Course events
     if(!empty($SESSION->cal_show_course)) {
-        echo '<td class="cal_event_course" style="width: 8px;"></td><td><strong>'.get_string('courseevents', 'calendar').':</strong> ';
+        echo '<td class="event_course" style="width: 8px;"></td><td><strong>'.get_string('courseevents', 'calendar').':</strong> ';
         echo get_string('shown', 'calendar').' (<a href="'.CALENDAR_URL.'set.php?var=showcourses&amp;'.$getvars.'">'.get_string('clickhide', 'calendar').'</a>)</td>'."\n";
     }
     else {
@@ -466,11 +521,11 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
 
     echo "</tr>\n";
 
-    if(!isguest($USER->id)) {
+    if(!empty($USER->id) && !isguest()) {
         echo '<tr>';
         // Group events
         if($SESSION->cal_show_groups) {
-            echo '<td class="cal_event_group" style="width: 8px;"></td><td><strong>'.get_string('groupevents', 'calendar').':</strong> ';
+            echo '<td class="event_group" style="width: 8px;"></td><td><strong>'.get_string('groupevents', 'calendar').':</strong> ';
             echo get_string('shown', 'calendar').' (<a href="'.CALENDAR_URL.'set.php?var=showgroups&amp;'.$getvars.'">'.get_string('clickhide', 'calendar').'</a>)</td>'."\n";
         }
         else {
@@ -479,7 +534,7 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         }
         // User events
         if($SESSION->cal_show_user) {
-            echo '<td class="cal_event_user" style="width: 8px;"></td><td><strong>'.get_string('userevents', 'calendar').':</strong> ';
+            echo '<td class="event_user" style="width: 8px;"></td><td><strong>'.get_string('userevents', 'calendar').':</strong> ';
             echo get_string('shown', 'calendar').' (<a href="'.CALENDAR_URL.'set.php?var=showuser&amp;'.$getvars.'">'.get_string('clickhide', 'calendar').'</a>)</td>'."\n";
         }
         else {
@@ -489,117 +544,62 @@ function calendar_show_month_detailed($m, $y, $courses, $groups, $users) {
         echo "</tr>\n";
     }
 
-    echo '<tbody></table><br />';
-    print_side_block_end();
+    echo '</table></div>';
 }
 
 function calendar_show_upcoming_events($courses, $groups, $users, $futuredays, $maxevents) {
+    global $USER;
 
     $events = calendar_get_upcoming($courses, $groups, $users, $futuredays, $maxevents);
 
-    // New event button
-    if(isguest()) {
-        $text = get_string('upcomingevents', 'calendar').': '.calendar_course_filter_selector('from=upcoming');
+    $text = '';
 
-    } else {
-        $text = '<div style="float: left;">'.get_string('upcomingevents', 'calendar').': '.calendar_course_filter_selector('from=upcoming').'</div><div style="float: right;">';
-        $text.= '<form style="display: inline;" action="'.CALENDAR_URL.'event.php" method="get">';
+    if(!isguest() && !empty($USER->id) && calendar_user_can_add_event()) {
+        $text.= '<div class="buttons">';
+        $text.= '<form action="'.CALENDAR_URL.'event.php" method="get">';
+        $text.= '<div>';
         $text.= '<input type="hidden" name="action" value="new" />';
         /*
         $text.= '<input type="hidden" name="cal_m" value="'.$m.'" />';
         $text.= '<input type="hidden" name="cal_y" value="'.$y.'" />';
         */
         $text.= '<input type="submit" value="'.get_string('newevent', 'calendar').'" />';
-        $text.= '</form></div>';
+        $text.= '</div></form></div>';
     }
 
-    print_side_block_start($text, '', 'mycalendar');
+    $text .= get_string('upcomingevents', 'calendar').': '.calendar_course_filter_selector('from=upcoming');
+
+    echo '<div class="header">'.$text.'</div>';
+
     if ($events) {
+        echo '<div class="eventlist">';
         foreach ($events as $event) {
             calendar_print_event($event);
         }
+        echo '</div>';
     } else {
-        echo '<br />';
         print_heading(get_string('noupcomingevents', 'calendar'));
     }
-    print_side_block_end();
 }
 
-
-function calendar_print_event($event) {
-    global $CFG, $THEME;
-
-    static $strftimetime;
-
-    echo '<table border="0" cellpadding="3" cellspacing="0" class="eventfull" width="100%">';
-    echo "<tr><td bgcolor=\"$THEME->cellcontent2\" class=\"eventfullpicture\" width=\"32\" valign=\"top\">";
-    if (!empty($event->icon)) {
-        echo $event->icon;
-    } else {
-        print_spacer(16,16);
-    }
-    echo '</td>';
-    echo "<td bgcolor=\"$THEME->cellheading\" class=\"eventfullheader\" width=\"100%\">";
-
-    if (!empty($event->referer)) {
-        echo '<span style="float:left;" class="calendarreferer">'.$event->referer.' </span>';
-    } else {
-        echo '<span style="float:left;" class="cal_event">'.$event->name."</span>";
-    }
-    if (!empty($event->courselink)) {
-        echo '<br /><span style="float:left; font-size: 0.8em;">'.$event->courselink.' </span>';
-    }
-    if (!empty($event->time)) {
-        echo '<span style="float:right;" class="cal_event_date">'.$event->time.'</span>';
-    } else {
-        echo '<span style="float:right;" class="cal_event_date">'.calendar_time_representation($event->timestart).'</span>';
-    }
-
-    echo "</td></tr>";
-    echo "<tr><td bgcolor=\"$THEME->cellcontent2\" valign=\"top\" class=\"eventfullside\" width=\"32\">&nbsp;</td>";
-    echo "<td bgcolor=\"$THEME->cellcontent\" class=\"eventfullmessage\">\n";
-    echo format_text($event->description, FORMAT_HTML);
-    if (calendar_edit_event_allowed($event)) {
-        echo '<div align="right">';
-        if (empty($event->cmid)) {
-            $editlink = CALENDAR_URL.'event.php?action=edit&amp;id='.$event->id;
-            $deletelink = CALENDAR_URL.'event.php?action=delete&amp;id='.$event->id;
-        } else {
-            $editlink   = "$CFG->wwwroot/mod/$event->modulename/view.php?id=$event->cmid";
-            $deletelink = "$CFG->wwwroot/course/mod.php?delete=$event->cmid";
-        }
-        echo ' <a href="'.$editlink.'"><img
-                  src="'.$CFG->pixpath.'/t/edit.gif" alt="'.get_string('tt_editevent', 'calendar').'"
-                  title="'.get_string('tt_editevent', 'calendar').'" /></a>';
-        echo ' <a href="'.$deletelink.'"><img
-                  src="'.$CFG->pixpath.'/t/delete.gif" alt="'.get_string('tt_deleteevent', 'calendar').'"
-                  title="'.get_string('tt_deleteevent', 'calendar').'" /></a>';
-        echo '</div>';
-    }
-    echo "</td></tr>\n</table><br />\n\n";
-
-}
-
-
 function calendar_course_filter_selector($getvars = '') {
     global $USER, $SESSION;
 
-    if (isguest($USER->id)) {
+    if (empty($USER->id) or isguest()) {
         return '';
     }
 
-    if (isadmin($USER->id)) {
-        $courses = get_courses('all', 'c.shortname');
-
+    if (has_capability('moodle/calendar:manageentries', get_context_instance(CONTEXT_SYSTEM, SITEID)) && !empty($CFG->calendar_adminseesall)) {
+        $courses = get_courses('all', 'c.shortname','c.id,c.shortname');
     } else {
         $courses = get_my_courses($USER->id, 'shortname');
     }
 
-    unset($courses[1]);
+    unset($courses[SITEID]);
 
-    $courseoptions[1] = get_string('fulllistofcourses');
+    $courseoptions[SITEID] = get_string('fulllistofcourses');
     foreach ($courses as $course) {
-        $courseoptions[$course->id] = $course->shortname;
+        $courseoptions[$course->id] = format_string($course->shortname);
     }
 
     if (is_numeric($SESSION->cal_courses_shown)) {
@@ -608,10 +608,8 @@ function calendar_course_filter_selector($getvars = '') {
         $selected = '';
     }
 
-    $form = popup_form(CALENDAR_URL.'set.php?var=setcourse&amp;'.$getvars.'&amp;id=',
+    return popup_form(CALENDAR_URL.'set.php?var=setcourse&amp;'.$getvars.'&amp;id=',
                        $courseoptions, 'cal_course_flt', $selected, '', '', '', true);
-
-    return str_replace('<form', '<form style="display: inline;"', $form);
 }
 
 ?>
