@@ -1,4 +1,4 @@
-<?PHP // $Id: config-dist.php,v 1.62.2.3 2005/02/13 22:43:04 martinlanghoff Exp $
+<?PHP // $Id: config-dist.php,v 1.98 2006/11/11 17:23:33 skodak Exp $
 ///////////////////////////////////////////////////////////////////////////
 //                                                                       //
 // Moodle configuration file                                             //
@@ -110,7 +110,7 @@ $CFG->dataroot  = '/home/example/moodledata';
 // to make sure the web server process (eg Apache) can access the files.
 // NOTE: the prefixed 0 is important, and don't use quotes.
 
-$CFG->directorypermissions = 0777;
+$CFG->directorypermissions = 02777;
 
 
 //=========================================================================
@@ -139,53 +139,158 @@ $CFG->admin = 'admin';
 // Useful for webhost operators who have alternate methods of backups
 //      $CFG->disablescheduledbackups = true;
 //
-// Restrict certain usernames from doing things that may mess up a site
-// This is especially useful for demonstration teacher accounts
-//      $CFG->restrictusers = 'teacher,fred,jim';
+// Prevent stats processing and hide the GUI
+//      $CFG->disablestatsprocessing = true;
 //
-// Turning this on will make Moodle filter more than usual, including
-// forum subjects, activity names and so on (in ADDITION to the normal
-// texts like forum postings, journals etc).  This is mostly only useful
-// when using the multilang filter.   This feature may not be complete.
-//      $CFG->filterall = true;
+// Set global password for "Login as", teacher is prompted only once in each session.
+// Set your own password and tell it only to teachers that should have access to this feature.
+//      $CFG->loginaspassword = 'yoursharedpassword';
 //
 // Setting this to true will enable admins to edit any post at any time
 //      $CFG->admineditalways = true;
 //
-// This variable will override the default block configuration on newly
-// created courses, or on upgraded courses from Moodle 1.2.1 and earlier.
-// The names here should all be existing blocks in the "blocks" directory.
-//      $CFG->defaultblocks = "participants,activity_modules,search_forums,admin,course_list:news_items,calendar_upcoming,recent_activity";
+// These variables define DEFAULT block variables for new courses
+// If this one is set it overrides all others and is the only one used.
+//      $CFG->defaultblocks_override = 'participants,activity_modules,search_forums,admin,course_list:news_items,calendar_upcoming,recent_activity';
 //
-// This setting will put Moodle in Unicode mode.  It's very new and
-// most likely doesn't work yet.   THIS IS FOR DEVELOPERS ONLY, IT IS
+// These variables define the specific settings for defined course formats.
+// They override any settings defined in the formats own config file.
+//      $CFG->defaultblocks_site = 'site_main_menu,admin,course_list:course_summary,calendar_month';
+//      $CFG->defaultblocks_social = 'participants,search_forums,calendar_month,calendar_upcoming,social_activities,recent_activity,admin,course_list';
+//      $CFG->defaultblocks_topics = 'participants,activity_modules,search_forums,admin,course_list:news_items,calendar_upcoming,recent_activity';
+//      $CFG->defaultblocks_weeks = 'participants,activity_modules,search_forums,admin,course_list:news_items,calendar_upcoming,recent_activity';
+//
+// These blocks are used when no other default setting is found.
+//      $CFG->defaultblocks = 'participants,activity_modules,search_forums,admin,course_list:news_items,calendar_upcoming,recent_activity';
+//
+//
+// Allow unicode characters in uploaded files, generated reports, etc.
+// This setting is new and not much tested, there are known problems
+// with backup/restore that will not be solved, because native infozip
+// binaries are doing some weird conversions - use internal PHP zipping instead.
 // NOT RECOMMENDED FOR PRODUCTION SITES
-//      $CFG->unicode = true;
-//
-// To use spell-checking (experimental) define a path below to your
-// locally-installed copy of Aspell (0.50.1 or newer)
-//      $CFG->aspellpath = '/usr/bin/aspell'; // *nix
-//      $CFG->aspellpath = '"c:\path\to\aspell\aspell.exe"'; // Windows
+//     $CFG->unicodecleanfilename = true;
 //
 // Seconds for files to remain in caches. Decrease this if you are worried
 // about students being served outdated versions of uploaded files.
-//      $CFG->filelifetime = 86400;
+//     $CFG->filelifetime = 86400;
 //
-// The following two settings allow you to specify allowed domains for 
-// email addresses.  If the first one is set, then Moodle will DISALLOW
-// all domains EXCEPT those listed.  Otherwise, if the second one is set
-// then all addresses are ALLOWED EXCEPT those listed.
-//      $CFG->allowemailaddresses = "myschool.edu.au hotmail.com";
-//      $CFG->denyemailaddresses = "hotmail.com yahoo.com";
+// This setting will prevent the 'My Courses' page being displayed when a student
+// logs in. The site front page will always show the same (logged-out) view.
+//     $CFG->disablemycourses = true;
+// 
+// If this setting is set to true, then Moodle will track the IP of the 
+// current user to make sure it hasn't changed during a session.  This 
+// will prevent the possibility of sessions being hijacked via XSS, but it 
+// may break things for users coming using proxies that change all the time,
+// like AOL.
+//      $CFG->tracksessionip = true;
+//
+//
+// The following lines are for handling email bounces.
+//      $CFG->handlebounces = true;
+//      $CFG->minbounces = 10;
+//      $CFG->bounceratio = .20;
+// The next lines are needed both for bounce handling and any other email to module processing.
+// mailprefix must be EXACTLY four characters.
+// Uncomment and customise this block for Postfix 
+//      $CFG->mailprefix = 'mdl+'; // + is the separator for Exim and Postfix.
+//      $CFG->mailprefix = 'mdl-'; // - is the separator for qmail 
+//      $CFG->maildomain = 'youremaildomain.com';
 //
 // The following setting will tell Moodle to respect your PHP session 
 // settings. Use this if you want to control session configuration
 // from php.ini, httpd.conf or .htaccess files. 
-//     $CFG->respectsessionsettings = true;
+//      $CFG->respectsessionsettings = true;
+//
+// This setting will cause the userdate() function not to fix %d in 
+// date strings, and just let them show with a zero prefix.
+//      $CFG->nofixday = true;
+//
+// This setting will make some graphs (eg user logs) use lines instead of bars
+//      $CFG->preferlinegraphs = true;
+//
+// Enabling this will allow custom scripts to replace existing moodle scripts.
+// For example: if $CFG->customscripts/course/view.php exists then
+// it will be used instead of $CFG->wwwroot/course/view.php
+// At present this will only work for files that include config.php and are called
+// as part of the url (index.php is implied).
+// Some examples are:
+//      http://my.moodle.site/course/view.php
+//      http://my.moodle.site/index.php
+//      http://my.moodle.site/admin            (index.php implied)
+// Custom scripts should not include config.php
+// Warning: Replacing standard moodle scripts may pose security risks and/or may not
+// be compatible with upgrades. Use this option only if you are aware of the risks
+// involved. 
+// Specify the full directory path to the custom scripts
+//      $CFG->customscripts = '/home/example/customscripts';
+//
+// Performance profiling 
+// 
+//   If you set Debug to "Yes" in the Configuration->Variables page some
+//   performance profiling data will show up on your footer (in default theme).
+//   With these settings you get more granular control over the capture
+//   and printout of the data
+//
+//   Capture performance profiling data
+//   define('MDL_PERF'  , true);
+//
+//   Capture additional data from DB
+//   define('MDL_PERFDB'  , true);
+//
+//   Print to log (for passive profiling of production servers)
+//   define('MDL_PERFTOLOG'  , true);
+//
+//   Print to footer (works with the default theme)
+//   define('MDL_PERFTOFOOT', true);
+//
+// Force displayed usernames
+//   A little hack to anonymise user names for all students.  If you set these 
+//   then all non-teachers will always see these for every person.
+//       $CFG->forcefirstname = 'Bruce';
+//       $CFG->forcelastname  = 'Simpson';
+//
+// The following setting will turn SQL Error logging on. This will output an
+// entry in apache error log indicating the position of the error and the statement
+// called. This option will action disregarding error_reporting setting.
+//     $CFG->dblogerror = true;
+//
+// The following setting will turn on username logging into Apache log. For full details regarding setting
+// up of this function please refer to the install section of the document.
+//     $CFG->apacheloguser = 0; // Turn this feature off. Default value.
+//     $CFG->apacheloguser = 1; // Log user id.
+//     $CFG->apacheloguser = 2; // Log full name in cleaned format. ie, Darth Vader will be displayed as darth_vader.
+//     $CFG->apacheloguser = 3; // Log username. 
+// To get the values logged in Apache's log, add to your httpd.conf
+// the following statements. In the General part put:
+//     LogFormat "%h %l %{MOODLEUSER}n %t \"%r\" %s %b \"%{Referer}i\" \"%{User-Agent}i\"" moodleformat
+// And in the part specific to your Moodle install / virtualhost:
+//     CustomLog "/your/path/to/log" moodleformat
+// CAUTION: Use of this option will expose usernames in the Apache log,
+// If you are going to publish your log, or the output of your web stats analyzer
+// this will weaken the security of your website.
+// 
+// Email database connection errors to someone.  If Moodle cannot connect to the 
+// database, then email this address with a notice.
+//
+//     $CFG->emailconnectionerrorsto = 'your@emailaddress.com';
+// 
+// Restore pre-1.6 behaviour where courses could still be available
+// even if the category they were in was hidden
+//     $CFG->allowvisiblecoursesinhiddencategories = true;
+// 
+// NOTE: if you are using custompix in your theme, see /fixpix.php.
 
 //=========================================================================
 // ALL DONE!  To continue installation, visit your main page with a browser
 //=========================================================================
+if ($CFG->wwwroot == 'http://example.com/moodle') {
+    echo "<p>Error detected in configuration file</p>";
+    echo "<p>Your server address can not be: \$CFG->wwwroot = 'http://example.com/moodle';</p>";
+    die;
+}
+
 if (file_exists("$CFG->dirroot/lib/setup.php"))  {       // Do not edit
     include_once("$CFG->dirroot/lib/setup.php");
 } else {
