@@ -1,12 +1,29 @@
-<?PHP // $Id: mod.php,v 1.60.2.4 2005/02/08 01:05:50 stronk7 Exp $
+<?php // $Id: mod.php,v 1.119 2007/02/07 07:09:31 vyshane Exp $
 
 //  Moves, adds, updates, duplicates or deletes modules in a course
 
     require("../config.php");
-    require("lib.php");
+    require_once("lib.php");
 
     require_login();
 
+    $sectionreturn = optional_param('sr', '', PARAM_INT);
+    $add           = optional_param('add','', PARAM_ALPHA);
+    $type          = optional_param('type', '', PARAM_ALPHA);
+    $indent        = optional_param('indent', 0, PARAM_INT);
+    $update        = optional_param('update', 0, PARAM_INT);
+    $hide          = optional_param('hide', 0, PARAM_INT);
+    $show          = optional_param('show', 0, PARAM_INT);
+    $copy          = optional_param('copy', 0, PARAM_INT);
+    $moveto        = optional_param('moveto', 0, PARAM_INT);
+    $movetosection = optional_param('movetosection', 0, PARAM_INT);
+    $delete        = optional_param('delete', 0, PARAM_INT);
+    $course        = optional_param('course', 0, PARAM_INT);
+    $groupmode     = optional_param('groupmode', -1, PARAM_INT);
+    $duplicate     = optional_param('duplicate', 0, PARAM_INT);
+    $cancel        = optional_param('cancel', 0, PARAM_BOOL);
+    $cancelcopy    = optional_param('cancelcopy', 0, PARAM_BOOL);
+
     if (isset($SESSION->modform)) {   // Variables are stored in the session
         $mod = $SESSION->modform;
         unset($SESSION->modform);
@@ -14,36 +31,69 @@
         $mod = (object)$_POST;
     }
 
-    if (isset($cancel)) {  
+    if ($cancel) {
         if (!empty($SESSION->returnpage)) {
             $return = $SESSION->returnpage;
             unset($SESSION->returnpage);
             redirect($return);
         } else {
-            redirect("view.php?id=$mod->course");
+            redirect("view.php?id=$mod->course#section-$sectionreturn");
         }
     }
 
+    //check if we are adding / editing a module that has new forms using formslib
+    if (!empty($add)){
+        $modname=$add;
+        if (file_exists("../mod/$modname/mod_form.php")) {
+            $id          = required_param('id', PARAM_INT);
+            $section     = required_param('section', PARAM_INT);
+            $type        = optional_param('type', '', PARAM_ALPHA);
+            $returntomod = optional_param('return', 0, PARAM_BOOL);
 
-    if (isset($_POST["course"])) {    // add or update form submitted
+            redirect("modedit.php?add=$add&type=$type&course=$id&section=$section&return=$returntomod");
+        }
+    }elseif (!empty($update)){
+        if (!$modname=get_field_sql("SELECT md.name
+                           FROM {$CFG->prefix}course_modules cm,
+                                {$CFG->prefix}modules md
+                           WHERE cm.id = '$update' AND
+                                 md.id = cm.module")){
+            error('Invalid course module id!');
+        }
+        $returntomod = optional_param('return', 0, PARAM_BOOL);
+        if (file_exists("../mod/$modname/mod_form.php")) {
+            redirect("modedit.php?update=$update&return=$returntomod");
+        }
+    }
+    //not adding / editing a module that has new forms using formslib
+    //carry on
 
-        //It caller is correct, $SESSION->sesskey must exist and coincide
-        if (empty($SESSION->sesskey) or !confirm_sesskey($SESSION->sesskey)) {
-            error(get_string('confirmsesskeybad', 'error'));
+    if (!empty($course) and confirm_sesskey()) {    // add, delete or update form submitted
+
+        if (empty($mod->coursemodule)) { //add
+            if (! $course = get_record("course", "id", $mod->course)) {
+                error("This course doesn't exist");
+            }
+            $mod->instance = '';
+            $mod->coursemodule = '';
+        } else { //delete and update
+            if (! $cm = get_record("course_modules", "id", $mod->coursemodule)) {
+                error("This course module doesn't exist");
+            }
+
+            if (! $course = get_record("course", "id", $cm->course)) {
+                error("This course doesn't exist");
+            }
+            $mod->instance = $cm->instance;
+            $mod->coursemodule = $cm->id;
         }
 
-        //Unset this, check done
-        unset($SESSION->sesskey);
+        require_login($course->id); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $course->id);
+        require_capability('moodle/course:manageactivities', $context);
 
-        if (!$course = get_record("course", "id", $mod->course)) {
-            error("This course doesn't exist");
-        }
-
-        if (!isteacheredit($course->id)) {
-            error("You can't modify this course!");
-        }
-
-        $mod->modulename = clean_filename($mod->modulename);  // For safety
+        $mod->course = $course->id;
+        $mod->modulename = clean_param($mod->modulename, PARAM_SAFEDIR);  // For safety
         $modlib = "$CFG->dirroot/mod/$mod->modulename/lib.php";
 
         if (file_exists($modlib)) {
@@ -59,8 +109,10 @@
         switch ($mod->mode) {
             case "update":
 
-                if (trim($mod->name) == '') {
-                    unset($mod->name);
+                if (isset($mod->name)) {
+                    if (trim($mod->name) == '') {
+                        unset($mod->name);
+                    }
                 }
 
                 $return = $updateinstancefunction($mod);
@@ -76,19 +128,35 @@
                     error($return, "view.php?id=$course->id");
                 }
 
-                $SESSION->returnpage = "$CFG->wwwroot/mod/$mod->modulename/view.php?id=$mod->coursemodule";
+                if (isset($mod->visible)) {
+                    set_coursemodule_visible($mod->coursemodule, $mod->visible);
+                }
 
-                add_to_log($course->id, "course", "update mod", 
-                           "../mod/$mod->modulename/view.php?id=$mod->coursemodule", 
-                           "$mod->modulename $mod->instance"); 
-                add_to_log($course->id, $mod->modulename, "update", 
-                           "view.php?id=$mod->coursemodule", 
-                           "$mod->instance", $mod->coursemodule); 
+                if (isset($mod->groupmode)) {
+                    set_coursemodule_groupmode($mod->coursemodule, $mod->groupmode);
+                }
+
+                if (isset($mod->redirect)) {
+                    $SESSION->returnpage = $mod->redirecturl;
+                } else {
+                    $SESSION->returnpage = "$CFG->wwwroot/mod/$mod->modulename/view.php?id=$mod->coursemodule";
+                }
+
+                add_to_log($course->id, "course", "update mod",
+                           "../mod/$mod->modulename/view.php?id=$mod->coursemodule",
+                           "$mod->modulename $mod->instance");
+                add_to_log($course->id, $mod->modulename, "update",
+                           "view.php?id=$mod->coursemodule",
+                           "$mod->instance", $mod->coursemodule);
                 break;
 
             case "add":
 
-                if (trim($mod->name) == '') {
+                if (!course_allowed_module($course,$mod->modulename)) {
+                    error("This module ($mod->modulename) has been disabled for this particular course");
+                }
+
+                if (!isset($mod->name) || trim($mod->name) == '') {
                     $mod->name = get_string("modulename", $mod->modulename);
                 }
 
@@ -105,10 +173,13 @@
                     error($return, "view.php?id=$course->id");
                 }
 
-                $mod->groupmode = $course->groupmode;  /// Default groupmode the same as course
+                if (!isset($mod->groupmode)) { // to deal with pre-1.5 modules
+                    $mod->groupmode = $course->groupmode;  /// Default groupmode the same as course
+                }
 
                 $mod->instance = $return;
-                // course_modules and course_sections each contain a reference 
+
+                // course_modules and course_sections each contain a reference
                 // to each other, so we have to update one of them twice.
 
                 if (! $mod->coursemodule = add_course_module($mod) ) {
@@ -117,27 +188,31 @@
                 if (! $sectionid = add_mod_to_section($mod) ) {
                     error("Could not add the new course module to that section");
                 }
-                //We get the section's visible field status
-                $visible = get_field("course_sections","visible","id",$sectionid);
-
-                if (! set_field("course_modules", "visible", $visible, "id", $mod->coursemodule)) {
-                    error("Could not update the course module with the correct visibility");
-                }   
 
                 if (! set_field("course_modules", "section", $sectionid, "id", $mod->coursemodule)) {
                     error("Could not update the course module with the correct section");
-                }   
+                }
 
-                $SESSION->returnpage = "$CFG->wwwroot/mod/$mod->modulename/view.php?id=$mod->coursemodule";
-                
-                add_to_log($course->id, "course", "add mod", 
-                           "../mod/$mod->modulename/view.php?id=$mod->coursemodule", 
-                           "$mod->modulename $mod->instance"); 
-                add_to_log($course->id, $mod->modulename, "add", 
-                           "view.php?id=$mod->coursemodule", 
-                           "$mod->instance", $mod->coursemodule); 
+                if (!isset($mod->visible)) {   // We get the section's visible field status
+                    $mod->visible = get_field("course_sections","visible","id",$sectionid);
+                }
+                // make sure visibility is set correctly (in particular in calendar)
+                set_coursemodule_visible($mod->coursemodule, $mod->visible);
+
+                if (isset($mod->redirect)) {
+                    $SESSION->returnpage = $mod->redirecturl;
+                } else {
+                    $SESSION->returnpage = "$CFG->wwwroot/mod/$mod->modulename/view.php?id=$mod->coursemodule";
+                }
+
+                add_to_log($course->id, "course", "add mod",
+                           "../mod/$mod->modulename/view.php?id=$mod->coursemodule",
+                           "$mod->modulename $mod->instance");
+                add_to_log($course->id, $mod->modulename, "add",
+                           "view.php?id=$mod->coursemodule",
+                           "$mod->instance", $mod->coursemodule);
                 break;
-                
+
             case "delete":
                 if (! $deleteinstancefunction($mod->instance)) {
                     notify("Could not delete the $mod->modulename (instance)");
@@ -151,9 +226,9 @@
 
                 unset($SESSION->returnpage);
 
-                add_to_log($course->id, "course", "delete mod", 
-                           "view.php?id=$mod->course", 
-                           "$mod->modulename $mod->instance", $mod->coursemodule); 
+                add_to_log($course->id, "course", "delete mod",
+                           "view.php?id=$mod->course",
+                           "$mod->modulename $mod->instance", $mod->coursemodule);
                 break;
             default:
                 error("No mode defined");
@@ -167,50 +242,25 @@
             unset($SESSION->returnpage);
             redirect($return);
         } else {
-            redirect("view.php?id=$course->id");
+            redirect("view.php?id=$course->id#section-$sectionreturn");
         }
         exit;
     }
 
+    if ((!empty($movetosection) or !empty($moveto)) and confirm_sesskey()) {
 
-    if (isset($_GET['move']) and confirm_sesskey()) {  
-
-        require_variable($id);   
-
-        if (! $cm = get_record("course_modules", "id", $id)) {
-            error("This course module doesn't exist");
-        }
-
-        if (!isteacheredit($cm->course)) {
-            error("You can't modify this course!");
-        }
-    
-        move_module($cm, $_GET['move']);
-
-        rebuild_course_cache($cm->course);
-
-        $site = get_site();
-        if ($site->id == $cm->course) {
-            redirect($CFG->wwwroot);
-        } else {
-            redirect("view.php?id=$cm->course");
-        }
-        exit;
-
-    } else if ((isset($_GET['movetosection']) or isset($_GET['moveto'])) and confirm_sesskey()) {  
-        
         if (! $cm = get_record("course_modules", "id", $USER->activitycopy)) {
             error("The copied course module doesn't exist!");
         }
 
-        if (isset($_GET['movetosection'])) {
-            if (! $section = get_record("course_sections", "id", $_GET['movetosection'])) {
+        if (!empty($movetosection)) {
+            if (! $section = get_record("course_sections", "id", $movetosection)) {
                 error("This section doesn't exist");
             }
             $beforecm = NULL;
 
         } else {                      // normal moveto
-            if (! $beforecm = get_record("course_modules", "id", $_GET['moveto'])) {
+            if (! $beforecm = get_record("course_modules", "id", $moveto)) {
                 error("The destination course module doesn't exist");
             }
             if (! $section = get_record("course_sections", "id", $beforecm->section)) {
@@ -218,9 +268,9 @@
             }
         }
 
-        if (!isteacheredit($section->course)) {
-            error("You can't modify this course!");
-        }
+        require_login($section->course); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $section->course);
+        require_capability('moodle/course:manageactivities', $context);
 
         if (!ismoving($section->course)) {
             error("You need to copy something first!");
@@ -234,22 +284,25 @@
 
         rebuild_course_cache($section->course);
 
-        $site = get_site();
-        if ($site->id == $section->course) {
+        if (SITEID == $section->course) {
             redirect($CFG->wwwroot);
         } else {
-            redirect("view.php?id=$section->course");
+            redirect("view.php?id=$section->course#section-$sectionreturn");
         }
 
-    } else if (isset($_GET['indent']) and confirm_sesskey()) {  
+    } else if (!empty($indent) and confirm_sesskey()) {
 
-        require_variable($id);   
+        $id = required_param('id',PARAM_INT);
 
         if (! $cm = get_record("course_modules", "id", $id)) {
             error("This course module doesn't exist");
         }
 
-        $cm->indent += $_GET['indent'];
+        require_login($cm->course); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $cm->course);
+        require_capability('moodle/course:manageactivities', $context);
+
+        $cm->indent += $indent;
 
         if ($cm->indent < 0) {
             $cm->indent = 0;
@@ -259,45 +312,43 @@
             error("Could not update the indent level on that course module");
         }
 
-        $site = get_site();
-        if ($site->id == $cm->course) {
+        if (SITEID == $cm->course) {
             redirect($CFG->wwwroot);
         } else {
-            redirect("view.php?id=$cm->course");
+            redirect("view.php?id=$cm->course#section-$sectionreturn");
         }
         exit;
 
-    } else if (isset($_GET['hide']) and confirm_sesskey()) {
+    } else if (!empty($hide) and confirm_sesskey()) {
 
-        if (! $cm = get_record("course_modules", "id", $_GET['hide'])) {
+        if (! $cm = get_record("course_modules", "id", $hide)) {
             error("This course module doesn't exist");
         }
 
-        if (!isteacheredit($cm->course)) {
-            error("You can't modify this course!");
-        }
-   
-        hide_course_module($cm->id);
+        require_login($cm->course); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $cm->course);
+        require_capability('moodle/course:activityvisibility', $context);
+
+        set_coursemodule_visible($cm->id, 0);
 
         rebuild_course_cache($cm->course);
 
-        $site = get_site();
-        if ($site->id == $cm->course) {
+        if (SITEID == $cm->course) {
             redirect($CFG->wwwroot);
         } else {
-            redirect("view.php?id=$cm->course");
+            redirect("view.php?id=$cm->course#section-$sectionreturn");
         }
         exit;
 
-    } else if (isset($_GET['show']) and confirm_sesskey()) {
+    } else if (!empty($show) and confirm_sesskey()) {
 
-        if (! $cm = get_record("course_modules", "id", $_GET['show'])) {
+        if (! $cm = get_record("course_modules", "id", $show)) {
             error("This course module doesn't exist");
         }
 
-        if (!isteacheredit($cm->course)) {
-            error("You can't modify this course!");
-        }
+        require_login($cm->course); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $cm->course);
+        require_capability('moodle/course:activityvisibility', $context);
 
         if (! $section = get_record("course_sections", "id", $cm->section)) {
             error("This module doesn't exist");
@@ -307,51 +358,50 @@
             error("This module doesn't exist");
         }
 
-        $site = get_site();
-
-        if ($module->visible and ($section->visible or ($site->id == $cm->course))) {
-            show_course_module($cm->id);
+        if ($module->visible and ($section->visible or (SITEID == $cm->course))) {
+            set_coursemodule_visible($cm->id, 1);
             rebuild_course_cache($cm->course);
         }
 
-        if ($site->id == $cm->course) {
+        if (SITEID == $cm->course) {
             redirect($CFG->wwwroot);
         } else {
-            redirect("view.php?id=$cm->course");
+            redirect("view.php?id=$cm->course#section-$sectionreturn");
         }
         exit;
 
-    } else if (isset($_GET['groupmode']) and confirm_sesskey()) {
+    } else if ($groupmode > -1 and confirm_sesskey()) {
 
-        if (! $cm = get_record("course_modules", "id", $_GET['id'])) {
+        $id = required_param( 'id', PARAM_INT );
+
+        if (! $cm = get_record("course_modules", "id", $id)) {
             error("This course module doesn't exist");
         }
 
-        if (!isteacheredit($cm->course)) {
-            error("You can't modify this course!");
-        }
-   
-        set_groupmode_for_module($cm->id, $_GET['groupmode']);
+        require_login($cm->course); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $cm->course);
+        require_capability('moodle/course:manageactivities', $context);
+
+        set_coursemodule_groupmode($cm->id, $groupmode);
 
         rebuild_course_cache($cm->course);
 
-        $site = get_site();
-        if ($site->id == $cm->course) {
+        if (SITEID == $cm->course) {
             redirect($CFG->wwwroot);
         } else {
-            redirect("view.php?id=$cm->course");
+            redirect("view.php?id=$cm->course#section-$sectionreturn");
         }
         exit;
 
-    } else if (isset($_GET['copy']) and confirm_sesskey()) { // value = course module
+    } else if (!empty($copy) and confirm_sesskey()) { // value = course module
 
-        if (! $cm = get_record("course_modules", "id", $_GET['copy'])) {
+        if (! $cm = get_record("course_modules", "id", $copy)) {
             error("This course module doesn't exist");
         }
 
-        if (!isteacheredit($cm->course)) {
-            error("You can't modify this course!");
-        }
+        require_login($cm->course); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $cm->course);
+        require_capability('moodle/course:manageactivities', $context);
 
         if (! $section = get_record("course_sections", "id", $cm->section)) {
             error("This module doesn't exist");
@@ -369,9 +419,9 @@
         $USER->activitycopycourse = $cm->course;
         $USER->activitycopyname = $instance->name;
 
-        redirect("view.php?id=$cm->course");
+        redirect("view.php?id=$cm->course#section-$sectionreturn");
 
-    } else if (isset($_GET['cancelcopy']) and confirm_sesskey()) { // value = course module
+    } else if (!empty($cancelcopy) and confirm_sesskey()) { // value = course module
 
         $courseid = $USER->activitycopycourse;
 
@@ -379,11 +429,11 @@
         unset($USER->activitycopycourse);
         unset($USER->activitycopyname);
 
-        redirect("view.php?id=$courseid");
+        redirect("view.php?id=$courseid#section-$sectionreturn");
 
-    } else if (isset($_GET['delete']) and confirm_sesskey()) {   // value = course module
+    } else if (!empty($delete) and confirm_sesskey()) {   // value = course module
 
-        if (! $cm = get_record("course_modules", "id", $_GET['delete'])) {
+        if (! $cm = get_record("course_modules", "id", $delete)) {
             error("This course module doesn't exist");
         }
 
@@ -391,9 +441,9 @@
             error("This course doesn't exist");
         }
 
-        if (!isteacheredit($course->id)) {
-            error("You can't modify this course!");
-        }
+        require_login($cm->course); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $cm->course);
+        require_capability('moodle/course:manageactivities', $context);
 
         if (! $module = get_record("modules", "id", $cm->module)) {
             error("This module doesn't exist");
@@ -401,12 +451,12 @@
 
         if (! $instance = get_record($module->name, "id", $cm->instance)) {
             // Delete this module from the course right away
-            if (! delete_course_module($cm->id)) {
-                notify("Could not delete the $module->name (coursemodule)");
-            }
             if (! delete_mod_from_section($cm->id, $cm->section)) {
                 notify("Could not delete the $module->name from that section");
             }
+            if (! delete_course_module($cm->id)) {
+                notify("Could not delete the $module->name (coursemodule)");
+            }
             error("The required instance of this module didn't exist.  Module deleted.",
                   "$CFG->wwwroot/course/view.php?id=$course->id");
         }
@@ -420,26 +470,27 @@
         $form->modulename   = $module->name;
         $form->fullmodulename  = $fullmodulename;
         $form->instancename = $instance->name;
-        $SESSION->sesskey = !empty($USER->id) ? $USER->sesskey : '';
+        $form->sesskey      = !empty($USER->id) ? $USER->sesskey : '';
 
-        $strdeletecheck = get_string("deletecheck", "", "$form->fullmodulename");
-        $strdeletecheckfull = get_string("deletecheckfull", "", "$form->fullmodulename '$form->instancename'");
+        $strdeletecheck = get_string('deletecheck', '', $form->fullmodulename);
+        $strdeletecheckfull = get_string('deletecheckfull', '', "$form->fullmodulename '$form->instancename'");
 
-        print_header_simple("$strdeletecheck", "",
-                     "$strdeletecheck");
+        $CFG->pagepath = 'mod/'.$module->name.'/delete';
 
-        print_simple_box_start("center", "60%", "#FFAAAA", 20, "noticebox");
+        print_header_simple($strdeletecheck, '', $strdeletecheck);
+
+        print_simple_box_start('center', '60%', '#FFAAAA', 20, 'noticebox');
         print_heading($strdeletecheckfull);
-        include_once("mod_delete.html");
+        include_once('mod_delete.html');
         print_simple_box_end();
         print_footer($course);
 
         exit;
 
 
-    } else if (isset($_GET['update']) and confirm_sesskey()) {   // value = course module
+    } else if (!empty($update) and confirm_sesskey()) {   // value = course module
 
-        if (! $cm = get_record("course_modules", "id", $_GET['update'])) {
+        if (! $cm = get_record("course_modules", "id", $update)) {
             error("This course module doesn't exist");
         }
 
@@ -447,9 +498,9 @@
             error("This course doesn't exist");
         }
 
-        if (!isteacheredit($course->id)) {
-            error("You can't modify this course!");
-        }
+        require_login($course->id); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $course->id);
+        require_capability('moodle/course:manageactivities', $context);
 
         if (! $module = get_record("modules", "id", $cm->module)) {
             error("This module doesn't exist");
@@ -458,12 +509,12 @@
         if (! $form = get_record($module->name, "id", $cm->instance)) {
             error("The required instance of this module doesn't exist");
         }
-        
+
         if (! $cw = get_record("course_sections", "id", $cm->section)) {
             error("This course section doesn't exist");
         }
 
-        if (isset($return)) {  
+        if (isset($return)) {
             $SESSION->returnpage = "$CFG->wwwroot/mod/$module->name/view.php?id=$cm->id";
         }
 
@@ -474,22 +525,30 @@
         $form->modulename   = $module->name;
         $form->instance     = $cm->instance;
         $form->mode         = "update";
-        $SESSION->sesskey = !empty($USER->id) ? $USER->sesskey : '';
+        $form->sesskey      = !empty($USER->id) ? $USER->sesskey : '';
 
-        $sectionname    = get_string("name$course->format");
-        $fullmodulename = strtolower(get_string("modulename", $module->name));
+        $sectionname = get_section_name($course->format);
+        $fullmodulename = get_string("modulename", $module->name);
 
-        if ($form->section) {
+        if ($form->section && $course->format != 'site') {
             $heading->what = $fullmodulename;
             $heading->in   = "$sectionname $cw->section";
             $pageheading = get_string("updatingain", "moodle", $heading);
         } else {
             $pageheading = get_string("updatinga", "moodle", $fullmodulename);
         }
+        $strnav = "<a href=\"$CFG->wwwroot/mod/$module->name/view.php?id=$cm->id\">".format_string($form->name,true)."</a> ->";
 
-    } else if (isset($_GET['duplicate']) and confirm_sesskey()) {   // value = course module
+        if ($module->name == 'resource') {
+            $CFG->pagepath = 'mod/'.$module->name.'/'.$form->type;
+        } else {
+            $CFG->pagepath = 'mod/'.$module->name.'/mod';
+        }
 
-        if (! $cm = get_record("course_modules", "id", $_GET['duplicate'])) {
+    } else if (!empty($duplicate) and confirm_sesskey()) {   // value = course module
+
+
+        if (! $cm = get_record("course_modules", "id", $duplicate)) {
             error("This course module doesn't exist");
         }
 
@@ -497,9 +556,9 @@
             error("This course doesn't exist");
         }
 
-        if (!isteacheredit($course->id)) {
-            error("You can't modify this course!");
-        }
+        require_login($course->id); // needed to setup proper $COURSE
+        $context = get_context_instance(CONTEXT_COURSE, $course->id);
+        require_capability('moodle/course:manageactivities', $context);
 
         if (! $module = get_record("modules", "id", $cm->module)) {
             error("This module doesn't exist");
@@ -508,15 +567,15 @@
         if (! $form = get_record($module->name, "id", $cm->instance)) {
             error("The required instance of this module doesn't exist");
         }
-        
+
         if (! $cw = get_record("course_sections", "id", $cm->section)) {
             error("This course section doesn't exist");
         }
 
-        if (isset($return)) {  
+        if (isset($return)) {
             $SESSION->returnpage = "$CFG->wwwroot/mod/$module->name/view.php?id=$cm->id";
         }
-        
+
         $section = get_field('course_sections', 'section', 'id', $cm->section);
 
         $form->coursemodule = $cm->id;
@@ -526,10 +585,10 @@
         $form->modulename   = $module->name;
         $form->instance     = $cm->instance;
         $form->mode         = "add";
-        $SESSION->sesskey = !empty($USER->id) ? $USER->sesskey : '';
+        $form->sesskey      = !empty($USER->id) ? $USER->sesskey : '';
 
         $sectionname    = get_string("name$course->format");
-        $fullmodulename = strtolower(get_string("modulename", $module->name));
+        $fullmodulename = get_string("modulename", $module->name);
 
         if ($form->section) {
             $heading->what = $fullmodulename;
@@ -538,26 +597,33 @@
         } else {
             $pageheading = get_string("duplicatinga", "moodle", $fullmodulename);
         }
+        $strnav = "<a href=\"$CFG->wwwroot/mod/$module->name/view.php?id=$cm->id\">$form->name</a> ->";
 
-        
-    } else if (isset($_GET['add']) and confirm_sesskey()) {
+        $CFG->pagepath = 'mod/'.$module->name.'/mod';
 
-        if (empty($_GET['add'])) {
-            redirect($_SERVER["HTTP_REFERER"]);
-            die;
-        }
 
-        require_variable($id);
-        require_variable($section);
+    } else if (!empty($add) and confirm_sesskey()) {
+
+        $id = required_param('id',PARAM_INT);
+        $section = required_param('section',PARAM_INT);
 
         if (! $course = get_record("course", "id", $id)) {
             error("This course doesn't exist");
         }
 
-        if (! $module = get_record("modules", "name", $_GET['add'])) {
+        if (! $module = get_record("modules", "name", $add)) {
             error("This module type doesn't exist");
         }
 
+        $context = get_context_instance(CONTEXT_COURSE, $course->id);
+        require_capability('moodle/course:manageactivities', $context);
+
+        if (!course_allowed_module($course,$module->id)) {
+            error("This module has been disabled for this particular course");
+        }
+
+        require_login($course->id); // needed to setup proper $COURSE
+
         $form->section    = $section;         // The section number itself
         $form->course     = $course->id;
         $form->module     = $module->id;
@@ -565,47 +631,56 @@
         $form->instance   = "";
         $form->coursemodule = "";
         $form->mode       = "add";
-        $SESSION->sesskey = !empty($USER->id) ? $USER->sesskey : '';
-        if (isset($_GET['type'])) {
-            $form->type = $_GET['type'];
+        $form->sesskey    = !empty($USER->id) ? $USER->sesskey : '';
+        if (!empty($type)) {
+            $form->type = $type;
         }
 
         $sectionname    = get_string("name$course->format");
         $fullmodulename = get_string("modulename", $module->name);
 
-        if ($form->section) {
+        if ($form->section && $course->format != 'site') {
             $heading->what = $fullmodulename;
             $heading->to   = "$sectionname $form->section";
             $pageheading = get_string("addinganewto", "moodle", $heading);
         } else {
             $pageheading = get_string("addinganew", "moodle", $fullmodulename);
         }
+        $strnav = '';
+
+        $CFG->pagepath = 'mod/'.$module->name;
+        if (!empty($type)) {
+            $CFG->pagepath .= '/' . $type;
+        }
+        else {
+            $CFG->pagepath .= '/mod';
+        }
 
     } else {
         error("No action was specfied");
     }
 
-    if (!isteacheredit($course->id)) {
-        error("You can't modify this course!");
-    }
+    require_login($course->id); // needed to setup proper $COURSE
+    $context = get_context_instance(CONTEXT_COURSE, $course->id);
+    require_capability('moodle/course:manageactivities', $context);
 
     $streditinga = get_string("editinga", "moodle", $fullmodulename);
     $strmodulenameplural = get_string("modulenameplural", $module->name);
 
     if ($module->name == "label") {
-        $focuscursor = "";
+        $focuscursor = "form.content";
     } else {
         $focuscursor = "form.name";
     }
 
-    if ($course->category) {
-        print_header("$course->shortname: $streditinga", "$course->fullname",
-                     "<A HREF=\"$CFG->wwwroot/course/view.php?id=$course->id\">$course->shortname</A> -> 
-                      <A HREF=\"$CFG->wwwroot/mod/$module->name/index.php?id=$course->id\">$strmodulenameplural</A> -> 
-                      $streditinga", $focuscursor, "", false);
-    } else {
-        print_header("$course->shortname: $streditinga", "$course->fullname",
-                     "$streditinga", $focuscursor, "", false);
+    print_header_simple($streditinga, '',
+     "<a href=\"$CFG->wwwroot/mod/$module->name/index.php?id=$course->id\">$strmodulenameplural</a> ->
+     $strnav $streditinga", $focuscursor, "", false);
+
+    if (!empty($cm->id)) {
+        $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+        $currenttab = 'update';
+        include_once($CFG->dirroot.'/'.$CFG->admin.'/roles/tabs.php');
     }
 
     unset($SESSION->modform); // Clear any old ones that may be hanging around.
@@ -621,14 +696,14 @@
             $defaultformat = FORMAT_MOODLE;
         }
 
-        $icon = "<img align=absmiddle height=16 width=16 src=\"$CFG->modpixpath/$module->name/icon.gif\">&nbsp;";
+        $icon = '<img class="icon" src="'.$CFG->modpixpath.'/'.$module->name.'/icon.gif" alt="'.get_string('modulename',$module->name).'"/>';
 
         print_heading_with_help($pageheading, "mods", $module->name, $icon);
-        print_simple_box_start("center", "", "$THEME->cellheading");
+        print_simple_box_start('center', '', '', 5, 'generalbox', $module->name);
         include_once($modform);
         print_simple_box_end();
 
-        if ($usehtmleditor and empty($nohtmleditorneeded)) { 
+        if ($usehtmleditor and empty($nohtmleditorneeded)) {
             use_html_editor($editorfields);
         }
 
@@ -637,5 +712,4 @@
     }
 
     print_footer($course);
-
 ?>
