@@ -1,21 +1,22 @@
-<?PHP // $Id: scales.php,v 1.8.8.4 2005/01/08 10:47:00 stronk7 Exp $
+<?php // $Id: scales.php,v 1.30.2.1 2007/02/28 05:36:14 nicolasconnault Exp $
       // Allows a creator to edit custom scales, and also display help about scales
 
     require_once("../config.php");
     require_once("lib.php");
 
-    require_variable($id);             // course id
-    optional_variable($scaleid);       // scale id
-    optional_variable($action,"undefined");        // action to execute
-    optional_variable($name);          // scale name
-    optional_variable($description);   // scale description
-    optional_variable($scalescale);         // scale scale
+    $id          = required_param('id', PARAM_INT);               // course id
+    $scaleid     = optional_param('scaleid', 0, PARAM_INT);       // scale id
+    $action      = optional_param('action', 'undefined', PARAM_ALPHA); // action to execute
+    $name        = optional_param('name', '', PARAM_CLEAN);       // scale name
+    $description = optional_param('description', '', PARAM_CLEAN);// scale description
+    $list        = optional_param('list', 0, PARAM_BOOL);         // show listing in help window
 
     if (! $course = get_record("course", "id", $id)) {
         error("Course ID was incorrect");
     }
 
     require_login($course->id);
+    $context = get_context_instance(CONTEXT_COURSE, $course->id);
 
     $strscale = get_string("scale");
     $strscales = get_string("scales");
@@ -43,7 +44,7 @@
     $courses = array();
 
     /// If scale data is being submitted, then save it and continue
-
+    $focus = "";
     $errors = NULL;
 
     if ($action == 'sendform' and confirm_sesskey()) {
@@ -56,7 +57,7 @@
                 $errors[$scaleid]->scalescale = true;
                 $focus = "form$scaleid.save";
             }
-            
+
             if (!$errors) {
                 $newscale=NULL;
                 $newscale->name = $form->name;
@@ -65,7 +66,7 @@
                 $newscale->courseid = $form->courseid;
                 $newscale->userid = $USER->id;
                 $newscale->timemodified = time();
-                
+
                 if (empty($scaleid)) {
                     $newscale->courseid = $course->id;
                     if (!insert_record("scale", $newscale)) {
@@ -77,7 +78,7 @@
                         error("Could not update that scale!");
                     }
                 }
-    
+
                 $notify = "$newscale->name: $strchangessaved";
                 $focus = "form$scaleid.save";
             } else {
@@ -89,13 +90,12 @@
             }
         }
     }
-    
+
     //If action is details, show the popup info
     if ($action == "details") {
         //Check for teacher edit
-        if (! isteacheredit($course->id)) {
-            error("Only editing teachers can view scales !");
-        }
+           require_capability('moodle/course:managescales', $context);
+       
         //Check for scale
         if (! $scale = get_record("scale", "id", $scaleid)) {
             error("Scale ID was incorrect");
@@ -105,12 +105,12 @@
         //        $scales_site_uses = site_scale_used($scale->id,$courses);
         $scalemenu = make_menu_from_list($scale->scale);
 
-        print_header("$course->shortname: $strscales", "$course->fullname",
+        print_header("$course->shortname: $strscales", $course->fullname,
                  "$course->shortname -> $strscales -> $scale->name", "", "", true, "&nbsp;", "&nbsp;");
 
         close_window_button();
-  
-        echo "<p>";
+
+        echo "<p/>";
         print_simple_box_start("center");
         print_heading($scale->name);
         echo "<center>";
@@ -118,10 +118,10 @@
         echo "</center>";
         echo text_to_html($scale->description);
         print_simple_box_end();
-        echo "<p>";
+        echo "<p/>";
 
         close_window_button();
-
+        print_footer();
         exit;
     }
 
@@ -130,23 +130,22 @@
 
         $sesskey = !empty($USER->id) ? $USER->sesskey : '';
 
-        //Check for teacher edit
-        if (! isteacheredit($course->id)) {
-            error("Only editing teachers can modify scales !");
-        }
+           require_capability('moodle/course:managescales', $context);
+           
         //Check for scale if action = edit
         if ($action == "edit") {
             if (! $scale = get_record("scale", "id", $scaleid)) {
                 error("Scale ID was incorrect");
             }
         } else {
+            $scale = new object();
             $scale->id = 0;
             $scale->courseid = $course->id;
             $scale->name = "";
             $scale->scale = "";
             $scale->description = "";
         }
-            
+
         //Calculate the uses
         if ($scale->courseid == 0) {
             $scale_uses = site_scale_used($scale->id,$courses);
@@ -160,19 +159,16 @@
         }
 
         //Check for standard scales
-        if ($scale->courseid == 0 and !isadmin()) {
+        if ($scale->courseid == 0 and !has_capability('moodle/course:managescales', get_context_instance(CONTEXT_SYSTEM, SITEID))) {
             error("Only administrators can edit this scale",$CFG->wwwroot.'/course/scales.php?id='.$course->id);
         }
-        
+
         //Print out the headers
-        if (!isset($focus)) {
-            $focus = "";
-        }
-        print_header("$course->shortname: $strscales", "$course->fullname",
+        print_header("$course->shortname: $strscales", $course->fullname,
                  "<a href=\"view.php?id=$course->id\">$course->shortname</a>".
                  " -> <a href=\"scales.php?id=$course->id\">$strscales</a>".
                  " -> ".get_string("editinga","",$strscale), $focus);
-        
+
         //Title
         print_heading_with_help($strscales, "scales");
 
@@ -181,38 +177,37 @@
             $scale->scale = $form->scalescale;
             $scale->description = $form->description;
         }
-        echo "<form method=\"post\" action=\"scales.php\" name=\"form$scale->id\">";
-        echo "<table cellpadding=9 cellspacing=0 align=center class=generalbox>";
-        echo "<tr valign=top>";
+        echo "<form method=\"post\" action=\"scales.php\" id=\"form$scale->id\">";
+        echo "<table cellpadding=\"9\" cellspacing=\"0\" align=\"center\" class=\"generalbox\">";
+        echo "<tr valign=\"top\">";
         if (!empty($errors[$scale->id]->name)) {
             $class = "class=\"highlight\"";
         } else {
             $class = "";
         }
-        echo "<td align=\"right\"><p><b>$strname:</b></p></td>";
-        echo "<td $class><input type=\"text\" name=\"name\" size=\"50\" value=\"".s($scale->name)."\">";
+        echo "<td align=\"right\"><b>$strname:</b></td>";
+        echo "<td $class><input type=\"text\" name=\"name\" size=\"50\" value=\"".s($scale->name)."\" />";
         echo "</td>";
         echo "</tr>";
-        echo "<tr valign=top>";
+        echo "<tr valign=\"top\">";
         if (!empty($errors[$scale->id]->scalescale)) {
             $class = "class=\"highlight\"";
         } else {
             $class = "";
         }
-        echo "<td align=\"right\"><p><b>$strscale:</b></p></td>";
-        echo "<td $class><textarea name=\"scalescale\" cols=50 rows=2 wrap=virtual>".s($scale->scale)."</textarea>";
+        echo "<td align=\"right\"><b>$strscale:</b></td>";
+        echo "<td $class><textarea name=\"scalescale\" cols=\"50\" rows=\"2\" wrap=\"virtual\">".s($scale->scale)."</textarea>";
         echo "</td>";
         echo "</tr>";
-        echo "<tr valign=top>";
-        echo "<td align=\"right\"><p><b>$strdescription:</b></p>";
+        echo "<tr valign=\"top\">";
+        echo "<td align=\"right\"><b>$strdescription:</b>";
         helpbutton("text", $strhelptext);
         echo "</td>";
-        echo "<td><textarea name=\"description\" cols=50 rows=8 wrap=virtual>".s($scale->description)."</textarea>";
+        echo "<td><textarea name=\"description\" cols=\"50\" rows=\"8\" wrap=\"virtual\">".s($scale->description)."</textarea>";
         echo "</td>";
         echo "</tr>";
-        echo "<tr>";
         if ($scale->id) {
-            echo "<tr valign=top>";
+            echo "<tr valign=\"top\">";
             echo "<td align=\"right\">";
             echo "</td>";
             echo "<td>".get_string("usedinnplaces","",$scale_uses);
@@ -220,13 +215,13 @@
             echo "</tr>";
         }
         echo "<tr>";
-        echo "<td colspan=2 align=\"center\">";
-        echo "<input type=\"hidden\" name=\"id\" value=\"$course->id\">";
-        echo "<input type=\"hidden\" name=\"sesskey\" value=\"$sesskey\">";
-        echo "<input type=\"hidden\" name=\"courseid\" value=\"$scale->courseid\">";
-        echo "<input type=\"hidden\" name=\"scaleid\" value=\"$scale->id\">";
-        echo "<input type=\"hidden\" name=\"action\" value=\"sendform\">";
-        echo "<input type=\"submit\" name=\"save\" value=\"$strsavechanges\">";
+        echo "<td colspan=\"2\" align=\"center\">";
+        echo "<input type=\"hidden\" name=\"id\" value=\"$course->id\" />";
+        echo "<input type=\"hidden\" name=\"sesskey\" value=\"$sesskey\" />";
+        echo "<input type=\"hidden\" name=\"courseid\" value=\"$scale->courseid\" />";
+        echo "<input type=\"hidden\" name=\"scaleid\" value=\"$scale->id\" />";
+        echo "<input type=\"hidden\" name=\"action\" value=\"sendform\" />";
+        echo "<input type=\"submit\" name=\"save\" value=\"$strsavechanges\" />";
         echo "</td></tr></table>";
         echo "</form>";
         echo "<br />";
@@ -239,9 +234,7 @@
     //If action is delete, do it
     if ($action == "delete" and confirm_sesskey()) {
         //Check for teacher edit
-        if (! isteacheredit($course->id)) {
-            error("Only editing teachers can delete scales !");
-        }
+           require_capability('moodle/course:managescales', $context);
         //Check for scale if action = edit
         if (! $scale = get_record("scale", "id", $scaleid)) {
             error("Scale ID was incorrect");
@@ -260,7 +253,7 @@
         }
 
         //Check for standard scales
-        if ($scale->courseid == 0 and !isadmin()) {
+        if ($scale->courseid == 0 and !has_capability('moodle/course:managescales', get_context_instance(CONTEXT_SYSTEM, SITEID))) {
             error("Only administrators can delete this scale",$CFG->wwwroot.'/course/scales.php?id='.$course->id);
         }
 
@@ -272,9 +265,7 @@
     //If action is down or up, do it
     if (($action == "down" || $action == "up") and confirm_sesskey()) {
         //Check for teacher edit
-        if (! isadmin()) {
-            error("Only administrators can move scales",$CFG->wwwroot.'/course/scales.php?id='.$course->id);
-        }
+           require_capability('moodle/course:managescales', $context);
         //Check for scale if action = edit
         if (! $scale = get_record("scale", "id", $scaleid)) {
             error("Scale ID was incorrect");
@@ -303,12 +294,12 @@
         }
     }
 
-    if (isset($_GET['list'])) {       /// Just list the scales (in a helpwindow)
-
+    if ($list) {       /// Just list the scales (in a helpwindow)
+           require_capability('moodle/course:viewscales', $context);
         print_header($strscales);
 
-        if (isset($_GET['scale'])) {
-            if ($scale = get_record("scale", "id", "$scale")) {
+        if (!empty($scaleid)) {
+            if ($scale = get_record("scale", "id", "$scaleid")) {
                 $scalemenu = make_menu_from_list($scale->scale);
 
                 print_simple_box_start("center");
@@ -327,7 +318,7 @@
         if ($scales = get_records("scale", "courseid", "$course->id", "name ASC")) {
             print_heading($strcustomscales);
 
-            if (isteacheredit($course->id)) {
+            if (has_capability('moodle/course:managescales', get_context_instance(CONTEXT_COURSE, $course->id))) {
                 echo "<p align=\"center\">(";
                 print_string("scalestip");
                 echo ")</p>";
@@ -347,7 +338,7 @@
             }
 
         } else {
-            if (isteacheredit($course->id)) {
+            if (has_capability('moodle/course:managescales', $context)) {
                 echo "<p align=\"center\">(";
                 print_string("scalestip");
                 echo ")</p>";
@@ -377,14 +368,12 @@
 
 /// The rest is all about editing the scales
 
-    if (!isteacheredit($course->id)) {
-        error("Only editing teachers can modify scales !");
-    }
+    require_capability('moodle/course:managescales', $context);
 
 /// Print out the main page
 
-    print_header("$course->shortname: $strscales", "$course->fullname", 
-                 "<a href=\"view.php?id=$course->id\">$course->shortname</A> 
+    print_header("$course->shortname: $strscales", $course->fullname, 
+                 "<a href=\"view.php?id=$course->id\">$course->shortname</a> 
                   -> $strscales");
 
     print_heading_with_help($strscales, "scales");
@@ -397,7 +386,7 @@
     print_simple_box_start('center');
     print_single_button($CFG->wwwroot.'/course/scales.php',$options,$srtcreatenewscale,'POST');
     print_simple_box_end();
-    echo "<p>";
+    echo "<p />";
 
     if (!empty($notify)) {
         notify($notify, "green");
@@ -422,12 +411,6 @@
     if ($scales) {
         //Calculate the base path
         $path = "$CFG->wwwroot/course";
-        //Calculate pixpath
-        if (empty($THEME->custompix)) {
-            $pixpath = "$path/../pix";
-        } else {
-            $pixpath = "$path/../theme/$CFG->theme/pix";
-        }
 
         $data = array();
         $incustom = true;
@@ -439,7 +422,7 @@
                 $data[] = $line;
             }
             $line = array();
-            $line[] = "<a target=\"scale\" title=\"$scale->name\" href=\"$CFG->wwwroot/course/scales.php?id=$course->id&scaleid=$scale->id&action=details\" "."onClick=\"return openpopup('/course/scales.php?id=$course->id\&scaleid=$scale->id&action=details', 'scale', 'menubar=0,location=0,scrollbars,resizable,width=600,height=450', 0);\">".$scale->name."</a><br><font size=\"-1\">".str_replace(",",", ",$scale->scale)."</font>";
+            $line[] = "<a target=\"scale\" title=\"$scale->name\" href=\"$CFG->wwwroot/course/scales.php?id=$course->id&amp;scaleid=$scale->id&amp;action=details\" "."onclick=\"return openpopup('/course/scales.php?id=$course->id\&amp;scaleid=$scale->id&amp;action=details', 'scale', 'menubar=0,location=0,scrollbars,resizable,width=600,height=450', 0);\">".$scale->name."</a><br /><font size=\"-1\">".str_replace(",",", ",$scale->scale)."</font>";
             if (!empty($scale->courseid)) {
                 $scales_uses = course_scale_used($course->id,$scale->id);
             } else {
@@ -452,22 +435,22 @@
                 $line[] = $strstandardscale;
             }
             $buttons = "";
-            if (empty($scales_uses) && ($incustom || isadmin())) {
-                $buttons .= "<a title=\"$stredit\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=edit\"><img".
-                            " src=\"$pixpath/t/edit.gif\" hspace=2 height=11 width=11 border=0></a> ";
-                if ($incustom && isadmin()) {
-                    $buttons .= "<a title=\"$strdown\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=down&amp;sesskey=$USER->sesskey\"><img".
-                                " src=\"$pixpath/t/down.gif\" hspace=2 height=11 width=11 border=0></a> ";
+            if (empty($scales_uses) && ($incustom || has_capability('moodle/course:managescales', get_context_instance(CONTEXT_SYSTEM, SITEID)))) {
+                $buttons .= "<a title=\"$stredit\" href=\"$path/scales.php?id=$course->id&amp;scaleid=$scale->id&amp;action=edit\"><img".
+                            " src=\"$CFG->pixpath/t/edit.gif\" class=\"iconsmall\" alt=\"$stredit\" /></a> ";
+                if ($incustom && has_capability('moodle/course:managescales', get_context_instance(CONTEXT_SYSTEM, SITEID))) {
+                    $buttons .= "<a title=\"$strdown\" href=\"$path/scales.php?id=$course->id&amp;scaleid=$scale->id&amp;action=down&amp;sesskey=$USER->sesskey\"><img".
+                                " src=\"$CFG->pixpath/t/down.gif\" class=\"iconsmall\" alt=\"$strdown\" /></a> ";
                 }
-                if (!$incustom && isadmin()) {
-                    $buttons .= "<a title=\"$strup\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=up&amp;sesskey=$USER->sesskey\"><img".
-                                " src=\"$pixpath/t/up.gif\" hspace=2 height=11 width=11 border=0></a> ";
+                if (!$incustom && has_capability('moodle/course:managescales', get_context_instance(CONTEXT_SYSTEM, SITEID))) {
+                    $buttons .= "<a title=\"$strup\" href=\"$path/scales.php?id=$course->id&amp;scaleid=$scale->id&amp;action=up&amp;sesskey=$USER->sesskey\"><img".
+                                " src=\"$CFG->pixpath/t/up.gif\" class=\"iconsmall\" alt=\"$strup\" /></a> ";
                 }
-                $buttons .= "<a title=\"$strdelete\" href=\"$path/scales.php?id=$course->id&scaleid=$scale->id&action=delete&amp;sesskey=$USER->sesskey\"><img".
-                            " src=\"$pixpath/t/delete.gif\" hspace=2 height=11 width=11 border=0></a> ";
+                $buttons .= "<a title=\"$strdelete\" href=\"$path/scales.php?id=$course->id&amp;scaleid=$scale->id&amp;action=delete&amp;sesskey=$USER->sesskey\"><img".
+                            " src=\"$CFG->pixpath/t/delete.gif\" class=\"iconsmall\" alt=\"$strdelete\" /></a> ";
             }
             $line[] = $buttons;
-            
+
             $data[] = $line;
         }
         $head = $strscale.",".$stractivities.",".$strtype.",".$stroptions;
