@@ -1,4 +1,4 @@
-<?php // $Id: file.php,v 1.31.2.1 2006/07/30 22:43:58 skodak Exp $
+<?php // $Id: file.php,v 1.44.2.1 2007/04/02 16:12:26 skodak Exp $
       // This script fetches files from the dataroot directory
       // Syntax:      file.php/courseid/dir/dir/dir/filename.ext
       //              file.php/courseid/dir/dir/dir/filename.ext?forcedownload=1 (download instead of inline)
@@ -6,6 +6,11 @@
       // Workaround:  file.php?file=/courseid/dir/dir/dir/filename.ext
       // Test:        file.php/testslasharguments
 
+
+      //TODO: Blog attachments do not have access control implemented - anybody can read them!
+      //      It might be better to move the code to separate file because the access
+      //      control is quite complex - see bolg/index.php 
+
     require_once('config.php');
     require_once('lib/filelib.php');
 
@@ -14,7 +19,9 @@
     } else {
         $lifetime = $CFG->filelifetime;
     }
-    
+
+    // disable moodle specific debug messages
+    disable_debugging();
 
     $relativepath = get_file_argument('file.php');
     $forcedownload = optional_param('forcedownload', 0, PARAM_BOOL);
@@ -33,32 +40,46 @@
     if (count($args) == 0) { // always at least courseid, may search for index.html in course root
         error('No valid arguments supplied');
     }
-
+  
     // security: limit access to existing course subdirectories
-    // note: course ID must be specified
-    // note: the lang field is needed for the course language switching hack in weblib.php
-    if (!$course = get_record_sql("SELECT id, lang FROM {$CFG->prefix}course WHERE id='".(int)$args[0]."'")) {
+    if (($args[0]!='blog') and (!$course = get_record_sql("SELECT * FROM {$CFG->prefix}course WHERE id='".(int)$args[0]."'"))) {
         error('Invalid course ID');
     }
 
     // security: prevent access to "000" or "1 something" directories
-    if ($args[0] != $course->id) {
+    // hack for blogs, needs proper security check too
+    if (($args[0] != 'blog') and ($args[0] != $course->id)) {
         error('Invalid course ID');
     }
 
     // security: login to course if necessary
-    if ($course->id != SITEID) {
+    if ($args[0] == 'blog') {
+        if (empty($CFG->bloglevel)) {
+            error('Blogging is disabled!');
+        } else if ($CFG->bloglevel < BLOG_GLOBAL_LEVEL) {
+            require_login();
+        } else if ($CFG->forcelogin) {
+            require_login();
+        }
+    } else if ($course->id != SITEID) {
         require_login($course->id);
     } else if ($CFG->forcelogin) {
-        require_login();
+        if (!empty($CFG->sitepolicy)
+            and ($CFG->sitepolicy == $CFG->wwwroot.'/file.php'.$relativepath
+                 or $CFG->sitepolicy == $CFG->wwwroot.'/file.php?file='.$relativepath)) {
+            //do not require login for policy file
+        } else {
+            require_login();
+        }
     }
 
     // security: only editing teachers can access backups
-    if ((!isteacheredit($course->id))
-        and (count($args) >= 2)
-        and (strtolower($args[1]) == 'backupdata')) {
-
-        error('Access not allowed');
+    if ((count($args) >= 2) and (strtolower($args[1]) == 'backupdata')) {
+        if (!has_capability('moodle/site:backup', get_context_instance(CONTEXT_COURSE, $course->id))) {
+            error('Access not allowed');
+        } else {
+            $lifetime = 0; //disable browser caching for backups 
+        }
     }
 
     if (is_dir($pathname)) {
@@ -83,7 +104,8 @@
         and (strtolower($args[2]) == 'assignment')) {
 
         $lifetime = 0;  // do not cache assignments, students may reupload them
-        if ((!isteacher($course->id)) && (count($args) != 6 || $args[4] != $USER->id)) {
+        if (!has_capability('mod/assignment:grade', get_context_instance(CONTEXT_COURSE, $course->id))
+          and $args[4] != $USER->id) {
            error('Access not allowed');
         }
     }
@@ -101,14 +123,20 @@
             )) {
         $forcedownload  = 1; // force download of all attachments
     }
+    if ($args[0] == 'blog') {
+        $forcedownload  = 1; // force download of all attachments
+    }    
 
     // security: some protection of hidden resource files
     // warning: it may break backwards compatibility
     if ((!empty($CFG->preventaccesstohiddenfiles)) 
         and (count($args) >= 2)
-        and (!isteacher($course->id))) {
+        and (!(strtolower($args[1]) == 'moddata' and strtolower($args[2]) != 'resource')) // do not block files from other modules!
+        and (!has_capability('moodle/course:viewhiddenactivities', get_context_instance(CONTEXT_COURSE, $course->id)))) {
 
-        $reference = ltrim($relativepath, "/{$args[0]}/");
+        $rargs = $args;
+        array_shift($rargs);
+        $reference = implode('/', $rargs);
 
         $sql = "SELECT COUNT(r.id) " .
                  "FROM {$CFG->prefix}resource r, " .
@@ -131,15 +159,6 @@
         not_found($course->id);
     }
 
-    // extra security: keep symbolic links inside dataroot/courseid if required
-    /*if (!empty($CFG->checksymlinks)) {
-        $realpath = realpath($pathname);
-        $realdataroot = realpath($CFG->dataroot.'/'.$course->id);
-        if (strpos($realpath, $realdataroot) !== 0) {
-            not_found($course->id);
-        }
-    }*/
-
     // ========================================
     // finally send the file
     // ========================================
