@@ -1,4 +1,4 @@
-<?php // $Id: index.php,v 1.86.2.9 2006/10/03 18:13:47 gustav_delius Exp $
+<?php // $Id: index.php,v 1.111.2.5 2007/04/05 03:36:08 nicolasconnault Exp $
 
 //  Manage all uploaded files in a course file area
 
@@ -9,6 +9,7 @@
 
     require('../config.php');
     require($CFG->libdir.'/filelib.php');
+    require($CFG->libdir.'/adminlib.php');
 
     $id      = required_param('id', PARAM_INT);
     $file    = optional_param('file', '', PARAM_PATH);
@@ -23,7 +24,7 @@
     $confirm = optional_param('confirm', 0, PARAM_BOOL);
 
     if ($choose) {
-        if (count(explode('.', $choose)) != 2) {
+        if (count(explode('.', $choose)) > 2) {
             error('Incorrect format for choose parameter');
         }
     }
@@ -33,28 +34,26 @@
         error("That's an invalid course id");
     }
 
-    require_login($course->id);
+    require_login($course);
 
-    if (! isteacheredit($course->id) ) {
-        error("You need to be a teacher with editing privileges");
-    }
+    require_capability('moodle/course:managefiles', get_context_instance(CONTEXT_COURSE, $course->id));
 
     function html_footer() {
-        global $course, $choose;
+        global $course, $choose, $adminroot;
 
         echo '</td></tr></table>';
 
-        print_footer($course);
+        if ($course->id == SITEID) {
+                admin_externalpage_print_footer($adminroot);
+        } else {
+            print_footer($course);
+        }
     }
 
     function html_header($course, $wdir, $formfield=""){
         global $CFG, $ME, $choose;
 
-        if (! $site = get_site()) {
-            error("Invalid site!");
-        }
-
-        if ($course->id == $site->id) {
+        if ($course->id == SITEID) {
             $strfiles = get_string("sitefiles");
         } else {
             $strfiles = get_string("files");
@@ -80,43 +79,65 @@
             print_header();
 
             $chooseparts = explode('.', $choose);
-
+            if (count($chooseparts)==2){
             ?>
-            <script language="javascript" type="text/javascript">
-            <!--
+            <script type="text/javascript">
+            //<![CDATA[
             function set_value(txt) {
                 opener.document.forms['<?php echo $chooseparts[0]."'].".$chooseparts[1] ?>.value = txt;
                 window.close();
             }
-            -->
+            //]]>
             </script>
 
             <?php
-            $fullnav = str_replace('->', '&raquo;', "$course->shortname -> $fullnav");
+            } elseif (count($chooseparts)==1){
+            ?>
+            <script type="text/javascript">
+            //<![CDATA[
+            function set_value(txt) {
+                opener.document.getElementById('<?php echo $chooseparts[0] ?>').value = txt;
+                window.close();
+            }
+            //]]>
+            </script>
+
+            <?php
+
+            }
+            $fullnav = str_replace('->', '&raquo;', format_string($course->shortname) . " -> $fullnav");
             echo '<div id="nav-bar">'.$fullnav.'</div>';
 
-            if ($course->id == $site->id) {
+            if ($course->id == SITEID and $wdir != "/backupdata") {
                 print_heading(get_string("publicsitefileswarning"), "center", 2);
             }
 
         } else {
 
-            if ($course->id == $site->id) {
-                print_header("$course->shortname: $strfiles", "$course->fullname",
-                             "<a href=\"../$CFG->admin/index.php\">".get_string("administration").
-                             "</a> -> $fullnav", $formfield);
+            if ($course->id == SITEID) {
 
-                print_heading(get_string("publicsitefileswarning"), "center", 2);
+                if ($wdir == "/backupdata") {
+                    $adminroot = admin_get_root();
+                    admin_externalpage_setup('frontpagerestore', $adminroot);
+                    admin_externalpage_print_header($adminroot);
+                } else {
+                    $adminroot = admin_get_root();
+                    admin_externalpage_setup('sitefiles', $adminroot);
+                    admin_externalpage_print_header($adminroot);
+
+                    print_heading(get_string("publicsitefileswarning"), "center", 2);
+                    
+                }
 
             } else {
-                print_header("$course->shortname: $strfiles", "$course->fullname",
+                print_header("$course->shortname: $strfiles", $course->fullname,
                              "<a href=\"../course/view.php?id=$course->id\">$course->shortname".
                              "</a> -> $fullnav", $formfield);
             }
         }
 
 
-        echo "<table border=\"0\" align=\"center\" cellspacing=\"3\" cellpadding=\"3\" width=\"640\">";
+        echo "<table border=\"0\" style=\"margin-left:auto;margin-right:auto\" cellspacing=\"3\" cellpadding=\"3\" width=\"640\">";
         echo "<tr>";
         echo "<td colspan=\"2\">";
 
@@ -176,26 +197,28 @@
                 $strcancel = get_string("cancel");
 
                 echo "<p>$struploadafile ($strmaxsize) --> <b>$wdir</b></p>";
-                echo "<table><tr><td colspan=\"2\">";
                 echo "<form enctype=\"multipart/form-data\" method=\"post\" action=\"index.php\">";
+                echo "<div>";             
+                echo "<table><tr><td colspan=\"2\">";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
                 echo " <input type=\"hidden\" name=\"action\" value=\"upload\" />";
                 echo " <input type=\"hidden\" name=\"sesskey\" value=\"$USER->sesskey\" />";
                 upload_print_form_fragment(1,array('userfile'),null,false,null,$upload_max_filesize,0,false);
-                echo " </td></tr><tr><td width=\"10\">";
+                echo " </td></tr></table>";
                 echo " <input type=\"submit\" name=\"save\" value=\"$struploadthisfile\" />";
+                echo "</div>";
                 echo "</form>";
-                echo "</td><td width=\"100%\">";
                 echo "<form action=\"index.php\" method=\"get\">";
+                echo "<div>";             
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
                 echo " <input type=\"hidden\" name=\"action\" value=\"cancel\" />";
                 echo " <input type=\"submit\" value=\"$strcancel\" />";
+                echo "</div>";
                 echo "</form>";
-                echo "</td></tr></table>";
             }
             html_footer();
             break;
@@ -225,27 +248,19 @@
                     print_simple_box_end();
                     echo "<br />";
 
-                    $resourcelist = false;
-                    foreach ($USER->filelist as $file) {
-                        // If file is specified in a resource, then delete that too.
-                        $clean_name = substr($file, 1);
-                        if (record_exists('resource', 'reference', $clean_name)) {
-                            if (!$resourcelist) {
-                                print_simple_box_start("center");
-                                $resourcelist = true;
-                            }
-                            $resource_id = files_get_cm_from_resource_name($clean_name);
-                            echo '<p>'.get_string('warningdeleteresource', '', $file)." <a href='$CFG->wwwroot/course/mod.php?update=$resource_id&sesskey=$USER->sesskey'>".get_string('update')."</a></p>";
-                        }
-                    }
-                    if ($resourcelist) {
-                        print_simple_box_end();
-                        echo "<br />";
-                    }
+                    require_once($CFG->dirroot.'/mod/resource/lib.php');
+                    $block = resource_delete_warning($course, $USER->filelist);
 
-                    notice_yesno (get_string("deletecheckfiles"),
-                                "index.php?id=$id&amp;wdir=$wdir&amp;action=delete&amp;confirm=1&amp;sesskey=$USER->sesskey&amp;choose=$choose",
-                                "index.php?id=$id&amp;wdir=$wdir&amp;action=cancel&amp;choose=$choose");
+                    if (empty($CFG->resource_blockdeletingfile) or $block == '') {
+                        $optionsyes = array('id'=>$id, 'wdir'=>$wdir, 'action'=>'delete', 'confirm'=>1, 'sesskey'=>sesskey(), 'choose'=>$choose);
+                        $optionsno  = array('id'=>$id, 'wdir'=>$wdir, 'action'=>'cancel', 'choose'=>$choose);
+                        notice_yesno (get_string('deletecheckfiles'), 'index.php', 'index.php', $optionsyes, $optionsno, 'post', 'get');
+                    } else {
+
+                        notify(get_string('warningblockingdelete', 'resource'));
+                        $options  = array('id'=>$id, 'wdir'=>$wdir, 'action'=>'cancel', 'choose'=>$choose);
+                        print_continue("index.php?id=$id&amp;wdir=$wdir&amp;action=cancel&amp;choose=$choose");
+                    }
                 } else {
                     displaydir($wdir);
                 }
@@ -258,7 +273,7 @@
             if (($count = setfilelist($_POST)) and confirm_sesskey()) {
                 $USER->fileop     = $action;
                 $USER->filesource = $wdir;
-                echo "<p align=\"center\">";
+                echo "<p class=\"centerpara\">";
                 print_string("selectednowmove", "moodle", $count);
                 echo "</p>";
             }
@@ -274,7 +289,7 @@
                     $oldfile = $basedir.'/'.$file;
                     $newfile = $basedir.$wdir."/".$shortfile;
                     if (!rename($oldfile, $newfile)) {
-                        echo "<p>Error: $shortfile not moved";
+                        echo "<p>Error: $shortfile not moved</p>";
                     }
                 }
             }
@@ -291,23 +306,10 @@
                     echo "<center>Error: $name already exists!</center>";
                 } else if (!rename($basedir.$wdir."/".$oldname, $basedir.$wdir."/".$name)) {
                     echo "<p align=\"center\">Error: could not rename $oldname to $name</p>";
-                }
-
-                //if file is part of resource then update resource table as well
-                //this line only catch the root directory
-                if (record_exists('resource', 'reference', $oldname)) {
-                    set_field('resource', 'reference', $name, 'reference', $oldname);
-                }
-
-                if (get_dir_name_from_resource($oldname)) {
-                    $resources = get_dir_name_from_resource($oldname);
-                    print_simple_box_start("center");
-                    echo "<b>The following files might be referenced as a resource :</b><br>";
-                    foreach ($resources as $resource) {
-                        $resource_id = files_get_cm_from_resource_name($name);
-                        echo '<p align=\"center\">'. "$resource->reference :"."</align><a href='$CFG->wwwroot/course/mod.php?update=$resource_id&sesskey=$USER->sesskey'> ".get_string('update')."</a>";
-                    }
-                    print_simple_box_end();
+                } else {
+                    //file was renamed now update resources if needed
+                    require_once($CFG->dirroot.'/mod/resource/lib.php');
+                    resource_renamefiles($course, $wdir, $oldname, $name);
                 }
                 displaydir($wdir);
 
@@ -316,9 +318,10 @@
                 $strcancel = get_string("cancel");
                 $strrenamefileto = get_string("renamefileto", "moodle", $file);
                 html_header($course, $wdir, "form.name");
-                echo "<p>$strrenamefileto:";
+                echo "<p>$strrenamefileto:</p>";
                 echo "<table><tr><td>";
-                echo "<form action=\"index.php\" method=\"post\" name=\"form\">";
+                echo "<form action=\"index.php\" method=\"post\">";
+                echo "<fieldset class=\"invisiblefieldset\">";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
@@ -327,14 +330,17 @@
                 echo " <input type=\"hidden\" name=\"sesskey\" value=\"$USER->sesskey\" />";
                 echo " <input type=\"text\" name=\"name\" size=\"35\" value=\"$file\" />";
                 echo " <input type=\"submit\" value=\"$strrename\" />";
+                echo "</fieldset>";
                 echo "</form>";
                 echo "</td><td>";
                 echo "<form action=\"index.php\" method=\"get\">";
+                echo "<div>";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
                 echo " <input type=\"hidden\" name=\"action\" value=\"cancel\" />";
                 echo " <input type=\"submit\" value=\"$strcancel\" />";
+                echo "</div>";
                 echo "</form>";
                 echo "</td></tr></table>";
             }
@@ -359,7 +365,8 @@
                 html_header($course, $wdir, "form.name");
                 echo "<p>$strcreatefolder:</p>";
                 echo "<table><tr><td>";
-                echo "<form action=\"index.php\" method=\"post\" name=\"form\">";
+                echo "<form action=\"index.php\" method=\"post\">";
+                echo "<fieldset class=\"invisiblefieldset\">";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
@@ -367,14 +374,17 @@
                 echo " <input type=\"text\" name=\"name\" size=\"35\" />";
                 echo " <input type=\"hidden\" name=\"sesskey\" value=\"$USER->sesskey\" />";
                 echo " <input type=\"submit\" value=\"$strcreate\" />";
+                echo "</fieldset>";
                 echo "</form>";
                 echo "</td><td>";
                 echo "<form action=\"index.php\" method=\"get\">";
+                echo "<div>";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
                 echo " <input type=\"hidden\" name=\"action\" value=\"cancel\" />";
                 echo " <input type=\"submit\" value=\"$strcancel\" />";
+                echo "</div>";
                 echo "</form>";
                 echo "</td></tr></table>";
             }
@@ -406,7 +416,8 @@
                 print_heading("$streditfile");
 
                 echo "<table><tr><td colspan=\"2\">";
-                echo "<form action=\"index.php\" method=\"post\" name=\"form\">";
+                echo "<form action=\"index.php\" method=\"post\">";
+                echo "<div>";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
@@ -416,14 +427,17 @@
                 print_textarea($usehtmleditor, 25, 80, 680, 400, "text", $contents);
                 echo "</td></tr><tr><td>";
                 echo " <input type=\"submit\" value=\"".get_string("savechanges")."\" />";
+                echo "</div>";
                 echo "</form>";
                 echo "</td><td>";
                 echo "<form action=\"index.php\" method=\"get\">";
+                echo "<div>";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
                 echo " <input type=\"hidden\" name=\"action\" value=\"cancel\" />";
                 echo " <input type=\"submit\" value=\"".get_string("cancel")."\" />";
+                echo "</div>";
                 echo "</form>";
                 echo "</td></tr></table>";
 
@@ -464,7 +478,8 @@
                     echo "<br />";
                     echo "<p align=\"center\">".get_string("whattocallzip")."</p>";
                     echo "<table><tr><td>";
-                    echo "<form action=\"index.php\" method=\"post\" name=\"form\">";
+                    echo "<form action=\"index.php\" method=\"post\">";
+                    echo "<fieldset class=\"invisiblefieldset\">";
                     echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                     echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                     echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
@@ -472,14 +487,17 @@
                     echo " <input type=\"text\" name=\"name\" size=\"35\" value=\"new.zip\" />";
                     echo " <input type=\"hidden\" name=\"sesskey\" value=\"$USER->sesskey\" />";
                     echo " <input type=\"submit\" value=\"".get_string("createziparchive")."\" />";
+                    echo "<fieldset>";
                     echo "</form>";
                     echo "</td><td>";
                     echo "<form action=\"index.php\" method=\"get\">";
+                    echo "<div>";
                     echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                     echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                     echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
                     echo " <input type=\"hidden\" name=\"action\" value=\"cancel\" />";
                     echo " <input type=\"submit\" value=\"".get_string("cancel")."\" />";
+                    echo "</div>";
                     echo "</form>";
                     echo "</td></tr></table>";
                 } else {
@@ -504,14 +522,16 @@
                     error(get_string("unzipfileserror","error"));
                 }
 
-                echo "<center><form action=\"index.php\" method=\"get\">";
+                echo "<div style=\"text-align:center\"><form action=\"index.php\" method=\"get\">";
+                echo "<div>";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
                 echo " <input type=\"hidden\" name=\"action\" value=\"cancel\" />";
                 echo " <input type=\"submit\" value=\"$strok\" />";
+                echo "</div>";
                 echo "</form>";
-                echo "</center>";
+                echo "</div>";
             } else {
                 displaydir($wdir);
             }
@@ -537,7 +557,7 @@
 
                 } else {
                     echo "<table cellpadding=\"4\" cellspacing=\"2\" border=\"0\" width=\"640\" class=\"files\">";
-                    echo "<tr class=\"file\"><th align=\"left\" class=\"header name\">$strname</th><th align=\"right\" class=\"header size\">$strsize</th><th align=\"right\" class=\"header date\">$strmodified</th></tr>";
+                    echo "<tr class=\"file\"><th align=\"left\" class=\"header name\" scope=\"col\">$strname</th><th align=\"right\" class=\"header size\" scope=\"col\">$strsize</th><th align=\"right\" class=\"header date\" scope=\"col\">$strmodified</th></tr>";
                     foreach ($list as $item) {
                         echo "<tr>";
                         print_cell("left", s($item['filename']), 'name');
@@ -553,11 +573,13 @@
                     echo "</table>";
                 }
                 echo "<br /><center><form action=\"index.php\" method=\"get\">";
+                echo "<div>";
                 echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
                 echo " <input type=\"hidden\" name=\"action\" value=\"cancel\" />";
                 echo " <input type=\"submit\" value=\"$strok\" />";
+                echo "</div>";
                 echo "</form>";
                 echo "</center>";
             } else {
@@ -627,9 +649,12 @@ function clearfilelist() {
 function printfilelist($filelist) {
     global $CFG, $basedir;
 
+    $strfolder = get_string("folder");
+    $strfile   = get_string("file");
+
     foreach ($filelist as $file) {
         if (is_dir($basedir.'/'.$file)) {
-            echo "<img src=\"$CFG->pixpath/f/folder.gif\" height=\"16\" width=\"16\" alt=\"\" /> $file<br />";
+            echo "<img src=\"$CFG->pixpath/f/folder.gif\" class=\"icon\" alt=\"$strfolder\" /> $file<br />";
             $subfilelist = array();
             $currdir = opendir($basedir.'/'.$file);
             while (false !== ($subfile = readdir($currdir))) {
@@ -641,7 +666,7 @@ function printfilelist($filelist) {
 
         } else {
             $icon = mimeinfo("icon", $file);
-            echo "<img src=\"$CFG->pixpath/f/$icon\"  height=\"16\" width=\"16\" alt=\"\" /> $file<br />";
+            echo "<img src=\"$CFG->pixpath/f/$icon\"  class=\"icon\" alt=\"$strfile\" /> $file<br />";
         }
     }
 }
@@ -651,7 +676,7 @@ function print_cell($alignment='center', $text='&nbsp;', $class='') {
     if ($class) {
         $class = ' class="'.$class.'"';
     }
-    echo '<td align="'.$alignment.'" nowrap="nowrap"'.$class.'>'.$text.'</td>';
+    echo '<td align="'.$alignment.'" style="white-space:nowrap "'.$class.'>'.$text.'</td>';
 }
 
 function displaydir ($wdir) {
@@ -697,19 +722,23 @@ function displaydir ($wdir) {
     $strunzip  = get_string("unzip");
     $strlist   = get_string("list");
     $strrestore= get_string("restore");
-    $strchoose   = get_string("choose");
+    $strchoose = get_string("choose");
+    $strfolder = get_string("folder");
+    $strfile   = get_string("file");
 
 
-    echo "<form action=\"index.php\" method=\"post\" name=\"dirform\">";
+    echo "<form action=\"index.php\" method=\"post\" id=\"dirform\">";
+    echo "<div>";
     echo '<input type="hidden" name="choose" value="'.$choose.'" />';
-    echo "<hr width=\"640\" align=\"center\" noshade=\"noshade\" size=\"1\" />";
+    // echo "<hr align=\"center\" noshade=\"noshade\" size=\"1\" />";
+    echo "<hr/>";
     echo "<table border=\"0\" cellspacing=\"2\" cellpadding=\"2\" width=\"640\" class=\"files\">";
     echo "<tr>";
-    echo "<th width=\"5\"></th>";
-    echo "<th align=\"left\" class=\"header name\">$strname</th>";
-    echo "<th align=\"right\" class=\"header size\">$strsize</th>";
-    echo "<th align=\"right\" class=\"header date\">$strmodified</th>";
-    echo "<th align=\"right\" class=\"header commands\">$straction</th>";
+    echo "<th scope=\"col\"></th>";
+    echo "<th class=\"header name\" scope=\"col\">$strname</th>";
+    echo "<th class=\"header size\" scope=\"col\">$strsize</th>";
+    echo "<th class=\"header date\" scope=\"col\">$strmodified</th>";
+    echo "<th class=\"header commands\" scope=\"col\">$straction</th>";
     echo "</tr>\n";
 
     if ($wdir != "/") {
@@ -726,7 +755,8 @@ function displaydir ($wdir) {
             if ($dir == '..') {
                 $fileurl = rawurlencode(dirname($wdir));
                 print_cell();
-                print_cell('left', '<a href="index.php?id='.$id.'&amp;wdir='.$fileurl.'&amp;choose='.$choose.'"><img src="'.$CFG->pixpath.'/f/parent.gif" height="16" width="16" alt="'.get_string('parentfolder').'" /></a> <a href="index.php?id='.$id.'&amp;wdir='.$fileurl.'&amp;choose='.$choose.'">'.get_string('parentfolder').'</a>', 'name');
+                // alt attribute intentionally empty to prevent repetition in screen reader
+                print_cell('left', '<a href="index.php?id='.$id.'&amp;wdir='.$fileurl.'&amp;choose='.$choose.'"><img src="'.$CFG->pixpath.'/f/parent.gif" class="icon" alt="" />&nbsp;'.get_string('parentfolder').'</a>', 'name');
                 print_cell();
                 print_cell();
                 print_cell();
@@ -739,7 +769,7 @@ function displaydir ($wdir) {
                 $filesize = display_size(get_directory_size("$fullpath/$dir"));
                 $filedate = userdate(filemtime($filename), "%d %b %Y, %I:%M %p");
                 print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" />", 'checkbox');
-                print_cell("left", "<a href=\"index.php?id=$id&amp;wdir=$fileurl&amp;choose=$choose\"><img src=\"$CFG->pixpath/f/folder.gif\" height=\"16\" width=\"16\" border=\"0\" alt=\"Folder\" /></a> <a href=\"index.php?id=$id&amp;wdir=$fileurl&amp;choose=$choose\">".htmlspecialchars($dir)."</a>", 'name');
+                print_cell("left", "<a href=\"index.php?id=$id&amp;wdir=$fileurl&amp;choose=$choose\"><img src=\"$CFG->pixpath/f/folder.gif\" class=\"icon\" alt=\"$strfolder\" />&nbsp;".htmlspecialchars($dir)."</a>", 'name');
                 print_cell("right", $filesize, 'size');
                 print_cell("right", $filedate, 'date');
                 print_cell("right", "<a href=\"index.php?id=$id&amp;wdir=$wdir&amp;file=$filesafe&amp;action=rename&amp;choose=$choose\">$strrename</a>", 'commands');
@@ -768,18 +798,14 @@ function displaydir ($wdir) {
             echo "<tr class=\"file\">";
 
             print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" />", 'checkbox');
-            echo "<td align=\"left\" nowrap=\"nowrap\" class=\"name\">";
+            echo "<td align=\"left\" style=\"white-space:nowrap\" class=\"name\">";
             if ($CFG->slasharguments) {
                 $ffurl = str_replace('//', '/', "/file.php/$id/$fileurl");
             } else {
                 $ffurl = str_replace('//', '/', "/file.php?file=/$id/$fileurl");
             }
             link_to_popup_window ($ffurl, "display",
-                                  "<img src=\"$CFG->pixpath/f/$icon\" height=\"16\" width=\"16\" border=\"0\" alt=\"File\" />",
-                                  480, 640);
-            echo '&nbsp;';
-            link_to_popup_window ($ffurl, "display",
-                                  htmlspecialchars($file),
+                                  "<img src=\"$CFG->pixpath/f/$icon\" class=\"icon\" alt=\"$strfile\" />&nbsp;".htmlspecialchars($file),
                                   480, 640);
             echo "</td>";
 
@@ -799,7 +825,7 @@ function displaydir ($wdir) {
             } else if ($icon == "zip.gif") {
                 $edittext .= "<a href=\"index.php?id=$id&amp;wdir=$wdir&amp;file=$fileurl&amp;action=unzip&amp;sesskey=$USER->sesskey&amp;choose=$choose\">$strunzip</a>&nbsp;";
                 $edittext .= "<a href=\"index.php?id=$id&amp;wdir=$wdir&amp;file=$fileurl&amp;action=listzip&amp;sesskey=$USER->sesskey&amp;choose=$choose\">$strlist</a> ";
-                if (!empty($CFG->backup_version) and isteacheredit($id)) {
+                if (!empty($CFG->backup_version) and has_capability('moodle/site:restore', get_context_instance(CONTEXT_COURSE, $id))) {
                     $edittext .= "<a href=\"index.php?id=$id&amp;wdir=$wdir&amp;file=$filesafe&amp;action=restore&amp;sesskey=$USER->sesskey&amp;choose=$choose\">$strrestore</a> ";
                 }
             }
@@ -810,7 +836,8 @@ function displaydir ($wdir) {
         }
     }
     echo "</table>";
-    echo "<hr width=\"640\" align=\"center\" noshade=\"noshade\" size=\"1\" />";
+    echo "<hr />";
+    //echo "<hr width=\"640\" align=\"center\" noshade=\"noshade\" size=\"1\" />";
 
     echo "<table border=\"0\" cellspacing=\"2\" cellpadding=\"2\" width=\"640\">";
     echo "<tr><td>";
@@ -824,68 +851,60 @@ function displaydir ($wdir) {
                    "zip" => "$strcreateziparchive"
                );
     if (!empty($count)) {
-        choose_from_menu ($options, "action", "", "$strwithchosenfiles...", "javascript:document.dirform.submit()");
+        choose_from_menu ($options, "action", "", "$strwithchosenfiles...", "javascript:getElementById('dirform').submit()");
     }
-
+    echo "</td></tr></table>";
+    echo "</div>";
     echo "</form>";
+    echo "<table border=\"0\" cellspacing=\"2\" cellpadding=\"2\" width=\"640\"><tr>";
     echo "<td align=\"center\">";
     if (!empty($USER->fileop) and ($USER->fileop == "move") and ($USER->filesource <> $wdir)) {
         echo "<form action=\"index.php\" method=\"get\">";
+        echo "<div>";
         echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
         echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
         echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
         echo " <input type=\"hidden\" name=\"action\" value=\"paste\" />";
         echo " <input type=\"hidden\" name=\"sesskey\" value=\"$USER->sesskey\" />";
         echo " <input type=\"submit\" value=\"$strmovefilestohere\" />";
+        echo "</div>";
         echo "</form>";
     }
     echo "</td>";
     echo "<td align=\"right\">";
         echo "<form action=\"index.php\" method=\"get\">";
+        echo "<div>";
         echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
         echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
         echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
         echo " <input type=\"hidden\" name=\"action\" value=\"makedir\" />";
         echo " <input type=\"submit\" value=\"$strmakeafolder\" />";
+        echo "</div>";
         echo "</form>";
     echo "</td>";
     echo "<td align=\"right\">";
         echo "<form action=\"index.php\" method=\"get\">"; //dummy form - alignment only
+        echo "<fieldset class=\"invisiblefieldset\">";
         echo " <input type=\"button\" value=\"$strselectall\" onclick=\"checkall();\" />";
         echo " <input type=\"button\" value=\"$strselectnone\" onclick=\"uncheckall();\" />";
+        echo "</fieldset>";
         echo "</form>";
     echo "</td>";
     echo "<td align=\"right\">";
         echo "<form action=\"index.php\" method=\"get\">";
+        echo "<div>";
         echo ' <input type="hidden" name="choose" value="'.$choose.'" />';
         echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
         echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
         echo " <input type=\"hidden\" name=\"action\" value=\"upload\" />";
         echo " <input type=\"submit\" value=\"$struploadafile\" />";
+        echo "</div>";
         echo "</form>";
     echo "</td></tr>";
     echo "</table>";
-    echo "<hr width=\"640\" align=\"center\" noshade=\"noshade\" size=\"1\" />";
+    echo "<hr/>";
+    //echo "<hr width=\"640\" align=\"center\" noshade=\"noshade\" size=\"1\" />";
 
 }
 
-function files_get_cm_from_resource_name($clean_name) {
-    global $CFG;
-
-    $SQL =  'SELECT a.id  FROM '.$CFG->prefix.'course_modules a, '.$CFG->prefix.'resource b
-        WHERE a.instance = b.id AND b.reference = "'.$clean_name.'"';
-    $resource = get_record_sql($SQL);
-    return $resource->id;
-}
-
-function get_dir_name_from_resource($clean_name) {
-    global $CFG;
-
-    $LIKE    = sql_ilike();
-
-    $SQL  = 'SELECT * FROM '.$CFG->prefix.'resource WHERE reference '.$LIKE. "\"%$clean_name%\"";
-    $resource = get_records_sql($SQL);
-    return $resource;
-}
-
 ?>
