@@ -1,4 +1,4 @@
-<?PHP // $Id: algebradebug.php,v 1.8 2004/04/05 02:46:52 fiedorow Exp $
+<?PHP // $Id: algebradebug.php,v 1.18.2.1 2007/03/14 11:31:18 skodak Exp $
       // This function fetches math. images from the data directory
       // If not, it obtains the corresponding TeX expression from the cache_tex db table
       // and uses mimeTeX to create the image file
@@ -7,10 +7,22 @@
 
     require_once("../../config.php");
 
+    if (empty($CFG->textfilters)) {
+        error ('Filter not enabled!');
+    } else {
+        $filters = explode(',', $CFG->textfilters);
+        if (array_search('filter/algebra', $filters) === FALSE) {
+            error ('Filter not enabled!');
+        }
+    }
 
     $CFG->texfilterdir = "filter/tex";
     $CFG->algebrafilterdir = "filter/algebra";
     $CFG->algebraimagedir = "filter/algebra";
+    if ( (PHP_OS == "WINNT") || (PHP_OS == "WIN32") || (PHP_OS == "Windows") ) {
+      $CFG->algebrafilterdirwin = "filter\\algebra";
+    }
+
 
     $query = urldecode($_SERVER['QUERY_STRING']);
     error_reporting(E_ALL);
@@ -21,11 +33,11 @@
       $algebra = substr($query,8,$splitpos);
       $md5 = md5($algebra);
       if (strpos($query,'ShowDB') || strpos($query,'DeleteDB')) {
-	$texcache = get_record("cache_filters","filter","algebra", "md5key", $md5);
+        $texcache = get_record("cache_filters","filter","algebra", "md5key", $md5);
       }
       if (strpos($query,'ShowDB')) {
         if ($texcache) {
-	  $output = "DB cache_filters entry for $algebra\n";
+          $output = "DB cache_filters entry for $algebra\n";
           $output .= "id = $texcache->id\n";
           $output .= "filter = $texcache->filter\n";
           $output .= "version = $texcache->version\n";
@@ -41,7 +53,7 @@
           $output = "Deleting DB cache_filters entry for $algebra\n";
           $result =  delete_records("cache_filters","id",$texcache->id);
           if ($result) {
-	    $result = 1;
+            $result = 1;
           } else {
             $result = 0;
           }
@@ -51,16 +63,20 @@
         }
       }
       if (strpos($query,'TeXStage1')) {
-	$output = algebra2tex($algebra);
+        $output = algebra2tex($algebra);
       }
       if (strpos($query,'TeXStage2')) {
-	$output = algebra2tex($algebra);
+        $output = algebra2tex($algebra);
         $output = refineTeX($output);
       }
-      if (strpos($query,'ShowImage')) {
-	$output = algebra2tex($algebra);
+      if (strpos($query,'ShowImage')||strpos($query,'SlashArguments')) {
+        $output = algebra2tex($algebra);
         $output = refineTeX($output);
-        tex2image($output, $md5);
+        if (strpos($query,'ShowImage')) {
+          tex2image($output, $md5);
+        } else {
+          slasharguments($output, $md5);
+        }
       } else {   
         outputText($output);
       }
@@ -68,7 +84,7 @@
     }
 
 function algebra2tex($algebra) {
-  Global $CFG;
+  global $CFG;
   $algebra = str_replace('&lt;','<',$algebra);
   $algebra = str_replace('&gt;','>',$algebra);
   $algebra = str_replace('<>','#',$algebra);
@@ -83,12 +99,37 @@ function algebra2tex($algebra) {
   $algebra = str_replace('epsilon','zepslon',$algebra);
   $algebra = str_replace('upsilon','zupslon',$algebra);
   $algebra = preg_replace('!\r\n?!',' ',$algebra);
+  $algebra = escapeshellarg($algebra);
 
   if ( (PHP_OS == "WINNT") || (PHP_OS == "WIN32") || (PHP_OS == "Windows") ) {
-    $algebra = "\"". str_replace('"','\"',$algebra) . "\"";
-    $cmd  = "cd $CFG->dirroot/$CFG->algebrafilterdir & algebra2tex.pl $algebra";
+    $cmd  = "cd $CFG->dirroot\\$CFG->algebrafilterdirwin & algebra2tex.pl x/2";
+    $test = `$cmd`;
+    if ($test != '\frac{x}{2}') {
+      echo "There is a problem with either Perl or the script algebra2tex.pl<br/>";
+      $ecmd = $cmd . " 2>&1";
+      echo `$ecmd` . "<br/>\n";
+      echo "The shell command<br/>$cmd<br/>returned status = $status<br/>\n";
+      $commandpath = "$CFG->dirroot\\$CFG->algebrafilterdirwin\\algebra2tex.pl";
+      if (file_exists($commandpath)) {
+        echo "The file permissions of algebra2tex.pl are: " . decoct(fileperms($commandpath)) . "<br/>";
+      }
+      die;
+    }
+    $cmd  = "cd $CFG->dirroot\\$CFG->algebrafilterdirwin & algebra2tex.pl $algebra";
   } else {      
-    $algebra = escapeshellarg($algebra);
+    $cmd  = "cd $CFG->dirroot/$CFG->algebrafilterdir; ./algebra2tex.pl x/2";
+    $test = `$cmd`;
+    if ($test != '\frac{x}{2}') {
+      echo "There is a problem with either Perl or the script algebra2tex.pl<br/>";
+      $ecmd = $cmd . " 2>&1";
+      echo `$ecmd` . "<br/>\n";
+      echo "The shell command<br/>$cmd<br/>returned status = $status<br/>\n";
+      $commandpath = "$CFG->dirroot/$CFG->algebrafilterdir/algebra2tex.pl";
+      if (file_exists($commandpath)) {
+        echo "The file permissions of algebra2tex.pl are: " . decoct(fileperms($commandpath)) . "<br/>";
+      }
+      die;
+    }
     $cmd  = "cd $CFG->dirroot/$CFG->algebrafilterdir; ./algebra2tex.pl $algebra";
   }
   $texexp = `$cmd`;
@@ -163,59 +204,67 @@ function outputText($texexp) {
   echo "</pre></body></html>\n";
 }
 
-function tex2image($texexp, $md5) {
-  global $CFG;
-  $error_message1 = "Your system is not configured to run mimeTeX. ";
-  $error_message1 .= "You need to download the appropriate<br> executable ";
-  $error_message1 .= "from <a href=\"http://moodle.org/download/mimetex/\">";
-  $error_message1 .= "http://moodle.org/download/mimetex/</a>, or obtain the ";
-  $error_message1 .= "C source<br> from <a href=\"http://www.forkosh.com/mimetex.zip\">";
-  $error_message1 .= "http://www.forkosh.com/mimetex.zip</a>, compile it and ";
-  $error_message1 .= "put the executable into your<br> moodle/filter/tex/ directory. ";
-  $error_message1 .= "You also need to edit your moodle/filter/algebra/pix.php file<br>";
-  $error_message1 .= ' by adding the line<br><pre>       case "' . PHP_OS . "\":\n";
-  $error_message1 .= "           \$cmd = \"\\\\\"\$CFG->dirroot/\$CFG->texfilterdir/";
-  $error_message1 .= 'mimetex.' . strtolower(PHP_OS) . "\\\\\" -e \\\\\"\$pathname\\\\\" \". escapeshellarg(\$texexp);";
-  $error_message1 .= "</pre>You also need to add this to your algebradebug.php file.";
+function tex2image($texexp, $md5, $return=false) {
+    global $CFG;
+    $error_message1 = "Your system is not configured to run mimeTeX. ";
+    $error_message1 .= "You need to download the appropriate<br /> executable ";
+    $error_message1 .= "from <a href=\"http://moodle.org/download/mimetex/\">";
+    $error_message1 .= "http://moodle.org/download/mimetex/</a>, or obtain the ";
+    $error_message1 .= "C source<br /> from <a href=\"http://www.forkosh.com/mimetex.zip\">";
+    $error_message1 .= "http://www.forkosh.com/mimetex.zip</a>, compile it and ";
+    $error_message1 .= "put the executable into your<br /> moodle/filter/tex/ directory. ";
+    $error_message1 .= "You also need to edit your moodle/filter/algebra/pix.php file<br />";
+    $error_message1 .= ' by adding the line<br /><pre>       case "' . PHP_OS . "\":\n";
+    $error_message1 .= "           \$cmd = \"\\\\\"\$CFG->dirroot/\$CFG->texfilterdir/";
+    $error_message1 .= 'mimetex.' . strtolower(PHP_OS) . "\\\\\" -e \\\\\"\$pathname\\\\\" \". escapeshellarg(\$texexp);";
+    $error_message1 .= "</pre>You also need to add this to your algebradebug.php file.";
 
-  if ($texexp) {
-       $texexp = '\Large ' . $texexp;
-       $lifetime = 86400;
-       $image  = $md5 . ".gif";
-       $filetype = 'image/gif';
-       if (!file_exists("$CFG->dataroot/$CFG->algebraimagedir")) {
-          make_upload_directory($CFG->algebraimagedir);
-       }
-       $pathname = "$CFG->dataroot/$CFG->algebraimagedir/$image";
-       if (file_exists($pathname)) {
-	 unlink($pathname);
-       } 
-       $commandpath = "";
-       $cmd = "";
-         switch (PHP_OS) {
-       case "Linux":
-         $commandpath="$CFG->dirroot/$CFG->texfilterdir/mimetex.linux";
-         $cmd = "\"$CFG->dirroot/$CFG->texfilterdir/mimetex.linux\" -e \"$pathname\" ". escapeshellarg($texexp);
-       break;
-       case "WINNT":
-       case "WIN32":
-       case "Windows":
-	 $commandpath="$CFG->dirroot/$CFG->texfilterdir/mimetex.exe";
-	 $texexp = str_replace('"','\"',$texexp);
-	 $cmd = str_replace(' ','^ ',$commandpath);
-	 $cmd .= " ++ -e  \"$pathname\" \"$texexp\"";
-       break;
-       case "Darwin":
-	 $commandpath="$CFG->dirroot/$CFG->texfilterdir/mimetex.darwin";
-         $cmd = "\"$CFG->dirroot/$CFG->texfilterdir/mimetex.darwin\" -e \"$pathname\" ". escapeshellarg($texexp);
-       break;
-       }
-       if (!$cmd) {
-	   error($error_message1);
-       }
-       system($cmd, $status);
-  }
-  if ($texexp && file_exists($pathname)) {
+    if ($texexp) {
+        $texexp = '\Large ' . $texexp;
+        $lifetime = 86400;
+        $image  = $md5 . ".gif";
+        $filetype = 'image/gif';
+        if (!file_exists("$CFG->dataroot/$CFG->algebraimagedir")) {
+            make_upload_directory($CFG->algebraimagedir);
+        }
+        $pathname = "$CFG->dataroot/$CFG->algebraimagedir/$image";
+        if (file_exists($pathname)) {
+            unlink($pathname);
+        } 
+        $commandpath = "";
+        $cmd = "";
+        $texexp = escapeshellarg($texexp);
+        switch (PHP_OS) {
+            case "Linux":
+                $commandpath="$CFG->dirroot/$CFG->texfilterdir/mimetex.linux";
+                $cmd = "\"$CFG->dirroot/$CFG->texfilterdir/mimetex.linux\" -e \"$pathname\" $texexp";
+            break;
+            case "WINNT":
+            case "WIN32":
+            case "Windows":
+                $commandpath="$CFG->dirroot/$CFG->texfilterdir/mimetex.exe";
+                $cmd = str_replace(' ','^ ',$commandpath);
+                $cmd .= " ++ -e  \"$pathname\" $texexp";
+            break;
+            case "Darwin":
+                $commandpath="$CFG->dirroot/$CFG->texfilterdir/mimetex.darwin";
+                $cmd = "\"$CFG->dirroot/$CFG->texfilterdir/mimetex.darwin\" -e \"$pathname\" $texexp";
+            break;
+        }
+        if (!$cmd) {
+            if (is_executable("$CFG->dirroot/$CFG->texfilterdir/mimetex")) {   /// Use the custom binary
+                $commandpath="$CFG->dirroot/$CFG->texfilterdir/mimetex";
+                $cmd = "$CFG->dirroot/$CFG->texfilterdir/mimetex -e $pathname $texexp";
+            } else {
+                error($error_message1);
+            }
+        }
+        system($cmd, $status);
+    }
+    if ($return) {
+        return $image;
+    }
+    if ($texexp && file_exists($pathname)) {
            $lastmodified = filemtime($pathname);
            header("Last-Modified: " . gmdate("D, d M Y H:i:s", $lastmodified) . " GMT");
            header("Expires: " . gmdate("D, d M Y H:i:s", time() + $lifetime) . " GMT");
@@ -225,34 +274,52 @@ function tex2image($texexp, $md5) {
            header("Content-length: ".filesize($pathname));
            header("Content-type: $filetype");
            readfile("$pathname");
-   } else {
+    } else {
            $ecmd = "$cmd 2>&1";
-           echo `$ecmd` . "<br>\n";
-           echo "The shell command<br>$cmd<br>returned status = $status<br>\n";
+           echo `$ecmd` . "<br />\n";
+           echo "The shell command<br />$cmd<br />returned status = $status<br />\n";
            if ($status == 4) {
-             echo "Status corresponds to illegal instruction<br>\n";
+             echo "Status corresponds to illegal instruction<br />\n";
            } else if ($status == 11) {
-             echo "Status corresponds to bus error<br>\n";
+             echo "Status corresponds to bus error<br />\n";
            } else if ($status == 22) {
-             echo "Status corresponds to abnormal termination<br>\n";
+             echo "Status corresponds to abnormal termination<br />\n";
            }
            if (file_exists($commandpath)) {
-              echo "File size of mimetex executable  $commandpath is " . filesize($commandpath) . "<br>";
-              echo "The file permissions are: " . decoct(fileperms($commandpath)) . "<br>";
+              echo "File size of mimetex executable  $commandpath is " . filesize($commandpath) . "<br />";
+              echo "The file permissions are: " . decoct(fileperms($commandpath)) . "<br />";
               if (function_exists("md5_file")) {
-                echo "The md5 checksum of the file is " . md5_file($commandpath) . "<br>";
+                echo "The md5 checksum of the file is " . md5_file($commandpath) . "<br />";
               } else {
                 $handle = fopen($commandpath,"rb");
                 $contents = fread($handle,16384);
                 fclose($handle);
-                echo "The md5 checksum of the first 16384 bytes is " . md5($contents) . "<br>";
+                echo "The md5 checksum of the first 16384 bytes is " . md5($contents) . "<br />";
               }
            } else {
-              echo "mimetex executable $commandpath not found!<br>";
+              echo "mimetex executable $commandpath not found!<br />";
            }
            echo "Image not found!";
-   }
+    }
 }
+
+function slasharguments($texexp, $md5) {
+  global $CFG;
+  $admin = $CFG->wwwroot . '/' . $CFG->admin . '/config.php';
+  $image = tex2image($texexp,$md5,true);
+  echo "<p>If the following image displays correctly, set your ";
+  echo "<a href=\"$admin\" target=\"_blank\">Administration->Configuration->Variables</a> ";
+  echo "setting for slasharguments to file.php/1/pic.jpg: ";
+  echo "<img src=\"pix.php/$image\" align=\"absmiddle\"></p>\n";
+  echo "<p>Otherwise set it to file.php?file=/1/pic.jpg ";
+  echo "It should display correctly as ";
+  echo "<img src=\"pix.php?file=$image\" align=\"absmiddle\"></p>\n";
+  echo "<p>If neither equation image displays correctly, please seek ";
+  echo "further help at moodle.org at the ";
+  echo "<a href=\"http://moodle.org/mod/forum/view.php?id=752&username=guest\" target=\"_blank\">";
+  echo "Mathematics Tools Forum</a></p>";
+}
+
 ?>
 
 <html>
@@ -263,28 +330,30 @@ function tex2image($texexp, $md5) {
           <form action="algebradebug.php" method="get"
            target="inlineframe">
             <center>
-             <input type="text" name="algebra" size=50
-                    value="sin(z)/(x^2+y^2)">
+             <input type="text" name="algebra" size="50"
+                    value="sin(z)/(x^2+y^2)" />
             </center>
            <ol>
-           <li>First click on this button <input type="submit" name="ShowDB" value="Show DB Entry">
+           <li>First click on this button <input type="submit" name="ShowDB" value="Show DB Entry" />
                to see the cache_filters database entry for this expression.</li>
-	   <li>If the database entry looks corrupt, click on this button to delete it:
-               <input type="submit" name="DeleteDB" value="Delete DB Entry"></li>
-           <li>Now click on this button <input type="submit" name="TeXStage1" value="First Stage Tex Translation">.
+           <li>If the database entry looks corrupt, click on this button to delete it:
+               <input type="submit" name="DeleteDB" value="Delete DB Entry" /></li>
+           <li>Now click on this button <input type="submit" name="TeXStage1" value="First Stage Tex Translation" />.
                A preliminary translation into TeX will appear in the box below.</li>
-           <li>Next click on this button <input type="submit" name="TeXStage2" value="Second Stage Tex Translation">.
+           <li>Next click on this button <input type="submit" name="TeXStage2" value="Second Stage Tex Translation" />.
                A more refined translation into TeX will appear in the box below.</li>
-           <li>Finally click on this button <input type="submit" name="ShowImage" value="Show Image">
+           <li>Then click on this button <input type="submit" name="ShowImage" value="Show Image" />
                to show a graphic image of the algebraic expression.</li>
+           <li>Finally check your slash arguments setting
+               <input type="submit" name="SlashArguments" value="Check Slash Arguments" /></li>
            </ol>
-          </form> <br> <br>
+          </form> <br /> <br />
        <center>
           <iframe name="inlineframe" align="middle" width="80%" height="200">
           &lt;p&gt;Something is wrong...&lt;/p&gt; 
           </iframe>
-       </center> <br>
-<hr>
+       </center> <br />
+<hr />
 <a name="help">
 <h2>Debugging Help</h2>
 </a>
@@ -325,7 +394,7 @@ edit your moodle/filter/algebra/pix.php file to add
 <br /><?PHP echo "case &quot;" . PHP_OS . "&quot;:" ;?><br ?> to the list of operating systems
 in the switch (PHP_OS) statement. Windows users may have a problem properly
 unzipping mimetex.exe. Make sure that mimetex.exe is is <b>PRECISELY</b>
-329728 bytes in size. If not, download fresh copy from
+433152 bytes in size. If not, download fresh copy from
 <a href="http://moodle.org/download/mimetex/windows/mimetex.exe">
 http://moodle.org/download/mimetex/windows/mimetex.exe</a>. Lastly check
 the execute permissions on your mimetex binary, as outlined in item 2 above.</li>
