@@ -1,4 +1,4 @@
-<?php // $Id: displaytex.php,v 1.3 2005/07/21 07:52:09 thepurpleblob Exp $
+<?php // $Id: displaytex.php,v 1.4 2006/11/15 20:39:27 skodak Exp $
       // This script displays tex source code.
 
     require_once('../../config.php');
@@ -8,12 +8,12 @@
     // entities are usually encoded twice, first in HTML editor then in tex/filter.php
     $texexp = html_entity_decode(html_entity_decode($texexp));
     // encode all entities (saves non-ISO)
-    $texexp = htmlentities($texexp,ENT_COMPAT,get_string("thischarset","moodle"));
+    $texexp = htmlentities($texexp,ENT_COMPAT,'utf-8');
 ?>
 <html>
   <head>
     <title>TeX Source</title>
-    <meta http-equiv="content-type" content="text/html; charset=<?php echo get_string('thischarset'); ?>" />
+    <meta http-equiv="content-type" content="text/html; charset=utf-8" />
   </head>
   <body bgcolor="#FFFFFF">
     <?php echo $texexp; ?>
