@@ -1,11 +1,10 @@
-<?php // $Id: quiz.php,v 1.30.2.7 2006/10/05 15:53:19 tjhunt Exp $ 
-      // quiz.php - created with Moodle 1.5 ALPHA (2005050600)
+<?PHP // $Id: quiz.php,v 1.57.2.10 2007/05/29 17:47:25 wildgirl Exp $ 
 
-$string['30minutes'] = '30 Minutes';
+$string['1day'] = '1 Day';
 $string['1hour'] = '1 Hour';
 $string['2hours'] = '2 Hours';
+$string['30minutes'] = '30 Minutes';
 $string['6hours'] = '6 Hours';
-$string['1day'] = '1 Day';
 $string['acceptederror'] = 'Accepted error';
 $string['action'] = 'Action';
 $string['adaptive'] = 'Adaptive mode';
@@ -14,8 +13,8 @@ $string['addingquestions'] = 'This side of the page is where you manage your dat
 $string['addquestions'] = 'Add questions';
 $string['addquestionstoquiz'] = 'Add questions to current quiz';
 $string['addrandom'] = 'Add $a random questions';
-$string['addrandom1'] = ' << Add ';
-$string['addrandom2'] = 'random questions ';
+$string['addrandom1'] = '<< Add';
+$string['addrandom2'] = 'random questions';
 $string['addselectedtoquiz'] = 'Add selected to quiz';
 $string['addtoquiz'] = 'Add to quiz';
 $string['affectedstudents'] = 'Affected $a';
@@ -44,17 +43,18 @@ $string['attemptincomplete'] = 'That attempt (by $a) is not yet completed.';
 $string['attemptlast'] = 'Last attempt';
 $string['attemptquiznow'] = 'Attempt quiz now';
 $string['attempts'] = 'Attempts';
-$string['attemptsonly'] = 'Show only students with attempts';
 $string['attemptsallowed'] = 'Attempts allowed';
-$string['attemptselection'] = 'Select which attempts to analyze per user: ';
+$string['attemptselection'] = 'Select which attempts to analyze per user:';
 $string['attemptsexist'] = 'You can no longer add or remove questions.';
+$string['attemptsonly'] = 'Show only students with attempts';
 $string['attemptsunlimited'] = 'Unlimited attempts';
 $string['back'] = 'Back to preview question';
+$string['backtoquestionlist'] = 'Back to Question List';
 $string['backtoquiz'] = 'Back to quiz editing';
 $string['bestgrade'] = 'Best grade';
-$string['bothattempts'] = 'Show students with and without attempts';
 $string['blackboard'] = 'Blackboard';
 $string['blackboard_6'] = 'Blackboard V6+';
+$string['bothattempts'] = 'Show students with and without attempts';
 $string['calculated'] = 'Calculated';
 $string['calculatedquestion'] = 'Calculated Question not supported at line $a. The question will be ignored';
 $string['cannotcreatepath'] = 'Path cannot be created ($a)';
@@ -72,24 +72,28 @@ $string['categorydeleted'] = 'The category \'$a\' was deleted';
 $string['categoryinfo'] = 'Category info';
 $string['categorymove'] = 'The category \'$a->name\' contains $a->count questions (some of them may be old, hidden, questions that are still in use in some existing quizzes).<br />Please choose another category to move them to.';
 $string['categorymoveto'] = 'Move them to this category';
+$string['categorynamecantbeblank'] = 'The category name cannot be blank.';
 $string['categorynoedit'] = 'You do not have editing privileges in the category \'$a\'.';
 $string['categoryupdated'] = 'The category was successfully updated';
+$string['changessaved'] = 'Grading Changes Saved';
 $string['checkanswer'] = 'Check';
 $string['choice'] = 'Choice';
 $string['choices'] = 'Available choices';
 $string['choosedatasetproperties'] = 'Choose dataset properties';
 $string['choosefile'] = 'Choose a file';
 $string['close'] = 'Close window';
+$string['closebeforeopen'] = 'Could not update the quiz. You have specified a close date before the open date.';
 $string['closepreview'] = 'Close preview';
 $string['closereview'] = 'Close review';
 $string['comment'] = 'Comment';
 $string['commentorgrade'] = 'Make comment or override grade';
+$string['comments'] = 'Comments';
 $string['completedon'] = 'Completed on';
 $string['confirmclose'] = 'You are about to close this attempt. Once you close the attempt you will no longer be able to change your answers.';
 $string['confirmserverdelete'] = 'Are you sure you want to remove the server <b>$a</b> from the list?';
-$string['confirmstarttimelimit'] = 'The Quiz has a time limit. Are you sure that you wish to start?';
 $string['confirmstartattemptlimit'] = 'This quiz is limited to $a attempt(s). You are about to start a new attempt.  Do you wish to proceed?';
 $string['confirmstartattempttimelimit'] = 'This quiz has a time limit and is limited to $a attempt(s). You are about to start a new attempt.  Do you wish to proceed?';
+$string['confirmstarttimelimit'] = 'The Quiz has a time limit. Are you sure that you wish to start?';
 $string['containercategorycreated'] = 'This category has been created to store all the original categories moved to site level due to the causes specified below.';
 $string['continueattemptquiz'] = 'Continue the last attempt';
 $string['copyingfrom'] = 'Creating a copy of the question \'$a\'';
@@ -97,6 +101,7 @@ $string['copyingquestion'] = 'Copying a question';
 $string['correct'] = 'Correct';
 $string['correctanswer'] = 'Correct answer';
 $string['correctanswerformula'] = 'Correct Answer Formula';
+$string['correctansweris'] = 'Correct answer: $a';
 $string['correctanswerlength'] = 'Significant Figures';
 $string['correctanswers'] = 'Correct answers';
 $string['correctanswershows'] = 'Correct answer shows';
@@ -105,7 +110,7 @@ $string['countdown'] = 'Countdown';
 $string['countdownfinished'] = 'The quiz is closing, you should submit your answers now.';
 $string['countdowntenminutes'] = 'The quiz will be closing in ten minutes.';
 $string['coursetestmanager'] = 'Course Test Manager format';
-$string['createfirst'] = 'You must create some short-answer questions first. ';
+$string['createfirst'] = 'You must create some short-answer questions first.';
 $string['createmultiple'] = 'Add several random questions to quiz';
 $string['createnewquestion'] = 'Create new question';
 $string['custom'] = 'Custom format';
@@ -115,8 +120,8 @@ $string['datasetnumber'] = 'Number';
 $string['daysavailable'] = 'Days available';
 $string['decimaldigits'] = 'Decimal digits in grades';
 $string['decimalformat'] = 'decimals';
-$string['decimalpoints'] = 'Decimal points'; // unused in 1.6
-$string['decimals'] = ' with $a ';
+$string['decimalpoints'] = 'Decimal points';
+$string['decimals'] = 'with $a';
 $string['default'] = 'Default';
 $string['defaultgrade'] = 'Default question grade';
 $string['defaultinfo'] = 'The default category for questions.';
@@ -124,7 +129,7 @@ $string['delay1'] = 'Time delay between first and second attempt';
 $string['delay2'] = 'Time delay between later attempts';
 $string['deleteattemptcheck'] = 'Are you absolutely sure you want to completely delete these attempts?';
 $string['deletequestioncheck'] = 'Are you absolutely sure you want to delete \'$a\'?';
-$string['deletequestionscheck'] = 'Are you absolutely sure you want to delete the following questions? <div>$a</div>';
+$string['deletequestionscheck'] = 'Are you absolutely sure you want to delete the following questions?<br /><br />$a';
 $string['deleteselected'] = 'Delete selected';
 $string['description'] = 'Description';
 $string['discrimination'] = 'Discrim. Index';
@@ -139,6 +144,7 @@ $string['editcatquestions'] = 'Edit category questions';
 $string['editdatasets'] = 'Edit the datasets';
 $string['editingcalculated'] = 'Editing a Calculated question';
 $string['editingdescription'] = 'Editing a Description';
+$string['editingessay'] = 'Editing Essay';
 $string['editingmatch'] = 'Editing a Matching Question';
 $string['editingmultianswer'] = 'Editing Embedded Answers (Cloze)';
 $string['editingmultichoice'] = 'Editing a Multiple Choice question';
@@ -154,9 +160,12 @@ $string['editqcats'] = 'Edit questions categories';
 $string['editquestions'] = 'Edit questions';
 $string['editquiz'] = 'Edit Quiz';
 $string['editquizquestions'] = 'Edit Quiz Questions';
+$string['errorinquestion'] = 'Error in question';
 $string['errormissingquestion'] = 'Error: The system is missing the question with id $a';
 $string['errornotnumbers'] = 'Error - answers must be numeric';
 $string['errorsdetected'] = '$a error(s) detected';
+$string['essay'] = 'Essay';
+$string['essayquestions'] = 'Questions';
 $string['event1'] = 'Autosave';
 $string['event2'] = 'Save';
 $string['event3'] = 'Grade';
@@ -166,9 +175,6 @@ $string['event7'] = 'Submit';
 $string['event8'] = 'Close';
 $string['event9'] = 'Manual Grade';
 $string['examview'] = 'Examview';
-$string['existingcategory1'] = 'a literal from an already existing set of literals that are also used by other questions in this category';
-$string['existingcategory2'] = 'a file from an already existing set of files that are also used by other questions in this category';
-$string['existingcategory3'] = 'a link from an already existing set of links that are also used by other questions in this category';
 $string['export'] = 'Export';
 $string['exporterror'] = 'An error occurred during export processing';
 $string['exportfilename'] = 'quiz';
@@ -178,11 +184,17 @@ $string['exportnameformat'] = '%%Y%%m%%d-%%H%%M';
 $string['exportquestions'] = 'Export questions to file';
 $string['false'] = 'False';
 $string['feedback'] = 'Feedback';
+$string['feedbackerrorboundaryformat'] = 'Feedback grade boundaries must be either a percentage or a number. The value you entered in boundary $a is not recognised.';
+$string['feedbackerrorboundaryoutofrange'] = 'Feedback grade boundaries must be between 0%% and 100%%. The value you entered in boundary $a is out of range.';
+$string['feedbackerrorjunkinboundary'] = 'You must fill in the feedback grade boundary boxes without leaving any gaps.';
+$string['feedbackerrorjunkinfeedback'] = 'You must fill in the feedback boxes without leaving any gaps.';
+$string['feedbackerrororder'] = 'Feedback grade boundaries must in order, highest first. The value you entered in boundary $a is out of sequence.';
 $string['file'] = 'File';
 $string['fileformat'] = 'File format';
 $string['fillcorrect'] = 'Fill with correct';
-$string['filloutoneanswer'] = 'You must fill out at least one possible answer.  Answers left blank will not be used.';
-$string['filloutthreequestions'] = 'You must fill out at least three questions.  Questions left blank will not be used.';
+$string['filloutnumericalanswer'] = 'You provide at least one possible answer and tolerance. The first matching answer will be used to determine the score and feedback. If you supply some feedback with no answer at the end, that will be shown to students whose response is not matched by any of the other answers.';
+$string['filloutoneanswer'] = 'You must provide at least one possible answer. Answers left blank will not be used. \'*\' can be used as a wildcard to match any characters. The first matching answer will be used to determine the score and feedback.';
+$string['filloutthreequestions'] = 'You must provide at least three questions with matching answers. You can provide extra wrong answers by giving an answer with a blank question. Entries where both the question and the answer are blank will be ignored.';
 $string['fillouttwochoices'] = 'You must fill out at least two choices.  Choices left blank will not be used.';
 $string['finishattempt'] = 'Submit all and finish';
 $string['forceregeneration'] = 'force regeneration';
@@ -190,30 +202,44 @@ $string['formatnotfound'] = 'Import/export format $a not found';
 $string['formatnotimplemented'] = 'This format has not been correctly implemented, please post a bug report';
 $string['fractionsaddwrong'] = 'The positive grades you have chosen do not add up to 100%%<br />Instead, they add up to $a%%<br />Do you want to go back and fix this question?';
 $string['fractionsnomax'] = 'One of the answers should be 100%%, so that it is<br />possible to get a full grade for this question.<br />Do you want to go back and fix this question?';
+$string['fromfile'] = 'from file:';
 $string['functiontakesatleasttwo'] = 'The function $a must have at least two arguments';
 $string['functiontakesnoargs'] = 'The function $a does not take any arguments';
 $string['functiontakesonearg'] = 'The function $a must have exactly one argument';
 $string['functiontakesoneortwoargs'] = 'The function $a must have either one or two arguments';
 $string['functiontakestwoargs'] = 'The function $a must have exactly two arguments';
+$string['generalfeedback'] = 'General feedback';
 $string['generatevalue'] = 'Generate a new value between';
 $string['geometric'] = 'Geometric';
 $string['gift'] = 'GIFT format';
+$string['giftleftbraceerror'] = 'Could not find a {';
+$string['giftmatchingformat'] = 'Matching question answers are improperly formatted';
+$string['giftnonumericalanswers'] = 'No answers found for numerical question';
+$string['giftnovalidquestion'] = 'No valid question found';
+$string['giftqtypenotset'] = 'Question type is not set';
+$string['giftrightbraceerror'] = 'Could not find a }';
 $string['grade'] = 'Grade';
+$string['gradeall'] = 'Grade All';
 $string['gradeaverage'] = 'Average grade';
+$string['gradeboundary'] = 'Grade boundary';
+$string['gradeessays'] = 'Grade Essays';
 $string['gradehighest'] = 'Highest grade';
 $string['grademethod'] = 'Grading method';
-$string['gradingdetails'] = 'Marks for this submission: $a->raw/$a->max. ';
-$string['gradingdetailsadjustment'] = 'With previous penalties this gives <strong>$a->cur/$a->max</strong>. ';
-$string['gradingdetailspenalty'] = 'This submission attracted a penalty of $a. ';
-$string['gradingdetailszeropenalty'] = 'You were not penalized for this submission. ';
+$string['gradesofar'] = '$a->method: $a->mygrade / $a->quizgrade.';
+$string['gradingdetails'] = 'Marks for this submission: $a->raw/$a->max.';
+$string['gradingdetailsadjustment'] = 'With previous penalties this gives <strong>$a->cur/$a->max</strong>.';
+$string['gradingdetailspenalty'] = 'This submission attracted a penalty of $a.';
+$string['gradingdetailszeropenalty'] = 'You were not penalized for this submission.';
 $string['guestsno'] = 'Sorry, guests cannot see or attempt quizzes';
-$string['history'] = 'History of Responses: ';
+$string['history'] = 'History of Responses:';
 $string['hotpot'] = 'Hot Potatoes format';
 $string['illegalformulasyntax'] = 'Illegal formula syntax starting with \'$a\'';
 $string['imagedisplay'] = 'Image to display';
 $string['imagemissing'] = 'Image not available at line $a. The filename will be ignored';
 $string['import'] = 'Import';
+$string['importcategory'] = 'import category';
 $string['importerror'] = 'An error occurred during import processing';
+$string['importerrorquestion'] = 'Error importing question';
 $string['importfilearea'] = 'Import from file already in course files...';
 $string['importfileupload'] = 'Import from file upload...';
 $string['importfromthisfile'] = 'Import from this file';
@@ -226,6 +252,9 @@ $string['incorrect'] = 'Incorrect';
 $string['indivresp'] = 'Responses of Individuals to Each Item';
 $string['info'] = 'Info';
 $string['introduction'] = 'Introduction';
+$string['invalidcategory'] = 'Category ID is invalid';
+$string['invalidnumericanswer'] = 'One of the answers you entered was not a valid number.';
+$string['invalidnumerictolerance'] = 'One of the tolerances you entered was not a valid number.';
 $string['invalidsource'] = 'The source is not accepted as valid.';
 $string['invalidsourcetype'] = 'Invalid source type.';
 $string['itemanal'] = 'Item Response Analysis';
@@ -233,12 +262,6 @@ $string['itemdefinition'] = 'Definition';
 $string['itemsource'] = 'Item Source';
 $string['itemsourceformat'] = 'Item Source Format';
 $string['itemtypes'] = 'Remote Question Types';
-$string['keptcategory1'] = 'a literal from the same category reusable set of literals as before';
-$string['keptcategory2'] = 'a file from the same category reusable set of files as before';
-$string['keptcategory3'] = 'a link from the same category reusable set of links as before';
-$string['keptlocal1'] = 'a literal from the same question private set of literals as before';
-$string['keptlocal2'] = 'a file from the same question private set of files as before';
-$string['keptlocal3'] = 'a link from the same question private set of links as before';
 $string['lastanswer'] = 'Your last answer was';
 $string['learnwise'] = 'Learnwise format';
 $string['link'] = 'Link';
@@ -253,6 +276,7 @@ $string['markall'] = 'Submit page';
 $string['marks'] = 'Marks';
 $string['match'] = 'Matching';
 $string['matchanswer'] = 'Matching answer';
+$string['matchanswerno'] = 'Matching answer $a';
 $string['matcherror'] = 'Grades do not match grade options - question skipped';
 $string['matchgrades'] = 'Match grades';
 $string['matchgradeserror'] = 'Error if grade not listed';
@@ -277,28 +301,26 @@ $string['multipleanswers'] = 'Choose at least one answer.';
 $string['multiplier'] = 'Multiplier';
 $string['name'] = 'Name';
 $string['newattemptfail'] = 'Error: Could not start a new attempt at the quiz';
-$string['newcategory1'] = 'a literal from a new set of literals that may also be used by other questions in this category';
-$string['newcategory2'] = 'a file from a new set of files that may also be used by other questions in this category';
-$string['newcategory3'] = 'a link from a new set of links that may also be used by other questions in this category';
-$string['newlocal1'] = 'a literal from a new set of literals that will only be used by this question';
-$string['newlocal2'] = 'a file  from a new set of files that will only be used by this question';
-$string['newlocal3'] = 'a link from a new set of links that will only be used by this question';
 $string['noanswers'] = 'No answers were selected!';
 $string['noattempts'] = 'No attempts have been made on this quiz';
 $string['noattemptstoshow'] = 'There are no attempts to show';
 $string['nocategory'] = 'Incorrect or no category specified';
+$string['nocommentsyet'] = 'No comments yet.';
 $string['noconnection'] = 'There is currently no connection to a web service that can process this question. Please contact your administrator';
 $string['nodataset'] = 'nothing - it is not a wild card';
+$string['noessayquestionsfound'] = 'No manually graded questions found';
+$string['nomatchinganswer'] = 'You must specify an answer matching the question \'$a\'.';
 $string['nominal'] = 'Nominal';
 $string['nomoreattempts'] = 'No more attempts are allowed';
+$string['none'] = 'None';
 $string['nopossibledatasets'] = 'No possible datasets';
 $string['noquestionintext'] = 'The question text does not contain any embedded questions';
 $string['noquestions'] = 'No questions have been added yet';
 $string['noquestionsfound'] = 'No questions found';
+$string['noquestionsinfile'] = 'There are no questions in the import file';
 $string['noresponse'] = 'No Response';
 $string['noreview'] = 'You are not allowed to review this quiz';
 $string['noreviewuntil'] = 'You are not allowed to review this quiz until $a';
-$string['noquestionsinfile'] = 'There are no questions in the import file';
 $string['noscript'] = 'JavaScript must be enabled to continue!';
 $string['notavailable'] = 'Sorry, this quiz is not available';
 $string['notavailabletostudents'] = 'Note: This quiz is not currently available to your students';
@@ -308,21 +330,23 @@ $string['notimedependentitems'] = 'Time dependent items are not currently suppor
 $string['numattempts'] = '$a->studentnum $a->studentstring have made $a->attemptnum attempts';
 $string['numberabbr'] = '#';
 $string['numerical'] = 'Numerical';
-$string['none']= 'None';
-$string['onlyteachersimport'] = 'Only teachers with editing rights can import questions';
 $string['onlyteachersexport'] = 'Only teachers can export questions';
+$string['onlyteachersimport'] = 'Only teachers with editing rights can import questions';
 $string['optional'] = 'optional';
 $string['outof'] = '$a->grade out of a maximum of $a->maxgrade';
+$string['overallfeedback'] = 'Overall feedback';
 $string['overdue'] = 'Overdue';
-$string['pagesize'] = 'Attempts shown per page: ';
+$string['pagesize'] = 'Attempts shown per page:';
 $string['paragraphquestion'] = 'Paragraph Question not supported at line $a. The question will be ignored';
 $string['parent'] = 'Parent';
+$string['parsingquestions'] = 'Parsing questions from import file.';
 $string['partiallycorrect'] = 'Partially correct';
 $string['passworderror'] = 'The password entered was incorrect';
 $string['penalty'] = 'Penalty';
 $string['penaltyfactor'] = 'Penalty factor';
 $string['penaltyscheme'] = 'Apply penalties';
 $string['percentcorrect'] = 'Percent Correct';
+$string['pleaseclose'] = 'Your request has been processed. You can now close this window';
 $string['popup'] = 'Show quiz in a &quot;secure&quot; window';
 $string['popupblockerwarning'] = 'This section of the test is in secure mode, this means that you need to take the quiz in a secure window. Please turn off your popup blocker. Thank you.';
 $string['popupnotice'] = 'Students will see this quiz in a secure window';
@@ -336,16 +360,27 @@ $string['qti'] = 'IMS QTI format';
 $string['qti2'] = 'IMS QTI 2.0 format';
 $string['question'] = 'Question';
 $string['questioncats'] = 'Question Categories';
-$string['questionsinclhidden'] = 'Questions (including hidden)';
 $string['questiondeleted'] = 'This question has been deleted. Please contact your teacher';
 $string['questioninuse'] = 'The question \'$a->questionname\' is currently being used in: <br />$a->quiznames<br />The question will not be deleted from these quizzes but only from the category list.';
 $string['questionname'] = 'Question name';
 $string['questionnametoolong'] = 'Question name too long at line $a (255 char. max). It has been truncated.';
+$string['questionno'] = 'Question $a';
 $string['questions'] = 'Questions';
+$string['questionsinclhidden'] = 'Questions (including hidden)';
 $string['questionsinuse'] = '(* Questions marked by an asterisk are already in use in some quizzes. These question will not be deleted from these quizzes but only from the category list.)';
+$string['questionsinthisquiz'] = 'Questions in this quiz';
 $string['questionsperpage'] = 'Questions per page';
+$string['questiontext'] = 'Question text';
 $string['questiontype'] = 'Question type $a';
 $string['questiontypesetupoptions'] = 'Setup options for question types:';
+$string['quiz:attempt'] = 'Attempt quizzes';
+$string['quiz:deleteattempts'] = 'Delete quiz attempts';
+$string['quiz:grade'] = 'Grade quizzes manually';
+$string['quiz:ignoretimelimits'] = 'Ignores time limit on quizzes';
+$string['quiz:manage'] = 'Manage quizzes';
+$string['quiz:preview'] = 'Preview quizzes';
+$string['quiz:view'] = 'View quiz information';
+$string['quiz:viewreports'] = 'View quiz reports';
 $string['quizavailable'] = 'The quiz is available until: $a';
 $string['quizclose'] = 'Close the quiz';
 $string['quizclosed'] = 'This quiz closed on $a';
@@ -353,9 +388,9 @@ $string['quizcloses'] = 'Quiz closes';
 $string['quiznotavailable'] = 'The quiz will not be available until: $a';
 $string['quizopen'] = 'Open the quiz';
 $string['quizopens'] = 'Quiz opens';
+$string['quizsettings'] = 'Quiz settings';
 $string['quiztimelimit'] = 'Time limit: $a';
 $string['quiztimer'] = 'Quiz Timer';
-$string['pleaseclose'] = 'Your request has been processed. You can now close this window';
 $string['random'] = 'Random Question';
 $string['randomcreate'] = 'Create Random Questions';
 $string['randomsamatch'] = 'Random Short-Answer Matching';
@@ -376,7 +411,7 @@ $string['relative'] = 'Relative';
 $string['remove'] = 'Remove';
 $string['rename'] = 'Rename';
 $string['renderingserverconnectfailed'] = 'The server $a failed to process an RQP request. Check that the URL is correct.';
-$string['reordertool'] = 'Show the reordering tool ';
+$string['reordertool'] = 'Show the reordering tool';
 $string['repaginate'] = 'Repaginate with $a questions per page';
 $string['replace'] = 'Replace';
 $string['replacementoptions'] = 'Replacement Options';
@@ -441,48 +476,51 @@ $string['showfeedback'] = 'After answering, show feedback?';
 $string['showhidden'] = 'Also show old questions';
 $string['shownoattempts'] = 'Show students with no attempts';
 $string['shownoattemptsonly'] = 'Show only students with no attempts';
+$string['showquestiontext'] = 'Show question text in the question list';
 $string['showteacherattempts'] = 'Show teacher attempts';
 $string['shuffle'] = 'Shuffle';
 $string['shuffleanswers'] = 'Shuffle answers';
 $string['shufflequestions'] = 'Shuffle questions';
 $string['shufflewithin'] = 'Shuffle within questions';
-$string['significantfigures'] = ' with $a ';
+$string['significantfigures'] = 'with $a';
 $string['significantfiguresformat'] = 'significant figures';
 $string['singleanswer'] = 'Choose one answer.';
+$string['sortage'] = 'Sort by age';
 $string['sortalpha'] = 'Sort by name';
-$string['sortage']   = 'Sort by age';
-$string['sortsubmit']   = 'Sort questions';
+$string['sortsubmit'] = 'Sort questions';
 $string['sorttypealpha'] = 'Sort by type, name';
 $string['startagain'] = 'Start again';
-$string['startagain'] = 'Start again';
-$string['startagain'] = 'Start again';
 $string['startedon'] = 'Started on';
+$string['stoponerror'] = 'Stop on error';
 $string['subneterror'] = 'Sorry, this quiz has been locked so that it is only accessible from certain locations.  Currently your computer is not one of those allowed to use this quiz.';
 $string['subnetnotice'] = 'This quiz has been locked so that it is only accessible from certain locations. Your computer is not on an allowed subnet. As teacher you are allowed to preview anyway.';
 $string['substitutedby'] = 'will be substituted by';
-$string['temporaryblocked'] = 'You are temporarily not allowed to re-attempt the quiz.<br /> You will be able to take another attempt on: ';
+$string['temporaryblocked'] = 'You are temporarily not allowed to re-attempt the quiz.<br /> You will be able to take another attempt on:';
 $string['time'] = 'Time';
-$string['timedelay'] = 'You are not allowed to do the quiz since you have not passed the time delay before attempting another quiz';
 $string['timecompleted'] = 'Completed';
+$string['timedelay'] = 'You are not allowed to do the quiz since you have not passed the time delay before attempting another quiz';
 $string['timeleft'] = 'Time Remaining';
 $string['timelimit'] = 'Time limit';
 $string['timelimitexeeded'] = 'Sorry! Quiz time limit exceeded!';
 $string['timestr'] = '%%H:%%M:%%S on %%d/%%m/%%y';
 $string['timesup'] = 'Time is up!';
 $string['timetaken'] = 'Time taken';
+$string['tofile'] = 'to file';
 $string['tolerance'] = 'Tolerance';
 $string['tolerancetype'] = 'Tolerance Type';
 $string['toomanyrandom'] = 'The number of random questions required is more than are still available in the category!';
 $string['top'] = 'Top';
 $string['true'] = 'True';
 $string['truefalse'] = 'True/False';
+$string['truefalseimporterror'] = '<b>Warning</b>: The True/False question \'$a->questiontext\' could not be imported properly. It was not clear whether the correct answer is True of False. The question has been imported assuming that the answer is \'$a->answer\'. If this is not correct, you will need to edit the question.';
 $string['type'] = 'Type';
 $string['unfinished'] = 'open';
+$string['ungraded'] = 'Ungraded';
 $string['uniform'] = 'decimals, from a uniform distribution';
 $string['unit'] = 'Unit';
 $string['unknowntype'] = 'Question type not supported at line $a. The question will be ignored';
-$string['unusedcategorydeleted'] = 'This category has been deleted because, after deleting the course, its questions weren\'t used anymore.';
 $string['unsupportedformulafunction'] = 'The function $a is not supported';
+$string['unusedcategorydeleted'] = 'This category has been deleted because, after deleting the course, its questions weren\'t used anymore.';
 $string['updatesettings'] = 'Update quiz settings';
 $string['upgradesure'] = '<div style=\"color: red;\">In particular the quiz module will perform an extensive change of the quiz tables and this upgrade has not yet been sufficiently tested. You are very strongly urged to backup your database tables before proceeding.</div>';
 $string['url'] = 'URL';
@@ -492,29 +530,19 @@ $string['viewallanswers'] = 'View $a quiz attempts';
 $string['viewallreports'] = 'View reports for $a attempts';
 $string['warningmissingtype'] = '<b>This question is of a type that has not been installed on your Moodle yet.<br />Please alert your Moodle administrator.</b>';
 $string['warningsdetected'] = '$a warning(s) detected';
-$string['wheregrade'] = 'Where\'s my grade?';
 $string['webct'] = 'WebCT format';
+$string['wheregrade'] = 'Where\'s my grade?';
 $string['wildcard'] = 'Wild card';
 $string['withselected'] = 'With selected';
 $string['withsummary'] = 'with Summary Statistics';
-$string['wronggrade'] = 'Wrong grade (after line $a) : ';
+$string['wronggrade'] = 'Wrong grade (after line $a) :';
 $string['wronguse'] = 'You can not use this page like that';
 $string['xhtml'] = 'XHTML Format';
 $string['xml'] = 'Moodle XML format';
+$string['xmlimportnoname'] = 'Missing question name in xml file';
+$string['xmlimportnoquestion'] = 'Missing question text in xml file';
 $string['xmltypeunsupported'] = 'Question type $a is not supported by xml import';
-$string['yourfinalgradeis'] = 'Your final grade for this quiz is $a';
+$string['yourfinalgradeis'] = 'Your final grade for this quiz is $a.';
 $string['zerosignificantfiguresnotallowed'] = 'The correct answer cannot have zero significant figures!';
 
-$string['backtoquestionlist'] = 'Back to Question List';
-$string['changessaved'] = 'Grading Changes Saved';
-$string['comments'] = 'Comments';
-$string['editingessay'] = 'Editing Essay';
-$string['essay'] = 'Essay';
-$string['essayquestions'] = 'Questions';
-$string['gradeall'] = 'Grade All';
-$string['gradeessays'] = 'Grade Essays';
-$string['nocommentsyet'] = 'No comments yet.';
-$string['noessayquestionsfound'] = 'No manually graded questions found';
-$string['ungraded'] = 'Ungraded';
-
-?>
\ No newline at end of file
+?>
