@@ -1,7 +1,7 @@
 <?php
 
 /**
-  V4.71 24 Jan 2006  (c) 2000-2006 John Lim (jlim@natsoft.com.my). All rights reserved.
+  V4.93 10 Oct 2006  (c) 2000-2006 John Lim (jlim#natsoft.com.my). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence.
@@ -32,7 +32,7 @@ class ADODB2_informix extends ADODB_DataDict {
 		case 'B': return 'BLOB';
 			
 		case 'D': return 'DATE';
-		case 'T': return 'DATETIME';
+		case 'T': return 'DATETIME YEAR TO SECOND';
 		
 		case 'L': return 'SMALLINT';
 		case 'I': return 'INTEGER';
