@@ -1,4 +1,4 @@
-<?php // $Id: coursefiles.php,v 1.2.2.1 2006/05/21 08:08:48 skodak Exp $
+<?php // $Id: coursefiles.php,v 1.13 2007/01/27 23:23:45 skodak Exp $
 
 //  Manage all uploaded files in a course file area
 
@@ -30,11 +30,8 @@
         error("That's an invalid course id");
     }
 
-    require_login($course->id);
-
-    if (! isteacheredit($course->id) ) {
-        error("Only teachers can edit files");
-    }
+    require_login($course);
+    require_capability('moodle/course:managefiles', get_context_instance(CONTEXT_COURSE, $id));
 
     function html_footer() {
         echo "\n\n</body>\n</html>";
@@ -49,10 +46,12 @@
             "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
         <html>
         <head>
-        <meta http-equiv="content-type" content="text/html; charset=<?php print_string("thischarset");?>" />
+        <meta http-equiv="content-type" content="text/html; charset=utf-8" />
         <title>coursefiles</title>
-        <script language="javscript" type="text/javascript">
-        <!--
+        <script type="text/javascript">
+//<![CDATA[
+
+
         function set_value(params) {
             /// function's argument is an object containing necessary values
             /// to export parent window (url,isize,itype,iwidth,iheight, imodified)
@@ -120,9 +119,8 @@
         }
 
         function set_rename(strfile) {
-            if(window.parent.document.irename != null) {
-                window.parent.document.irename.file.value = strfile;
-            }
+            var upper = window.parent.document;
+            upper.getElementById('irename').value = strfile;
             return true;
         }
 
@@ -140,11 +138,8 @@
                     }
                 }
             }
+            upper.getElementById('irename').value = 'xx';
 
-            var ren = upper.getElementById('irename');
-            if(ren != null) {
-                upper.irename.file.value = "";
-            }
             var prev = window.parent.ipreview;
             if(prev != null) {
                 prev.location.replace('about:blank');
@@ -153,13 +148,12 @@
             if(uploader != null) {
                 uploader.reset();
             }
-            set_dir('<?php print(!empty($_REQUEST['wdir'])) ? $_REQUEST['wdir'] : "";?>');
+            set_dir('<?php print($wdir);?>');
             return true;
         }
-        -->
+//]]>
         </script>
         <style type="text/css">
-        <!--
         body {
             background-color: white;
             margin-top: 2px;
@@ -171,11 +165,17 @@
             font-size: 11px;
         }
         select {
-        position: absolute;
-        top: -20px;
-        left: 0px;
+            position: absolute;
+            top: -20px;
+            left: 0px;
+        }
+        img.icon {
+          vertical-align:middle;
+          margin-right:4px;
+          width:16px;
+          height:16px;
+          border:0px;
         }
-        -->
         </style>
         </head>
         <body onload="reset_value();">
@@ -192,18 +192,10 @@
 //  End of configuration and access control
 
 
-    if (!$wdir) {
-        $wdir="/";
+    if ($wdir == '') {
+        $wdir='/';
     }
 
-    if (($wdir != '/' and detect_munged_arguments($wdir, 0))
-      or ($file != '' and detect_munged_arguments($file, 0))) {
-        $message = "Error: Directories can not contain \"..\"";
-        $wdir = "/";
-        $action = "";
-    }
-
-
     switch ($action) {
 
         case "upload":
@@ -318,10 +310,9 @@
             if (!empty($name) and confirm_sesskey()) {
                 html_header($course, $wdir);
                 $name    = clean_filename($name);
-                $oldname = clean_filename($oldname);
                 if (file_exists($basedir.$wdir."/".$name)) {
                     echo "Error: $name already exists!";
-                } else if (!rename($basedir.$wdir."/".$oldname, $basedir.$wdir."/".$name)) {
+                } else if (!@rename($basedir.$wdir."/".$oldname, $basedir.$wdir."/".$name)) {
                     echo "Error: could not rename $oldname to $name";
                 }
                 displaydir($wdir);
@@ -333,12 +324,12 @@
                 html_header($course, $wdir, "form.name");
                 echo "<p>$strrenamefileto:";
                 echo "<table border=\"0\">\n<tr>\n<td>\n";
-                echo "<form action=\"coursefiles.php\" method=\"post\" name=\"form\">\n";
+                echo "<form action=\"coursefiles.php\" method=\"post\" id=\"form\">\n";
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />\n";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />\n";
                 echo " <input type=\"hidden\" name=\"action\" value=\"rename\" />\n";
                 echo " <input type=\"hidden\" name=\"sesskey\" value=\"$USER->sesskey\" />\n";
-                echo " <input type=\"hidden\" name=oldname value=\"$file\" />\n";
+                echo " <input type=\"hidden\" name=\"oldname\" value=\"$file\" />\n";
                 echo " <input type=\"text\" name=\"name\" size=\"35\" value=\"$file\" />\n";
                 echo " <input type=\"submit\" value=\"$strrename\" />\n";
                 echo "</form>\n";
@@ -429,7 +420,7 @@
                 echo "</td></tr></table>\n";
 
                 if ($usehtmleditor) {
-                    print_richedit_javascript("form", "text", "yes");
+                    use_html_editor("text");
                 }
 
 
@@ -470,7 +461,7 @@
                     echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />\n";
                     echo " <input type=\"hidden\" name=\"action\" value=\"zip\" />\n";
                     echo " <input type=\"hidden\" name=\"sesskey\" value=\"$USER->sesskey\" />\n";
-                    echo " <INPUT TYPE=text name=name SIZE=35 value=\"new.zip\" />\n";
+                    echo " <INPUT type=\"text\" name=\"name\" size=\"35\" value=\"new.zip\" />\n";
                     echo " <input type=\"submit\" value=\"".get_string("createziparchive")."\" />";
                     echo "</form>\n";
                     echo "</td>\n<td>\n";
@@ -535,7 +526,7 @@
 
                 } else {
                     echo "<table cellpadding=\"4\" cellspacing=\"2\" border=\"0\">\n";
-                    echo "<tr>\n<th align=\"left\">$strname</th><th align=\"right\">$strsize</th><th align=\"right\">$strmodified</th></tr>";
+                    echo "<tr>\n<th align=\"left\" scope=\"col\">$strname</th><th align=\"right\" scope=\"col\">$strsize</th><th align=\"right\" scope=\"col\">$strmodified</th></tr>";
                     foreach ($list as $item) {
                         echo "<tr>";
                         print_cell("left", $item['filename']);
@@ -610,7 +601,7 @@ function printfilelist($filelist) {
 
     foreach ($filelist as $file) {
         if (is_dir($basedir.$file)) {
-            echo "<img src=\"$CFG->pixpath/f/folder.gif\" height=\"16\" width=\"16\" alt=\"\" /> $file<br />";
+            echo "<img src=\"$CFG->pixpath/f/folder.gif\" class=\"icon\" alt=\"".get_string('folder')."\" /> $file<br />";
             $subfilelist = array();
             $currdir = opendir($basedir.$file);
             while (false !== ($subfile = readdir($currdir))) {
@@ -622,7 +613,7 @@ function printfilelist($filelist) {
 
         } else {
             $icon = mimeinfo("icon", $file);
-            echo "<img src=\"$CFG->pixpath/f/$icon\"  height=\"16\" width=\"16\" alt=\"\" /> $file<br />";
+            echo "<img src=\"$CFG->pixpath/f/$icon\"  class=\"icon\" alt=\"".get_string('file')."\" /> $file<br />";
         }
     }
 }
@@ -707,7 +698,7 @@ function displaydir ($wdir) {
         }
         print "<tr>\n<td colspan=\"5\">";
         print "<a href=\"coursefiles.php?id=$id&amp;wdir=$bdir&amp;usecheckboxes=$usecheckboxes\" onclick=\"return reset_value();\">";
-        print "<img src=\"$CFG->wwwroot/lib/editor/htmlarea/images/folderup.gif\" height=\"14\" width=\"24\" border=\"0\" alt=\"Move up\" />";
+        print "<img src=\"$CFG->wwwroot/lib/editor/htmlarea/images/folderup.gif\" height=\"14\" width=\"24\" border=\"0\" alt=\"".get_string('parentfolder')."\" />";
         print "</a></td>\n</tr>\n";
     }
 
@@ -720,16 +711,15 @@ function displaydir ($wdir) {
             $count++;
 
             $filename = $fullpath."/".$dir;
-            $fileurl  = rawurlencode($wdir."/".$dir);
-            $filesafe = rawurlencode($dir);
+            $fileurl  = $wdir."/".$dir;
             $filedate = userdate(filemtime($filename), "%d %b %Y, %I:%M %p");
 
             echo "<tr>";
 
             if ($usecheckboxes) {
-                print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" onclick=\"return set_rename('$filesafe');\" />");
+                print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" onclick=\"return set_rename('$dir');\" />");
             }
-            print_cell("left", "<a href=\"coursefiles.php?id=$id&amp;wdir=$fileurl\" onclick=\"return reset_value();\"><img src=\"$CFG->pixpath/f/folder.gif\" height=\"16\" width=\"16\" border=\"0\" alt=\"folder\" /></a> <a href=\"coursefiles.php?id=$id&amp;wdir=$fileurl&amp;usecheckboxes=$usecheckboxes\" onclick=\"return reset_value();\">".htmlspecialchars($dir)."</a>");
+            print_cell("left", "<a href=\"coursefiles.php?id=$id&amp;wdir=$fileurl\" onclick=\"return reset_value();\"><img src=\"$CFG->pixpath/f/folder.gif\" class=\"icon\" alt=\"".get_string('folder')."\" /></a> <a href=\"coursefiles.php?id=$id&amp;wdir=$fileurl&amp;usecheckboxes=$usecheckboxes\" onclick=\"return reset_value();\">".htmlspecialchars($dir)."</a>");
             print_cell("right", "&nbsp;");
             print_cell("right", $filedate);
 
@@ -748,8 +738,6 @@ function displaydir ($wdir) {
             $count++;
             $filename    = $fullpath."/".$file;
             $fileurl     = "$wdir/$file";
-            $filesafe    = rawurlencode($file);
-            $fileurlsafe = rawurlencode($fileurl);
             $filedate    = userdate(filemtime($filename), "%d %b %Y, %I:%M %p");
 
             $dimensions = get_image_size($filename);
@@ -764,7 +752,7 @@ function displaydir ($wdir) {
             echo "<tr>\n";
 
             if ($usecheckboxes) {
-                print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" onclick=\"return set_rename('$filesafe');\" />");
+                print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" onclick=\";return set_rename('$file');\" />");
             }
             echo "<td align=\"left\" nowrap=\"nowrap\">";
             if ($CFG->slasharguments) {
@@ -773,7 +761,7 @@ function displaydir ($wdir) {
                 $ffurl = "/file.php?file=/$id$fileurl";
             }
             link_to_popup_window ($ffurl, "display",
-                                  "<img src=\"$CFG->pixpath/f/$icon\" height=\"16\" width=\"16\" border=\"0\" align=\"middle\" alt=\"$strfile\" />",
+                                  "<img src=\"$CFG->pixpath/f/$icon\" class=\"icon\" alt=\"$strfile\" />",
                                   480, 640);
             $file_size = filesize($filename);
 
@@ -811,7 +799,7 @@ function displaydir ($wdir) {
                    "zip" => "$strcreateziparchive"
                );
     if (!empty($count)) {
-        choose_from_menu ($options, "action", "", "$strwithchosenfiles...", "javascript:document.dirform.submit()");
+        choose_from_menu ($options, "action", "", "$strwithchosenfiles...", "javascript:getElementById('dirform').submit()");
     }
     if (!empty($USER->fileop) and ($USER->fileop == "move") and ($USER->filesource <> $wdir)) {
         echo "<form action=\"coursefiles.php\" method=\"get\">\n";
