@@ -1,7 +1,34 @@
-<?php //$Id: filelib.php,v 1.25.2.1 2006/06/30 07:21:55 skodak Exp $
+<?php //$Id: filelib.php,v 1.39.2.2 2007/04/04 19:43:53 skodak Exp $
+
+require_once($CFG->libdir.'/libcurlemu/libcurlemu.inc.php'); // might be moved to setup.php later
 
 define('BYTESERVING_BOUNDARY', 's1k2o3d4a5k6s7'); //unique string constant
 
+/**
+ * Fetches content of file from Internet (using proxy if defined).
+ *
+ * @return mixed false if request failed or content of the file as string if ok.
+ */
+function download_file_content($url) {
+    $ch = curl_init($url);
+    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
+    curl_setopt($ch, CURLOPT_HEADER, false);
+    if (!empty($CFG->proxyhost)) {
+        curl_setopt($ch, CURLOPT_HTTPPROXYTUNNEL, true);
+        if (empty($CFG->proxyport)) {
+            curl_setopt($ch, CURLOPT_PROXY, $CFG->proxy);
+        } else {
+            curl_setopt($ch, CURLOPT_PROXY, $CFG->proxy.':'.$CFG->proxyport);
+        }
+        if(!empty($CFG->proxyuser) and !empty($CFG->proxypassword)) {
+            curl_setopt($ch, CURLOPT_PROXYUSERPWD, $CFG->proxyuser.':'.$CFG->proxypassword);
+        }
+    }
+    $result = curl_exec($ch);
+    curl_close($ch);
+    return $result;
+}
+
 /**
  * @return List of information about file types based on extensions. 
  *   Associative array of extension (lower-case) to associative array
@@ -35,6 +62,7 @@ function get_mimetypes_array() {
         'dir'  => array ('type'=>'application/x-director', 'icon'=>'flash.gif'),
         'dxr'  => array ('type'=>'application/x-director', 'icon'=>'flash.gif'),
         'eps'  => array ('type'=>'application/postscript', 'icon'=>'pdf.gif'),
+        'fdf'  => array ('type'=>'application/pdf', 'icon'=>'pdf.gif'),
         'gif'  => array ('type'=>'image/gif', 'icon'=>'image.gif'),
         'gtar' => array ('type'=>'application/x-gtar', 'icon'=>'zip.gif'),
         'tgz'   => array ('type'=>'application/g-zip', 'icon'=>'zip.gif'),
@@ -43,8 +71,10 @@ function get_mimetypes_array() {
         'h'    => array ('type'=>'text/plain', 'icon'=>'text.gif'),
         'hpp'  => array ('type'=>'text/plain', 'icon'=>'text.gif'),
         'hqx'  => array ('type'=>'application/mac-binhex40', 'icon'=>'zip.gif'),
+        'htc'  => array ('type'=>'text/x-component', 'icon'=>'text.gif'),
         'html' => array ('type'=>'text/html', 'icon'=>'html.gif'),
         'htm'  => array ('type'=>'text/html', 'icon'=>'html.gif'),
+        'ico'  => array ('type'=>'image/vnd.microsoft.icon', 'icon'=>'image.gif'), 
         'java' => array ('type'=>'text/plain', 'icon'=>'text.gif'),
         'jcb'  => array ('type'=>'text/xml', 'icon'=>'jcb.gif'),
         'jcl'  => array ('type'=>'text/xml', 'icon'=>'jcl.gif'),
@@ -70,17 +100,17 @@ function get_mimetypes_array() {
         'odt'  => array ('type'=>'application/vnd.oasis.opendocument.text', 'icon'=>'odt.gif'),
         'ott'  => array ('type'=>'application/vnd.oasis.opendocument.text-template', 'icon'=>'odt.gif'),
         'oth'  => array ('type'=>'application/vnd.oasis.opendocument.text-web', 'icon'=>'odt.gif'),
-        'odm'  => array ('type'=>'application/vnd.oasis.opendocument.text-master', 'icon'=>'odt.gif'),
-        'odg'  => array ('type'=>'application/vnd.oasis.opendocument.graphics', 'icon'=>'odt.gif'),
-        'otg'  => array ('type'=>'application/vnd.oasis.opendocument.graphics-template', 'icon'=>'odt.gif'),
-        'odp'  => array ('type'=>'application/vnd.oasis.opendocument.presentation', 'icon'=>'odt.gif'),
-        'otp'  => array ('type'=>'application/vnd.oasis.opendocument.presentation-template', 'icon'=>'odt.gif'),
-        'ods'  => array ('type'=>'application/vnd.oasis.opendocument.spreadsheet', 'icon'=>'odt.gif'),
-        'ots'  => array ('type'=>'application/vnd.oasis.opendocument.spreadsheet-template', 'icon'=>'odt.gif'),
-        'odc'  => array ('type'=>'application/vnd.oasis.opendocument.chart', 'icon'=>'odt.gif'),
-        'odf'  => array ('type'=>'application/vnd.oasis.opendocument.formula', 'icon'=>'odt.gif'),
-        'odb'  => array ('type'=>'application/vnd.oasis.opendocument.database', 'icon'=>'odt.gif'),
-        'odi'  => array ('type'=>'application/vnd.oasis.opendocument.image', 'icon'=>'odt.gif'),
+        'odm'  => array ('type'=>'application/vnd.oasis.opendocument.text-master', 'icon'=>'odm.gif'),
+        'odg'  => array ('type'=>'application/vnd.oasis.opendocument.graphics', 'icon'=>'odg.gif'),
+        'otg'  => array ('type'=>'application/vnd.oasis.opendocument.graphics-template', 'icon'=>'odg.gif'),
+        'odp'  => array ('type'=>'application/vnd.oasis.opendocument.presentation', 'icon'=>'odp.gif'),
+        'otp'  => array ('type'=>'application/vnd.oasis.opendocument.presentation-template', 'icon'=>'odp.gif'),
+        'ods'  => array ('type'=>'application/vnd.oasis.opendocument.spreadsheet', 'icon'=>'ods.gif'),
+        'ots'  => array ('type'=>'application/vnd.oasis.opendocument.spreadsheet-template', 'icon'=>'ods.gif'),
+        'odc'  => array ('type'=>'application/vnd.oasis.opendocument.chart', 'icon'=>'odc.gif'),
+        'odf'  => array ('type'=>'application/vnd.oasis.opendocument.formula', 'icon'=>'odf.gif'),
+        'odb'  => array ('type'=>'application/vnd.oasis.opendocument.database', 'icon'=>'odb.gif'),
+        'odi'  => array ('type'=>'application/vnd.oasis.opendocument.image', 'icon'=>'odi.gif'),
 
         'pct'  => array ('type'=>'image/pict', 'icon'=>'image.gif'),
         'pdf'  => array ('type'=>'application/pdf', 'icon'=>'pdf.gif'),
@@ -103,6 +133,8 @@ function get_mimetypes_array() {
         'smi'  => array ('type'=>'application/smil', 'icon'=>'text.gif'),
         'smil' => array ('type'=>'application/smil', 'icon'=>'text.gif'),
         'sqt'  => array ('type'=>'text/xml', 'icon'=>'xml.gif'),
+        'svg'  => array ('type'=>'image/svg+xml', 'icon'=>'image.gif'),
+        'svgz' => array ('type'=>'image/svg+xml', 'icon'=>'image.gif'),
         'swa'  => array ('type'=>'application/x-director', 'icon'=>'flash.gif'),
         'swf'  => array ('type'=>'application/x-shockwave-flash', 'icon'=>'flash.gif'),
         'swfl' => array ('type'=>'application/x-shockwave-flash', 'icon'=>'flash.gif'),
@@ -129,6 +161,9 @@ function get_mimetypes_array() {
         'wav'  => array ('type'=>'audio/wav', 'icon'=>'audio.gif'),
         'wmv'  => array ('type'=>'video/x-ms-wmv', 'icon'=>'avi.gif'),
         'asf'  => array ('type'=>'video/x-ms-asf', 'icon'=>'avi.gif'),
+        'xdp'  => array ('type'=>'application/pdf', 'icon'=>'pdf.gif'),
+        'xfd'  => array ('type'=>'application/pdf', 'icon'=>'pdf.gif'),
+        'xfdf' => array ('type'=>'application/pdf', 'icon'=>'pdf.gif'),
         'xls'  => array ('type'=>'application/vnd.ms-excel', 'icon'=>'excel.gif'),
         'xml'  => array ('type'=>'application/xml', 'icon'=>'xml.gif'),
         'xsl'  => array ('type'=>'text/xml', 'icon'=>'xml.gif'),
@@ -203,15 +238,44 @@ function get_mimetype_description($mimetype,$capitalise=false) {
 }
 
 /** 
- * @PARAM $filter int 0=no filtering, 1=all files, 2=html files only
+ * Handles the sending of file data to the user's browser, including support for 
+ * byteranges etc. 
+ * @param string $path Path of file on disk (including real filename), or actual content of file as string
+ * @param string $filename Filename to send
+ * @param int $lifetime Number of seconds before the file should expire from caches (default 24 hours)
+ * @param int $filter 0 (default)=no filtering, 1=all files, 2=html files only
+ * @param bool $pathisstring If true (default false), $path is the content to send and not the pathname
+ * @param bool $forcedownload If true (default false), forces download of file rather than view in browser/plugin
+ * @param string $mimetype Include to specify the MIME type; leave blank to have it guess the type from $filename
  */
-function send_file($path, $filename, $lifetime=86400 , $filter=0, $pathisstring=false, $forcedownload=false) {
-    global $CFG;
+function send_file($path, $filename, $lifetime=86400 , $filter=0, $pathisstring=false, $forcedownload=false, $mimetype='') {
+    global $CFG, $COURSE;
 
-    $mimetype     = $forcedownload ? 'application/x-forcedownload' : mimeinfo('type', $filename);
+    // Use given MIME type if specified, otherwise guess it using mimeinfo.
+    // IE, Konqueror and Opera open html file directly in browser from web even when directed to save it to disk :-O
+    // only Firefox saves all files locally before opening when content-disposition: attachment stated
+    $isFF         = check_browser_version('Firefox', '1.5'); // only FF > 1.5 properly tested
+    $mimetype     = ($forcedownload and !$isFF) ? 'application/x-forcedownload' : 
+                         ($mimetype ? $mimetype : mimeinfo('type', $filename));
     $lastmodified = $pathisstring ? time() : filemtime($path);
     $filesize     = $pathisstring ? strlen($path) : filesize($path);
 
+    //Adobe Acrobat Reader XSS prevention
+    if ($mimetype=='application/pdf' or mimeinfo('type', $filename)=='application/pdf') {
+        //please note that it prevents opening of pdfs in browser when http referer disabled
+        //or file linked from another site; browser caching of pdfs is now disabled too
+        if (!empty($_SERVER['HTTP_RANGE'])) {
+            //already byteserving
+            $lifetime = 1; // >0 needed for byteserving    
+        } else if (empty($_SERVER['HTTP_REFERER']) or strpos($_SERVER['HTTP_REFERER'], $CFG->wwwroot)!==0) {
+            $mimetype = 'application/x-forcedownload';
+            $forcedownload = true;
+            $lifetime = 0;
+        } else {
+            $lifetime = 1; // >0 needed for byteserving    
+        }
+    }
+
     //IE compatibiltiy HACK!
     if (ini_get('zlib.output_compression')) {
         ini_set('zlib.output_compression', 'Off');
@@ -297,7 +361,7 @@ function send_file($path, $filename, $lifetime=86400 , $filter=0, $pathisstring=
             $filesize = strlen($path);
             $pathisstring = true;
         } else if ($mimetype == 'text/plain') {
-            @header('Content-Type: Text/plain; charset='.current_charset()); //add encoding
+            @header('Content-Type: Text/plain; charset=utf-8'); //add encoding
         } else {
             @header('Content-Type: '.$mimetype);
         }
@@ -309,16 +373,12 @@ function send_file($path, $filename, $lifetime=86400 , $filter=0, $pathisstring=
             readfile_chunked($path);
         }
     } else {     // Try to put the file through filters
-        global $course;  // HACK!
-        if (!empty($course->id)) {
-            $courseid = $course->id;
-        } else {
-            $courseid = SITEID;
-        }
         if ($mimetype == 'text/html') {
+            $options = new object();
             $options->noclean = true;
+            $options->nocache = true; // temporary workaround for MDL-5136
             $text = $pathisstring ? $path : implode('', file($path));
-            $output = format_text($text, FORMAT_HTML, $options, $courseid);
+            $output = format_text($text, FORMAT_HTML, $options, $COURSE->id);
             if (!empty($CFG->usesid) && empty($_COOKIE['MoodleSession'.$CFG->sessioncookie])) {
                 //cookieless mode - rewrite links
                 $output = sid_ob_rewrite($output);
@@ -330,17 +390,18 @@ function send_file($path, $filename, $lifetime=86400 , $filter=0, $pathisstring=
             echo $output;
         // only filter text if filter all files is selected
         } else if (($mimetype == 'text/plain') and ($filter == 1)) {
+            $options = new object();
             $options->newlines = false;
             $options->noclean = true;
             $text = htmlentities($pathisstring ? $path : implode('', file($path)));
-            $output = '<pre>'. format_text($text, FORMAT_MOODLE, $options, $courseid) .'</pre>';
+            $output = '<pre>'. format_text($text, FORMAT_MOODLE, $options, $COURSE->id) .'</pre>';
             if (!empty($CFG->usesid) && empty($_COOKIE['MoodleSession'.$CFG->sessioncookie])) {
                 //cookieless mode - rewrite links
                 $output = sid_ob_rewrite($output);
             }
 
             @header('Content-Length: '.strlen($output));
-            @header('Content-Type: text/html; charset='.current_charset()); //add encoding
+            @header('Content-Type: text/html; charset=utf-8'); //add encoding
             while (@ob_end_flush()); //flush the buffers - save memory and disable sid rewrite
             echo $output;
         } else {    // Just send it out raw
@@ -457,14 +518,6 @@ function put_records_csv($file, $records, $table = NULL) {
 }
 
 
-if (!function_exists('file_get_contents')) {
-   function file_get_contents($file) {
-       $file = file($file);
-       return !$file ? false : implode('', $file);
-   }
-}
-
-
 /**
  * Recursively delete the file or folder with path $location. That is, 
  * if it is a file delete it. If it is a folder, delete all its content
