@@ -1,4 +1,4 @@
-<?php //$Id: pagelib.php,v 1.40.2.1 2006/07/19 07:59:16 skodak Exp $
+<?php //$Id: pagelib.php,v 1.52.2.1 2007/02/24 23:31:22 defacer Exp $
 
 /**
  * This file contains the parent class for moodle pages, page_base, 
@@ -7,7 +7,7 @@
  * (courseid, blogid, activity id, etc).
  *
  * @author Jon Papaioannou
- * @version  $Id: pagelib.php,v 1.40.2.1 2006/07/19 07:59:16 skodak Exp $
+ * @version  $Id: pagelib.php,v 1.52.2.1 2007/02/24 23:31:22 defacer Exp $
  * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
  * @package pages
  */
@@ -69,9 +69,7 @@ function page_create_object($type, $id = NULL) {
 
     if ($object->get_type() !== $type) {
         // Somehow somewhere someone made a mistake
-        if ($CFG->debug > 7) {
-            error('Page object\'s type ('. $object->get_type() .') does not match requested type ('. $type .')');
-        }
+        debugging('Page object\'s type ('. $object->get_type() .') does not match requested type ('. $type .')');
     }
 
     $object->init_quick($data);
@@ -99,15 +97,11 @@ function page_map_class($type, $classname = NULL) {
     }
 
     if (!isset($mappings[$type])) {
-        if ($CFG->debug > 7) {
-            error('Page class mapping requested for unknown type: '.$type);
-        }
+        debugging('Page class mapping requested for unknown type: '.$type);
     }
 
     if (empty($classname) && !class_exists($mappings[$type])) {
-        if ($CFG->debug > 7) {
-            error('Page class mapping for id "'.$type.'" exists but class "'.$mappings[$type].'" is not defined');
-        }
+        debugging('Page class mapping for id "'.$type.'" exists but class "'.$mappings[$type].'" is not defined');
     }
 
     return $mappings[$type];
@@ -301,7 +295,7 @@ class page_base {
 
     // is this  page always editable, regardless of anything else?
     function edit_always() {
-        return (isadmin() &&  defined('ADMIN_STICKYBLOCKS'));
+        return (has_capability('moodle/site:manageblocks', get_context_instance(CONTEXT_SYSTEM)) &&  defined('ADMIN_STICKYBLOCKS'));
     }
 }
 
@@ -349,19 +343,20 @@ class page_course extends page_base {
 
     // USER-RELATED THINGS
 
-    // When is a user said to have "editing rights" in this page? This would have something
-    // to do with roles, in the future.
+    // Can user edit the course page or "sticky page"?
+    // This is also about editting of blocks BUT mainly activities in course page layout, see
+    // update_course_icon() - it must use the same capability
     function user_allowed_editing() {
-        if (isadmin() && defined('ADMIN_STICKYBLOCKS')) {
+        if (has_capability('moodle/site:manageblocks', get_context_instance(CONTEXT_SYSTEM)) && defined('ADMIN_STICKYBLOCKS')) {
             return true;
         }
-        return isteacheredit($this->id);
+        return has_capability('moodle/course:manageactivities', get_context_instance(CONTEXT_COURSE, $this->id));
     }
 
-    // Is the user actually editing this page right now? This would have something
-    // to do with roles, in the future.
+    // Is the user actually editing this course page or "sticky page" right now?
     function user_is_editing() {
-        if (isadmin() && defined('ADMIN_STICKYBLOCKS')) {
+        if (has_capability('moodle/site:manageblocks', get_context_instance(CONTEXT_SYSTEM)) && defined('ADMIN_STICKYBLOCKS')) {
+            //always in edit mode on sticky page
             return true;
         }
         return isediting($this->id);
@@ -371,7 +366,7 @@ class page_course extends page_base {
 
     // This function prints out the common part of the page's header.
     // You should NEVER print the header "by hand" in other code.
-    function print_header($title, $morebreadcrumbs = NULL) {
+    function print_header($title, $morebreadcrumbs=NULL, $meta='', $bodytags='') {
         global $USER, $CFG;
 
         $this->init_full();
@@ -407,11 +402,13 @@ class page_course extends page_base {
 
         // The "Editing On" button will be appearing only in the "main" course screen
         // (i.e., no breadcrumbs other than the default one added inside this function)
-        $buttons = update_course_icon($this->courserecord->id ) . update_studentview_button( $this->courserecord->id );
+        $buttons = switchroles_form($this->courserecord->id) . update_course_icon($this->courserecord->id );
         $buttons = empty($morebreadcrumbs) ? $buttons : '&nbsp;';
 
         print_header($title, $this->courserecord->fullname, $crumbtext,
-                     '', '', true, $buttons, user_login_string($this->courserecord, $USER));
+                     '', $meta, true, $buttons, user_login_string($this->courserecord, $USER), false, $bodytags);
+
+        echo '<div class="accesshide"><a href="#startofcontent">'.get_string('skiptomaincontent').'</a></div>';
     }
 
     // SELF-REPORTING SECTION
@@ -433,7 +430,8 @@ class page_course extends page_base {
         if($this->id == SITEID) {
             return parent::get_format_name();
         }
-        return $this->body_id.'-'.$this->courserecord->format;
+        // This needs to reflect the path hierarchy under Moodle root.
+        return 'course-view-'.$this->courserecord->format;
     }
 
     // This should return a fully qualified path to the URL which is responsible for displaying us.
@@ -495,7 +493,7 @@ class page_course extends page_base {
             }
             /// Failsafe - in case nothing was defined.
             else {
-                $blocknames = 'site_main_menu,admin:course_summary,calendar_month';
+                $blocknames = 'site_main_menu,admin_tree:course_summary,calendar_month';
             }
         }
         // It's a normal course, so do it according to the course format
@@ -580,7 +578,7 @@ class page_generic_activity extends page_base {
 
     function user_allowed_editing() {
         $this->init_full();
-        return isteacheredit($this->modulerecord->course);
+        return has_capability('moodle/site:manageblocks', get_context_instance(CONTEXT_COURSE, $this->modulerecord->course));
     }
 
     function user_is_editing() {
