@@ -5,16 +5,16 @@
  * Normally this is only called by the main config.php file
  * Normally this file does not need to be edited.
  * @author Martin Dougiamas
- * @version $Id: setup.php,v 1.123.2.8 2005/07/14 20:09:10 stronk7 Exp $
+ * @version $Id: setup.php,v 1.198.2.2 2007/04/05 05:00:40 martinlanghoff Exp $
  * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
  * @package moodlecore
  */
 
 ////// DOCUMENTATION IN PHPDOC FORMAT FOR MOODLE GLOBALS AND COMMON OBJECT TYPES /////////////
 /**
- * This global variable is read in from the 'config' table.
+ * $USER is a global instance of a typical $user record.
  *
- * Some typical settings in the $CFG global:
+ * Items found in the user record:
  *  - $USER->emailstop - Does the user want email sent to them?
  *  - $USER->email - The user's email address.
  *  - $USER->id - The unique integer identified of this user in the 'user' table.
@@ -29,12 +29,12 @@
  */
 global $USER;
 /**
- * $USER is a global instance of a typical $user record.
+ * This global variable is read in from the 'config' table.
  *
- * Items found in the user record:
+ * Some typical settings in the $CFG global:
  *  - $CFG->wwwroot - Path to moodle index directory in url format.
  *  - $CFG->dataroot - Path to moodle index directory on server's filesystem.
- *  - $CFG->libroot  - Path to moodle's library folder on server's filesystem.
+ *  - $CFG->libdir  - Path to moodle's library folder on server's filesystem.
  *
  * @global object(cfg) $CFG
  */
@@ -44,6 +44,10 @@ global $CFG;
  * @global object(session) $SESSION
  */
 global $SESSION;
+/** 
+ * Definition of shared memory cache
+ */
+global $MCACHE;
 /**
  * Definition of course type
  * @global object(course) $COURSE
@@ -74,13 +78,24 @@ global $THEME;
 global $HTTPSPAGEREQUIRED;
 
 
+/// First try to detect some attacks on older buggy PHP versions
+    if (isset($_REQUEST['GLOBALS']) || isset($_COOKIE['GLOBALS']) || isset($_FILES['GLOBALS'])) {
+        die('Fatal: Illegal GLOBALS overwrite attempt detected!');
+    }
+
+
     if (!isset($CFG->wwwroot)) {
+        trigger_error('Fatal: $CFG->wwwroot is not configured! Exiting.');
         die;
     }
 
 /// Set httpswwwroot default value (this variable will replace $CFG->wwwroot
 /// inside some URLs used in HTTPSPAGEREQUIRED pages.
-$CFG->httpswwwroot = $CFG->wwwroot;
+    $CFG->httpswwwroot = $CFG->wwwroot;
+
+    $CFG->libdir   = $CFG->dirroot .'/lib';
+
+    require_once($CFG->libdir .'/setuplib.php');        // Functions that MUST be loaded first
 
 /// Time to start counting    
     init_performance_info();        
@@ -99,12 +114,19 @@ $CFG->httpswwwroot = $CFG->wwwroot;
 
 /// Connect to the database using adodb
 
-    $CFG->libdir   = $CFG->dirroot .'/lib';
+/// Some defines required BEFORE including AdoDB library
+    define ('ADODB_ASSOC_CASE', 0); //Use lowercase fieldnames for ADODB_FETCH_ASSOC
+                                    //(only meaningful for oci8po, it's the default
+                                    //for other DB drivers so this won't affect them)
 
     require_once($CFG->libdir .'/adodb/adodb.inc.php'); // Database access functions
 
     $db = &ADONewConnection($CFG->dbtype);
 
+    // See MDL-6760 for why this is necessary. In Moodle 1.8, once we start using NULLs properly,
+    // we probably want to change this value to ''.
+    $db->null2null = 'A long random string that will never, ever match something we want to insert into the database, I hope. \'';
+
     error_reporting(0);  // Hide errors
 
     if (!isset($CFG->dbpersist) or !empty($CFG->dbpersist)) {    // Use persistent connection (default)
@@ -130,9 +152,22 @@ $CFG->httpswwwroot = $CFG->wwwroot;
         echo '<p>The site administrator should also check that the database details have been correctly specified in config.php</p>';
         echo '</td></tr></table>';
         echo '</body></html>';
+
+        if (!empty($CFG->emailconnectionerrorsto)) {
+            mail($CFG->emailconnectionerrorsto, 
+                 'WARNING: Database connection error: '.$CFG->wwwroot, 
+                 'Connection error: '.$CFG->wwwroot);
+        }
         die;
     }
 
+/// Forcing ASSOC mode for ADOdb (some DBs default to FETCH_BOTH)
+    $db->SetFetchMode(ADODB_FETCH_ASSOC);
+
+/// Starting here we have a correct DB conection but me must avoid
+/// to execute any DB transaction until "set names" has been executed
+/// some lines below!
+
     error_reporting(E_ALL);       // Show errors from now on.
 
     if (!isset($CFG->prefix)) {   // Just in case it isn't defined in config.php
@@ -146,20 +181,33 @@ $CFG->httpswwwroot = $CFG->wwwroot;
         $CFG->admin = 'admin';   // This is relative to the wwwroot and dirroot
     }
 
+/// Increase memory limits if possible
+    raise_memory_limit('96M');    // We should never NEED this much but just in case...
 
 /// Load up standard libraries
 
+    require_once($CFG->libdir .'/textlib.class.php');   // Functions to handle multibyte strings
     require_once($CFG->libdir .'/weblib.php');          // Functions for producing HTML
-    require_once($CFG->libdir .'/datalib.php');         // Functions for accessing databases
+    require_once($CFG->libdir .'/dmllib.php');          // Functions to handle DB data (DML)
+    require_once($CFG->libdir .'/datalib.php');         // Legacy lib with a big-mix of functions.
+    require_once($CFG->libdir .'/accesslib.php');       // Access control functions
+    require_once($CFG->libdir .'/deprecatedlib.php');   // Deprecated functions included for backward compatibility
     require_once($CFG->libdir .'/moodlelib.php');       // Other general-purpose functions
 
+/// Disable errors for now - needed for installation when debug enabled in config.php
+    if (isset($CFG->debug)) {
+        $originalconfigdebug = $CFG->debug;
+        unset($CFG->debug);
+    } else {
+        $originalconfigdebug = -1;
+    }
 
-/// Increase memory limits if possible
-
-    raise_memory_limit('64M');    // We should never NEED this much but just in case...
-
+/// Set the client/server and connection to utf8
+/// and configure some other specific variables for each db
+    configure_dbconnection();
 
 /// Load up any configuration from the config table
+    unset($CFG->rcache);
     $CFG = get_config();
 
 /// Turn on SQL logging if required
@@ -167,17 +215,95 @@ $CFG->httpswwwroot = $CFG->wwwroot;
         $db->LogSQL();
     }
 
+/// Prevent warnings from roles when upgrading with debug on
+    if (isset($CFG->debug)) {
+        $originaldatabasedebug = $CFG->debug;
+        unset($CFG->debug);
+    } else {
+        $originaldatabasedebug = -1;
+    }
+
+
+/// For now, only needed under apache (and probably unstable in other contexts)
+    if (function_exists('apache_child_terminate')) {
+        register_shutdown_function('moodle_request_shutdown');
+    }
+
+//// Defining the site
+    if ($SITE = get_site()) {
+        /**
+         * If $SITE global from {@link get_site()} is set then SITEID to $SITE->id, otherwise set to 1.
+         */
+        define('SITEID', $SITE->id);
+        /// And the 'default' course
+        $COURSE = clone($SITE);   // For now.  This will usually get reset later in require_login() etc.
+    } else {
+        /**
+         * @ignore
+         */
+        define('SITEID', 1);
+        /// And the 'default' course
+        $COURSE = new object;  // no site created yet
+        $COURSE->id = 1;
+    }
+
 
 /// Set error reporting back to normal
-    if (empty($CFG->debug)) {
-        $CFG->debug = 7;
+    if ($originaldatabasedebug == -1) {
+        $CFG->debug = DEBUG_MINIMAL;
+    } else {
+        $CFG->debug = $originaldatabasedebug;
     }
+    if ($originalconfigdebug !== -1) {
+        $CFG->debug = $originalconfigdebug; 
+    }
+    unset($originalconfigdebug);
+    unset($originaldatabasedebug);
     error_reporting($CFG->debug);
 
 
+/// If we want to display Moodle errors, then try and set PHP errors to match
+    if (!isset($CFG->debugdisplay)) {
+        //keep it as is during installation
+    } else if (empty($CFG->debugdisplay)) {
+        @ini_set('display_errors', '0');
+        @ini_set('log_errors', '1');
+    } else {
+        @ini_set('display_errors', '1');
+    }
+
+/// Shared-Memory cache init -- will set $MCACHE
+/// $MCACHE is a global object that offers at least add(), set() and delete()
+/// with similar semantics to the memcached PHP API http://php.net/memcache
+    if (!empty($CFG->cachetype)) {
+        if ($CFG->cachetype === 'memcached' && !empty($CFG->memcachedhosts)) {
+            if (!init_memcached()) {
+                debugging("Error initialising memcached");
+            }
+        } elseif ($CFG->cachetype === 'eaccelerator') {
+            if (!init_eaccelerator()) {
+                debugging("Error initialising eaccelerator cache");
+            }
+        }
+    } else { // just make sure it is defined
+        $CFG->cachetype = '';
+    }
+/// Ensure we define rcache - so we can later check for it
+/// with a really fast and unambiguous $CFG->rcache === false
+    if (empty($CFG->rcache)) {
+        $CFG->rcache = false;
+    } else {
+        $CFG->rcache = true;
+    }
+
 /// Set a default enrolment configuration (see bug 1598)
     if (!isset($CFG->enrol)) {
-        $CFG->enrol = 'internal';
+        $CFG->enrol = 'manual';
+    }
+
+/// Set default enabled enrolment plugins
+    if (!isset($CFG->enrol_plugins_enabled)) {
+        $CFG->enrol_plugins_enabled = 'manual';
     }
 
 /// File permissions on created directories in the $CFG->dataroot
@@ -186,6 +312,20 @@ $CFG->httpswwwroot = $CFG->wwwroot;
         $CFG->directorypermissions = 0777;      // Must be octal (that's why it's here)
     }
 
+/// Calculate and set $CFG->ostype to be used everywhere. Possible values are:
+/// - WINDOWS: for any Windows flavour.
+/// - UNIX: for the rest
+/// Also, $CFG->os can continue being used if more specialization is required
+    if (stristr(PHP_OS, 'win') && !stristr(PHP_OS, 'darwin')) {
+        $CFG->ostype = 'WINDOWS';
+    } else {
+        $CFG->ostype = 'UNIX';
+    }
+    $CFG->os = PHP_OS;
+
+/// Set up default frame target string, based on $CFG->framename
+    $CFG->frametarget = frametarget();
+
 /// Setup cache dir for Smarty and others
     if (!file_exists($CFG->dataroot .'/cache')) {
         make_upload_directory('cache');
@@ -228,9 +368,12 @@ $CFG->httpswwwroot = $CFG->wwwroot;
             $ADODB_SESSION_USER    = $CFG->dbuser;
             $ADODB_SESSION_PWD     = $CFG->dbpass;
             $ADODB_SESSION_DB      = $CFG->dbname;
-            $ADODB_SESSION_TBL     = $CFG->prefix.'sessions';
+            $ADODB_SESSION_TBL     = $CFG->prefix.'sessions2';
+            if (!empty($CFG->sessiontimeout)) {
+                $ADODB_SESS_LIFE   = $CFG->sessiontimeout;
+            }
 
-            require_once($CFG->libdir. '/adodb/session/adodb-session.php');
+            require_once($CFG->libdir. '/adodb/session/adodb-session2.php');
         }
     }
 /// Set sessioncookie variable if it isn't already
@@ -250,6 +393,7 @@ $CFG->httpswwwroot = $CFG->wwwroot;
 
 
 /// A hack to get around magic_quotes_gpc being turned off
+/// It is strongly recommended to enable "magic_quotes_gpc"!
 
     if (!ini_get_bool('magic_quotes_gpc') ) {
         function addslashes_deep($value) {
@@ -261,21 +405,58 @@ $CFG->httpswwwroot = $CFG->wwwroot;
         $_POST = array_map('addslashes_deep', $_POST);
         $_GET = array_map('addslashes_deep', $_GET);
         $_COOKIE = array_map('addslashes_deep', $_COOKIE);
+        $_REQUEST = array_map('addslashes_deep', $_REQUEST);
+        if (!empty($_SERVER['REQUEST_URI'])) {
+            $_SERVER['REQUEST_URI'] = addslashes($_SERVER['REQUEST_URI']);
+        }
+        if (!empty($_SERVER['QUERY_STRING'])) {
+            $_SERVER['QUERY_STRING'] = addslashes($_SERVER['QUERY_STRING']);
+        }
+        if (!empty($_SERVER['HTTP_REFERER'])) {
+            $_SERVER['HTTP_REFERER'] = addslashes($_SERVER['HTTP_REFERER']);
+        }
+       if (!empty($_SERVER['PATH_INFO'])) {
+            $_SERVER['PATH_INFO'] = addslashes($_SERVER['PATH_INFO']);
+        }
+        if (!empty($_SERVER['PHP_SELF'])) {
+            $_SERVER['PHP_SELF'] = addslashes($_SERVER['PHP_SELF']);
+        }
+        if (!empty($_SERVER['PATH_TRANSLATED'])) {
+            $_SERVER['PATH_TRANSLATED'] = addslashes($_SERVER['PATH_TRANSLATED']);
+        }
     }
 
 
-/// The following is a hack to get around the problem of PHP installations
-/// that have "register_globals" turned off (default since PHP 4.1.0).
-/// Eventually I'll go through and upgrade all the code to make this unnecessary
+/// The following code can emulate "register globals" if required.
+/// This hack is no longer being applied as of Moodle 1.6 unless you really 
+/// really want to use it (by defining  $CFG->enableglobalshack = true)
 
-    if (isset($_GET)) {
-        extract($_GET, EXTR_SKIP);    // Skip existing variables, ie CFG
-    }
-    if (isset($_POST)) {
-        extract($_POST, EXTR_SKIP);   // Skip existing variables, ie CFG
-    }
-    if (isset($_SERVER)) {
-        extract($_SERVER);
+    if (!empty($CFG->enableglobalshack)) {
+        if (!empty($CFG->detect_unchecked_vars)) {
+            global $UNCHECKED_VARS;
+            $UNCHECKED_VARS->url = $_SERVER['PHP_SELF'];
+            $UNCHECKED_VARS->vars = array();
+        }
+    
+        if (isset($_GET)) {
+            extract($_GET, EXTR_SKIP);    // Skip existing variables, ie CFG
+            if (!empty($CFG->detect_unchecked_vars)) {
+                foreach ($_GET as $key => $val) {
+                    $UNCHECKED_VARS->vars[$key]=$val;
+                }
+            }
+        }
+        if (isset($_POST)) {
+            extract($_POST, EXTR_SKIP);   // Skip existing variables, ie CFG
+            if (!empty($CFG->detect_unchecked_vars)) {
+                foreach ($_POST as $key => $val) {
+                    $UNCHECKED_VARS->vars[$key]=$val;
+                }
+            }
+        }
+        if (isset($_SERVER)) {
+            extract($_SERVER);
+        }
     }
 
 
@@ -283,30 +464,36 @@ $CFG->httpswwwroot = $CFG->wwwroot;
 
     class object {};
 
-    unset(${'MoodleSession'.$CFG->sessioncookie});
-    unset($_GET['MoodleSession'.$CFG->sessioncookie]);
-    unset($_POST['MoodleSession'.$CFG->sessioncookie]);
-
-    //compatibility hack for Moodle Cron, cookies not deleted, but set to "deleted"
+    //discard session ID from POST, GET and globals to tighten security,
+    //this session fixation prevention can not be used in cookieless mode
+    if (empty($CFG->usesid)) {
+        unset(${'MoodleSession'.$CFG->sessioncookie});
+        unset($_GET['MoodleSession'.$CFG->sessioncookie]);
+        unset($_POST['MoodleSession'.$CFG->sessioncookie]);
+    }
+    //compatibility hack for Moodle Cron, cookies not deleted, but set to "deleted" - should not be needed with $nomoodlecookie in cron.php now 
     if (!empty($_COOKIE['MoodleSession'.$CFG->sessioncookie]) && $_COOKIE['MoodleSession'.$CFG->sessioncookie] == "deleted") {
         unset($_COOKIE['MoodleSession'.$CFG->sessioncookie]);
     }
     if (!empty($_COOKIE['MoodleSessionTest'.$CFG->sessioncookie]) && $_COOKIE['MoodleSessionTest'.$CFG->sessioncookie] == "deleted") {
         unset($_COOKIE['MoodleSessionTest'.$CFG->sessioncookie]);
     }
+    if (!empty($CFG->usesid) && empty($_COOKIE['MoodleSession'.$CFG->sessioncookie])) {
+        require_once("$CFG->dirroot/lib/cookieless.php");
+        sid_start_ob();
+    }
 
-    if (!isset($nomoodlecookie)) {
+    if (empty($nomoodlecookie)) {
         session_name('MoodleSession'.$CFG->sessioncookie);
         @session_start();
         if (! isset($_SESSION['SESSION'])) {
             $_SESSION['SESSION'] = new object;
             $_SESSION['SESSION']->session_test = random_string(10);
-            if (empty($_COOKIE['MoodleSessionTest'.$CFG->sessioncookie])) {
-                setcookie('MoodleSessionTest'.$CFG->sessioncookie, $_SESSION['SESSION']->session_test, 0, '/');
-                $_COOKIE['MoodleSessionTest'.$CFG->sessioncookie] = $_SESSION['SESSION']->session_test;
-            } else {
-                $_COOKIE['MoodleSessionTest'.$CFG->sessioncookie] = 'error!!';
+            if (!empty($_COOKIE['MoodleSessionTest'.$CFG->sessioncookie])) {
+                $_SESSION['SESSION']->has_timed_out = true;
             }
+            setcookie('MoodleSessionTest'.$CFG->sessioncookie, $_SESSION['SESSION']->session_test, 0, '/');
+            $_COOKIE['MoodleSessionTest'.$CFG->sessioncookie] = $_SESSION['SESSION']->session_test;
         }
         if (! isset($_SESSION['USER']))    {
             $_SESSION['USER']    = new object;
@@ -314,10 +501,14 @@ $CFG->httpswwwroot = $CFG->wwwroot;
 
         $SESSION = &$_SESSION['SESSION'];   // Makes them easier to reference
         $USER    = &$_SESSION['USER'];
+        if (!isset($USER->id)) {
+            $USER->id = 0; // to enable proper function of $CFG->notloggedinroleid hack
+        }
     }
     else {
-        $SESSION = NULL;
-        $USER    = NULL;
+        $SESSION  = NULL;
+        $USER     = new object();
+        $USER->id = 0; // user not logged in when session disabled
     }
 
     if (defined('FULLME')) {     // Usually in command-line scripts like admin/cron.php
@@ -338,15 +529,18 @@ $CFG->httpswwwroot = $CFG->wwwroot;
 /// Load up theme variables (colours etc)
 
     if (!isset($CFG->themedir)) {
-        $CFG->themedir = $CFG->dirroot.'/theme/';
-        $CFG->themewww = $CFG->wwwroot.'/theme/';
+        $CFG->themedir = $CFG->dirroot.'/theme';
+        $CFG->themewww = $CFG->wwwroot.'/theme';
     }
+    $CFG->httpsthemewww = $CFG->themewww; 
 
     if (isset($_GET['theme'])) {
         if ($CFG->allowthemechangeonurl || confirm_sesskey()) {
-            if (!detect_munged_arguments($_GET['theme'], 0) and file_exists($CFG->themedir. $_GET['theme'])) {
-                $SESSION->theme = $_GET['theme'];
+            $themename = clean_param($_GET['theme'], PARAM_SAFEDIR);
+            if (($themename != '') and file_exists($CFG->themedir.'/'.$themename)) {
+                $SESSION->theme = $themename;
             }
+            unset($themename);
         }
     }
 
@@ -354,59 +548,76 @@ $CFG->httpswwwroot = $CFG->wwwroot;
         $CFG->theme = 'standardwhite';
     }
 
-    theme_setup();  // Sets up theme global variables
-
-/// now do a session test to prevent random user switching
-    if ($SESSION != NULL) {
-        if (empty($_COOKIE['MoodleSessionTest'.$CFG->sessioncookie])) {
-            report_session_error();
-        } else if (isset($SESSION->session_test) && $_COOKIE['MoodleSessionTest'.$CFG->sessioncookie] != $SESSION->session_test) {
-            report_session_error();
+/// now do a session test to prevent random user switching - observed on some PHP/Apache combinations,
+/// disable checks when working in cookieless mode
+    if (empty($CFG->usesid) || !empty($_COOKIE['MoodleSession'.$CFG->sessioncookie])) {
+        if ($SESSION != NULL) {
+            if (empty($_COOKIE['MoodleSessionTest'.$CFG->sessioncookie])) {
+                report_session_error();
+            } else if (isset($SESSION->session_test) && $_COOKIE['MoodleSessionTest'.$CFG->sessioncookie] != $SESSION->session_test) {
+                report_session_error();
+            }
         }
     }
 
 
-
 /// Set language/locale of printed times.  If user has chosen a language that
 /// that is different from the site language, then use the locale specified
 /// in the language file.  Otherwise, if the admin hasn't specified a locale
 /// then use the one from the default language.  Otherwise (and this is the
 /// majority of cases), use the stored locale specified by admin.
-
-    if (isset($_GET['lang'])) {
-        if (!detect_munged_arguments($lang, 0) and file_exists($CFG->dirroot .'/lang/'. $lang)) {
+    if ($SESSION !== NULL && isset($_GET['lang']) && ($lang = clean_param($_GET['lang'], PARAM_SAFEDIR))) {
+        if (file_exists($CFG->dataroot .'/lang/'. $lang) or file_exists($CFG->dirroot .'/lang/'. $lang)) {
             $SESSION->lang = $lang;
-            $SESSION->encoding = get_string('thischarset');
+        } else if (file_exists($CFG->dataroot.'/lang/'.$lang.'_utf8') or 
+                   file_exists($CFG->dirroot .'/lang/'.$lang.'_utf8')) {
+            $SESSION->lang = $lang.'_utf8';
         }
     }
+
+    setup_lang_from_browser();
+
+    unset($lang);
+
     if (empty($CFG->lang)) {
-        $CFG->lang = "en";
+        if (empty($SESSION->lang)) {
+            $CFG->lang = 'en_utf8';
+        } else {
+            $CFG->lang = $SESSION->lang;
+        }
     }
 
-    moodle_setlocale();
+    // set default locale and themes - might be changed again later from require_login()
+    course_setup();
 
     if (!empty($CFG->opentogoogle)) {
-        if (empty($_SESSION['USER'])) {
+        if (empty($USER->id)) {  // Ignore anyone logged in
             if (!empty($_SERVER['HTTP_USER_AGENT'])) {
                 if (strpos($_SERVER['HTTP_USER_AGENT'], 'Googlebot') !== false ) {
                     $USER = guest_user();
-                }
-                if (strpos($_SERVER['HTTP_USER_AGENT'], 'google.com') !== false ) {
+                } else if (strpos($_SERVER['HTTP_USER_AGENT'], 'google.com') !== false ) {
+                    $USER = guest_user();
+                } else if (strpos($_SERVER['HTTP_USER_AGENT'], 'Yahoo! Slurp') !== false ) {
+                    $USER = guest_user();
+                } else if (strpos($_SERVER['HTTP_USER_AGENT'], 'MSNBOT') !== false ) {
                     $USER = guest_user();
                 }
             }
-            if (empty($_SESSION['USER']) and !empty($_SERVER['HTTP_REFERER'])) {
+            if (empty($USER) && !empty($_SERVER['HTTP_REFERER'])) {
                 if (strpos($_SERVER['HTTP_REFERER'], 'google') !== false ) {
                     $USER = guest_user();
                 } else if (strpos($_SERVER['HTTP_REFERER'], 'altavista') !== false ) {
                     $USER = guest_user();
                 }
             }
+            if (!empty($USER)) {
+                load_all_capabilities();
+            }
         }
     }
 
     if ($CFG->theme == 'standard' or $CFG->theme == 'standardwhite') {    // Temporary measure to help with XHTML validation
-        if (empty($_SESSION['USER']->id)) {      // Allow W3CValidator in as user called w3cvalidator (or guest)
+        if (isset($_SERVER['HTTP_USER_AGENT']) and empty($_SESSION['USER']->id)) {      // Allow W3CValidator in as user called w3cvalidator (or guest)
             if ((strpos($_SERVER['HTTP_USER_AGENT'], 'W3C_Validator') !== false) or
                 (strpos($_SERVER['HTTP_USER_AGENT'], 'Cynthia') !== false )) {
                 if ($USER = get_complete_user_data("username", "w3cvalidator")) {
@@ -421,16 +632,26 @@ $CFG->httpswwwroot = $CFG->wwwroot;
 /// Apache log intergration. In apache conf file one can use ${MOODULEUSER}n in
 /// LogFormat to get the current logged in username in moodle.
     if ($USER && function_exists('apache_note') && !empty($CFG->apacheloguser)) {
+        $apachelog_username = clean_filename($USER->username);
+        $apachelog_name = clean_filename($USER->firstname. " ".$USER->lastname);
+        $apachelog_userid = $USER->id;
+        if (isset($USER->realuser)) {
+            if ($realuser = get_record('user', 'id', $USER->realuser)) {
+                $apachelog_username = clean_filename($realuser->username." as ".$apachelog_username);
+                $apachelog_name = clean_filename($realuser->firstname." ".$realuser->lastname ." as ".$apachelog_name);
+                $apachelog_userid = clean_filename($realuser->id." as ".$apachelog_userid);
+            }
+        }
         switch ($CFG->apacheloguser) {
             case 3:
-                $logname = clean_filename($USER->username);
+                $logname = $apachelog_username;
                 break;
             case 2:
-                $logname = clean_filename($USER->firstname." ".$USER->lastname);
+                $logname = $apachelog_name;
                 break;
             case 1:
             default:
-                $logname = $USER->id;
+                $logname = $apachelog_userid;
                 break;
         }
         apache_note('MOODLEUSER', $logname);
@@ -439,32 +660,14 @@ $CFG->httpswwwroot = $CFG->wwwroot;
 /// Adjust ALLOWED_TAGS
     adjust_allowed_tags();
 
-/***
- *** init_performance_info() {
- ***
- *** Initializes our performance info early.
- *** 
- *** Pairs up with get_performance_info() which is actually
- *** in moodlelib.php. This function is here so that we can 
- *** call it before all the libs are pulled in. 
- ***
- **/
-function init_performance_info() {
 
-    global $PERF;
-
-    $PERF = new Object;
-    $PERF->dbqueries = 0;   
-    $PERF->logwrites = 0;
-    if (function_exists('microtime')) {
-        $PERF->starttime = microtime();
+/// Use a custom script replacement if one exists
+    if (!empty($CFG->customscripts)) {
+        if (($customscript = custom_script_path()) !== false) {
+            require ($customscript);
         }
-    if (function_exists('memory_get_usage')) {
-        $PERF->startmemory = memory_get_usage();
     }
-    if (function_exists('posix_times')) {
-        $PERF->startposixtimes = posix_times();  
-    }
-}
 
+/// note: we can not block non utf-8 installatrions here, because empty mysql database
+/// might be converted to utf-8 in admin/index.php during installation
 ?>
