@@ -1,4 +1,4 @@
-<?php // $Id: tablelib.php,v 1.6.2.5 2005/11/23 21:10:51 mjollnir_ Exp $
+<?php // $Id: tablelib.php,v 1.19.2.2 2007/02/22 18:25:21 stronk7 Exp $
 
 define('TABLE_VAR_SORT',   1);
 define('TABLE_VAR_HIDE',   2);
@@ -288,6 +288,19 @@ class flexible_table {
 
         $this->currpage = optional_param($this->request[TABLE_VAR_PAGE], 0);
         $this->setup = true;
+
+    /// Always introduce the "flexible" class for the table if not specified
+    /// No attributes, add flexible class
+        if (empty($this->attributes)) {
+            $this->attributes['class'] = 'flexible';
+    /// No classes, add flexible class
+        } else if (!isset($this->attributes['class'])) {
+            $this->attributes['class'] = 'flexible';
+    /// No flexible class in passed classes, add flexible class
+        } else if (!in_array('flexible', explode(' ', $this->attributes['class']))) {
+            $this->attributes['class'] = trim('flexible ' . $this->attributes['class']);
+        }
+
     }
 
     function get_sql_sort($uniqueid = NULL) {
@@ -447,10 +460,12 @@ class flexible_table {
 
             if($this->is_collapsible) {
                 if(!empty($this->sess->collapse[$column])) {
-                    $icon_hide = ' <a href="'.$this->baseurl.$this->request[TABLE_VAR_SHOW].'='.$column.'"><img src="'.$CFG->pixpath.'/t/switch_plus.gif" title="'.get_string('show').' '.$this->headers[$index].'" /></a>';
+                    // some headers contain < br/> tags, do not include in title
+                    $icon_hide = ' <a href="'.$this->baseurl.$this->request[TABLE_VAR_SHOW].'='.$column.'"><img src="'.$CFG->pixpath.'/t/switch_plus.gif" title="'.get_string('show').' '.strip_tags($this->headers[$index]).'" alt="'.get_string('show').'" /></a>';
                 }
                 else if($this->headers[$index] !== NULL) {
-                    $icon_hide = ' <a href="'.$this->baseurl.$this->request[TABLE_VAR_HIDE].'='.$column.'"><img src="'.$CFG->pixpath.'/t/switch_minus.gif" title="'.get_string('hide').' '.$this->headers[$index].'" /></a>';
+                    // some headers contain < br/> tags, do not include in title
+                    $icon_hide = ' <a href="'.$this->baseurl.$this->request[TABLE_VAR_HIDE].'='.$column.'"><img src="'.$CFG->pixpath.'/t/switch_minus.gif" title="'.get_string('hide').' '.strip_tags($this->headers[$index]).'" alt="'.get_string('hide').'" /></a>';
                 }
             }
 
@@ -467,48 +482,73 @@ class flexible_table {
                 if($this->is_sortable) {
                     $icon_sort_first = $icon_sort_last = '';
                     if($primary_sort_column == 'firstname') {
+                        $lsortorder = get_string('asc');
                         if($primary_sort_order == SORT_ASC) {
-                            $icon_sort_first = ' <img src="'.$CFG->pixpath.'/t/down.gif" />';
+                            $icon_sort_first = ' <img src="'.$CFG->pixpath.'/t/down.gif" alt="'.get_string('asc').'" />';
+                            $fsortorder = get_string('asc');
                         }
                         else {
-                            $icon_sort_first = ' <img src="'.$CFG->pixpath.'/t/up.gif" />';
+                            $icon_sort_first = ' <img src="'.$CFG->pixpath.'/t/up.gif" alt="'.get_string('desc').'" />';
+                            $fsortorder = get_string('desc');
                         }
                     }
                     else if($primary_sort_column == 'lastname') {
+                        $fsortorder = get_string('asc');
                         if($primary_sort_order == SORT_ASC) {
-                            $icon_sort_last = ' <img src="'.$CFG->pixpath.'/t/down.gif" />';
+                            $icon_sort_last = ' <img src="'.$CFG->pixpath.'/t/down.gif" alt="'.get_string('asc').'" />';
+                            $lsortorder = get_string('asc');
                         }
                         else {
-                            $icon_sort_last = ' <img src="'.$CFG->pixpath.'/t/up.gif" />';
+                            $icon_sort_last = ' <img src="'.$CFG->pixpath.'/t/up.gif" alt="'.get_string('desc').'" />';
+                            $lsortorder = get_string('desc');
                         }
+                    } else {
+                        $fsortorder = get_string('asc');
+                        $lsortorder = get_string('asc');
                     }
-                    $this->headers[$index] = '<a href="'.$this->baseurl.$this->request[TABLE_VAR_SORT].'=firstname">'.get_string('firstname').'</a> '.$icon_sort_first.' / '.
-                                          '<a href="'.$this->baseurl.$this->request[TABLE_VAR_SORT].'=lastname">'.get_string('lastname').'</a> '.$icon_sort_last;
+                    $this->headers[$index] = '<a href="'.$this->baseurl.$this->request[TABLE_VAR_SORT].'=firstname">'.get_string('firstname').'<span class="accesshide">'.get_string('sortby').' '.get_string('firstname').' '.$fsortorder.'</span></a> '.$icon_sort_first.' / '.
+                                          '<a href="'.$this->baseurl.$this->request[TABLE_VAR_SORT].'=lastname">'.get_string('lastname').'<span class="accesshide">'.get_string('sortby').' '.get_string('lastname').' '.$lsortorder.'</span></a> '.$icon_sort_last;
                 }
                 break;
 
+                case 'userpic':
+                    // do nothing, do not display sortable links      
+                break;
+
                 default:
                 if($this->is_sortable) {
                     if($primary_sort_column == $column) {
                         if($primary_sort_order == SORT_ASC) {
-                            $icon_sort = ' <img src="'.$CFG->pixpath.'/t/down.gif" />';
+                            $icon_sort = ' <img src="'.$CFG->pixpath.'/t/down.gif" alt="'.get_string('asc').'" />';
+                            $localsortorder = get_string('asc');
                         }
                         else {
-                            $icon_sort = ' <img src="'.$CFG->pixpath.'/t/up.gif" />';
+                            $icon_sort = ' <img src="'.$CFG->pixpath.'/t/up.gif" alt="'.get_string('desc').'" />';
+                            $localsortorder = get_string('desc');
                         }
+                    } else {
+                        $localsortorder = get_string('asc');  
                     }
-                    $this->headers[$index] = '<a href="'.$this->baseurl.$this->request[TABLE_VAR_SORT].'='.$column.'">'.$this->headers[$index].'</a>';
+                    $this->headers[$index] = '<a href="'.$this->baseurl.$this->request[TABLE_VAR_SORT].'='.$column.'">'.$this->headers[$index].'<span class="accesshide">'.get_string('sortby').' '.$this->headers[$index].' '.$localsortorder.'</span></a>';
                 }
             }
 
             if($this->headers[$index] === NULL) {
-                echo '<th class="header c'.$index.$this->column_class[$column].'">&nbsp;</th>';
+                echo '<th class="header c'.$index.$this->column_class[$column].'" scope="col">&nbsp;</th>';
             }
             else if(!empty($this->sess->collapse[$column])) {
-                echo '<th class="header c'.$index.$this->column_class[$column].'">'.$icon_hide.'</th>';
+                echo '<th class="header c'.$index.$this->column_class[$column].'" scope="col">'.$icon_hide.'</th>';
             }
             else {
-                echo '<th class="header c'.$index.$this->column_class[$column].'" nowrap="nowrap"'.$this->make_styles_string($this->column_style[$column]).'>'.$this->headers[$index].$icon_sort.'<div class="commands">'.$icon_hide.'</div></th>';
+                // took out nowrap for accessibility, might need replacement
+                if (!is_array($this->column_style[$column])) {
+                    // $usestyles = array('white-space:nowrap');
+                    $usestyles = '';
+                 } else {
+                    // $usestyles = $this->column_style[$column]+array('white-space'=>'nowrap');
+                    $usestyles = $this->column_style[$column];
+                 }
+                echo '<th class="header c'.$index.$this->column_class[$column].'" '.$this->make_styles_string($usestyles).' scope="col">'.$this->headers[$index].$icon_sort.'<div class="commands">'.$icon_hide.'</div></th>';
             }
 
         }
