@@ -4,12 +4,12 @@
  * uploadlib.php - This class handles all aspects of fileuploading
  *
  * @author ?
- * @version 1.5
+ * @version $Id: uploadlib.php,v 1.22.4.2 2007/04/02 14:53:13 skodak Exp $
  * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
  * @package moodlecore
  */
 
-error_reporting(E_ALL ^ E_NOTICE);
+//error_reporting(E_ALL ^ E_NOTICE);
 /**
  * This class handles all aspects of fileuploading
  */
@@ -64,10 +64,15 @@ class upload_manager {
      * @param int $modbytes Max bytes for this module - this and $course->maxbytes are used to get the maxbytes from {@link get_max_upload_file_size()}.
      * @param boolean $silent Whether to notify errors or not.
      * @param boolean $allownull Whether we care if there's no file when we've set the input name.
+     * @param boolean $allownullmultiple Whether we care if there's no files AT ALL  when we've got multiples. This won't complain if we have file 1 and file 3 but not file 2, only for NO FILES AT ALL.
      */
-    function upload_manager($inputname='', $deleteothers=false, $handlecollisions=false, $course=null, $recoverifmultiple=false, $modbytes=0, $silent=false, $allownull=false) {
+    function upload_manager($inputname='', $deleteothers=false, $handlecollisions=false, $course=null, $recoverifmultiple=false, $modbytes=0, $silent=false, $allownull=false, $allownullmultiple=true) {
         
-        global $CFG;
+        global $CFG, $SITE;
+
+        if (empty($course->id)) {
+            $course = $SITE;
+        }
         
         $this->config->deleteothers = $deleteothers;
         $this->config->handlecollisions = $handlecollisions;
@@ -80,7 +85,7 @@ class upload_manager {
         $this->course = $course;
         $this->inputname = $inputname;
         if (empty($this->inputname)) {
-            $this->config->allownull = true;
+            $this->config->allownull = $allownullmultiple;
         }
     }
     
@@ -94,18 +99,20 @@ class upload_manager {
      */
     function preprocess_files() {
         global $CFG;
+
         foreach ($_FILES as $name => $file) {
             $this->status = true; // only set it to true here so that we can check if this function has been called.
             if (empty($this->inputname) || $name == $this->inputname) { // if we have input name, only process if it matches.
                 $file['originalname'] = $file['name']; // do this first for the log.
                 $this->files[$name] = $file; // put it in first so we can get uploadlog out in print_upload_log.
+                $this->files[$name]['uploadlog'] = ''; // initialize error log
                 $this->status = $this->validate_file($this->files[$name]); // default to only allowing empty on multiple uploads.
-                if (!$this->status && ($this->files[$name]['error'] == 0 || $this->files[$name]['error'] == 4) && $this->config->allownull) {
+                if (!$this->status && ($this->files[$name]['error'] == 0 || $this->files[$name]['error'] == 4) && ($this->config->allownull || empty($this->inputname))) {
                     // this shouldn't cause everything to stop.. modules should be responsible for knowing which if any are compulsory.
                     continue; 
                 }
-                if ($this->status && $CFG->runclamonupload) {
-                    $this->status = clam_scan_file($this->files[$name],$this->course);
+                if ($this->status && !empty($CFG->runclamonupload)) {
+                    $this->status = clam_scan_moodle_file($this->files[$name],$this->course);
                 }
                 if (!$this->status) {
                     if (!$this->config->recoverifmultiple && count($this->files) > 1) {
@@ -119,12 +126,12 @@ class upload_manager {
                         }
                         $this->status = false;
                         return false;
-                    }
-                    else if (count($this->files) == 1) {
-                        if (!$this->config->silent) {
+
+                    } else if (count($this->files) == 1) {
+
+                        if (!$this->config->silent and !$this->config->allownull) {
                             notify($this->files[$name]['uploadlog']);
-                        }
-                        else {
+                        } else {
                             $this->notify .= '<br />'. $this->files[$name]['uploadlog'];
                         }
                         $this->status = false;
@@ -140,6 +147,7 @@ class upload_manager {
                     }
                     $this->files[$name]['name'] = $newname;
                     $this->files[$name]['clear'] = true; // ok to save.
+                    $this->config->somethingtosave = true;
                 }
             }
         }
@@ -185,6 +193,14 @@ class upload_manager {
         if (!$this->status) { // preprocess_files hasn't been run
             $this->preprocess_files();
         }
+
+        // if there are no files, bail before we create an empty directory.
+        if (empty($this->config->somethingtosave)) {
+            return true;
+        }
+
+        $savedsomething = false;
+
         if ($this->status) {
             if (!(strpos($destination, $CFG->dataroot) === false)) {
                 // take it out for giving to make_upload_directory
@@ -229,8 +245,11 @@ class upload_manager {
                 $this->delete_other_files($destination, $exceptions);
             }
         }
-        if (!$savedsomething) {
+        if (empty($savedsomething)) {
             $this->status = false;
+            if ((empty($this->config->allownull) && !empty($this->inputname)) || (empty($this->inputname) && empty($this->config->allownullmultiple))) {
+                notify(get_string('uploadnofilefound'));
+            }
             return false;
         }
         return $this->status;
@@ -256,6 +275,7 @@ class upload_manager {
      * @param array $exceptions Full paths of files to KEEP.
      */
     function delete_other_files($destination, $exceptions=null) {
+        $deletedsomething = false;
         if ($filestodel = get_directory_list($destination)) {
             foreach ($filestodel as $file) {
                 if (!is_array($exceptions) || !in_array($file, $exceptions)) {
@@ -283,7 +303,10 @@ class upload_manager {
      * @todo verify return type - this function does not appear to return anything since $file is passed in by reference
      */
     function handle_filename_collision($destination, &$file, $format='%s_%d.%s') {
-        $bits = explode('.', $file['name']);
+        $part1 = explode('.', $file['name']); 
+        $bits = array(); 
+        $bits[1] = array_pop($part1); 
+        $bits[0] = implode('.', $part1);
         // check for collisions and append a nice numberydoo.
         if (file_exists($destination .'/'. $file['name'])) {
             $a->oldname = $file['name'];
@@ -368,8 +391,11 @@ class upload_manager {
      * prints a log of everything that happened (of interest) to each file in _FILES
      * @param $return - optional, defaults to false (log is echoed)
      */
-    function print_upload_log($return=false) {
+    function print_upload_log($return=false,$skipemptyifmultiple=false) {
         foreach (array_keys($this->files) as $i => $key) {
+            if (count($this->files) > 1 && !empty($skipemptyifmultiple) && $this->files[$key]['error'] == 4) {
+                continue;
+            }
             $str .= '<strong>'. get_string('uploadfilelog', 'moodle', $i+1) .' '
                 .((!empty($this->files[$key]['originalname'])) ? '('.$this->files[$key]['originalname'].')' : '')
                 .'</strong> :'. nl2br($this->files[$key]['uploadlog']) .'<br />';
@@ -385,7 +411,7 @@ class upload_manager {
      @return boolean
      */
     function get_new_filename() {
-        if (!empty($this->inputname) && count($this->files) == 1) {
+        if (!empty($this->inputname) and count($this->files) == 1 and $this->files[$this->inputname]['error'] != 4) {
             return $this->files[$this->inputname]['name'];
         }
         return false;
@@ -396,7 +422,7 @@ class upload_manager {
      * @return boolean
      */
     function get_new_filepath() {
-        if (!empty($this->inputname) && count($this->files) == 1) {
+        if (!empty($this->inputname) and count($this->files) == 1 and $this->files[$this->inputname]['error'] != 4) {
             return $this->files[$this->inputname]['fullpath'];
         }
         return false;
@@ -407,7 +433,7 @@ class upload_manager {
      * @return boolean
      */
     function get_original_filename() {
-        if (!empty($this->inputname) && count($this->files) == 1) {
+        if (!empty($this->inputname) and count($this->files) == 1 and $this->files[$this->inputname]['error'] != 4) {
             return $this->files[$this->inputname]['originalname'];
         }
         return false;
@@ -418,7 +444,7 @@ class upload_manager {
      * @return string
      */
     function get_errors() {
-        return '<p style="color:red;">'. $this->notify .'</p>';
+        return '<p class="notifyproblem">'. $this->notify .'</p>';
     }
 }
 
@@ -562,7 +588,7 @@ function clam_replace_infected_file($file) {
  * @param course $course {@link $COURSE}
  * @return int 1 if good, 0 if something goes wrong (opposite from actual error code from clam)
  */ 
-function clam_scan_file(&$file, $course) {
+function clam_scan_moodle_file(&$file, $course) {
     global $CFG, $USER;
 
     if (is_array($file) && is_uploaded_file($file['tmp_name'])) { // it's from $_FILES
@@ -650,7 +676,7 @@ function clam_mail_admins($notice) {
     
     $site = get_site();
         
-    $subject = get_string('clamemailsubject', 'moodle', $site->fullname);
+    $subject = get_string('clamemailsubject', 'moodle', format_string($site->fullname));
     $admins = get_admins();
     foreach ($admins as $admin) {
         email_to_user($admin, get_admin(), $subject, $notice);
@@ -751,20 +777,15 @@ function clam_change_log($oldpath, $newpath, $update=true) {
     global $CFG;
     
     if (!$record = get_record('log', 'info', $oldpath, 'module', 'upload')) {
-        error_log('couldn\'t find record');
         return false;
     }
     $record->info = $newpath;
     if ($update) {
-        if (update_record('log', $record)) {
-            error_log('updated record');
-        }
+        update_record('log', $record);
     }
     else {
         unset($record->id);
-        if (insert_record('log', $record)) {
-            error_log('inserted record');
-        }
+        insert_record('log', $record);
     }
 }
-?>
\ No newline at end of file
+?>
