@@ -1,7 +1,14 @@
-<?php // $Id: index.php,v 1.88.2.5 2006/07/06 10:09:34 skodak Exp $
+<?php // $Id: index.php,v 1.109.2.13 2007/07/06 17:39:56 stronk7 Exp $
+
 
     require_once("../config.php");
 
+    // check if major upgrade needed - also present in /index.php
+    if ((int)$CFG->version < 2006101100) { //1.7 or older
+        @require_logout();
+        redirect("$CFG->wwwroot/$CFG->admin/");
+    }
+
     $loginguest  = optional_param('loginguest', 0, PARAM_BOOL); // determines whether visitors are logged in as guest automatically
     $testcookies = optional_param('testcookies', 0, PARAM_BOOL); // request cookie test
 
@@ -16,44 +23,36 @@
         $session_has_timed_out = false;
     }
 
-    //HTTPS is potentially required in this page
-    httpsrequired();
-
 /// Check if the guest user exists.  If not, create one.
-    if (! record_exists("user", "username", "guest")) {
-        $guest->auth        = "manual"; 
-        $guest->username    = "guest"; 
-        $guest->password    = hash_internal_user_password("guest");
-        $guest->firstname   = addslashes(get_string("guestuser"));
-        $guest->lastname    = " ";
-        $guest->email       = "root@localhost";
-        $guest->description = addslashes(get_string("guestuserinfo"));
-        $guest->confirmed   = 1;
-        $guest->lang        = $CFG->lang;
-        $guest->timemodified= time();
-
-        if (! $guest->id = insert_record("user", $guest)) {
-            notify("Could not create guest user record !!!");
+    if (! record_exists('user', 'username', 'guest')) {
+        if (! $guest = create_guest_record()) {
+            notify('Could not create guest user record !!!');
         }
     }
 
-/// Load alternative login screens if necessary
+// setup and verify auth settings
 
-    if ($CFG->auth == 'cas' && !empty($CFG->cas_enabled)) {
-        require($CFG->dirroot.'/auth/cas/login.php');
-    }
+if (!isset($CFG->registerauth)) {
+    set_config('registerauth', '');
+}
 
-//  See http://moodle.org/mod/forum/discuss.php?d=39918#187611
-//    if ($CFG->auth == 'shibboleth') {
-//        if (!empty($SESSION->shibboleth_checked) ) {  // Just come from there
-//            unset($SESSION->shibboleth_checked);
-//        } else if (empty($_POST)) {                   // No incoming data, so redirect
-//            redirect($CFG->wwwroot.'/auth/shibboleth/index.php');
-//        }
-//    }
-    
+if (!isset($CFG->auth_instructions)) {
+    set_config('auth_instructions', '');
+}
+
+// auth plugins may override these - SSO anyone?
+$frm  = false;
+$user = false;
+
+$authsequence = get_enabled_auth_plugins(true); // auths, in sequence
+foreach($authsequence as $authname) {
+    $authplugin = get_auth_plugin($authname);
+    $authplugin->loginpage_hook();
+}
+
+//HTTPS is potentially required in this page
+httpsrequired();
 
-    
 /// Define variables used in page
     if (!$site = get_site()) {
         error("No site found!");
@@ -64,23 +63,26 @@
     } else {
         $currlang = current_language();
         $langs    = get_list_of_languages();
-        $langmenu = popup_form ("$CFG->httpswwwroot/login/index.php?lang=", $langs, "chooselang", $currlang, "", "", "", true);
+        $langlabel = '<span class="accesshide">'.get_string('language').':</span>';
+        $langmenu = popup_form ("$CFG->httpswwwroot/login/index.php?lang=", $langs, "chooselang", $currlang, "", "", "", true, 'self', $langlabel);
     }
 
     $loginsite = get_string("loginsite");
 
     $loginurl = (!empty($CFG->alternateloginurl)) ? $CFG->alternateloginurl : '';
 
-    $frm = false;
-    $user = false;
 
+    if ($user !== false or $frm !== false) {
+        // some auth plugin already supplied these
 
-    if ((!empty($SESSION->wantsurl) and strstr($SESSION->wantsurl,'username=guest')) or $loginguest) {
+    } else if ((!empty($SESSION->wantsurl) and strstr($SESSION->wantsurl,'username=guest')) or $loginguest) {
         /// Log in as guest automatically (idea from Zbigniew Fiedorowicz)
         $frm->username = 'guest';
         $frm->password = 'guest';
+
     } else if (!empty($SESSION->wantsurl) && file_exists($CFG->dirroot.'/login/weblinkauth.php')) {
         // Handles the case of another Moodle site linking into a page on this site
+        //TODO: move weblink into own auth plugin
         include($CFG->dirroot.'/login/weblinkauth.php');
         if (function_exists(weblink_auth)) {
             $user = weblink_auth($SESSION->wantsurl);
@@ -90,6 +92,7 @@
         } else {
             $frm = data_submitted($loginurl);
         }
+
     } else {
         $frm = data_submitted($loginurl);
     }
@@ -100,11 +103,11 @@
 
         $errormsg = get_string("cookiesnotenabled");
 
-    } else  if ($frm) {                             // Login WITH cookies
+    } else if ($frm) {                             // Login WITH cookies
 
         $frm->username = trim(moodle_strtolower($frm->username));
 
-        if ($CFG->auth == 'none' && empty($CFG->extendedusernamechars)) {
+        if (is_enabled_auth('none') && empty($CFG->extendedusernamechars)) {
             $string = eregi_replace("[^(-\.[:alnum:])]", "", $frm->username);
             if (strcmp($frm->username, $string)) {
                 $errormsg = get_string('username').': '.get_string("alphanumerical");
@@ -112,10 +115,12 @@
             }
         }
 
-        if (($frm->username == 'guest') and empty($CFG->guestloginbutton)) {
+        if ($user) {
+            //user already supplied by aut plugin prelogin hook
+        } else if (($frm->username == 'guest') and empty($CFG->guestloginbutton)) {
             $user = false;    /// Can't log in as guest if guest button is disabled
             $frm = false;
-        } else if (!$user) {
+        } else {
             if (empty($errormsg)) {
                 $user = authenticate_user_login($frm->username, $frm->password);
             }
@@ -124,6 +129,16 @@
 
         if ($user) {
 
+            // language setup
+            if ($user->username == 'guest') {
+                // no predefined language for guests - use existing session or default site lang
+                unset($user->lang);
+
+            } else if (!empty($user->lang)) {
+                // unset previous session language - use user preference instead
+                unset($SESSION->lang);
+            }
+
             if (empty($user->confirmed)) {       // This account was never confirmed
                 print_header(get_string("mustconfirm"), get_string("mustconfirm") ); 
                 print_heading(get_string("mustconfirm"));
@@ -139,34 +154,44 @@
 
 
             update_user_login_times();
-            set_moodle_cookie($USER->username);
+            if (empty($CFG->nolastloggedin)) {
+                set_moodle_cookie($USER->username);
+            } else {
+                // do not store last logged in user in cookie
+                // auth plugins can temporarily override this from loginpage_hook()
+                // do not save $CFG->nolastloggedin in database!
+                set_moodle_cookie('nobody');
+            }
             set_login_session_preferences();
-        
-        
+
+            /// This is what lets the user do anything on the site :-)
+            load_all_capabilities();
+
             //Select password change url
-            if (is_internal_auth($USER->auth) || $CFG->{'auth_'.$USER->auth.'_stdchangepassword'}){
-                $passwordchangeurl=$CFG->wwwroot.'/login/change_password.php';
-            } elseif($CFG->changepassword) {
-                $passwordchangeurl=$CFG->changepassword;
+            $userauth = get_auth_plugin($USER->auth);
+            if ($userauth->can_change_password()) {
+                if ($userauth->change_password_url()) {
+                    $passwordchangeurl = $userauth->change_password_url();
+                } else {
+                    $passwordchangeurl = $CFG->httpswwwroot.'/login/change_password.php';
+                }
             } else {
                 $passwordchangeurl = '';
             }
-            
+
             // check whether the user should be changing password
             if (get_user_preferences('auth_forcepasswordchange', false) || $frm->password == 'changeme'){
                 if ($passwordchangeurl != '') {
                     redirect($passwordchangeurl);
                 } else {
-                    error("You cannot proceed without changing your password. 
-                           However there is no available page for changing it.
-                           Please contact your Moodle Administrator.");
+                    error(get_strin('nopasswordchangeforced', 'auth'));
                 }
             }
 
 
           /// Prepare redirection
             if (user_not_fully_set_up($USER)) {
-                $urltogo = $CFG->wwwroot.'/user/edit.php?id='.$USER->id.'&amp;course='.SITEID;
+                $urltogo = $CFG->wwwroot.'/user/edit.php';
                 // We don't delete $SESSION->wantsurl yet, so we get there later
 
             } else if (isset($SESSION->wantsurl) and (strpos($SESSION->wantsurl, $CFG->wwwroot) === 0)) {
@@ -175,12 +200,12 @@
 
             } else {
                 // no wantsurl stored or external - go to homepage
-                $urltogo = $CFG->wwwroot;
+                $urltogo = $CFG->wwwroot.'/';
                 unset($SESSION->wantsurl);
             }
 
           /// Go to my-moodle page instead of homepage if mymoodleredirect enabled
-            if (!isadmin() and !empty($CFG->mymoodleredirect) and !isguest()) {
+            if (!has_capability('moodle/site:config',get_context_instance(CONTEXT_SYSTEM)) and !empty($CFG->mymoodleredirect) and !isguest()) {
                 if ($urltogo == $CFG->wwwroot or $urltogo == $CFG->wwwroot.'/' or $urltogo == $CFG->wwwroot.'/index.php') {
                     $urltogo = $CFG->wwwroot.'/my/';
                 }
@@ -189,21 +214,19 @@
 
             // check if user password has expired
             // Currently supported only for ldap-authentication module
-            if (isset($CFG->ldap_expiration) && $CFG->ldap_expiration == 1 ) {
-                if (function_exists('auth_password_expire')){
-                    $days2expire = auth_password_expire($USER->username);
-                    if (intval($days2expire) > 0 && intval($days2expire) < intval($CFG->{$USER->auth.'_expiration_warning'})) {
-                        print_header("$site->fullname: $loginsite", "$site->fullname", $loginsite, $focus, "", true, "<div align=\"right\">$langmenu</div>"); 
+            if (!empty($userauth->config->expiration) and $userauth->config->expiration == 1) {
+                    $days2expire = $userauth->password_expire($USER->username);
+                        if (intval($days2expire) > 0 && intval($days2expire) < intval($userauth->config->expiration_warning)) {
+                        print_header("$site->fullname: $loginsite", "$site->fullname", $loginsite, $focus, "", true, "<div class=\"langmenu\">$langmenu</div>"); 
                         notice_yesno(get_string('auth_passwordwillexpire', 'auth', $days2expire), $passwordchangeurl, $urltogo); 
                         print_footer();
                         exit;
                     } elseif (intval($days2expire) < 0 ) {
-                        print_header("$site->fullname: $loginsite", "$site->fullname", $loginsite, $focus, "", true, "<div align=\"right\">$langmenu</div>"); 
+                        print_header("$site->fullname: $loginsite", "$site->fullname", $loginsite, $focus, "", true, "<div class=\"langmenu\">$langmenu</div>"); 
                         notice_yesno(get_string('auth_passwordisexpired', 'auth'), $passwordchangeurl, $urltogo);
                         print_footer();
                         exit;
                     }    
-                }
             }
 
             reset_login_count();
@@ -216,6 +239,13 @@
             if (empty($errormsg)) {
                 $errormsg = get_string("invalidlogin");
             }
+
+            // TODO: if the user failed to authenticate, check if the username corresponds to a remote mnet user
+            if ( !empty($CFG->mnet_dispatcher_mode) 
+                 && $CFG->mnet_dispatcher_mode === 'strict'
+                 && is_enabled_auth('mnet')) {
+                $errormsg .= get_string('loginlinkmnetuser', 'mnet', "mnet_email.php?u=$frm->username");
+            }
         }
     }
 
@@ -248,28 +278,25 @@
         set_moodle_cookie('nobody');   // To help search for cookies
     }
     
-    if (empty($frm->username) && $CFG->auth != 'shibboleth') {  // See bug 5184
+    if (empty($frm->username) && $authsequence[0] != 'shibboleth') {  // See bug 5184
         $frm->username = get_moodle_cookie() === 'nobody' ? '' : get_moodle_cookie();
         $frm->password = "";
     }
     
     if (!empty($frm->username)) {
-        $focus = "login.password";
+        $focus = "password";
     } else {
-        $focus = "login.username";
+        $focus = "username";
     }
-    
-    if (isset($CFG->auth_instructions)) {
-        $CFG->auth_instructions = trim($CFG->auth_instructions);
-    }
-    if ($CFG->auth == "email" or $CFG->auth == "none" or !empty($CFG->auth_instructions)) {
+
+    if (!empty($CFG->registerauth) or is_enabled_auth('none') or !empty($CFG->auth_instructions)) {
         $show_instructions = true;
     } else {
         $show_instructions = false;
     }
 
     print_header("$site->fullname: $loginsite", $site->fullname, $loginsite, $focus, 
-                 '', true, '<div class="langmenu" align="right">'.$langmenu.'</div>'); 
+                 '', true, '<div class="langmenu">'.$langmenu.'</div>'); 
 
     include("index_form.html");
 
