@@ -1,4 +1,4 @@
-<?php // $Id: assignment.class.php,v 1.8.2.8 2005/11/25 08:42:12 toyomoyo Exp $
+<?php // $Id: assignment.class.php,v 1.30.2.1 2007/04/05 03:18:45 nicolasconnault Exp $
 
 /**
  * Extend the base assignment class for assignments where you upload a single file
@@ -29,7 +29,7 @@ class assignment_uploadsingle extends assignment_base {
                     }
                     //died right here
                     //require_once($ffurl);                
-                    $output = '<img align="middle" src="'.$CFG->pixpath.'/f/'.$icon.'" height="16" width="16" alt="'.$icon.'" />'.
+                    $output = '<img align="middle" src="'.$CFG->pixpath.'/f/'.$icon.'" class="icon" alt="'.$icon.'" />'.
                             '<a href="'.$ffurl.'" >'.$file.'</a><br />';
                 }
             }
@@ -45,8 +45,13 @@ class assignment_uploadsingle extends assignment_base {
     }
 
     function view() {
-
+    
         global $USER;
+        
+        $context = get_context_instance(CONTEXT_MODULE,$this->cm->id);
+        require_capability('mod/assignment:view', $context);
+        
+        add_to_log($this->course->id, "assignment", "view", "view.php?id={$this->cm->id}", $this->assignment->id, $this->cm->id);
 
         $this->view_header();
 
@@ -59,12 +64,13 @@ class assignment_uploadsingle extends assignment_base {
         if ($submission = $this->get_submission()) {
             if ($submission->timemarked) {
                 $this->view_feedback();
-            } else if ($filecount) {
+            }
+            if ($filecount) {
                 print_simple_box($this->print_user_files($USER->id, true), 'center');
             }
         }
 
-        if ($this->isopen() && (!$filecount || $this->assignment->resubmit || !$submission->timemarked)) {
+        if (has_capability('mod/assignment:submit', $context)  && $this->isopen() && (!$filecount || $this->assignment->resubmit || !$submission->timemarked)) {
             $this->view_upload_form();
         }
 
@@ -77,25 +83,26 @@ class assignment_uploadsingle extends assignment_base {
         $struploadafile = get_string("uploadafile");
         $strmaxsize = get_string("maxsize", "", display_size($this->assignment->maxbytes));
 
-        echo '<center>';
+        echo '<div style="text-align:center">';
         echo '<form enctype="multipart/form-data" method="post" '.
              "action=\"$CFG->wwwroot/mod/assignment/upload.php\">";
+        echo '<fieldset class="invisiblefieldset">';
         echo "<p>$struploadafile ($strmaxsize)</p>";
         echo '<input type="hidden" name="id" value="'.$this->cm->id.'" />';
         require_once($CFG->libdir.'/uploadlib.php');
         upload_print_form_fragment(1,array('newfile'),false,null,0,$this->assignment->maxbytes,false);
         echo '<input type="submit" name="save" value="'.get_string('uploadthisfile').'" />';
+        echo '</fieldset>';
         echo '</form>';
-        echo '</center>';
+        echo '</div>';
     }
 
 
     function upload() {
+        
         global $CFG, $USER;
-
-        if (isguest($USER->id)) {
-            error(get_string('guestnoupload','assignment'));
-        }
+        
+        require_capability('mod/assignment:submit', get_context_instance(CONTEXT_MODULE, $this->cm->id));
 
         $this->view_header(get_string('upload'));
 
@@ -112,13 +119,13 @@ class assignment_uploadsingle extends assignment_base {
             $dir = $this->file_area_name($USER->id);
 
             require_once($CFG->dirroot.'/lib/uploadlib.php');
-            $um = new upload_manager('newfile',true,false,$course,false,$this->assignment->maxbytes);
+            $um = new upload_manager('newfile',true,false,$this->course,false,$this->assignment->maxbytes);
             if ($um->process_file_uploads($dir)) {
                 $newfile_name = $um->get_new_filename();
                 if ($submission) {
                     $submission->timemodified = time();
                     $submission->numfiles     = 1;
-                    $submission->comment = addslashes($submission->comment);
+                    $submission->submissioncomment = addslashes($submission->submissioncomment);
                     unset($submission->data1);  // Don't need to update this.
                     unset($submission->data2);  // Don't need to update this.
                     if (update_record("assignment_submissions", $submission)) {
@@ -131,6 +138,7 @@ class assignment_uploadsingle extends assignment_base {
                     }
                 } else {
                     $newsubmission = $this->prepare_new_submission($USER->id);
+                    $newsubmission->timemodified = time();
                     $newsubmission->numfiles = 1;
                     if (insert_record('assignment_submissions', $newsubmission)) {
                         add_to_log($this->course->id, 'assignment', 'upload', 
@@ -151,52 +159,26 @@ class assignment_uploadsingle extends assignment_base {
         $this->view_footer();
     }
 
+    function setup_elements(&$mform) {
+        global $CFG, $COURSE;
 
-    /*
-     *  Display and process the submissions 
-     */ 
-    function process_feedback() {                 
-                
-        global $USER;
-         
-        if (!$feedback = data_submitted()) {      // No incoming data?
-            return false;
-        }     
-                          
-        ///For save and next, we need to know the userid to save, and the userid to go...
-        ///We use a new hidden field in the form, and set it to -1. If it's set, we use this
-        ///as the userid to store...
-        if ((int)$feedback->saveuserid !== -1){
-            $feedback->userid = $feedback->saveuserid;
-        }       
-        
-        if (!empty($feedback->cancel)) {          // User hit cancel button
-            return false;
-        }       
-        
-        $newsubmission = $this->get_submission($feedback->userid, true);  // Get or make one
-                
-        $newsubmission->grade      = $feedback->grade;
-        $newsubmission->comment    = $feedback->comment;
-        $newsubmission->format     = $feedback->format;
-        $newsubmission->teacher    = $USER->id;
-        $newsubmission->mailed     = 0;       // Make sure mail goes out (again, even)
-        $newsubmission->timemarked = time();
+        $ynoptions = array( 0 => get_string('no'), 1 => get_string('yes'));
 
-        unset($newsubmission->data1);  // Don't need to update this.
-        unset($newsubmission->data2);  // Don't need to update this.
+        $mform->addElement('select', 'resubmit', get_string("allowresubmit", "assignment"), $ynoptions);
+        $mform->setHelpButton('resubmit', array('resubmit', get_string('allowresubmit', 'assignment'), 'assignment'));
+        $mform->setDefault('resubmit', 0);
 
-        if (! update_record('assignment_submissions', $newsubmission)) {
-            return false;
-        }
-        
-        add_to_log($this->course->id, 'assignment', 'update grades', 
-                   'submissions.php?id='.$this->assignment->id.'&user='.$feedback->userid, $feedback->userid, $this->cm->id);   
-        
-        return $newsubmission;
-                 
-    }   
+        $mform->addElement('select', 'emailteachers', get_string("emailteachers", "assignment"), $ynoptions);
+        $mform->setHelpButton('emailteachers', array('emailteachers', get_string('emailteachers', 'assignment'), 'assignment'));
+        $mform->setDefault('emailteachers', 0);
 
+        $choices = get_max_upload_sizes($CFG->maxbytes, $COURSE->maxbytes);
+        $choices[1] = get_string('uploadnotallowed');
+        $choices[0] = get_string('courseuploadlimit') . ' ('.display_size($COURSE->maxbytes).')';
+        $mform->addElement('select', 'maxbytes', get_string('maximumsize', 'assignment'), $choices);
+        $mform->setDefault('maxbytes', $CFG->assignment_maxbytes);
+
+    }
 
 }
 
