@@ -17,14 +17,17 @@ define('CHAT_SIDEKICK_MESSAGE',     0x22);
 define('CHAT_SIDEKICK_BEEP',        0x23);
 
 $phpversion = phpversion();
-echo 'Moodle chat daemon v1.0 on PHP '.$phpversion." (\$Id: chatd.php,v 1.13.2.11 2005/02/06 10:02:29 skodak Exp $)\n\n";
+echo 'Moodle chat daemon v1.0 on PHP '.$phpversion." (\$Id: chatd.php,v 1.32 2007/01/28 21:18:17 skodak Exp $)\n\n";
 
 /// Set up all the variables we need   /////////////////////////////////////
 
 /// $CFG variables are now defined in database by chat/lib.php
 
-$_SERVER['PHP_SELF']    = 'dummy';
-$_SERVER['SERVER_NAME'] = 'dummy';
+$_SERVER['PHP_SELF']        = 'dummy';
+$_SERVER['SERVER_NAME']     = 'dummy';
+$_SERVER['HTTP_USER_AGENT'] = 'dummy';
+
+$nomoodlecookie = true;
 
 include('../../config.php');
 include('lib.php');
@@ -41,6 +44,10 @@ if(!empty($safemode)) {
     die("Error: Cannot run with PHP safe_mode = On. Turn off safe_mode in php.ini.\n");
 }
 
+if(ini_get('allow_call_time_pass_reference') == '0') {
+    die("Error: Cannot run with PHP allow_call_time_pass_reference = Off. Turn on allow_call_time_pass_reference in php.ini.\n");
+}
+
 @set_time_limit (0);
 set_magic_quotes_runtime(0);
 error_reporting(E_ALL);
@@ -64,7 +71,7 @@ class ChatConnection {
 
     function ChatConnection($resource) {
         $this->handle = $resource;
-        socket_getpeername($this->handle, &$this->ip, &$this->port);
+        @socket_getpeername($this->handle, &$this->ip, &$this->port);
     }
 }
 
@@ -84,6 +91,9 @@ class ChatDaemon {
     var $sets_info = array();    // Keyed by sessionid exactly like conn_sets, one of these for each of those
     var $chatrooms = array();    // Keyed by chatid, holding arrays of data
 
+    // IMPORTANT: $conn_sets, $sets_info and $chatrooms must remain synchronized!
+    //            Pay extra attention when you write code that affects any of them!
+
     function ChatDaemon() {
         $this->_trace_level         = E_ALL ^ E_USER_NOTICE;
         $this->_pcntl_exists        = function_exists('pcntl_fork');
@@ -113,7 +123,9 @@ class ChatDaemon {
                 if(!empty($chatroom['users'])) {
                     foreach($chatroom['users'] as $sessionid => $userid) {
                         // We will be polling each user as required
+                        $this->trace('...shall we poll '.$sessionid.'?');
                         if($this->sets_info[$sessionid]['chatuser']->lastmessageping < $this->_last_idle_poll) {
+                            $this->trace('YES!');
                             // This user hasn't been polled since his last message
                             if($this->write_data($this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL], '<!-- poll -->') === false) {
                                 // User appears to have disconnected
@@ -211,12 +223,12 @@ class ChatDaemon {
 
     function get_user_window($sessionid) {
 
-        global $CFG, $THEME;
+        global $CFG;
 
         static $str;
 
         $info = &$this->sets_info[$sessionid];
-        $oldlang = chat_language_override($info['lang']);
+        course_setup($info['course'], $info['user']);
 
         $timenow = time();
 
@@ -235,8 +247,8 @@ class ChatDaemon {
 
         ob_start();
         echo '<html><head>';
-        echo '<script language="JavaScript">';
-        echo "<!-- //hide\n";
+        echo '<script text="text/javascript">';
+        echo "//<![CDATA[\n";
 
         echo 'function openpopup(url,name,options,fullscreen) {';
         echo 'fullurl = "'.$CFG->wwwroot.'" + url;';
@@ -247,8 +259,8 @@ class ChatDaemon {
         echo '}';
         echo 'windowobj.focus();';
         echo 'return false;';
-        echo "}\n-->\n";
-        echo '</script></head><body style="font-face: serif;" bgcolor="'.$THEME->body.'">';
+        echo "}\n//]]>\n";
+        echo '</script></head><body style="font-face: serif;" bgcolor="#FFFFFF">';
 
         echo '<table style="width: 100%;"><tbody>';
 
@@ -269,7 +281,7 @@ class ChatDaemon {
             echo fullname($userinfo['user'])."<br />";
             echo "<font color=\"#888888\">$str->idle: ".format_time($lastping, $str)."</font> ";
             echo '<a target="empty" href="http://'.$CFG->chat_serverhost.':'.$CFG->chat_serverport.'/?win=beep&amp;beep='.$userinfo['user']->id.
-                 '&chat_sid='.$sessionid.'&amp;groupid='.$this->sets_info[$sessionid]['groupid'].'">'.$str->beep."</a>\n";
+                 '&chat_sid='.$sessionid.'">'.$str->beep."</a>\n";
             echo "</font></p>";
             echo "<td></tr>";
         }
@@ -281,7 +293,6 @@ class ChatDaemon {
 
         echo "</body>\n</html>\n";
 
-        chat_language_restore($oldlang);
         return ob_get_clean();
 
     }
@@ -321,7 +332,7 @@ class ChatDaemon {
                 $msg->timestamp = time();
 
                 // Commit to DB
-                insert_record('chat_messages', $msg);
+                insert_record('chat_messages', $msg, false);
 
                 // OK, now push it out to all users
                 $this->message_broadcast($msg, $this->sets_info[$sessionid]['user']);
@@ -367,8 +378,8 @@ class ChatDaemon {
 
                 // The refresh value is 2 seconds higher than the configuration variable because we are doing JS refreshes all the time.
                 // However, if the JS doesn't work for some reason, we still want to refresh once in a while.
-                $header .= "Refresh: ".(intval($CFG->chat_refresh_userlist) + 2)."; URL=http://$CFG->chat_serverhost:$CFG->chat_serverport/?win=users&".
-                           "chat_sid=".$sessionid."&groupid=".$this->sets_info[$sessionid]['groupid']."\n";
+                $header .= "Refresh: ".(intval($CFG->chat_refresh_userlist) + 2)."; url=http://$CFG->chat_serverhost:$CFG->chat_serverport/?win=users&".
+                           "chat_sid=".$sessionid."\n";
                 $header .= "\n";
 
                 // That's enough headers for one lousy dummy response
@@ -415,7 +426,7 @@ class ChatDaemon {
                 $msg->message = addslashes($msg->message);
 
                 // Commit to DB
-                insert_record('chat_messages', $msg);
+                insert_record('chat_messages', $msg, false);
 
                 // Undo the hack
                 $msg->message = $origmsg;
@@ -453,7 +464,7 @@ class ChatDaemon {
         socket_close($handle);
     }
 
-    function promote_final($sessionid, $groupid, $customdata) {
+    function promote_final($sessionid, $customdata) {
         if(isset($this->conn_sets[$sessionid])) {
             $this->trace('Set cannot be finalized: Session '.$sessionid.' is already active');
             return false;
@@ -483,18 +494,6 @@ class ChatDaemon {
 
         global $CHAT_HTMLHEAD_JS, $CFG;
 
-        // A really sad thing, to have to do this by hand.... :-(
-        $lang = NULL;
-        if(empty($lang) && !empty($course->lang)) {
-            $lang = $course->lang;
-        }
-        if(empty($lang) && !empty($user->lang)) {
-            $lang = $user->lang;
-        }
-        if(empty($lang)) {
-            $lang = $CFG->lang;
-        }
-
         $this->conn_sets[$sessionid] = $this->conn_half[$sessionid];
 
         // This whole thing needs to be purged of redundant info, and the
@@ -502,13 +501,14 @@ class ChatDaemon {
         $this->sets_info[$sessionid] = array(
             'lastinfocommit' => 0,
             'lastmessageindex' => 0,
+            'course'    => $course,
             'courseid'  => $course->id,
             'chatuser'  => $chatuser,
             'chatid'    => $chat->id,
             'user'      => $user,
             'userid'    => $user->id,
-            'groupid'   => $groupid,
-            'lang'      => $lang,
+            'groupid'   => $chatuser->groupid,
+            'lang'      => $chatuser->lang,
             'quirks'    => $customdata['quirks']
         );
 
@@ -525,25 +525,25 @@ class ChatDaemon {
 
         $this->dismiss_half($sessionid, false);
         $this->write_data($this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL], $CHAT_HTMLHEAD_JS);
-        $this->trace('Connection accepted: '.$this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL].', SID: '.$sessionid.' UID: '.$chatuser->userid.' GID: '.intval($groupid), E_USER_WARNING);
+        $this->trace('Connection accepted: '.$this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL].', SID: '.$sessionid.' UID: '.$chatuser->userid.' GID: '.$chatuser->groupid, E_USER_WARNING);
 
         // Finally, broadcast the "entered the chat" message
 
         $msg = &New stdClass;
         $msg->chatid = $chatuser->chatid;
         $msg->userid = $chatuser->userid;
-        $msg->groupid = 0;
+        $msg->groupid = $chatuser->groupid;
         $msg->system = 1;
         $msg->message = 'enter';
         $msg->timestamp = time();
 
-        insert_record('chat_messages', $msg);
+        insert_record('chat_messages', $msg, false);
         $this->message_broadcast($msg, $this->sets_info[$sessionid]['user']);
 
         return true;
     }
 
-    function promote_ufo($handle, $type, $sessionid, $groupid, $customdata) {
+    function promote_ufo($handle, $type, $sessionid, $customdata) {
         if(empty($this->conn_ufo)) {
             return false;
         }
@@ -585,7 +585,7 @@ class ChatDaemon {
                     $this->conn_half[$sessionid][$type] = $handle;
 
                     // Do the bookkeeping
-                    $this->promote_final($sessionid, $groupid, $customdata);
+                    $this->promote_final($sessionid, $customdata);
 
                     // It's not an UFO anymore
                     $this->dismiss_ufo($handle, false);
@@ -627,6 +627,7 @@ class ChatDaemon {
         unset($this->conn_sets[$sessionid]);
         unset($this->sets_info[$sessionid]);
         unset($this->chatrooms[$chatroom]['users'][$sessionid]);
+        $this->trace('Removed all traces of user with session '.$sessionid, E_USER_NOTICE);
         return true;
     }
 
@@ -706,7 +707,8 @@ class ChatDaemon {
             {
 
                 // Simply give them the message
-                $output = chat_format_message_manually($message, $info['courseid'], $sender, $info['user'], $info['lang']);
+                course_setup($info['course'], $info['user']);
+                $output = chat_format_message_manually($message, $info['courseid'], $sender, $info['user']);
                 $this->trace('Delivering message "'.$output->text.'" to '.$this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL]);
 
                 if($output->beep) {
@@ -734,13 +736,13 @@ class ChatDaemon {
         $msg = &New stdClass;
         $msg->chatid = $info['chatid'];
         $msg->userid = $info['userid'];
-        $msg->groupid = 0;
+        $msg->groupid = $info['groupid'];
         $msg->system = 1;
         $msg->message = 'exit';
         $msg->timestamp = time();
 
         $this->trace('User has disconnected, destroying uid '.$info['userid'].' with SID '.$sessionid, E_USER_WARNING);
-        insert_record('chat_messages', $msg);
+        insert_record('chat_messages', $msg, false);
 
         // *************************** IMPORTANT
         //
@@ -972,7 +974,13 @@ while(true) {
                     continue;
                 }
 
-                if(!ereg('win=(chat|users|message|beep).*&chat_sid=([a-zA-Z0-9]*)&groupid=([0-9]*) HTTP', $data, $info)) {
+                if (strlen($data) == 2048) { // socket_read has more data, ignore all data
+                    $DAEMON->trace('UFO with '.$handle.': Data too long; connection closed', E_USER_WARNING);
+                    $DAEMON->dismiss_ufo($handle, true, 'Data too long; connection closed');
+                    continue;
+                }
+
+                if(!ereg('win=(chat|users|message|beep).*&chat_sid=([a-zA-Z0-9]*) HTTP', $data, $info)) {
                     // Malformed data
                     $DAEMON->trace('UFO with '.$handle.': Request with malformed data; connection closed', E_USER_WARNING);
                     $DAEMON->dismiss_ufo($handle, true, 'Request with malformed data; connection closed');
@@ -981,7 +989,6 @@ while(true) {
 
                 $type      = $info[1];
                 $sessionid = $info[2];
-                $groupid   = $info[3];
 
                 $customdata = array();
 
@@ -1027,7 +1034,7 @@ while(true) {
                 }
 
                 // OK, now we know it's something good... promote it and pass it all the data it needs
-                $DAEMON->promote_ufo($handle, $type, $sessionid, $groupid, $customdata);
+                $DAEMON->promote_ufo($handle, $type, $sessionid, $customdata);
                 continue;
             }
         }
@@ -1036,7 +1043,7 @@ while(true) {
     $now = time();
 
     // Clean up chatrooms with no activity as required
-    if($now - $DAEMON->_last_idle_poll > $DAEMON->_freq_poll_idle_chat) {
+    if($now - $DAEMON->_last_idle_poll >= $DAEMON->_freq_poll_idle_chat) {
         $DAEMON->poll_idle_chats($now);
     }
 
