@@ -1,4 +1,4 @@
-<?php  // $Id: chatinput.php,v 1.11.2.1 2006/07/12 02:28:37 martinlanghoff Exp $
+<?php  // $Id: chatinput.php,v 1.19 2007/01/28 21:18:17 skodak Exp $
 
     $nomoodlecookie = true;     // Session not needed!
 
@@ -11,33 +11,26 @@
         error('Not logged in!');
     }
 
-    //Get the course theme
-    $course = get_record('course','id',$chatuser->course,'','','','','id,theme');
-    //Set the global course if necessary
-    if (!empty($course->theme)) {
-        global $course;
-    }
     //Get the user theme
-    $USER = get_record('user','id',$chatuser->userid,'','','','','id, theme');
+    $USER = get_record('user', 'id', $chatuser->userid);
 
-    //Adjust the prefered theme (main, course, user)
-    theme_setup();
-
-    chat_force_language($chatuser->lang);
+    //Setup course, lang and theme
+    course_setup($chatuser->course);
 
     ob_start();
     ?>
     <script type="text/javascript">
-    <!--
+    //<![CDATA[
     var waitFlag = false;
     function empty_field_and_submit() {
         if(waitFlag) return false;
         waitFlag = true;
         var input_chat_message = document.getElementById('input_chat_message');
-        document.sendForm.chat_message.value = input_chat_message.value;
+        document.getElementById('sendForm').chat_message.value = input_chat_message.value;
         input_chat_message.value = '';
         input_chat_message.className = 'wait';
-        document.sendForm.submit();
+        document.getElementById('sendForm').submit();
+        enableForm();
         return false;
     }
 
@@ -48,23 +41,25 @@
         input_chat_message.focus();
     }
 
-    // -->
+    //]]>
     </script>
     <?php
 
     $meta = ob_get_clean();
-    print_header('', '', '', 'inputForm.chat_message', $meta, false);
+    print_header('', '', '', 'input_chat_message', $meta, false);
 
 ?>
-    <form action="../empty.php" method="POST" target="empty" name="inputForm"
-          OnSubmit="return empty_field_and_submit()">
+    <form action="../empty.php" method="post" target="empty" id="inputForm"
+          onsubmit="return empty_field_and_submit()">
         &gt;&gt;<input type="text" id="input_chat_message" name="chat_message" size="60" value="" />
         <?php helpbutton('chatting', get_string('helpchatting', 'chat'), 'chat', true, false); ?>
     </form>
 
-    <form action="insert.php" method="POST" target="empty" name="sendForm">
+    <form action="insert.php" method="post" target="empty" id="sendForm">
         <input type="hidden" name="chat_sid" value="<?php echo $chat_sid ?>" />
         <input type="hidden" name="chat_message" />
     </form>
+</div>
+</div>
 </body>
 </html>
