@@ -1,4 +1,4 @@
-<?php  // $Id: view.php,v 1.44.2.1 2006/08/10 15:30:58 skodak Exp $
+<?php  // $Id: view.php,v 1.56.2.6 2007/05/15 18:27:07 skodak Exp $
 ///////////////////////////////////////////////////////////////////////////
 //                                                                       //
 // NOTICE OF COPYRIGHT                                                   //
@@ -28,7 +28,7 @@
     require_once("$CFG->libdir/rsslib.php");
 
     require_once('pagelib.php');
-    
+
 
 /// One of these is necessary!
     $id    = optional_param('id', 0, PARAM_INT);  // course module id
@@ -43,7 +43,6 @@
     $approve = optional_param('approve', 0, PARAM_INT);    //approval recordid
     $delete = optional_param('delete', 0, PARAM_INT);    //delete recordid
 
-    
     if ($id) {
         if (! $cm = get_coursemodule_from_id('data', $id)) {
             error('Course Module ID was incorrect');
@@ -82,12 +81,13 @@
         $record = NULL;
     }
 
-
     require_course_login($course, true, $cm);
 
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+    require_capability('mod/data:viewentry', $context);
 
 /// If it's hidden then it's don't show anything.  :)
-    if (empty($cm->visible) and !isteacher($course->id)) {
+    if (empty($cm->visible) and !has_capability('mod/data:managetemplates', $context)) {
         $strdatabases = get_string("modulenameplural", "data");
         $navigation = "<a href=\"index.php?id=$course->id\">$strdatabases</a> ->";
         print_header_simple(format_string($data->name), "",
@@ -96,7 +96,7 @@
     }
 
 /// If we have an empty Database then redirect because this page is useless without data
-    if (isteacher($course->id)) {
+    if (has_capability('mod/data:managetemplates', $context)) {
         if (!record_exists('data_fields','dataid',$data->id)) {      // Brand new database!
             redirect($CFG->wwwroot.'/mod/data/field.php?d='.$data->id);  // Redirect to field entry
         }
@@ -114,6 +114,10 @@
         $SESSION->dataprefs[$data->id]['order'] = ($data->defaultsortdir == 0) ? 'ASC' : 'DESC';
     }
     $search = optional_param('search', $SESSION->dataprefs[$data->id]['search'], PARAM_NOTAGS);
+    $textlib = new textlib();
+    if ($textlib->strlen($search) < 2) {
+        $search = '';
+    }
     $SESSION->dataprefs[$data->id]['search'] = $search;   // Make it sticky
 
     $sort = optional_param('sort', $SESSION->dataprefs[$data->id]['sort'], PARAM_INT);
@@ -147,20 +151,24 @@
         $USER->editing = $edit;
     }
 
-/// RSS and CSS meta
+/// RSS and CSS and JS meta
     $meta = '';
     if (!empty($CFG->enablerssfeeds) && !empty($CFG->data_enablerssfeeds) && $data->rssarticles > 0) {
         $rsspath = rss_get_url($course->id, $USER->id, 'data', $data->id);
         $meta .= '<link rel="alternate" type="application/rss+xml" ';
-        $meta .= 'title ="'.$course->shortname.': %fullname%" href="'.$rsspath.'" />';
+        $meta .= 'title ="'. format_string($course->shortname) .': %fullname%" href="'.$rsspath.'" />';
     }
     if ($data->csstemplate) {
         $meta .= '<link rel="stylesheet" type="text/css" href="'.$CFG->wwwroot.'/mod/data/css.php?d='.$data->id.'" /> ';
     }
-    
+    if ($data->jstemplate) {
+        $meta .= '<script type="text/javascript" src="'.$CFG->wwwroot.'/mod/data/js.php?d='.$data->id.'"></script>';
+    }
+
+
 /// Print the page header
     $PAGE->print_header($course->shortname.': %fullname%', '', $meta);
-    
+
 
 /// If we have blocks, then print the left side here
     if (!empty($CFG->showblocksonmodpages)) {
@@ -173,8 +181,14 @@
         echo '<td id="middle-column">';
     }
 
+/// Check to see if groups are being used here
+    $groupmode = groupmode($course, $cm);
+    $currentgroup = setup_and_print_groups($course, $groupmode,
+                                            'view.php?d='.$data->id.'&amp;search='.s($search).'&amp;sort='.s($sort).
+                                            '&amp;order='.s($order).'&amp;');
+
     print_heading(format_string($data->name));
-    
+
     // Do we need to show a link to the RSS feed for the records?
     if (!empty($CFG->enablerssfeeds) && !empty($CFG->data_enablerssfeeds) && $data->rssarticles > 0) {
         echo '<div style="float:right;">';
@@ -182,23 +196,14 @@
         echo '</div>';
         echo '<div style="clear:both;"></div>';
     }
-    
-    if ($data->intro and empty($page) and empty($record) and $mode != 'single') {
-        print_simple_box(format_text($data->intro), 'center', '70%', '', 5, 'generalbox', 'intro');
-    }
 
-/// Check to see if groups are being used here
-    if ($groupmode = groupmode($course, $cm)) {   // Groups are being used
-        $currentgroup = setup_and_print_groups($course, $groupmode, 
-                                            'view.php?d='.$data->id.'&amp;search='.s($search).'&amp;sort='.s($sort).
-                                            '&amp;order='.s($order).'&amp;');
-    } else {
-        $currentgroup = 0;
+    if ($data->intro and empty($page) and empty($record) and $mode != 'single') {
+        print_box(format_text($data->intro), 'generalbox', 'intro');
     }
 
 /// Delete any requested records
 
-    if ($delete && confirm_sesskey() && (isteacher($course->id) or data_isowner($delete))) {
+    if ($delete && confirm_sesskey() && (has_capability('mod/data:manageentries', $context) or data_isowner($delete))) {
         if ($confirm = optional_param('confirm',0,PARAM_INT)) {
             if ($deleterecord = get_record('data_records', 'id', $delete)) {   // Need to check this is valid
                 if ($deleterecord->dataid == $data->id) {                       // Must be from this database
@@ -221,7 +226,7 @@
         } else {   // Print a confirmation page
             if ($deleterecord = get_record('data_records', 'id', $delete)) {   // Need to check this is valid
                 if ($deleterecord->dataid == $data->id) {                       // Must be from this database
-                    notice_yesno(get_string('confirmdeleterecord','data'), 
+                    notice_yesno(get_string('confirmdeleterecord','data'),
                             'view.php?d='.$data->id.'&amp;delete='.$delete.'&amp;confirm=1&amp;sesskey='.sesskey(),
                             'view.php?d='.$data->id);
 
@@ -244,12 +249,12 @@
     } else {
         $currenttab = 'list';
     }
-    include('tabs.php'); 
+    include('tabs.php');
 
 
 /// Approve any requested records
 
-    if ($approve && confirm_sesskey() && isteacher($course->id)) {
+    if ($approve && confirm_sesskey() && has_capability('mod/data:approve', $context)) {
         if ($approverecord = get_record('data_records', 'id', $approve)) {   // Need to check this is valid
             if ($approverecord->dataid == $data->id) {                       // Must be from this database
                 $newrecord->id = $approverecord->id;
@@ -262,7 +267,7 @@
     }
 
 // If not teacher, check whether user has sufficient records to view
-    if (!isteacher($course->id) and data_numentries($data) < $data->requiredentriestoview){
+    if (!has_capability('mod/data:managetemplates', $context) and data_numentries($data) < $data->requiredentriestoview){
         notify (($data->requiredentriestoview - data_numentries($data)).'&nbsp;'.get_string('insufficiententries','data'));
         echo '</td></tr></table>';
         print_footer($course);
@@ -272,7 +277,7 @@
 
 /// We need to examine the whole dataset to produce the correct paging
 
-    if ((!isteacher($course->id)) && ($data->approval)) {
+    if ((!has_capability('mod/data:managetemplates', $context)) && ($data->approval)) {
         if (isloggedin()) {
             $approveselect = ' AND (r.approved=1 OR r.userid='.$USER->id.') ';
         } else {
@@ -289,36 +294,35 @@
     }
 
 /// Find the field we are sorting on
-    if ($sort) {
-        
-        $sortfield = data_get_field_from_id($sort, $data);
+    if ($sort and $sortfield = data_get_field_from_id($sort, $data)) {
+
         $sortcontent = $sortfield->get_sort_field();
         $sortcontentfull = $sortfield->get_sort_sql('c.'.$sortcontent);
 
-        $what = ' DISTINCT r.id, r.approved, r.userid, u.firstname, u.lastname, c.'.$sortcontent.' ';
+        $what = ' DISTINCT r.id, r.approved, r.userid, u.firstname, u.lastname, c.'.$sortcontent.', '.$sortcontentfull.' AS _order ';
         $count = ' COUNT(DISTINCT c.recordid) ';
         $tables = $CFG->prefix.'data_content c,'.$CFG->prefix.'data_records r,'.$CFG->prefix.'data_content c1, '.$CFG->prefix.'user u ';
-        $where =  'WHERE c.recordid = r.id 
-                     AND c.fieldid = '.$sort.' 
-                     AND r.dataid = '.$data->id.' 
-                     AND r.userid = u.id 
+        $where =  'WHERE c.recordid = r.id
+                     AND c.fieldid = '.$sort.'
+                     AND r.dataid = '.$data->id.'
+                     AND r.userid = u.id
                      AND c1.recordid = r.id ';
-        $sortorder = ' ORDER BY '.$sortcontentfull.' '.$order.' , r.id ASC ';
+        $sortorder = ' ORDER BY _order '.$order.' , r.id ASC ';
         if ($search) {
-            $searchselect = ' AND (c1.content LIKE "%'.$search.'%") ';
+            $searchselect = ' AND (c1.content ' . sql_ilike() . " '%$search%') "; //Be case-insensitive
         } else {
             $searchselect = ' ';
         }
 
-    } else if ($search) { 
+    } else if ($search) {
         $what = ' DISTINCT r.id, r.approved, r.userid, u.firstname, u.lastname ';
         $count = ' COUNT(DISTINCT c.recordid) ';
         $tables = $CFG->prefix.'data_content c,'.$CFG->prefix.'data_records r, '.$CFG->prefix.'user u ';
-        $where =  'WHERE c.recordid = r.id 
-                     AND r.userid = u.id 
+        $where =  'WHERE c.recordid = r.id
+                     AND r.userid = u.id
                      AND r.dataid = '.$data->id;
         $sortorder = ' ORDER BY r.id ASC ';
-        $searchselect = ' AND (c.content LIKE "%'.$search.'%") ';
+        $searchselect = ' AND (c.content ' . sql_ilike() . " '%$search%') "; //Be case-insensitive
 
     } else {
         $what = ' DISTINCT r.id, r.approved, r.timecreated, r.userid, u.firstname, u.lastname ';
@@ -333,7 +337,7 @@
 /// To actually fetch the records
 
     $fromsql = ' FROM '.$tables.$where.$groupselect.$approveselect.$searchselect;
-     
+
     $sqlselect = 'SELECT '.$what.$fromsql.$sortorder;
 
     $sqlcount  = 'SELECT '.$count.$fromsql;   // Total number of records
@@ -351,10 +355,10 @@
 #            if ($content = get_field('data_content', 'content', 'recordid', $record->id, 'fieldid', $sort)) {
 #                $content = addslashes($content);
 #                if ($order == 'ASC') {
-#                    $lessthan = " AND $sortcontentfull < '$content' 
+#                    $lessthan = " AND $sortcontentfull < '$content'
 #                                   OR ($sortcontentfull = '$content' AND r.id < '$record->id') ";
 #                } else {
-#                    $lessthan = " AND $sortcontentfull > '$content' 
+#                    $lessthan = " AND $sortcontentfull > '$content'
 #                                   OR ($sortcontentfull = '$content' AND r.id < '$record->id') ";
 #                }
 #            } else {   // Failed to find data (shouldn't happen), so fall back to something easy
@@ -385,12 +389,11 @@
 
 /// Get the actual records
 
-    $limit = sql_paging_limit($page * $nowperpage, $nowperpage);
-    $records = get_records_sql($sqlselect.$limit);
+    $records = get_records_sql($sqlselect, $page * $nowperpage, $nowperpage);
 
     if (empty($records)) {     // Nothing to show!
         if ($record) {         // Something was requested so try to show that at least (bug 5132)
-            if (isteacher($course->id) || empty($data->approval) || 
+            if (has_capability('mod/data:manageentries', $context) || empty($data->approval) ||
                      $record->approved || (isloggedin() && $record->userid == $USER->id)) {
                 if (!$currentgroup || $record->groupid == $currentgroup || $record->groupid == 0) {
                     $records[] = $record;
@@ -401,6 +404,7 @@
             data_print_template('singletemplate', $records, $data, $search, $page);
         } else if ($search){
             notify(get_string('nomatch','data'));
+            data_print_show_all_form($data, $perpage, $sort, $order, $mode);  
         } else {
             notify(get_string('norecords','data'));
         }
@@ -440,7 +444,7 @@
     }
 
     if ($records || $search || $page) {
-        data_print_preference_form($data, $perpage, $search, $sort, $order);
+        data_print_preference_form($data, $perpage, $search, $sort, $order, $mode);
     }
 
 /// If we have blocks, then print the left side here
@@ -451,7 +455,7 @@
             blocks_print_group($PAGE, $pageblocks, BLOCK_POS_RIGHT);
             echo '</td>';
         }
-        echo '</table>';
+        echo '</tr></table>';
     }
 
     print_footer($course);
