@@ -1,10 +1,11 @@
-<?php  // $Id: index.php,v 1.70.2.2 2005/11/21 15:40:53 stronk7 Exp $
+<?php  // $Id: index.php,v 1.90.2.3 2007/05/15 18:27:03 skodak Exp $
 
     require_once("../../config.php");
     require_once("lib.php");
     require_once("$CFG->libdir/rsslib.php");
 
-    optional_variable($id);          // course
+    $id = optional_param('id', 0, PARAM_INT);                   // Course id
+    $subscribe = optional_param('subscribe', null, PARAM_INT);  // Subscribe/Unsubscribe all forums
 
     if ($id) {
         if (! $course = get_record("course", "id", $id)) {
@@ -17,8 +18,9 @@
     }
 
     require_course_login($course);
+    $currentgroup = get_and_set_current_group($course, groupmode($course));
+    $coursecontext = get_context_instance(CONTEXT_COURSE, $course->id);
 
-    $currentgroup = get_current_group($course->id);
 
     unset($SESSION->fromdiscussion);
 
@@ -39,6 +41,8 @@
     $stryes = get_string('yes');
     $strno = get_string('no');
     $strrss = get_string("rss");
+    $strweek = get_string('week');
+    $strsection = get_string('section');
 
     $searchform = forum_search_form($course);
 
@@ -58,7 +62,7 @@
         $generaltable->align[] = 'center';
     }
 
-    if ($can_subscribe = (isstudent($course->id) or isteacher($course->id) or isadmin())) {
+    if ($can_subscribe = has_capability('moodle/course:view', $coursecontext)) {
         $generaltable->head[] = $strsubscribed;
         $generaltable->align[] = 'center';
     }
@@ -77,7 +81,7 @@
 
     $generalforums = array();            // For now
     $learningforums = get_all_instances_in_course("forum", $course);
-
+    
     if ($forums = get_records("forum", "course", $id, "name ASC")) {  // All known forums
 
         if ($learningforums) {           // Copy "full" data into this complete array
@@ -88,9 +92,19 @@
         }
 
         foreach ($forums as $forum) {
+            
+            $cm = get_coursemodule_from_instance("forum", $forum->id, $course->id);
+            $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+            
+            if (!has_capability('mod/forum:viewdiscussion', $context)) {
+                if (isset($forum->keyreference)) {
+                    unset($learningforums[$forum->keyreference]);
+                }
+                continue;
+            }
             if (!isset($forum->visible)) {
                 $forum->visible = instance_is_visible("forum", $forum);
-                if (!$forum->visible and !isteacher($course->id)) {
+                if (!$forum->visible and !has_capability('moodle/course:viewhiddenactivities', $context)) {
                     if (isset($forum->keyreference)) {
                         unset($learningforums[$forum->keyreference]);
                     }
@@ -105,14 +119,8 @@
                         unset($learningforums[$forum->keyreference]);
                     }
                     break;
-                case "teacher":
-                    if (isteacher($course->id)) {
-                        $forum->visible = true;
-                        $generalforums[] = $forum;
-                    }
-                    break;
                 default:
-                    if (!$course->category or empty($forum->section)) {   // Site level or section 0
+                    if (($course->id == SITEID) or empty($forum->section)) {   // Site level or section 0
                         $generalforums[] = $forum;
                         if (isset($forum->keyreference)) {
                             unset($learningforums[$forum->keyreference]);
@@ -123,17 +131,48 @@
         }
     }
 
+    /// Do course wide subscribe/unsubscribe
+    if (!is_null($subscribe) && !isguest()) {
+        $allforums = array_merge($generalforums, $learningforums);
+        if ($allforums) {
+            foreach ($allforums as $forum) {
+                if (!forum_is_forcesubscribed($forum->id)) {
+                    $subscribed = forum_is_subscribed($USER->id, $forum->id);
+                    if ($subscribe && !$subscribed) {
+                        forum_subscribe($USER->id, $forum->id);
+                    } elseif (!$subscribe && $subscribed) {
+                        forum_unsubscribe($USER->id, $forum->id);
+                    }
+                }
+            }
+        }
+        $returnto = forum_go_back_to("index.php?id=$course->id");
+        if ($subscribe) {
+            add_to_log($course->id, "forum", "subscribeall", "index.php?id=$course->id", $course->id);
+            redirect($returnto, get_string("nowallsubscribed", "forum", format_string($course->shortname)), 1);
+        } else {
+            add_to_log($course->id, "forum", "unsubscribeall", "index.php?id=$course->id", $course->id);
+            redirect($returnto, get_string("nowallunsubscribed", "forum", format_string($course->shortname)), 1);
+        }
+    }
+
     /// First, let's process the general forums and build up a display
 
     if ($generalforums) {
         foreach ($generalforums as $forum) {
+           
+            $cm = get_coursemodule_from_instance("forum", $forum->id, $course->id);
+            $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+           
             if (isset($forum->groupmode)) {
                 $groupmode = groupmode($course, $forum);  /// Can do this because forum->groupmode is defined
             } else {
                 $groupmode = NOGROUPS;
             }
 
-            if ($groupmode == SEPARATEGROUPS and !isteacheredit($course->id)) {
+
+            // this is potentially wrong logic. could possibly check for if user has the right to hmmm
+            if ($groupmode == SEPARATEGROUPS and !has_capability('moodle/site:accessallgroups', $context)) {
                 $count = count_records_select("forum_discussions", "forum = '$forum->id' AND (groupid = '$currentgroup' OR groupid = '-1')");
             } else {
                 $count = count_records("forum_discussions", "forum", "$forum->id");
@@ -141,16 +180,17 @@
 
             if ($usetracking) {
                 if (($forum->trackingtype == FORUM_TRACKING_ON) || !isset($untracked[$forum->id])) {
-                    $groupid = ($groupmode==SEPARATEGROUPS && !isteacheredit($course->id)) ? $currentgroup : false;
+                    $groupid = ($groupmode==SEPARATEGROUPS && !has_capability('moodle/site:accessallgroups', $context)) ? $currentgroup : false;
                     $unread = forum_tp_count_forum_unread_posts($USER->id, $forum->id, $groupid);
                     if ($unread > 0) {
                         $unreadlink = '<span class="unread"><a href="view.php?f='.$forum->id.'">'.$unread.'</a>';
                         $unreadlink .= '<a title="'.$strmarkallread.'" href="markposts.php?f='.
-                                       $forum->id.'&amp;mark=read"><img src="'.$CFG->pixpath.'/t/clear.gif" alt="" /></a></span>';
+                                       $forum->id.'&amp;mark=read"><img src="'.$CFG->pixpath.'/t/clear.gif" alt="'.$strmarkallread.'" /></a></span>';
                     } else {
-                        $unreadlink = '<span class="read"><a href="view.php?f='.$forum->id.'">'.$unread.'</a>';
+                        $unreadlink = '<span class="read"><a href="view.php?f='.$forum->id.'">'.$unread.'</a></span>';
                     }
 
+
                     if ($forum->trackingtype == FORUM_TRACKING_OPTIONAL) {
                         $trackedlink = '<a title="'.$strnotrackforum.'" href="settracking.php?id='.
                                        $forum->id.'">'.$stryes.'</a>';
@@ -200,7 +240,7 @@
                 if (forum_is_forcesubscribed($forum->id)) {
                     $sublink = $stryes;
                 } else {
-                    if ($groupmode and !isteacheredit($course->id) and !mygroupid($course->id)) {
+                    if ($groupmode and !has_capability('moodle/site:accessallgroups', $context) and !mygroupid($course->id)) {
                         $sublink = $strno;   // Can't subscribe to a group forum (not in a group)
                         $forumlink = format_string($forum->name,true);
                     } else {
@@ -211,7 +251,12 @@
                             $subscribed = $strno;
                             $subtitle = get_string("subscribe", "forum");
                         }
-                        $sublink = "<a title=\"$subtitle\" href=\"subscribe.php?id=$forum->id\">$subscribed</a>";
+                        if ($forum->forcesubscribe == FORUM_DISALLOWSUBSCRIBE
+                                    && !has_capability('mod/forum:managesubscriptions', $context)) {
+                            $sublink = '-';
+                        } else {
+                            $sublink = "<a title=\"$subtitle\" href=\"subscribe.php?id=$forum->id\">$subscribed</a>";
+                        }
                     }
                 }
                 $row = array ($forumlink, $forum->intro, $discussionlink);
@@ -251,7 +296,7 @@
         $learningtable->align[] = 'center';
     }
 
-    if ($can_subscribe = (isstudent($course->id) or isteacher($course->id) or isadmin())) {
+    if ($can_subscribe) {
         $learningtable->head[] = $strsubscribed;
         $learningtable->align[] = 'center';
     }
@@ -265,19 +310,27 @@
 
     /// Now let's process the learning forums
 
-    if ($course->category) {    // Only real courses have learning forums
+    if ($course->id != SITEID) {    // Only real courses have learning forums
         // Add extra field for section number, at the front
-        array_unshift($learningtable->head, "");
+        if ($course->format == 'weeks' or $course->format == 'weekscss') {
+            array_unshift($learningtable->head, $strweek);
+        } else {
+            array_unshift($learningtable->head, $strsection);
+        }
         array_unshift($learningtable->align, "center");
 
 
         if ($learningforums) {
             $currentsection = "";
-
             foreach ($learningforums as $key => $forum) {
                 $groupmode = groupmode($course, $forum);  /// Can do this because forum->groupmode is defined
-
-                if ($groupmode == SEPARATEGROUPS and !isteacheredit($course->id)) {
+                $forum->visible = instance_is_visible("forum", $forum)
+                                    || has_capability('moodle/course:view', $coursecontext);
+                
+                $cm = get_coursemodule_from_instance("forum", $forum->id, $course->id);
+                $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+ 
+                if ($groupmode == SEPARATEGROUPS and !has_capability('moodle/site:accessallgroups', $context)) {
                     $count = count_records("forum_discussions", "forum", "$forum->id", "groupid", $currentgroup);
                 } else {
                     $count = count_records("forum_discussions", "forum", "$forum->id");
@@ -286,12 +339,14 @@
                 if ($usetracking) {
                     if (($forum->trackingtype == FORUM_TRACKING_ON) || 
                         !isset($untracked[$forum->id])) {
-                        $groupid = ($groupmode==SEPARATEGROUPS && !isteacheredit($course->id)) ? $currentgroup : false;
+                        $groupid = ($groupmode==SEPARATEGROUPS
+                                    && !has_capability('moodle/site:accessallgroups', $context))
+                                    ? $currentgroup : false;
                         $unread = forum_tp_count_forum_unread_posts($USER->id, $forum->id, $groupid);
                         if ($unread > 0) {
                             $unreadlink = '<span class="unread"><a href="view.php?f='.$forum->id.'">'.$unread.'</a>';
                             $unreadlink .= '<a title="'.$strmarkallread.'" href="markposts.php?f='.
-                                           $forum->id.'&amp;mark=read"><img src="'.$CFG->pixpath.'/t/clear.gif" alt="" /></a></span>';
+                                           $forum->id.'&amp;mark=read"><img src="'.$CFG->pixpath.'/t/clear.gif" alt="'.$strmarkallread.'" /></a></span>';
                         } else {
                             $unreadlink = '<span class="read"><a href="view.php?f='.$forum->id.'">'.$unread.'</a></span>';
                         }
@@ -350,7 +405,8 @@
                     if (forum_is_forcesubscribed($forum->id)) {
                         $sublink = $stryes;
                     } else {
-                        if ($groupmode and !isteacheredit($course->id) and !mygroupid($course->id)) {
+                        if ($groupmode and !has_capability('moodle/site:accessallgroups', $context)
+                                    and !mygroupid($course->id)) {
                             $sublink = $strno;   // Can't subscribe to a group forum (not in a group)
                             if ($groupmode == SEPARATEGROUPS) {
                                 $forumlink = format_string($forum->name,true);
@@ -396,15 +452,26 @@
 
     /// Output the page
 
-    if ($course->category) {
-        print_header("$course->shortname: $strforums", "$course->fullname",
+    if ($course->id != SITEID) {
+        print_header("$course->shortname: $strforums", $course->fullname,
                     "<a href=\"../../course/view.php?id=$course->id\">$course->shortname</a> -> $strforums",
                     "", "", true, $searchform, navmenu($course));
     } else {
-        print_header("$course->shortname: $strforums", "$course->fullname", "$strforums",
+        print_header("$course->shortname: $strforums", $course->fullname, "$strforums",
                     "", "", true, $searchform, navmenu($course));
     }
 
+    if (!isguest()) {
+        print_box_start('subscription');
+        echo '<span class="helplink">';
+        echo '<a href="index.php?id='.$course->id.'&amp;subscribe=1">'.get_string('allsubscribe', 'forum').'</a>';
+        echo '</span><br /><span class="helplink">';
+        echo '<a href="index.php?id='.$course->id.'&amp;subscribe=0">'.get_string('allunsubscribe', 'forum').'</a>';
+        echo '</span>';
+        print_box_end();
+        print_box('&nbsp;', 'clearer');
+    }
+
     if ($generalforums) {
         print_heading(get_string("generalforums", "forum"));
         print_table($generaltable);
