@@ -1,24 +1,32 @@
-<?php // $Id: rate.php,v 1.16 2005/11/15 21:49:30 skodak Exp $
+<?php // $Id: rate.php,v 1.22 2006/10/23 03:29:54 moodler Exp $
 
 //  Collect ratings, store them, then return to where we came from
 
 
     require_once("../../config.php");
     require_once("lib.php");
+    
 
-    if (isguest()) {
-        error("Guests are not allowed to rate posts.", $_SERVER["HTTP_REFERER"]);
+    $id = required_param('id',PARAM_INT);           // The course these ratings are part of
+    $forumid = required_param('forumid',PARAM_INT); // The forum the rated posts are from
+    
+    if (! $cm = get_coursemodule_from_instance('forum', $forumid, $id)) {
+        error('Course Module ID was incorrect');
     }
-
-    $id = required_param('id',PARAM_INT);  // The course these ratings are part of
-
+    
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+    
+    if (!has_capability('mod/forum:rate', $context)) {
+        error('You do not have the permission to rate this post');
+    }
+    
+    
     if (! $course = get_record("course", "id", $id)) {
         error("Course ID was incorrect");
     }
 
     require_login($course->id);
 
-    $CFG->debug = 0;    /// Temporarily
     $returntoview = false;
 
     if (!$data = data_submitted("$CFG->wwwroot/mod/forum/discuss.php")) {    // form submitted
@@ -39,7 +47,10 @@
             $postid = (int)$postid;
             $lastpostid = $postid;
 
-            if ($oldrating = get_record("forum_ratings", "userid", $USER->id, "post", $postid)) {
+            if ($rating == FORUM_UNSET_POST_RATING) {
+                delete_records('forum_ratings', 'post', $postid, 'userid', $USER->id);
+
+            } else if ($oldrating = get_record("forum_ratings", "userid", $USER->id, "post", $postid)) {
                 if ($rating != $oldrating->rating) {
                     $oldrating->rating = $rating;
                     $oldrating->time = time();
@@ -47,7 +58,7 @@
                         error("Could not update an old rating ($postid = $rating)");
                     }
                 }
-            } else if ($rating) {
+            } else {
                 unset($newrating);
                 $newrating->userid = $USER->id;
                 $newrating->time = time();
