@@ -1,4 +1,4 @@
-<?php //$Id: restorelib.php,v 1.30.2.5 2005/11/23 09:39:31 stronk7 Exp $
+<?php //$Id: restorelib.php,v 1.60 2006/12/19 07:00:14 vyshane Exp $
     //This php script contains all the stuff to backup/restore
     //forum mods
 
@@ -33,7 +33,7 @@
     //-----------------------------------------------------------
 
     function forum_restore_mods($mod,$restore) {
-
+        
         global $CFG,$db;
 
         $status = true;
@@ -44,6 +44,10 @@
         if ($data) {
             //Now get completed xmlized object
             $info = $data->info;
+            //if necessary, write to restorelog and adjust date/time fields
+            if ($restore->course_startdateoffset) {
+                restore_log_date_changes('Forum', $restore, $info['MOD']['#'], array('ASSESSTIMESTART', 'ASSESSTIMEFINISH'));
+            }
             //traverse_xmlize($info);                                                                     //Debug
             //print_object ($GLOBALS['traverse_array']);                                                  //Debug
             //$GLOBALS['traverse_array']="";                                                              //Debug
@@ -53,9 +57,18 @@
             $forum->type = backup_todb($info['MOD']['#']['TYPE']['0']['#']);
             $forum->name = backup_todb($info['MOD']['#']['NAME']['0']['#']);
             $forum->intro = backup_todb($info['MOD']['#']['INTRO']['0']['#']);
-            $forum->open = backup_todb($info['MOD']['#']['OPEN']['0']['#']);
-            $forum->assessed = backup_todb($info['MOD']['#']['ASSESSED']['0']['#']);
-            $forum->assesspublic = backup_todb($info['MOD']['#']['ASSESSPUBLIC']['0']['#']);
+            
+            // These get dropped in Moodle 1.7 when the new Roles System gets
+            // set up. Therefore they might or not be there depending on whether
+            // we are restoring a 1.6+ forum or a 1.7 or later forum backup.
+            if (isset($info['MOD']['#']['OPEN']['0']['#'])) {
+                $forum->open = backup_todb($info['MOD']['#']['OPEN']['0']['#']);
+            }
+            if (isset($info['MOD']['#']['ASSESSPUBLIC']['0']['#'])) {
+                $forum->assesspublic = backup_todb($info['MOD']['#']['ASSESSPUBLIC']['0']['#']);
+            }
+            
+            $forum->assessed = backup_todb($info['MOD']['#']['ASSESSED']['0']['#']);  
             $forum->assesstimestart = backup_todb($info['MOD']['#']['ASSESSTIMESTART']['0']['#']);
             $forum->assesstimefinish = backup_todb($info['MOD']['#']['ASSESSTIMEFINISH']['0']['#']);
             $forum->maxbytes = backup_todb($info['MOD']['#']['MAXBYTES']['0']['#']);
@@ -65,6 +78,10 @@
             $forum->rsstype = backup_todb($info['MOD']['#']['RSSTYPE']['0']['#']);
             $forum->rssarticles = backup_todb($info['MOD']['#']['RSSARTICLES']['0']['#']);
             $forum->timemodified = backup_todb($info['MOD']['#']['TIMEMODIFIED']['0']['#']);
+            $forum->warnafter = isset($info['MOD']['#']['WARNAFTER']['0']['#'])?backup_todb($info['MOD']['#']['WARNAFTER']['0']['#']):'';
+            $forum->blockafter = isset($info['MOD']['#']['BLOCKAFTER']['0']['#'])?backup_todb($info['MOD']['#']['BLOCKAFTER']['0']['#']):'';
+            $forum->blockperiod = isset($info['MOD']['#']['BLOCKPERIOD']['0']['#'])?backup_todb($info['MOD']['#']['BLOCKPERIOD']['0']['#']):'';
+
 
             //We have to recode the scale field if it's <0 (positive is a grade, not a scale)
             if ($forum->scale < 0) {
@@ -73,34 +90,25 @@
                     $forum->scale = -($scale->new_id);
                 }
             }
+            
+            $newid = insert_record("forum", $forum);
 
-            $forumtobeinserted = true;
-            //If the forum is a teacher forum, then we have to look if it exists in destination course
-            if ($forum->type == "teacher") {
-                //Look for teacher forum in destination course
-                $teacherforum = get_record("forum","course",$restore->course_id,"type","teacher");
-                if ($teacherforum) {
-                    $newid = $teacherforum->id;
-                    $forumtobeinserted = false;
-                }
-            }
-
-            //If the forum has to be inserted
-            if ($forumtobeinserted) {
-                //The structure is equal to the db, so insert the forum
-                $newid = insert_record ("forum",$forum);
-            }
 
             //Do some output
-            echo "<li>".get_string("modulename","forum")." \"".format_string(stripslashes($forum->name),true)."\"";
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "<li>".get_string("modulename","forum")." \"".format_string(stripslashes($forum->name),true)."\"</li>";
+            }
             backup_flush(300);
 
             if ($newid) {
                 //We have the newid, update backup_ids
                 backup_putid($restore->backup_unique_code,$mod->modtype,
                              $mod->id, $newid);
+
+                $forum->id = $newid;
+
                 //Now check if want to restore user data and do it.
-                if ($restore->mods['forum']->userinfo) {
+                if (restore_userdata_selected($restore,'forum',$mod->id)) {
                     //Restore forum_subscriptions
                     $status = forum_subscriptions_restore_mods ($newid,$info,$restore);
                     if ($status) {
@@ -112,9 +120,65 @@
                         $status = forum_read_restore_mods ($newid,$info,$restore);
                     }
                 }
+
+                // If forum type is single, just recreate the initial discussion/post automatically
+                // if it hasn't been created still (because no user data was selected on backup or
+                // restore.
+                if ($forum->type == 'single' && !record_exists('forum_discussions', 'forum', $newid)) {
+                    //Load forum/lib.php
+                    require_once ($CFG->dirroot.'/mod/forum/lib.php');
+                    // Calculate the default format
+                    if (can_use_html_editor()) {
+                        $defaultformat = FORMAT_HTML;
+                    } else {
+                        $defaultformat = FORMAT_MOODLE;
+                    }
+                    //Create discussion/post data
+                    $sd = new stdClass;
+                    $sd->course   = $forum->course;
+                    $sd->forum    = $newid;
+                    $sd->name     = $forum->name;
+                    $sd->intro    = $forum->intro;
+                    $sd->assessed = $forum->assessed;
+                    $sd->format   = $defaultformat;
+                    $sd->mailnow  = false;
+                    //Insert dicussion/post data
+                    $sdid = forum_add_discussion($sd, $sd->intro);
+                    //Now, mark the initial post of the discussion as mailed!
+                    if ($sdid) {
+                        set_field ('forum_posts','mailed', '1', 'discussion', $sdid);
+                    }
+                }
+            
             } else {
                 $status = false;
             }
+
+            // If the backup contained $forum->open and $forum->assesspublic,
+            // we need to convert the forum to use Roles. It means the backup
+            // was made pre Moodle 1.7.
+            if (isset($forum->open) && isset($forum->assesspublic)) {
+
+                $forummod = get_record('modules', 'name', 'forum');
+                
+                if (!$teacherroles = get_roles_with_capability('moodle/legacy:teacher', CAP_ALLOW)) {
+                      notice('Default teacher role was not found. Roles and permissions '.
+                             'for all your forums will have to be manually set.');
+                }
+                if (!$studentroles = get_roles_with_capability('moodle/legacy:student', CAP_ALLOW)) {
+                      notice('Default student role was not found. Roles and permissions '.
+                             'for all your forums will have to be manually set.');
+                }
+                if (!$guestroles = get_roles_with_capability('moodle/legacy:guest', CAP_ALLOW)) {
+                      notice('Default guest role was not found. Roles and permissions '.
+                             'for teacher forums will have to be manually set.');
+                }
+                require_once($CFG->dirroot.'/mod/forum/lib.php');
+                forum_convert_to_roles($forum, $forummod->id,
+                                       $teacherroles, $studentroles, $guestroles,
+                                       $restore->mods['forum']->instances[$mod->id]->restored_as_course_module);
+            }
+            
         } else {
             $status = false;
         }
@@ -130,7 +194,10 @@
         $status = true;
 
         //Get the discussions array
-        $subscriptions = $info['MOD']['#']['SUBSCRIPTIONS']['0']['#']['SUBSCRIPTION'];
+        $subscriptions = array();
+        if (isset($info['MOD']['#']['SUBSCRIPTIONS']['0']['#']['SUBSCRIPTION'])) {
+            $subscriptions = $info['MOD']['#']['SUBSCRIPTIONS']['0']['#']['SUBSCRIPTION'];
+        }
 
         //Iterate over subscriptions
         for($i = 0; $i < sizeof($subscriptions); $i++) {
@@ -158,9 +225,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo ".";
-                if (($i+1) % 1000 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -185,7 +254,11 @@
         $status = true;
 
         //Get the discussions array
-        $discussions = $info['MOD']['#']['DISCUSSIONS']['0']['#']['DISCUSSION'];
+        $discussions = array();
+        
+        if (!empty($info['MOD']['#']['DISCUSSIONS']['0']['#']['DISCUSSION'])) {
+            $discussions = $info['MOD']['#']['DISCUSSIONS']['0']['#']['DISCUSSION'];
+        }
 
         //Iterate over discussions
         for($i = 0; $i < sizeof($discussions); $i++) {
@@ -207,8 +280,12 @@
             $discussion->groupid = backup_todb($dis_info['#']['GROUPID']['0']['#']);
             $discussion->assessed = backup_todb($dis_info['#']['ASSESSED']['0']['#']);
             $discussion->timemodified = backup_todb($dis_info['#']['TIMEMODIFIED']['0']['#']);
-            $discussion->usermodified = backup_todb($dis_info['#']['USERMODIFIED']['0']['#']);
-
+            $discussion->timemodified += $restore->course_startdateoffset;
+            $discussion->usermodified = backup_todb($dis_info['#']['USERMODIFIED']['0']['#']);  
+            $discussion->timestart = backup_todb($dis_info['#']['TIMESTART']['0']['#']);
+            $discussion->timestart += $restore->course_startdateoffset;
+            $discussion->timeend = backup_todb($dis_info['#']['TIMEEND']['0']['#']);
+            $discussion->timeend += $restore->course_startdateoffset;
             //We have to recode the userid field
             $user = backup_getid($restore->backup_unique_code,"user",$discussion->userid);
             if ($user) {
@@ -216,7 +293,7 @@
             }
 
             //We have to recode the groupid field
-            $group = backup_getid($restore->backup_unique_code,"group",$discussion->groupid);
+            $group = backup_getid($restore->backup_unique_code, 'groups', $discussion->groupid);
             if ($group) {
                 $discussion->groupid = $group->new_id;
             }
@@ -232,9 +309,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo ".";
-                if (($i+1) % 1000 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -282,7 +361,10 @@
         $status = true;
 
         //Get the read array
-        $readposts = $info['MOD']['#']['READPOSTS']['0']['#']['READ'];
+        $readposts = array();
+        if (isset($info['MOD']['#']['READPOSTS']['0']['#']['READ'])) {
+            $readposts = $info['MOD']['#']['READPOSTS']['0']['#']['READ'];
+        }
 
         //Iterate over readposts
         for($i = 0; $i < sizeof($readposts); $i++) {
@@ -337,9 +419,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo ".";
-                if (($i+1) % 1000 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -380,15 +464,18 @@
             //Now, build the FORUM_POSTS record structure
             $post->discussion = $discussion_id;
             $post->parent = backup_todb($pos_info['#']['PARENT']['0']['#']);
-            $post->userid = backup_todb($pos_info['#']['USERID']['0']['#']);
+            $post->userid = backup_todb($pos_info['#']['USERID']['0']['#']);   
             $post->created = backup_todb($pos_info['#']['CREATED']['0']['#']);
+            $post->created += $restore->course_startdateoffset;
             $post->modified = backup_todb($pos_info['#']['MODIFIED']['0']['#']);
+            $post->modified += $restore->course_startdateoffset;             
             $post->mailed = backup_todb($pos_info['#']['MAILED']['0']['#']);
             $post->subject = backup_todb($pos_info['#']['SUBJECT']['0']['#']);
             $post->message = backup_todb($pos_info['#']['MESSAGE']['0']['#']);
             $post->format = backup_todb($pos_info['#']['FORMAT']['0']['#']);
             $post->attachment = backup_todb($pos_info['#']['ATTACHMENT']['0']['#']);
             $post->totalscore = backup_todb($pos_info['#']['TOTALSCORE']['0']['#']);
+            $post->mailnow = backup_todb($pos_info['#']['MAILNOW']['0']['#']);
 
             //We have to recode the userid field
             $user = backup_getid($restore->backup_unique_code,"user",$post->userid);
@@ -401,9 +488,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo ".";
-                if (($i+1) % 1000 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -518,7 +607,10 @@
         $status = true;
 
         //Get the ratings array
-        $ratings = $info['#']['RATINGS']['0']['#']['RATING'];
+        $ratings = array();
+        if (isset($info['#']['RATINGS']['0']['#']['RATING'])) {
+            $ratings = $info['#']['RATINGS']['0']['#']['RATING'];
+        }
 
         //Iterate over ratings
         for($i = 0; $i < sizeof($ratings); $i++) {
@@ -548,9 +640,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo ".";
-                if (($i+1) % 1000 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -599,9 +693,11 @@
                 //Do some output
                 $i++;
                 if (($i+1) % 1 == 0) {
-                    echo ".";
-                    if (($i+1) % 20 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 20 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                 }
@@ -817,7 +913,9 @@
             $status = true;
             break;
         default:
-            echo "action (".$log->module."-".$log->action.") unknow. Not restored<br />";                 //Debug
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "action (".$log->module."-".$log->action.") unknown. Not restored<br />";                 //Debug
+            }
             break;
         }
 
@@ -1020,15 +1118,19 @@
                     //Update record
                     $post->message = addslashes($result);
                     $status = update_record("forum_posts",$post);
-                    if ($CFG->debug>7) {
-                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                    if (debugging()) {
+                        if (!defined('RESTORE_SILENTLY')) {
+                            echo '<br /><hr />'.s($content).'<br />changed to<br />'.s($result).'<hr /><br />';
+                        }
                     }
                 }
                 //Do some output
                 if (($i+1) % 5 == 0) {
-                    echo ".";
-                    if (($i+1) % 100 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 100 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                 }
@@ -1050,15 +1152,19 @@
                     //Update record
                     $forum->intro = addslashes($result);
                     $status = update_record("forum",$forum);
-                    if ($CFG->debug>7) {
-                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                    if (debugging()) {
+                        if (!defined('RESTORE_SILENTLY')) {
+                            echo '<br /><hr />'.s($content).'<br />changed to<br />'.s($result).'<hr /><br />';
+                        }
                     }
                 }
                 //Do some output
                 if (($i+1) % 5 == 0) {
-                    echo ".";
-                    if (($i+1) % 100 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 100 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
                     }
