@@ -1,4 +1,4 @@
-<?php // $Id: search.php,v 1.61.2.1 2006/07/04 08:30:16 skodak Exp $
+<?php // $Id: search.php,v 1.72.2.5 2007/05/15 18:26:58 skodak Exp $
 
     require_once('../../config.php');
     require_once('lib.php');
@@ -114,17 +114,12 @@
 
     $searchform = forum_search_form($course, $search);
 
-    if ((!isteacheredit($course->id)) and forum_get_separate_modules($course->id)) {
-        $sepgroups = user_group($course->id, $USER->id);
-    } else {
-        $sepgroups = false;
-    }
 
-    if (!$posts = forum_search_posts($searchterms, $course->id, $page*$perpage, $perpage, $totalcount, $sepgroups)) {
+    if (!$posts = forum_search_posts($searchterms, $course->id, $page*$perpage, $perpage, $totalcount)) {
 
         print_header_simple("$strsearchresults", "",
                 "<a href=\"index.php?id=$course->id\">$strforums</a> ->
-                <a href=\"search.php?id=$course->id\">$strsearch</a> -> ".s($search), 'search.words',
+                <a href=\"search.php?id=$course->id\">$strsearch</a> -> ".s($search, true), 'search.words',
                 "", "", "&nbsp;", navmenu($course));
         print_heading(get_string("nopostscontaining", "forum", $search));
 
@@ -140,7 +135,7 @@
 
     print_header_simple("$strsearchresults", "",
             "<a href=\"index.php?id=$course->id\">$strforums</a> ->
-            <a href=\"search.php?id=$course->id\">$strsearch</a> -> ".s($search), '',
+            <a href=\"search.php?id=$course->id\">$strsearch</a> -> ".s($search, true), '',
             "", "",  $searchform, navmenu($course));
 
     echo '<div class="reportlink">';
@@ -204,14 +199,36 @@
         //Use highlight() with nonsense tags to spot search terms in the
         //actual text content first.          fiedorow - 9/2/2005
         $missing_terms = "";
-        $message = highlight($strippedsearch,format_text($post->message, $post->format, NULL, $course->id),
-                0,'<fgw9sdpq4>','</fgw9sdpq4>');
+
+        // Hack for posts of format FORMAT_PLAIN. Otherwise html tags added by
+        // the highlight() call bellow get stripped out by forum_print_post().
+        if ($post->format == FORMAT_PLAIN) {
+            $post->message = stripslashes_safe($post->message); 
+            $post->message = rebuildnolinktag($post->message); 
+            $post->message = str_replace(' ', '&nbsp; ', $post->message); 
+            $post->message = nl2br($post->message); 
+            $post->format = FORMAT_HTML;
+        }
+
+        $options = new object();
+        $options->trusttext = true;
+        // detect TRUSTTEXT marker before first call to format_text
+        if (trusttext_present($post->message)) {
+            $ttpresent = true;
+        } else {
+            $ttpresent = false;
+        }
+        $message = highlight($strippedsearch,
+                        format_text($post->message, $post->format, $options, $course->id),
+                        0, '<fgw9sdpq4>', '</fgw9sdpq4>');
 
         foreach ($searchterms as $searchterm) {
             if (preg_match("/$searchterm/i",$message) && !preg_match('/<fgw9sdpq4>'.$searchterm.'<\/fgw9sdpq4>/i',$message)) {
                 $missing_terms .= " $searchterm";
             }
         }
+        // now is the right time to strip the TRUSTTEXT marker, we will add it later if needed
+        $post->message = trusttext_strip($post->message);
 
         $message = str_replace('<fgw9sdpq4>','<span class="highlight">',$message);
         $message = str_replace('</fgw9sdpq4>','</span>',$message);
@@ -219,6 +236,7 @@
         if ($missing_terms) {
             $strmissingsearchterms = get_string('missingsearchterms','forum');
             $post->message = '<p class="highlight2">'.$strmissingsearchterms.' '.$missing_terms.'</p>'.$message;
+            $ttpresent = false;
         } else {
             $post->message = $message;
         }
@@ -226,6 +244,13 @@
         $fulllink = "<a href=\"discuss.php?d=$post->discussion#$post->id\">".get_string("postincontext", "forum")."</a>";
         //search terms already highlighted - fiedorow - 9/2/2005
         $SESSION->forum_search = true;
+
+        // reconstruct the TRUSTTEXT properly after processing
+        if ($ttpresent) {
+            $post->message = trusttext_mark($post->message);
+        } else {
+            $post->message = trusttext_strip($post->message); //make 100% sure TRUSTTEXT marker was not created during processing
+        }
         forum_print_post($post, $course->id, false, false, false, false, $fulllink);
         unset($SESSION->forum_search);
 
@@ -238,49 +263,58 @@
 
 
 
+/**
+ * @todo Document this function
+ */
 function forum_print_big_search_form($course) {
-    global $words, $subject, $phrase, $user, $userid, $fullwords, $notwords, $datefrom, $dateto;
+    global $CFG, $words, $subject, $phrase, $user, $userid, $fullwords, $notwords, $datefrom, $dateto;
 
     print_simple_box(get_string('searchforumintro', 'forum'), 'center', '', '', 'searchbox', 'intro');
 
     print_simple_box_start("center");
 
-    echo "<script type=\"text/javascript\" language=\"javascript\">\n";
+    echo "<script type=\"text/javascript\">\n";
     echo "var timefromitems = ['fromday','frommonth','fromyear','fromhour', 'fromminute'];\n";
     echo "var timetoitems = ['today','tomonth','toyear','tohour','tominute'];\n";
     echo "</script>\n";
 
-    echo '<form name="search" action="search.php" method="get">';
-    echo '<input type="hidden" value="'.$course->id.'" name="id" alt="">';
+    echo '<form id="searchform" action="search.php" method="get">';
     echo '<table cellpadding="10" class="searchbox" id="form">';
 
     echo '<tr>';
-    echo '<td class="c0">'.get_string('searchwords', 'forum').':</td>';
-    echo '<td class="c1"><input type="text" size="35" name="words" value="'.s($words).'" alt=""></td>';
+    echo '<td class="c0">'.get_string('searchwords', 'forum').':';
+    echo '<input type="hidden" value="'.$course->id.'" name="id" alt="" /></td>';
+    echo '<td class="c1"><input type="text" size="35" name="words" value="'.s($words, true).'" alt="" /></td>';
     echo '</tr>';
 
     echo '<tr>';
     echo '<td class="c0">'.get_string('searchphrase', 'forum').':</td>';
-    echo '<td class="c1"><input type="text" size="35" name="phrase" value="'.s($phrase).'" alt=""></td>';
+    echo '<td class="c1"><input type="text" size="35" name="phrase" value="'.s($phrase, true).'" alt="" /></td>';
     echo '</tr>';
 
     echo '<tr>';
     echo '<td class="c0">'.get_string('searchnotwords', 'forum').':</td>';
-    echo '<td class="c1"><input type="text" size="35" name="notwords" value="'.s($notwords).'" alt=""></td>';
+    echo '<td class="c1"><input type="text" size="35" name="notwords" value="'.s($notwords, true).'" alt="" /></td>';
     echo '</tr>';
 
-    echo '<tr>';
-    echo '<td class="c0">'.get_string('searchfullwords', 'forum').':</td>';
-    echo '<td class="c1"><input type="text" size="35" name="fullwords" value="'.s($fullwords).'" alt=""></td>';
-    echo '</tr>';
+    if ($CFG->dbfamily == 'mysql' || $CFG->dbfamily == 'postgres') {
+        echo '<tr>';
+        echo '<td class="c0">'.get_string('searchfullwords', 'forum').':</td>';
+        echo '<td class="c1"><input type="text" size="35" name="fullwords" value="'.s($fullwords, true).'" alt="" /></td>';
+        echo '</tr>';
+    }
 
     echo '<tr>';
     echo '<td class="c0">'.get_string('searchdatefrom', 'forum').':</td>';
     echo '<td class="c1">';
-    echo '<input name="timefromrestrict" type="checkbox" value="1" alt="'.get_string('searchdatefrom', 'forum').'" onclick="return lockoptions(\'search\', \'timefromrestrict\', timefromitems)" /> ';
-    if (empty($dateto)) {
+    if (empty($datefrom)) {
+        $datefromchecked = '';
         $datefrom = make_timestamp(2000, 1, 1, 0, 0, 0);
+    }else{
+        $datefromchecked = 'checked="checked"';
     }
+
+    echo '<input name="timefromrestrict" type="checkbox" value="1" alt="'.get_string('searchdatefrom', 'forum').'" onclick="return lockoptions(\'searchform\', \'timefromrestrict\', timefromitems)" '.  $datefromchecked . ' /> ';
     print_date_selector('fromday', 'frommonth', 'fromyear', $datefrom);
     print_time_selector('fromhour', 'fromminute', $datefrom);
 
@@ -296,10 +330,14 @@ function forum_print_big_search_form($course) {
     echo '<tr>';
     echo '<td class="c0">'.get_string('searchdateto', 'forum').':</td>';
     echo '<td class="c1">';
-    echo '<input name="timetorestrict" type="checkbox" value="1" alt="'.get_string('searchdateto', 'forum').'" onclick="return lockoptions(\'search\', \'timetorestrict\', timetoitems)" /> ';
     if (empty($dateto)) {
+        $datetochecked = '';
         $dateto = time()+3600;
+    }else{
+        $datetochecked = 'checked="checked"';
     }
+
+    echo '<input name="timetorestrict" type="checkbox" value="1" alt="'.get_string('searchdateto', 'forum').'" onclick="return lockoptions(\'searchform\', \'timetorestrict\', timetoitems)" ' .$datetochecked. ' /> ';
     print_date_selector('today', 'tomonth', 'toyear', $dateto);
     print_time_selector('tohour', 'tominute', $dateto);
 
@@ -321,31 +359,33 @@ function forum_print_big_search_form($course) {
 
     echo '<tr>';
     echo '<td class="c0">'.get_string('searchsubject', 'forum').':</td>';
-    echo '<td class="c1"><input type="text" size="35" name="subject" value="'.s($subject).'" alt=""></td>';
+    echo '<td class="c1"><input type="text" size="35" name="subject" value="'.s($subject, true).'" alt="" /></td>';
     echo '</tr>';
 
     echo '<tr>';
     echo '<td class="c0">'.get_string('searchuser', 'forum').':</td>';
-    echo '<td class="c1"><input type="text" size="35" name="user" value="'.s($user).'" alt=""></td>';
+    echo '<td class="c1"><input type="text" size="35" name="user" value="'.s($user, true).'" alt="" /></td>';
     echo '</tr>';
 
     echo '<tr>';
     echo '<td class="submit" colspan="2" align="center">';
-    echo '<input type="submit" value="'.get_string('searchforums', 'forum').'" alt=""></td>';
+    echo '<input type="submit" value="'.get_string('searchforums', 'forum').'" alt="" /></td>';
     echo '</tr>';
 
     echo '</table>';
     echo '</form>';
 
     echo "<script type=\"text/javascript\">";
-    echo "lockoptions('search','timefromrestrict', timefromitems);";
-    echo "lockoptions('search','timetorestrict', timetoitems);";
+    echo "lockoptions('searchform','timefromrestrict', timefromitems);";
+    echo "lockoptions('searchform','timetorestrict', timetoitems);";
     echo "</script>\n";
 
     print_simple_box_end();
 }
 
-
+/**
+ * @todo Document this function
+ */
 function forum_clean_search_terms($words, $prefix='') {
     $searchterms = explode(' ', $words);
     foreach ($searchterms as $key => $searchterm) {
@@ -358,18 +398,13 @@ function forum_clean_search_terms($words, $prefix='') {
     return trim(implode(' ', $searchterms));
 }
 
+/**
+ * @todo Document this function
+ */
 function forum_menu_list($course)  {
 
     $menu = array();
-
-    $currentgroup = get_current_group($course->id);
-    $isteacher = isteacher($course->id);
-
-    if ($isteacher) {   // Add teacher forum
-        if ($forum = forum_get_course_forum($course->id, 'teacher')) {
-            $menu[$forum->id] = format_string($forum->name,true);
-        }
-    }
+    $currentgroup = get_and_set_current_group($course, groupmode($course));
 
     if ($forums = get_all_instances_in_course("forum", $course)) {
         if ($course->format == 'weeks') {
@@ -379,23 +414,20 @@ function forum_menu_list($course)  {
         }
 
         foreach ($forums as $forum) {
-            if (!$isteacher) {   // Non-teachers
-                if ($forum->type == "teacher") {
+            if ($cm = get_coursemodule_from_instance('forum', $forum->id, $course->id)) {
+                $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+                if (!isset($forum->visible)) {
+                    if (!instance_is_visible("forum", $forum) &&
+                            !has_capability('moodle/course:viewhiddenactivities', $context)) {
+                        continue;
+                    }
+                }
+                $groupmode = groupmode($course, $cm);   // Groups are being used
+                if ($groupmode == SEPARATEGROUPS && ($currentgroup === false) &&
+                                  !has_capability('moodle/site:accessallgroups', $context)) {
                     continue;
                 }
-                if (!isset($forum->visible)) {
-                    if (! instance_is_visible("forum", $forum)) {
-                        continue;
-                    }
-                }
-                if ($cm = get_coursemodule_from_instance('forum', $forum->id, $course->id)) {
-                    $groupmode = groupmode($course, $cm);   // Groups are being used
-                    if (($groupmode == SEPARATEGROUPS) and ($currentgroup === false)) {
-                        continue;
-                    }
-                }
             }
-
             $menu[$forum->id] = format_string($forum->name,true);
         }
     }
@@ -404,4 +436,3 @@ function forum_menu_list($course)  {
 }
 
 ?>
-
