@@ -1,4 +1,4 @@
-<?php  // $Id: approve.php,v 1.11.2.1 2005/12/07 05:57:19 moodler Exp $
+<?php  // $Id: approve.php,v 1.16 2006/08/14 05:55:43 moodler Exp $
 
     require_once("../../config.php");
     require_once("lib.php");
@@ -9,10 +9,10 @@
     $mode = optional_param('mode','approval', PARAM_ALPHA);
     $hook = optional_param('hook','ALL', PARAM_CLEAN);
 
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('glossary', $id)) {
         error("Course Module ID was incorrect");
     }
-
+    
     if (! $course = get_record("course", "id", $cm->course)) {
         error("Course is misconfigured");
     }
@@ -21,10 +21,11 @@
         error("Course module is incorrect");
     }
 
-    require_login($course->id, false, $cm);
-    if (!isteacher($course->id)) {
-        error("You must be a teacher to use this page.");
-    }
+    require_login($course->id, false, $cm);    
+    
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+    require_capability('mod/glossary:approve', $context);
+
     $newentry->id = $eid;
     $newentry->approved = 1;
 
