@@ -1,4 +1,4 @@
-<?php // $Id: deleteentry.php,v 1.23.2.2 2005/12/07 05:57:19 moodler Exp $
+<?php // $Id: deleteentry.php,v 1.33 2006/11/15 03:15:59 toyomoyo Exp $
 
     require_once("../../config.php");
     require_once("lib.php");
@@ -16,7 +16,7 @@
     $entrydeleted = get_string("entrydeleted","glossary");
 
 
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('glossary', $id)) {
         error("Course Module ID was incorrect");
     }
 
@@ -29,18 +29,13 @@
     }
 
     require_login($course->id, false, $cm);
-
-    if (isguest()) {
-        error("Guests are not allowed to edit or delete entries", $_SERVER["HTTP_REFERER"]);
-    }
-
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+    $manageentries = has_capability('mod/glossary:manageentries', $context); 
+    
     if (! $glossary = get_record("glossary", "id", $cm->instance)) {
         error("Glossary is incorrect");
     }
 
-    if (!isteacher($course->id) and !$glossary->studentcanpost ) {
-        error("You are not allowed to edit or delete entries");
-    }
 
     $strareyousuredelete = get_string("areyousuredelete","glossary");
 
@@ -50,11 +45,11 @@
                   navmenu($course, $cm));
 
 
-    if (($entry->userid != $USER->id) and !isteacher($course->id)) {
+    if (($entry->userid != $USER->id) and !$manageentries) { // guest id is never matched, no need for special check here
         error("You can't delete other people's entries!");
     }
     $ineditperiod = ((time() - $entry->timecreated <  $CFG->maxeditingtime) || $glossary->editalways);
-    if (!$ineditperiod and !isteacher($course->id)) {
+    if (!$ineditperiod and !$manageentries) {
         error("You can't delete this. Time expired!");
     }
 
@@ -87,7 +82,7 @@
 
     } else {        // the operation has not been confirmed yet so ask the user to do so
 
-        notice_yesno("<b>$entry->concept</b><p>$strareyousuredelete</p>",
+        notice_yesno("<b>".format_string($entry->concept)."</b><p>$strareyousuredelete</p>",
                       "deleteentry.php?id=$cm->id&amp;mode=delete&amp;confirm=1&amp;entry=".s($entry->id)."&amp;prevmode=$prevmode&amp;hook=$hook",
                       "view.php?id=$cm->id&amp;mode=$prevmode&amp;hook=$hook");
 
