@@ -1,9 +1,9 @@
-<?php  // $Id: exportentry.php,v 1.15.2.2 2005/12/07 05:57:19 moodler Exp $
+<?php  // $Id: exportentry.php,v 1.26 2007/01/12 06:57:33 toyomoyo Exp $
     require_once('../../config.php');
     require_once('lib.php');
 
     $id    = required_param('id', PARAM_INT);           // course module ID
-    $entry = required_param('entry', 0, PARAM_INT);     // Entry ID
+    $entry = required_param('entry', PARAM_INT);     // Entry ID
     $confirm = optional_param('confirm', 0, PARAM_INT); // confirmation
 
     $hook = optional_param('hook', '', PARAM_ALPHANUM);
@@ -13,7 +13,7 @@
 
     $PermissionGranted = 1;
 
-    $cm = get_record('course_modules','id',$id);
+    $cm = get_coursemodule_from_id('glossary', $id);
     if ( ! $cm ) {
         $PermissionGranted = 0;
     } else {
@@ -23,16 +23,8 @@
         }
     }
     
-    if ($CFG->dbtype == 'postgres7' ) {
-            $ucase = 'upper';
-    } else {
-            $ucase = 'ucase';
-    }
-
-    if ( !isteacher($cm->course) ) {
-        $PermissionGranted = 0;
-        error('You must be a teacher to use this page.');
-    }
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+    require_capability('mod/glossary:export', $context);
 
     if (! $course = get_record('course', 'id', $cm->course)) {
         error('Course is misconfigured');
@@ -55,15 +47,15 @@
         $entry = get_record('glossary_entries', 'id', $entry);
 
         if ( !$confirm ) {
-            echo '<center>';
+            echo '<div class="boxaligncenter">';
             $areyousure = get_string('areyousureexport','glossary');
-            notice_yesno ('<center><h2>'.$entry->concept.'</h2><p align="center">'.$areyousure.'<br /><b>'.format_string($mainglossary->name).'</b>?',
+            notice_yesno ('<h2>'.format_string($entry->concept).'</h2><p align="center">'.$areyousure.'<br /><b>'.format_string($mainglossary->name).'</b>?',
                 'exportentry.php?id='.$id.'&amp;mode='.$mode.'&amp;hook='.$hook.'&amp;entry='.$entry->id.'&amp;confirm=1',
                 'view.php?id='.$cm->id.'&amp;mode='.$mode.'&amp;hook='.$hook);
-
+            echo '</div>';
         } else {
             if ( ! $mainglossary->allowduplicatedentries ) {
-                $dupentry = get_record('glossary_entries','glossaryid', $mainglossary->id, $ucase.'(concept)',strtoupper(addslashes($entry->concept)));
+                $dupentry = get_record('glossary_entries','glossaryid', $mainglossary->id, 'lower(concept)',moodle_strtolower(addslashes($entry->concept)));
                 if ( $dupentry ) {
                     $PermissionGranted = 0;
                 }
