@@ -3,6 +3,9 @@
     require_once("../../config.php");
     require_once("lib.php");
 
+    // disable moodle specific debug messages
+    disable_debugging();
+
     $id = required_param('id', PARAM_INT);      // Course Module ID
 
     $l   = optional_param('l','', PARAM_ALPHANUM);
@@ -21,12 +24,12 @@
     }
 
     require_login($course->id, false);
-    if (!isteacher($course->id)) {
-        error("You must be a teacher to use this page.");
-    }
-
+    
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+    require_capability('mod/glossary:export', $context);
+    
     $filename = clean_filename(strip_tags(format_string($glossary->name,true)).'.xml');
     $content = glossary_generate_export_file($glossary,$l,$cat);
     
     send_file($content, $filename, 0, 0, true, true);
-?>
\ No newline at end of file
+?>
