@@ -1,4 +1,4 @@
-<?php   // $Id: import.php,v 1.19.2.2 2005/12/07 05:57:19 moodler Exp $
+<?php   // $Id: import.php,v 1.33.2.5 2007/04/04 03:34:00 nicolasconnault Exp $
 
     require_once("../../config.php");
     require_once("lib.php");
@@ -8,17 +8,17 @@
     $id = required_param('id', PARAM_INT);    // Course Module ID
 
     $step     = optional_param('step', 0, PARAM_INT);
-    $current  = optional_param('dest', 'current', PARAM_ALPHA);   // current | new
+    $dest     = optional_param('dest', 'current', PARAM_ALPHA);   // current | new
     $file     = optional_param('file', '', PARAM_FILE);         // file to import
     $catsincl = optional_param('catsincl', 0, PARAM_INT);         // Import Categories too?
 
     $mode     = optional_param('mode', 'letter', PARAM_ALPHA );
     $hook     = optional_param('hook', 'ALL', PARAM_ALPHANUM);
 
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('glossary', $id)) {
         error("Course Module ID was incorrect");
     }
-
+    
     if (! $course = get_record("course", "id", $cm->course)) {
         error("Course is misconfigured");
     }
@@ -27,10 +27,10 @@
         error("Course module is incorrect");
     }
 
-    require_login($course->id, false);
-    if (!isteacher($course->id)) {
-        error("You must be a teacher to use this page.");
-    }
+    require_login($course->id, false);  
+    
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+    require_capability('mod/glossary:import', $context);
 
     if ($dest != 'new' and $dest != 'current') {
         $dest = 'current';
@@ -43,30 +43,22 @@
     $strsearchconcept = get_string("searchconcept", "glossary");
     $strsearchindefinition = get_string("searchindefinition", "glossary");
     $strsearch = get_string("search");
+    $strimportentries = get_string('importentriesfromxml', 'glossary');
 
     print_header_simple(format_string($glossary->name), "",
-        "<a href=\"index.php?id=$course->id\">$strglossaries</a> -> ".format_string($glossary->name),
+        "<a href=\"index.php?id=$course->id\">$strglossaries</a> -> " .
+        "<a href=\"view.php?id=$id\">" .format_string($glossary->name) . "</a> -> " .
+        $strimportentries,
         "", "", true, update_module_button($cm->id, $course->id, $strglossary),
         navmenu($course, $cm));
 
-    print_heading(format_string($glossary->name));
-
-/// Info box
-
-    if ( $glossary->intro ) {
-        print_simple_box(format_text($glossary->intro), 'center', '70%', '', 5, 'generalbox', 'intro');
-        echo '<br />';
-    }
-
-/// Tabbed browsing sections
-    $tab = GLOSSARY_IMPORT_VIEW;
-    include("tabs.html");
+    print_heading($strimportentries);
 
     if ( !$step ) {
+        print_box_start('glossarydisplay generalbox');
         include("import.html");
+        print_box_end();
 
-        echo '</center>';
-        glossary_print_tabbed_table_end();
         print_footer($course);
         exit;
     }
@@ -78,9 +70,10 @@
     $um = new upload_manager('file',false,false,$course,false,0);
 
     if (!$um->preprocess_files()) {
-        echo '</center>';
-        glossary_print_tabbed_table_end();
+        print_box_start('glossarydisplay generalbox');
         print_continue('import.php?id='.$id);
+        print_box_end();
+
         print_footer();
         die();
     }
@@ -97,10 +90,10 @@
 
             if ( $xmlglossary['NAME'][0]['#'] ) {
                 unset($glossary);
-                $glossary->name = addslashes(utf8_decode($xmlglossary['NAME'][0]['#']));
+                $glossary->name = addslashes($xmlglossary['NAME'][0]['#']);
                 $glossary->course = $course->id;
                 $glossary->globalglossary = addslashes($xmlglossary['GLOBALGLOSSARY'][0]['#']);
-                $glossary->intro = addslashes(utf8_decode($xmlglossary['INTRO'][0]['#']));
+                $glossary->intro = addslashes($xmlglossary['INTRO'][0]['#']);
                 $glossary->showspecial = addslashes($xmlglossary['SHOWSPECIAL'][0]['#']);
                 $glossary->showalphabet = addslashes($xmlglossary['SHOWALPHABET'][0]['#']);
                 $glossary->showall = addslashes($xmlglossary['SHOWALL'][0]['#']);
@@ -108,11 +101,6 @@
                 $glossary->timemodified = time();
 
                 // Setting the default values if no values were passed
-                if ( isset($xmlglossary['STUDENTCANPOST'][0]['#']) ) {
-                    $glossary->studentcanpost = addslashes($xmlglossary['STUDENTCANPOST'][0]['#']);
-                } else {
-                    $glossary->studentcanpost = $CFG->glossary_studentspost;
-                }
                 if ( isset($xmlglossary['ENTBYPAGE'][0]['#']) ) {
                     $glossary->entbypage = addslashes($xmlglossary['ENTBYPAGE'][0]['#']);
                 } else {
@@ -166,6 +154,7 @@
                     $mod->module = $currmodule->id;
                     $mod->course = $course->id;
                     $mod->modulename = 'glossary';
+                    $mod->section = 0;
 
                     if (! $mod->coursemodule = add_course_module($mod) ) {
                         error("Could not add a new course module");
@@ -198,8 +187,6 @@
                 }
             } else {
                 notify("Error while trying to create the new glossary.");
-                echo '</center>';
-                glossary_print_tabbed_table_end();
                 print_footer($course);
                 exit;
             }
@@ -210,8 +197,8 @@
             // Inserting the entries
             $xmlentry = $xmlentries[$i];
             unset($newentry);
-            $newentry->concept = addslashes(trim(utf8_decode($xmlentry['#']['CONCEPT'][0]['#'])));
-            $newentry->definition = addslashes(utf8_decode($xmlentry['#']['DEFINITION'][0]['#']));
+            $newentry->concept = trim(addslashes($xmlentry['#']['CONCEPT'][0]['#']));
+            $newentry->definition = trusttext_strip(addslashes($xmlentry['#']['DEFINITION'][0]['#']));
             if ( isset($xmlentry['#']['CASESENSITIVE'][0]['#']) ) {
                 $newentry->casesensitive    = addslashes($xmlentry['#']['CASESENSITIVE'][0]['#']);
             } else {
@@ -225,11 +212,7 @@
                     if ( $newentry->casesensitive ) {
                         $dupentry = get_record("glossary_entries","concept",$newentry->concept,"glossaryid",$glossary->id);
                     } else {
-                        if ($CFG->dbtype == 'postgres7') {
-                            $dupentry = get_record("glossary_entries","upper(concept)",strtoupper($newentry->concept),"glossaryid",$glossary->id);
-                        }else {
-                            $dupentry = get_record("glossary_entries","ucase(concept)",strtoupper($newentry->concept),"glossaryid",$glossary->id);
-                        }
+                        $dupentry = get_record("glossary_entries","lower(concept)",moodle_strtolower($newentry->concept),"glossaryid",$glossary->id);
                     }
                     if ($dupentry) {
                         $permissiongranted = 0;
@@ -263,7 +246,7 @@
                 if ( $newentry->id = insert_record("glossary_entries",$newentry) )  {
                     $importedentries++;
 
-                    $xmlaliases = $xmlentry['#']['ALIASES'][0]['#']['ALIAS'];
+                    $xmlaliases = @$xmlentry['#']['ALIASES'][0]['#']['ALIAS']; // ignore missing ALIASES
                     for($k = 0; $k < sizeof($xmlaliases); $k++) {
                     /// Importing aliases
                         $xmlalias = $xmlaliases[$k];
@@ -272,19 +255,19 @@
                         if (!empty($aliasname)) {
                             unset($newalias);
                             $newalias->entryid = $newentry->id;
-                            $newalias->alias = addslashes(trim(utf8_decode($aliasname)));
+                            $newalias->alias = trim(addslashes($aliasname));
                             $newalias->id = insert_record("glossary_alias",$newalias);
                         }
                     }
 
                     if ( $catsincl ) {
                         // If the categories must be imported...
-                        $xmlcats = $xmlentry['#']['CATEGORIES'][0]['#']['CATEGORY'];
+                        $xmlcats = @$xmlentry['#']['CATEGORIES'][0]['#']['CATEGORY']; // ignore missing CATEGORIES
                         for($k = 0; $k < sizeof($xmlcats); $k++) {
                             $xmlcat = $xmlcats[$k];
                             unset($newcat);
 
-                            $newcat->name = addslashes(utf8_decode($xmlcat['#']['NAME'][0]['#']));
+                            $newcat->name = addslashes($xmlcat['#']['NAME'][0]['#']);
                             $newcat->usedynalink = addslashes($xmlcat['#']['USEDYNALINK'][0]['#']);
                             if ( !$category = get_record("glossary_categories","glossaryid",$glossary->id,"name",$newcat->name) ) {
                                 // Create the category if it does not exist
@@ -332,12 +315,13 @@
             }
         }
         // processed entries
-        echo '<table border="0" width="100%">';
+        print_box_start('glossarydisplay generalbox');
+        echo '<table class="glossaryimportexport">';
         echo '<tr>';
         echo '<td width="50%" align="right">';
         echo get_string("totalentries","glossary");
         echo ':</td>';
-        echo '<td width="50%">';
+        echo '<td width="50%" align="left">';
         echo $importedentries + $entriesrejected;
         echo '</td>';
         echo '</tr>';
@@ -345,7 +329,7 @@
         echo '<td width="50%" align="right">';
         echo get_string("importedentries","glossary");
         echo ':</td>';
-        echo '<td width="50%">';
+        echo '<td width="50%" align="left">';
         echo $importedentries;
         if ( $entriesrejected ) {
             echo ' <small>(' . get_string("rejectedentries","glossary") . ": $entriesrejected)</small>";
@@ -362,23 +346,27 @@
             echo '</td>';
             echo '</tr>';
         }
-        echo '</table><hr width="75%">';
+        echo '</table><hr />';
 
         // rejected entries
         if ($rejections) {
-            echo '<center><table border="0" width="70%">';
+            echo '<table class="glossaryimportexport">';
             echo '<tr><td align="center" colspan="2" width="100%"><strong>' . get_string("rejectionrpt","glossary") . '</strong></tr>';
             echo $rejections;
-            echo '</table></center><p><hr width="75%">';
+            echo '</table><hr />';
         }
+    /// Print continue button, based on results
+        if ($importedentries) {
+            print_continue('view.php?id='.$id);
+        } else {
+            print_continue('import.php?id='.$id);
+        }
+        print_box_end();
     } else {
-        notify("Error while trying to read the file.");
+        notice(get_string('errorparsingxml', 'glossary'));
     }
 
-    glossary_print_tabbed_table_end();
-
 /// Finish the page
-
     print_footer($course);
 
 ?>
