@@ -1,4 +1,4 @@
-<?php   // $Id: print.php,v 1.29.2.1 2005/12/07 05:57:19 moodler Exp $
+<?php   // $Id: print.php,v 1.39.4.2 2007/03/30 07:02:58 toyomoyo Exp $
 
     global $CFG;
 
@@ -14,7 +14,7 @@
     $hook    = optional_param('hook','ALL', PARAM_ALPHANUM);   // what to show
     $sortkey = optional_param('sortkey','UPDATE', PARAM_ALPHA); // Sorting key
 
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('glossary', $id)) {
         error("Course Module ID was incorrect");
     }
 
@@ -33,8 +33,12 @@
     print_header();
 
     require_course_login($course, true, $cm);
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
 
-    if (!isteacher($course->id) and !$glossary->allowprintview) {
+/// Loading the textlib singleton instance. We are going to need it.
+    $textlib = textlib_get_instance();
+
+    if (!has_capability('mod/glossary:manageentries', $context) and !$glossary->allowprintview) {
         notice(get_string('printviewnotallowed', 'glossary'));
     }
 
@@ -140,34 +144,36 @@
     }
 
     $site = get_record("course","id",1);
-    echo '<p align="right"><font size="-1">' . userdate(time()) . '</font></p>';
-    echo get_string("site") . ': <strong>' . $site->fullname . '</strong><br />';
-    echo get_string("course") . ': <strong>' . $course->fullname . ' ('. $course->shortname . ')</strong><br />';
-    echo get_string("modulename","glossary") . ': <strong>' . format_string($glossary->name, true) . '</strong><p>';
+    echo '<p style="text-align:right"><span style="font-size:0.75em">' . userdate(time()) . '</span></p>';
+    echo get_string("site") . ': <strong>' . format_string($site->fullname) . '</strong><br />';
+    echo get_string("course") . ': <strong>' . format_string($course->fullname) . ' ('. format_string($course->shortname) . ')</strong><br />';
+    echo get_string("modulename","glossary") . ': <strong>' . format_string($glossary->name, true) . '</strong>';
     if ( $allentries ) {
         foreach ($allentries as $entry) {
 
             // Setting the pivot for the current entry
-            $pivot = $entry->pivot;
+            $pivot = $entry->glossarypivot;
+            $upperpivot = $textlib->strtoupper($pivot);
+            // Reduce pivot to 1cc if necessary
             if ( !$fullpivot ) {
-                $pivot = substr($pivot, 0, 1);
+                $upperpivot = $textlib->substr($upperpivot, 0, 1);
             }            
             
             // If there's  group break
-            if ( $currentpivot != strtoupper($pivot) ) {
+            if ( $currentpivot != $upperpivot ) {
 
                 // print the group break if apply
                 if ( $printpivot )  {
-                    $currentpivot = strtoupper($pivot);
+                    $currentpivot = $upperpivot;
 
                     $pivottoshow = $currentpivot;
-                    if ( isset($entry->uid) ) {
+                    if ( isset($entry->userispivot) ) {
                         // printing the user icon if defined (only when browsing authors)
-                        $user = get_record("user","id",$entry->uid);
-                        $pivottoshow = fullname($user, isteacher($course->id));
+                        $user = get_record("user","id",$entry->userid);
+                        $pivottoshow = fullname($user);
                     }
 
-                    echo "<p align=\"center\"><strong><i>".clean_text($pivottoshow)."</i></strong></p>" ;
+                    echo "<p align=\"center\"><strong>".clean_text($pivottoshow)."</strong></p>" ;
                 }
             }
 
@@ -175,5 +181,5 @@
         }
     }
 
-    echo '</body></html>';
+    echo '</div></div></body></html>';
 ?>
