@@ -1,4 +1,4 @@
-<?PHP  // $Id: rsslib.php,v 1.3.2.1 2004/09/29 07:52:34 moodler Exp $
+<?php  // $Id: rsslib.php,v 1.10.4.1 2007/02/27 18:21:08 stronk7 Exp $
     //This file adds support to rss feeds generation
 
     //This function is the main entry point to glossary
@@ -12,16 +12,10 @@
 
         //Check CFG->enablerssfeeds
         if (empty($CFG->enablerssfeeds)) {
-            //Some debug...
-            if ($CFG->debug > 7) {
-                echo "DISABLED (admin variables)";
-            }
+            debugging("DISABLED (admin variables)");
         //Check CFG->glossary_enablerssfeeds
         } else if (empty($CFG->glossary_enablerssfeeds)) {
-            //Some debug...
-            if ($CFG->debug > 7) {
-                echo "DISABLED (module configuration)";
-            }
+            debugging("DISABLED (module configuration)");
         //It's working so we start...
         } else {
             //Iterate over all glossaries
@@ -48,12 +42,8 @@
                             continue;
                         }
 
-                        mtrace("Updating RSS feed for $glossary->name, ID: $glossary->id");
+                        mtrace("Updating RSS feed for ".format_string($glossary->name,true).", ID: $glossary->id");
 
-                        //Some debug...
-                        if ($CFG->debug > 7) {
-                            echo "ID: $glossary->id->";
-                        }
                         //Get the XML contents
                         $result = glossary_rss_feed($glossary);
                         //Save the XML contents to file
@@ -61,14 +51,14 @@
                             $status = rss_save_file("glossary",$glossary,$result);
                         }
                         //Some debug...
-                        if ($CFG->debug > 7) {
+                        if (debugging()) {
                             if (empty($result)) {
-                                echo "(empty) ";
+                                echo "ID: $glossary->id-> (empty) ";
                             } else {
                                 if (!empty($status)) {
-                                    echo "OK ";
+                                    echo "ID: $glossary->id-> OK ";
                                 } else {
-                                    echo "FAIL ";
+                                    echo "ID: $glossary->id-> FAIL ";
                                 }
                             }
                         }
@@ -100,16 +90,10 @@
 
         //Check CFG->enablerssfeeds
         if (empty($CFG->enablerssfeeds)) {
-            //Some debug...
-            if ($CFG->debug > 7) {
-                echo "DISABLED (admin variables)"; 
-            }           
+            debugging("DISABLED (admin variables)");
         //Check CFG->glossary_enablerssfeeds
         } else if (empty($CFG->glossary_enablerssfeeds)) {
-            //Some debug... 
-            if ($CFG->debug > 7) {
-                echo "DISABLED (module configuration)";
-            }           
+            debugging("DISABLED (module configuration)");
         //It's working so we start...
         } else {
             //Check the glossary has rss activated
@@ -119,14 +103,14 @@
                     $items = glossary_rss_feed_withauthor($glossary);
                 } else {                //Without author RSS
                     $items = glossary_rss_feed_withoutauthor($glossary);
-     
+
                 }
                 //Now, if items, we begin building the structure
                 if (!empty($items)) {
                     //First all rss feeds common headers
-                    $header = rss_standard_header($glossary->name,
-                                                  $CFG->wwwroot."/mod/glossary/view.php?f=".$glossary->id,
-                                                  $glossary->intro);
+                    $header = rss_standard_header(format_string($glossary->name,true),
+                                                  $CFG->wwwroot."/mod/glossary/view.php?g=".$glossary->id,
+                                                  format_string($glossary->intro,true));
                     //Now all the rss items
                     if (!empty($header)) {
                         $articles = rss_add_items($items);
@@ -140,7 +124,7 @@
                         $status = $header.$articles.$footer;
                     } else {
                         $status = false;
-                    } 
+                    }
                 } else {
                     $status = false;
                 }
@@ -159,9 +143,9 @@
 
         if ($newsince) {
             $newsince = " AND e.timecreated > '$newsince'";
-        } else {        
+        } else {
             $newsince = "";
-        }       
+        }
 
         if ($recs = get_records_sql ("SELECT e.id AS entryid, 
                                              e.concept AS entryconcept, 
@@ -186,6 +170,10 @@
             $articlesleft = $glossary->rssarticles;
             $item = NULL;
             $user = NULL;
+
+            $formatoptions = new object;
+            $formatoptions->trusttext = true;
+
             foreach ($recs as $rec) {
                 unset($item);
                 unset($user);
@@ -195,7 +183,7 @@
                 $item->author = fullname($user);
                 $item->pubdate = $rec->entrytimecreated;
                 $item->link = $CFG->wwwroot."/mod/glossary/showentry.php?courseid=".$glossary->course."&eid=".$rec->entryid;
-                $item->description = format_text($rec->entrydefinition,$rec->entryformat,NULL,$glossary->course);
+                $item->description = format_text($rec->entrydefinition,$rec->entryformat,$formatoptions,$glossary->course);
                 $items[] = $item;
                 $articlesleft--;
                 if ($articlesleft < 1) {
@@ -244,6 +232,10 @@
             $articlesleft = $glossary->rssarticles;
             $item = NULL;
             $user = NULL;
+
+            $formatoptions = new object;
+            $formatoptions->trusttext = true;
+
             foreach ($recs as $rec) {
                 unset($item);
                 unset($user);
@@ -253,7 +245,7 @@
                 //$item->author = fullname($user);
                 $item->pubdate = $rec->entrytimecreated;
                 $item->link = $CFG->wwwroot."/mod/glossary/showentry.php?courseid=".$glossary->course."&eid=".$rec->entryid;
-                $item->description = format_text($rec->entrydefinition,$rec->entryformat,NULL,$glossary->course);
+                $item->description = format_text($rec->entrydefinition,$rec->entryformat,$formatoptions,$glossary->course);
                 $items[] = $item;
                 $articlesleft--;
                 if ($articlesleft < 1) {
@@ -263,5 +255,5 @@
         }
         return $items;
     }
-    
+
 ?>
