@@ -1,11 +1,11 @@
-<?php  // $Id: showentry.php,v 1.25.2.2 2006/01/07 12:29:29 stronk7 Exp $
+<?php  // $Id: showentry.php,v 1.32.4.2 2007/03/30 07:02:59 toyomoyo Exp $
     require_once("../../config.php");
     require_once("lib.php");
 
-    $concept  = optional_param('concept', '', PARAM_CLEAR);
+    $concept  = optional_param('concept', '', PARAM_CLEAN);
     $courseid = optional_param('courseid', 0, PARAM_INT);
     $eid      = optional_param('eid', 0, PARAM_INT); // glossary entry id
-    $displayformat = optional_param('displayformat',-1, PARAM_INT);
+    $displayformat = optional_param('displayformat',-1, PARAM_SAFEDIR);
 
     if ($CFG->forcelogin) {
         require_login();
@@ -18,7 +18,7 @@
         if (!$cm = get_coursemodule_from_instance("glossary", $glossary->id)) {
             error("Could not determine which course module this belonged to!");
         }
-        if (!$cm->visible and !isteacher($cm->course)) {
+        if (!$cm->visible and !has_capability('moodle/course:viewhiddenactivities', get_context_instance(CONTEXT_MODULE, $cm->id))) {
             redirect($CFG->wwwroot.'/course/view.php?id='.$cm->course, get_string('activityiscurrentlyhidden'));
         }
         $entry->cmid = $cm->id;
@@ -33,14 +33,14 @@
     if ($entries) {
         foreach ($entries as $key => $entry) {
             //$entries[$key]->footer = "<p align=\"right\">&raquo;&nbsp;<a onClick=\"if (window.opener) {window.opener.location.href='$CFG->wwwroot/mod/glossary/view.php?g=$entry->glossaryid'; return false;} else {openpopup('/mod/glossary/view.php?g=$entry->glossaryid', 'glossary', 'menubar=1,location=1,toolbar=1,scrollbars=1,directories=1,status=1,resizable=1', 0); return false;}\" href=\"$CFG->wwwroot/mod/glossary/view.php?g=$entry->glossaryid\" target=\"_blank\">".format_string($entry->glossaryname,true)."</a></p>";  // Could not get this to work satisfactorily in all cases  - Martin
-            $entries[$key]->footer = "<p align=\"right\">&raquo;&nbsp;<a target=\"_blank\" href=\"$CFG->wwwroot/mod/glossary/view.php?g=$entry->glossaryid\">".format_string($entry->glossaryname,true)."</a></p>";
+            $entries[$key]->footer = "<p style=\"text-align:right\">&raquo;&nbsp;<a href=\"$CFG->wwwroot/mod/glossary/view.php?g=$entry->glossaryid\">".format_string($entry->glossaryname,true)."</a></p>";
             add_to_log($entry->courseid, "glossary", "view entry", "showentry.php?eid=$entry->id", $entry->id, $entry->cmid);
         }
     }
 
     if (!empty($courseid)) {
         $course = get_record("course", "id", $courseid);
-        if ($course->category) {
+        if ($course->id != SITEID) {
             require_login($courseid);
         }
 
@@ -48,11 +48,11 @@
         $strsearch = get_string("search");
 
         $CFG->framename = "newwindow";
-        if ($course->category) {
-            print_header(strip_tags("$course->shortname: $strglossaries $strsearch"), "$course->fullname",
+        if ($course->id != SITEID) {
+            print_header(strip_tags("$course->shortname: $strglossaries $strsearch"), $course->fullname,
             "<a target=\"newwindow\" href=\"$CFG->wwwroot/course/view.php?id=$course->id\">$course->shortname</a> -> $strglossaries -> $strsearch", "", "", true, "&nbsp;", "&nbsp;");
         } else {
-            print_header(strip_tags("$course->shortname: $strglossaries $strsearch"), "$course->fullname",
+            print_header(strip_tags("$course->shortname: $strglossaries $strsearch"), $course->fullname,
             "$strglossaries -> $strsearch", "", "", true, "&nbsp;", "&nbsp;");
         }
 
@@ -66,4 +66,7 @@
 
     close_window_button();
 
+/// Show one reduced footer
+    print_footer('none');
+
 ?>
