@@ -1,4 +1,4 @@
-<?php  // $Id: report.php,v 1.5 2006/03/30 03:17:51 gbateson Exp $
+<?php  // $Id: report.php,v 1.10 2007/01/08 19:34:16 skodak Exp $
 /// Overview report just displays a big table of all the attempts
 class hotpot_report extends hotpot_default_report {
 
@@ -51,7 +51,7 @@ class hotpot_report extends hotpot_default_report {
 				$picture = print_user_picture($u->userid, $course->id, $u->picture, false, true);
 				$name = '<a href="'.$CFG->wwwroot.'/user/view.php?id='.$u->userid.'&course='.$course->id.'">'.$name.'</a>';
 			}
-			$grade = isset($user->grade) ? $user->grade : $spacer;
+			$grade = isset($user->grade) && $user->grade<>'&nbsp;' ? $user->grade : $spacer;
 			$attemptcount = count($user->attempts);
 			if ($attemptcount>1) {
 				$text = $name;
@@ -82,11 +82,11 @@ class hotpot_report extends hotpot_default_report {
 				}
 				$attemptnumber = $attempt->attempt;
 				$starttime = trim(userdate($attempt->timestart, $strtimeformat));
-				if ($is_html && isset($attempt->score) && (isteacher($course->id) || $hotpot->review)) {
+				if ($is_html && isset($attempt->score) && (has_capability('mod/hotpot:viewreport',get_context_instance(CONTEXT_COURSE, $course->id)) || $hotpot->review)) {
 					$attemptnumber = '<a href="review.php?hp='.$hotpot->id.'&attempt='.$attempt->id.'">'.$attemptnumber.'</a>';
 					$starttime = '<a href="review.php?hp='.$hotpot->id.'&attempt='.$attempt->id.'">'.$starttime.'</a>';
 				}
-				if ($is_html && isteacher($course->id)) {
+				if ($is_html && has_capability('mod/hotpot:viewreport',get_context_instance(CONTEXT_COURSE, $course->id))) {
 					$checkbox = '<input type=checkbox name="box'.$attempt->clickreportid.'" value="'.$attempt->clickreportid.'">'.$spacer;
 				} else {
 					$checkbox = '';
@@ -111,18 +111,18 @@ class hotpot_report extends hotpot_default_report {
 		// remove final 'hr' from data rows
 		array_pop($table->data);
 		// add the "delete" form to the table
-		if ($options['reportformat']=='htm' && isteacher($course->id)) {
+		if ($options['reportformat']=='htm' && has_capability('mod/hotpot:viewreport',get_context_instance(CONTEXT_COURSE, $course->id))) {
 			$strdeletecheck = get_string('deleteattemptcheck','quiz');
 			$table->start = $this->deleteform_javascript();
-			$table->start .= '<form method="post" action="report.php" name="deleteform" onsubmit="'."return deletecheck('".$strdeletecheck."', 'selection')".'">'."\n";
-			$table->start .= '<input type="hidden" name="del" value="selection">'."\n";
+			$table->start .= '<form method="post" action="report.php" id="deleteform" onsubmit="'."return deletecheck('".$strdeletecheck."', 'selection')".'">'."\n";
+			$table->start .= '<input type="hidden" name="del" value="selection" />'."\n";
 			$table->start .= '<input type="hidden" name="id" value="'.$cm->id.'">'."\n";
 			$table->finish = '<center>'."\n";
-			$table->finish .= '<input type="submit" value="'.get_string("deleteselected").'">&nbsp;'."\n";
+			$table->finish .= '<input type="submit" value="'.get_string("deleteselected").'" />&nbsp;'."\n";
 			if ($abandoned) {
-				$table->finish .= '<input type=button value="'.get_string('deleteabandoned', 'hotpot').'" onClick="if(deletecheck('."'".addslashes(get_string('deleteabandonedcheck', 'hotpot', $abandoned))."', 'abandoned', true".'))document.deleteform.submit();">'."\n";
+				$table->finish .= '<input type=button value="'.get_string('deleteabandoned', 'hotpot').'" onClick="if(deletecheck('."'".addslashes(get_string('deleteabandonedcheck', 'hotpot', $abandoned))."', 'abandoned', true".')) getElementById(\'deleteform\').submit();" />'."\n";
 			}
-			$table->finish .= '<input type=button value="'.get_string("deleteall").'" onClick="if(deletecheck('."'".addslashes($strdeletecheck)."', 'all', true".'))document.deleteform.submit();">'."\n";
+			$table->finish .= '<input type=button value="'.get_string("deleteall").'" onClick="if(deletecheck('."'".addslashes($strdeletecheck)."', 'all', true".'))getElementById(\'deleteform\').submit();" />'."\n";
 			$table->finish .= '</center>'."\n";
 			$table->finish .= '</form>'."\n";
 		}
@@ -136,7 +136,7 @@ class hotpot_report extends hotpot_default_report {
 function deletecheck(p, v, x) {
 	var r = false; // result
 	// get length of form elements
-	var f = document.deleteform;
+	var f = getElementById('deleteform');
 	var l = f ? f.elements.length : 0;
 	// count selected items, if necessary
 	if (!x) {
