@@ -1,4 +1,4 @@
-<?PHP //$Id: restorelib.php,v 1.11.2.3 2006/09/01 03:58:09 gbateson Exp $
+<?PHP //$Id: restorelib.php,v 1.24 2007/01/04 23:38:26 skodak Exp $
 //This php script contains all the stuff to restore hotpot mods
     //-----------------------------------------------------------
     // This is the "graphical" structure of the hotpot mod:
@@ -60,6 +60,7 @@ function hotpot_restore_mods($mod, $restore) {
     // $modinfo is an array
     //    'modname'    : array( 'restore'=> 0=no 1=yes, 'userinfo' => 0=no 1=yes)
 
+    global $CFG;
     $status = true;
 
     // get course module data this hotpot activity
@@ -77,7 +78,7 @@ function hotpot_restore_mods($mod, $restore) {
         $more_restore = '';
         // print a message after each hotpot is backed up
         if (!defined('RESTORE_SILENTLY')) {
-            $more_restore .= 'print "<li>".get_string("modulename", "hotpot")." &quot;".$record->name."&quot;</li>";';
+            $more_restore .= 'print "<li>".get_string("modulename", "hotpot")." &quot;".format_string(stripslashes($record->name),true)."&quot;</li>";';
         }
         $more_restore .= 'backup_flush(300);';
         if (function_exists('restore_userdata_selected')) {
@@ -105,6 +106,12 @@ function hotpot_restore_mods($mod, $restore) {
                 $more_restore .= '$status = hotpot_restore_attempts($restore, $status, $xml, $record);';
             }
         }
+
+        // if necessary, adjust HotPot date/time fields and write to restorelog
+        if ($restore->course_startdateoffset) {
+            restore_log_date_changes('Hotpot', $restore, $xml, array('TIMEOPEN', 'TIMECLOSE', 'TIMECREATED', 'TIMEMODIFIED'));
+        }
+
         $status = hotpot_restore_records(
             $restore, $status, $xml, $table, $foreign_keys, $more_restore
         );
@@ -291,7 +298,7 @@ function hotpot_restore_record(&$restore, $status, &$xml, $table, $foreign_keys,
     // maintain a cache of info on table columns
     static $table_columns = array();
     if (empty($table_columns[$table])) {
-        global $CFG, $db;
+        global $CFG, $db; 
         $table_columns[$table] = $db->MetaColumns("$CFG->prefix$table");
     }
 
@@ -306,7 +313,7 @@ function hotpot_restore_record(&$restore, $status, &$xml, $table, $foreign_keys,
         }
     }
 
-    // update secondary keys, if any
+    // update foreign keys, if any
     $ok = true;
     foreach ($foreign_keys as $key=>$value) {
         if (is_numeric($value)) {
@@ -326,8 +333,8 @@ function hotpot_restore_record(&$restore, $status, &$xml, $table, $foreign_keys,
                         } else {
                             // foreign key could not be updated
                             if (!defined('RESTORE_SILENTLY')) {
-                                print "<ul><li><b>Warning:</b><br>Foreign key could not be updated:<br>";
-                                print "'$key_table' record (old id=$old_id) is missing from backup data<br>";
+                                print "<ul><li><b>Warning:</b><br/>Foreign key could not be updated:<br/>";
+                                print "'$key_table' record (old id=$old_id) is missing from backup data<br/>";
                                 print "'$table' record ";
                                 if (isset($record->id)) {
                                     print "(old id=$record->id) ";
@@ -343,6 +350,14 @@ function hotpot_restore_record(&$restore, $status, &$xml, $table, $foreign_keys,
         }
     }
 
+    // set md5 keys if necessary (restoring from Moodle<1.6)
+    if ($table=='hotpot_questions' && empty($record->md5key)) {
+        $record->md5key = md5($record->name);
+    }
+    if ($table=='hotpot_strings' && empty($record->md5key)) {
+        $record->md5key = md5($record->string);
+    }
+
     // check all "not null" fields have been set
     foreach ($table_columns[$table] as $column) {
         if ($column->not_null) {
