@@ -1,11 +1,11 @@
-<?PHP // $Id: version.php,v 1.34.2.5 2006/09/13 08:26:16 gbateson Exp $
+<?PHP // $Id: version.php,v 1.45.2.2 2007/05/04 02:50:19 gbateson Exp $
 /////////////////////////////////////////////////////////////////////////////////
 ///  Code fragment to define the version of hotpot
 ///  This fragment is called by moodle_needs_upgrading() and /admin/index.php
 /////////////////////////////////////////////////////////////////////////////////
-$module->version  = 2006082900;   // change only last two digits in 1.6.x!!
-$module->release  = 'v2.1.23';    // human-friendly version name (used in mod/hotpot/lib.php)
-$module->requires = 2003091111;   // replace with 2005060241 if you want to use it with latest 1.5.4+
+$module->version  = 2007020202;   // release date of this version (see note below)
+$module->release  = 'v2.3.2';    // human-friendly version name (used in mod/hotpot/lib.php)
+$module->requires = 2007020200;  // Requires this Moodle version
 $module->cron     = 0;            // period for cron to check this module (secs)
 // interpretation of YYYYMMDDXY version numbers
 //     YYYY : year
