@@ -1,4 +1,4 @@
-<?PHP // $Id: lib.php,v 1.57 2004/05/16 00:36:00 stronk7 Exp $
+<?php // $Id: lib.php,v 1.79.2.1 2007/05/15 18:26:53 skodak Exp $
 
 
 if (!isset($CFG->journal_showrecentactivity)) {
@@ -28,7 +28,7 @@ function journal_user_complete($course, $user, $mod, $journal) {
 
         print_simple_box_start();
         if ($entry->modified) {
-            echo "<P><FONT SIZE=1>".get_string("lastedited").": ".userdate($entry->modified)."</FONT></P>";
+            echo "<p><font size=\"1\">".get_string("lastedited").": ".userdate($entry->modified)."</font></p>";
         }
         if ($entry->text) {
             echo format_text($entry->text, $entry->format);
@@ -55,7 +55,7 @@ function journal_user_complete_index($course, $user, $journal, $journalopen, $he
         $entryinfo = "";
     }
 
-    $journal->name = "<a href=\"view.php?id=$journal->coursemodule\">$journal->name</a>";
+    $journal->name = "<a href=\"view.php?id=$journal->coursemodule\">".format_string($journal->name,true)."</a>";
 
     if ($heading) {
         echo "<h3>$heading - $journal->name$entryinfo</h3>";
@@ -66,38 +66,41 @@ function journal_user_complete_index($course, $user, $journal, $journalopen, $he
     print_simple_box_start("left", "90%");
     echo format_text($journal->intro,  $journal->introformat);
     print_simple_box_end();
-    echo "<br clear=all />";
+    echo "<br clear=\"all\" />";
     echo "<br />";
+    
+    if (isstudent($course->id) or isteacher($course->id)) {
 
-    print_simple_box_start("right", "90%");
-
-    if ($journalopen) {
-        echo "<p align=right><a href=\"edit.php?id=$journal->coursemodule\">";
-        echo get_string("edit")."</a></p>";
-    } else {
-        echo "<p align=right><a href=\"view.php?id=$journal->coursemodule\">";
-        echo get_string("view")."</a></p>";
+        print_simple_box_start("right", "90%");
+    
+        if ($journalopen) {
+            echo "<p align=\"right\"><a href=\"edit.php?id=$journal->coursemodule\">";
+            echo get_string("edit")."</a></p>";
+        } else {
+            echo "<p align=\"right\"><a href=\"view.php?id=$journal->coursemodule\">";
+            echo get_string("view")."</a></p>";
+        }
+    
+        if ($entry = get_record("journal_entries", "userid", $user->id, "journal", $journal->id)) {
+            if ($entry->modified) {
+                echo "<p align=\"center\"><font size=\"1\">".get_string("lastedited").": ".userdate($entry->modified)."</font></p>";
+            }
+            if ($entry->text) {
+                echo format_text($entry->text, $entry->format);
+            }
+            if ($entry->teacher) {
+                $grades = make_grades_menu($journal->assessed);
+                journal_print_feedback($course, $entry, $grades);
+            }
+        } else {
+            print_string("noentry", "journal");
+        }
+    
+        print_simple_box_end();
+        echo "<br clear=\"all\" />";
+        echo "<br />";
     }
 
-    if ($entry = get_record("journal_entries", "userid", $user->id, "journal", $journal->id)) {
-        if ($entry->modified) {
-            echo "<p align=\"center\"><font size=1>".get_string("lastedited").": ".userdate($entry->modified)."</font></p>";
-        }
-        if ($entry->text) {
-            echo format_text($entry->text, $entry->format);
-        }
-        if ($entry->teacher) {
-            $grades = make_grades_menu($journal->assessed);
-            journal_print_feedback($course, $entry, $grades);
-        }
-    } else {
-        print_string("noentry", "journal");
-    }
-
-    print_simple_box_end();
-    echo "<br clear=all />";
-    echo "<br />";
-
 }
 
 
@@ -145,22 +148,24 @@ function journal_cron () {
 
             unset($journalinfo);
             $journalinfo->teacher = fullname($teacher);
-            $journalinfo->journal = "$entry->name";
+            $journalinfo->journal = format_string($entry->name,true);
             $journalinfo->url = "$CFG->wwwroot/mod/journal/view.php?id=$mod->id";
+            $modnamepl = get_string( 'modulenameplural','journal' );
+            $msubject = get_string( 'mailsubject','journal' );
 
-            $postsubject = "$course->shortname: Journal feedback: $entry->name";
-            $posttext  = "$course->shortname -> Journals -> $entry->name\n";
+            $postsubject = "$course->shortname: $msubject: ".format_string($entry->name,true);
+            $posttext  = "$course->shortname -> $modnamepl -> ".format_string($entry->name,true)."\n";
             $posttext .= "---------------------------------------------------------------------\n";
-            $posttext .= get_string("journalmail", "journal", $journalinfo);
+            $posttext .= get_string("journalmail", "journal", $journalinfo)."\n";
             $posttext .= "---------------------------------------------------------------------\n";
             if ($user->mailformat == 1) {  // HTML
                 $posthtml = "<p><font face=\"sans-serif\">".
                 "<a href=\"$CFG->wwwroot/course/view.php?id=$course->id\">$course->shortname</a> ->".
                 "<a href=\"$CFG->wwwroot/mod/journal/index.php?id=$course->id\">journals</a> ->".
-                "<a href=\"$CFG->wwwroot/mod/journal/view.php?id=$mod->id\">$entry->name</a></font></p>";
-                $posthtml .= "<hr><font face=\"sans-serif\">";
+                "<a href=\"$CFG->wwwroot/mod/journal/view.php?id=$mod->id\">".format_string($entry->name,true)."</a></font></p>";
+                $posthtml .= "<hr /><font face=\"sans-serif\">";
                 $posthtml .= "<p>".get_string("journalmailhtml", "journal", $journalinfo)."</p>";
-                $posthtml .= "</font><hr>";
+                $posthtml .= "</font><hr />";
             } else {
               $posthtml = "";
             }
@@ -180,17 +185,17 @@ function journal_cron () {
 function journal_print_recent_activity($course, $isteacher, $timestart) {
     global $CFG;
 
-    if (empty($CFG->journal_showrecentactivity)) {    // Don't even bother
+    if (!empty($CFG->journal_showrecentactivity)) {    // Don't even bother
         return false;
     }
 
     $content = false;
     $journals = NULL;
 
-    if (!$logs = get_records_select("log", "time > '$timestart' AND ".
-                                           "course = '$course->id' AND ".
-                                           "module = 'journal' AND ".
-                                           "(action = 'add entry' OR action = 'update entry')", "time ASC")){
+    if (!$logs = get_records_select('log', 'time > \''.$timestart.'\' AND '.
+                                           'course = \''.$course->id.'\' AND '.
+                                           'module = \'journal\' AND '.
+                                           '(action = \'add entry\' OR action = \'update entry\')', 'time ASC')){
         return false;
     }
 
@@ -209,21 +214,17 @@ function journal_print_recent_activity($course, $isteacher, $timestart) {
             if (!isset($journals[$log->info])) {
                 $journals[$log->info] = $j_log_info;
                 $journals[$log->info]->time = $log->time;
-                $journals[$log->info]->url = $log->url;
+                $journals[$log->info]->url = str_replace('&', '&amp;', $log->url);
             }
         }
     }
 
     if ($journals) {
         $content = true;
-        $strftimerecent = get_string("strftimerecent");
-        print_headline(get_string("newjournalentries", "journal").":");
+        print_headline(get_string('newjournalentries', 'journal').':');
         foreach ($journals as $journal) {
-            $date = userdate($journal->time, $strftimerecent);
-            echo "<p><font size=1>$date - ".fullname($journal)."<br />";
-            echo "\"<a href=\"$CFG->wwwroot/mod/journal/$journal->url\">";
-            echo "$journal->name";
-            echo "</a>\"</font></p>";
+            print_recent_activity_note($journal->time, $journal, $journal->name,
+                                       $CFG->wwwroot.'/mod/journal/'.$journal->url);
         }
     }
  
@@ -270,13 +271,13 @@ function journal_get_participants($journalid) {
     global $CFG;
 
     //Get students
-    $students = get_records_sql("SELECT DISTINCT u.*
+    $students = get_records_sql("SELECT DISTINCT u.id, u.id
                                  FROM {$CFG->prefix}user u,
                                       {$CFG->prefix}journal_entries j
                                  WHERE j.journal = '$journalid' and
                                        u.id = j.userid");
     //Get teachers
-    $teachers = get_records_sql("SELECT DISTINCT u.*
+    $teachers = get_records_sql("SELECT DISTINCT u.id, u.id
                                  FROM {$CFG->prefix}user u,
                                       {$CFG->prefix}journal_entries j
                                  WHERE j.journal = '$journalid' and
@@ -311,36 +312,24 @@ function journal_scale_used ($journalid,$scaleid) {
 function journal_get_users_done($journal) {
     global $CFG;
 
-    $studentjournals = get_records_sql ("SELECT u.*
+    $journals = get_records_sql ("SELECT u.*
                                   FROM {$CFG->prefix}journal_entries j,
-                                       {$CFG->prefix}user u, 
-                                       {$CFG->prefix}user_students s
+                                       {$CFG->prefix}user u 
                                  WHERE j.userid = u.id
-                                   AND s.userid = u.id 
                                    AND j.journal = $journal->id
-                                   AND s.course = $journal->course
                               ORDER BY j.modified DESC");
 
-    $teacherjournals = get_records_sql ("SELECT u.*
-                                  FROM {$CFG->prefix}journal_entries j,
-                                       {$CFG->prefix}user u, 
-                                       {$CFG->prefix}user_teachers t
-                                 WHERE j.userid = u.id
-                                   AND t.userid = u.id 
-                                   AND j.journal = $journal->id
-                                   AND t.course = $journal->course
-                              ORDER BY j.modified DESC");
+    if (empty($journals)) {
+        return NULL;
+    }
 
-    if ($studentjournals and !$teacherjournals) {
-        return $studentjournals;
+    // remove unenrolled participants
+    foreach ($journals as $key=>$user) {
+        if (!isteacher($journal->course, $user->id) and !isstudent($journal->course, $user->id)) {
+            unset($journals[$key]);
+        } 
     }
-    if ($teacherjournals and !$studentjournals) {
-        return $teacherjournals;
-    }
-    if (!$teacherjournals and !$studentjournals) {
-        return array();
-    }
-    return(array_merge($studentjournals, $teacherjournals));
+    return $journals;
 }
 
 function journal_count_entries($journal, $groupid=0) {
@@ -351,30 +340,30 @@ function journal_count_entries($journal, $groupid=0) {
     if ($groupid) {     /// How many in a particular group?
         return count_records_sql("SELECT COUNT(*) 
                                      FROM {$CFG->prefix}journal_entries j,
-                                          {$CFG->prefix}groups_members g
+                                          ".groups_members_from_sql()."
                                     WHERE j.journal = $journal->id 
-                                      AND g.groupid = '$groupid' 
-                                      AND j.userid = g.userid");
+                                      AND ".groups_members_where_sql($groupid, 'j.userid'));
 
     } else { /// Count all the entries from the whole course
-        $studentjournals = count_records_sql("SELECT COUNT(*)
-                                                 FROM {$CFG->prefix}journal_entries j,
-                                                      {$CFG->prefix}user u, 
-                                                      {$CFG->prefix}user_students s
-                                                WHERE j.userid = u.id
-                                                  AND s.userid = u.id 
-                                                  AND j.journal = $journal->id
-                                                  AND s.course = $journal->course ");
+    
+        $journals = get_records_sql ("SELECT u.*
+                                      FROM {$CFG->prefix}journal_entries j,
+                                           {$CFG->prefix}user u 
+                                     WHERE j.userid = u.id
+                                       AND j.journal = $journal->id
+                                  ORDER BY j.modified DESC");
 
-        $teacherjournals = count_records_sql("SELECT COUNT(*)
-                                                 FROM {$CFG->prefix}journal_entries j,
-                                                      {$CFG->prefix}user u, 
-                                                      {$CFG->prefix}user_teachers t
-                                                WHERE j.userid = u.id
-                                                  AND t.userid = u.id 
-                                                  AND j.journal = $journal->id
-                                                  AND t.course = $journal->course ");
-        return ($studentjournals + $teacherjournals);
+        if (empty($journals)) {
+            return 0;
+        }
+
+        // remove unenrolled participants
+        foreach ($journals as $key=>$user) {
+            if (!isteacher($journal->course, $user->id) and !isstudent($journal->course, $user->id)) {
+                unset($journals[$key]);
+            } 
+        }
+        return count($journals);
     }
 }
 
@@ -406,52 +395,46 @@ function journal_log_info($log) {
 
 
 function journal_print_user_entry($course, $user, $entry, $teachers, $grades) {
-    global $THEME, $USER;
+    global $USER;
 
-    if ($entry->timemarked < $entry->modified) {
-        $colour = $THEME->cellheading2;
-    } else {
-        $colour = $THEME->cellheading;
-    }
-
-    echo "\n<TABLE BORDER=1 CELLSPACING=0 valign=top cellpadding=10>";
+    echo "\n<table border=\"1\" cellspacing=\"0\" valign=\"top\" cellpadding=\"10\">";
         
-    echo "\n<TR>";
-    echo "\n<TD ROWSPAN=2 BGCOLOR=\"$THEME->body\" WIDTH=35 VALIGN=TOP>";
+    echo "\n<tr>";
+    echo "\n<td rowspan=\"2\" width=\"35\" valign=\"top\">";
     print_user_picture($user->id, $course->id, $user->picture);
-    echo "</TD>";
-    echo "<TD NOWRAP WIDTH=100% BGCOLOR=\"$colour\">".fullname($user);
+    echo "</td>";
+    echo "<td nowrap=\"nowrap\" width=\"100%\">".fullname($user);
     if ($entry) {
-        echo "&nbsp;&nbsp;<FONT SIZE=1>".get_string("lastedited").": ".userdate($entry->modified)."</FONT>";
+        echo "&nbsp;&nbsp;<font size=\"1\">".get_string("lastedited").": ".userdate($entry->modified)."</font>";
     }
-    echo "</TR>";
+    echo "</td></tr>";
 
-    echo "\n<TR><TD WIDTH=100% BGCOLOR=\"$THEME->cellcontent\">";
+    echo "\n<tr><td width=\"100%\">";
     if ($entry) {
         echo format_text($entry->text, $entry->format);
     } else {
         print_string("noentry", "journal");
     }
-    echo "</TD></TR>";
+    echo "</td></tr>";
 
     if ($entry) {
-        echo "\n<TR>";
-        echo "<TD WIDTH=35 VALIGN=TOP>";
+        echo "\n<tr>";
+        echo "<td width=\"35\" valign=\"top\">";
         if (!$entry->teacher) {
             $entry->teacher = $USER->id;
         }
         print_user_picture($entry->teacher, $course->id, $teachers[$entry->teacher]->picture);
-        echo "<TD BGCOLOR=\"$colour\">".get_string("feedback").":";
+        echo "<td>".get_string("feedback").":";
         choose_from_menu($grades, "r$entry->id", $entry->rating, get_string("nograde")."...");
         if ($entry->timemarked) {
-            echo "&nbsp;&nbsp;<FONT SIZE=1>".userdate($entry->timemarked)."</FONT>";
+            echo "&nbsp;&nbsp;<font size=\"1\">".userdate($entry->timemarked)."</font>";
         }
-        echo "<BR><TEXTAREA NAME=\"c$entry->id\" ROWS=12 COLS=60 WRAP=virtual>";
-        p($entry->comment);
-        echo "</TEXTAREA><BR>";
-        echo "</TD></TR>";
+        echo "<br /><textarea name=\"c$entry->id\" rows=\"12\" cols=\"60\" wrap=\"virtual\">";
+        p($entry->entrycomment);
+        echo "</textarea><br />";
+        echo "</td></tr>";
     }
-    echo "</TABLE><BR CLEAR=ALL>\n";
+    echo "</table><br clear=\"all\" />\n";
 }
 
 
@@ -504,37 +487,47 @@ function journal_delete_instance($id) {
 
 
 function journal_print_feedback($course, $entry, $grades) {
-    global $CFG, $THEME;
+    global $CFG;
 
-    if (! $teacher = get_record("user", "id", $entry->teacher)) {
-        error("Weird journal error");
+    if (! $teacher = get_record('user', 'id', $entry->teacher)) {
+        error('Weird journal error');
     }
 
-    echo "\n<TABLE BORDER=0 CELLPADDING=1 CELLSPACING=1 ALIGN=CENTER><TR><TD BGCOLOR=#888888>";
-    echo "\n<TABLE BORDER=0 CELLPADDING=3 CELLSPACING=0 VALIGN=TOP>";
+    echo '<table cellspacing="0" align="center" class="feedbackbox">';
 
-    echo "\n<TR>";
-    echo "\n<TD ROWSPAN=3 BGCOLOR=\"$THEME->body\" WIDTH=35 VALIGN=TOP>";
+    echo '<tr>';
+    echo '<td class="left picture">';
     print_user_picture($teacher->id, $course->id, $teacher->picture);
-    echo "</TD>";
-    echo "<TD NOWRAP WIDTH=100% BGCOLOR=\"$THEME->cellheading\">".fullname($teacher);
-    echo "&nbsp;&nbsp;<FONT SIZE=2><I>".userdate($entry->timemarked)."</I>";
-    echo "</TR>";
+    echo '</td>';
+    echo '<td class="entryheader">';
+    echo '<span class="author">'.fullname($teacher).'</span>';
+    echo '&nbsp;&nbsp;<span class="time">'.userdate($entry->timemarked).'</span>';
+    echo '</tr>';
 
-    echo "\n<TR><TD WIDTH=100% BGCOLOR=\"$THEME->cellcontent\">";
+    echo '<tr>';
+    echo '<td class="left side">&nbsp;</td>';
+    echo '<td class="entrycontent">';
 
-    echo "<P ALIGN=RIGHT><FONT SIZE=-1><I>";
-    if ($grades[$entry->rating]) {
-        echo get_string("grade").": ";
+    echo '<div class="grade">';
+    
+    if (!empty($entry->rating) and !empty($grades[$entry->rating])) {
+        echo get_string('grade').': ';
         echo $grades[$entry->rating];
     } else {
-        print_string("nograde");
+        print_string('nograde');
     }
-    echo "</I></FONT></P>";
+    echo '</div>';
 
-    echo format_text($entry->comment);
-    echo "</TD></TR></TABLE>";
-    echo "</TD></TR></TABLE>";
+    echo format_text($entry->entrycomment);
+    echo '</td></tr></table>';
+}
+
+function journal_get_view_actions() {
+    return array('view','view all','view responses');
+}
+
+function journal_get_post_actions() {
+    return array('add entry','update entry','update feedback');
 }
 
 ?>
