@@ -1,11 +1,11 @@
-<?PHP // $Id: report.php,v 1.26.2.1 2004/08/30 06:28:41 moodler Exp $
+<?php // $Id: report.php,v 1.34.6.1 2007/05/15 18:26:50 skodak Exp $
 
     require_once("../../config.php");
     require_once("lib.php");
 
-    require_variable($id);   // course module
+    $id = required_param('id', PARAM_INT);   // course module
 
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('journal', $id)) {
         error("Course Module ID was incorrect");
     }
 
@@ -13,7 +13,7 @@
         error("Course module is misconfigured");
     }
 
-    require_login($course->id);
+    require_login($course->id, false);
 
     if (!isteacher($course->id)) {
         error("Only teachers can look at this page");
@@ -29,7 +29,7 @@
             $entrybyuser[$ee->userid] = $ee;
             $entrybyentry[$ee->id]  = $ee;
         }
-        
+
     } else {
         $entrybyuser  = array () ;
         $entrybyentry = array () ;
@@ -40,19 +40,16 @@
 
     print_header_simple("$strjournals", "",
                  "<a href=\"index.php?id=$course->id\">$strjournals</a> ->
-                  <a href=\"view.php?id=$cm->id\">$journal->name</a> -> $strentries", "", "", true);
+                  <a href=\"view.php?id=$cm->id\">".format_string($journal->name,true)."</a> -> $strentries", "", "", true);
 
 
 /// Check to see if groups are being used in this journal
-    if ($groupmode = groupmode($course, $cm)) {   // Groups are being used
-        $currentgroup = setup_and_print_groups($course, $groupmode, "report.php?id=$cm->id");
-    } else {
-        $currentgroup = false;
-    }
+    $groupmode = groupmode($course, $cm);
+    $currentgroup = setup_and_print_groups($course, $groupmode, "report.php?id=$cm->id");
 
 /// Process incoming data if there is any
     if ($data = data_submitted()) {
-       
+
         $feedback = array();
         $data = (array)$data;
 
@@ -60,7 +57,7 @@
         foreach ($data as $key => $val) {
             if ($key <> "id") {
                 $type = substr($key,0,1);
-                $num  = substr($key,1); 
+                $num  = substr($key,1);
                 $feedback[$num][$type] = $val;
             }
         }
@@ -70,9 +67,9 @@
         foreach ($feedback as $num => $vals) {
             $entry = $entrybyentry[$num];
             // Only update entries where feedback has actually changed.
-            if (($vals['r'] <> $entry->rating) || ($vals['c'] <> addslashes($entry->comment))) {
+            if (($vals['r'] <> $entry->rating) || ($vals['c'] <> addslashes($entry->entrycomment))) {
                 $newentry->rating     = $vals['r'];
-                $newentry->comment    = $vals['c'];
+                $newentry->entrycomment    = $vals['c'];
                 $newentry->teacher    = $USER->id;
                 $newentry->timemarked = $timenow;
                 $newentry->mailed     = 0;           // Make sure mail goes out (again, even)
@@ -83,7 +80,7 @@
                     $count++;
                 }
                 $entrybyuser[$entry->userid]->rating     = $vals['r'];
-                $entrybyuser[$entry->userid]->comment    = $vals['c'];
+                $entrybyuser[$entry->userid]->entrycomment    = $vals['c'];
                 $entrybyuser[$entry->userid]->teacher    = $USER->id;
                 $entrybyuser[$entry->userid]->timemarked = $timenow;
             }
@@ -134,14 +131,14 @@
 
         if ($allowedtograde) {
             echo "<center>";
-            echo "<input type=hidden name=id value=\"$cm->id\">";
-            echo "<input type=submit value=\"".get_string("saveallfeedback", "journal")."\">";
+            echo "<input type=\"hidden\" name=\"id\" value=\"$cm->id\" />";
+            echo "<input type=\"submit\" value=\"".get_string("saveallfeedback", "journal")."\" />";
             echo "</center>";
             echo "</form>";
         }
     }
-    
+
     print_footer($course);
- 
+
 ?>
 
