@@ -1,8 +1,8 @@
-<?php  // $Id: attempt.php,v 1.63.2.11 2005/12/05 06:05:02 moodler Exp $
+<?php  // $Id: attempt.php,v 1.103.2.7 2007/04/11 20:06:57 tjhunt Exp $
 /**
 * This page prints a particular instance of quiz
 *
-* @version $Id: attempt.php,v 1.63.2.11 2005/12/05 06:05:02 moodler Exp $
+* @version $Id: attempt.php,v 1.103.2.7 2007/04/11 20:06:57 tjhunt Exp $
 * @author Martin Dougiamas and many others. This has recently been completely
 *         rewritten by Alex Smith, Julian Sedding and Gustav Delius as part of
 *         the Serving Mathematics project
@@ -32,7 +32,7 @@
     }
 
     if ($id) {
-        if (! $cm = get_record("course_modules", "id", $id)) {
+        if (! $cm = get_coursemodule_from_id('quiz', $id)) {
             error("There is no coursemodule with id $id");
         }
 
@@ -57,7 +57,15 @@
     }
 
     require_login($course->id, false, $cm);
-    $isteacher = isteacher($course->id);
+    $isteacher = has_capability('mod/quiz:grade', get_context_instance(CONTEXT_MODULE, $cm->id));
+    
+    $coursecontext = get_context_instance(CONTEXT_COURSE, $cm->course); // course context
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+    
+    // if no questions have been set up yet redirect to edit.php
+    if (!$quiz->questions and has_capability('mod/quiz:manage', $context)) {
+        redirect('edit.php?quizid=' . $quiz->id);
+    }
 
 // Get number for the next or unfinished attempt
     if(!$attemptnumber = (int)get_field_sql('SELECT MAX(attempt)+1 FROM ' .
@@ -76,7 +84,7 @@
         print_header($course->shortname.': '.format_string($quiz->name), '', '', '', '', false, '', '', false, '');
         include('protect_js.php');
     } else {
-        $strupdatemodule = isteacheredit($course->id)
+        $strupdatemodule = has_capability('moodle/course:manageactivities', $coursecontext)
                     ? update_module_button($cm->id, $course->id, get_string('modulename', 'quiz'))
                     : "";
         print_header_simple(format_string($quiz->name), "",
@@ -88,7 +96,7 @@
     echo '<div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div>'; // for overlib
 
     /// Print the quiz name heading and tabs for teacher
-    if ($isteacher) {
+    if (has_capability('mod/quiz:preview', $context)) {
         $currenttab = 'preview';
         include('tabs.php');
     } else {
@@ -100,7 +108,7 @@
     }
 
 /// Check availability
-    if (isguest()) {
+    if (isguestuser()) {
         print_heading(get_string('guestsno', 'quiz'));
         if (empty($popup)) {
             print_footer($course);
@@ -132,10 +140,11 @@
             }
             echo "<br />\n";
 
-            echo "<form name=\"passwordform\" method=\"post\" action=\"attempt.php?id=$cm->id\" autocomplete=\"off\">\n";
+            echo "<form id=\"passwordform\" method=\"post\" action=\"attempt.php?id=$cm->id\" onclick=\"this.autocomplete='off'\">\n";
+            echo '<fieldset class="invisiblefieldset">';
             print_simple_box_start("center");
 
-            echo "<div align=\"center\">\n";
+            echo "<div class=\"boxaligncenter\">\n";
             print_string("requirepasswordmessage", "quiz");
             echo "<br /><br />\n";
             echo " <input name=\"quizpassword\" type=\"password\" value=\"\" alt=\"password\" />";
@@ -143,6 +152,7 @@
             echo "</div>\n";
 
             print_simple_box_end();
+            echo '</fieldset>';
             echo "</form>\n";
 
             if (empty($popup)) {
@@ -157,9 +167,32 @@
         }
     }
 
+    if ($quiz->delay1 or $quiz->delay2) {
+        //quiz enforced time delay
+        if ($attempts = quiz_get_user_attempts($quiz->id, $USER->id)) {
+            $numattempts = count($attempts);
+        } else {
+            $numattempts = 0;
+        }
+        $timenow = time();
+        $lastattempt_obj = get_record_select('quiz_attempts', "quiz = $quiz->id AND attempt = $numattempts AND userid = $USER->id", 'timefinish');
+        if ($lastattempt_obj) {
+            $lastattempt = $lastattempt_obj->timefinish;
+        }
+        if ($numattempts == 1 && $quiz->delay1) {
+            if ($timenow - $quiz->delay1 < $lastattempt) {
+                error(get_string('timedelay', 'quiz'), 'view.php?q='.$quiz->id);
+            }
+        } else if($numattempts > 1 && $quiz->delay2) {
+            if ($timenow - $quiz->delay2 < $lastattempt) {
+                error(get_string('timedelay', 'quiz'), 'view.php?q='.$quiz->id);
+            }
+        }
+    }
+
 /// Load attempt or create a new attempt if there is no unfinished one
 
-    if ($isteacher and $forcenew) { // teacher wants a new preview
+    if (has_capability('mod/quiz:preview', $context) and $forcenew) { // teacher wants a new preview
         // so we set a finish time on the current attempt (if any).
         // It will then automatically be deleted below
         set_field('quiz_attempts', 'timefinish', $timestamp, 'quiz', $quiz->id, 'userid', $USER->id);
@@ -172,15 +205,14 @@
     if (!$attempt) {
         // Check if this is a preview request from a teacher
         // in which case the previous previews should be deleted
-        if ($isteacher) {
+        if (has_capability('mod/quiz:preview', $context)) {
             if ($oldattempts = get_records_select('quiz_attempts', "quiz = '$quiz->id'
              AND userid = '$USER->id'")) {
                 delete_records('quiz_attempts', 'quiz', $quiz->id, 'userid', $USER->id);
                 delete_records('quiz_grades', 'quiz', $quiz->id, 'userid', $USER->id);
                 foreach ($oldattempts as $oldattempt) {
                     // there should only be one but we loop just in case
-                    delete_records('quiz_states', 'attempt', $oldattempt->id);
-                    delete_records('quiz_newest_states', 'attemptid', $oldattempt->id);
+                    delete_attempt($oldattempt->uniqueid);
                 }
             }
         }
@@ -188,7 +220,7 @@
         // Start a new attempt and initialize the question sessions
         $attempt = quiz_create_attempt($quiz, $attemptnumber);
         // If this is an attempt by a teacher mark it as a preview
-        if ($isteacher) {
+        if (has_capability('mod/quiz:preview', $context)) {
             $attempt->preview = 1;
         }
         // Save the attempt
@@ -208,7 +240,7 @@
     } else {
         // log continuation of attempt only if some time has lapsed
         if (($timestamp - $attempt->timemodified) > 600) { // 10 minutes have elapsed
-             add_to_log($course->id, 'quiz', 'continue attempt',
+             add_to_log($course->id, 'quiz', 'continue attemp', // this action used to be called 'continue attempt' but the database field has only 15 characters
                            "review.php?attempt=$attempt->id",
                            "$quiz->id", $cm->id);
         }
@@ -238,7 +270,7 @@
     }
 
     $sql = "SELECT q.*, i.grade AS maxgrade, i.id AS instance".
-           "  FROM {$CFG->prefix}quiz_questions q,".
+           "  FROM {$CFG->prefix}question q,".
            "       {$CFG->prefix}quiz_question_instances i".
            " WHERE i.quiz = '$quiz->id' AND q.id = i.question".
            "   AND q.id IN ($questionlist)";
@@ -249,31 +281,39 @@
     }
 
     // Load the question type specific information
-    if (!quiz_get_question_options($questions)) {
+    if (!get_question_options($questions)) {
         error('Could not load question options');
     }
 
+    // If the new attempt is to be based on a previous attempt find its id
+    $lastattemptid = false;
+    if ($newattempt and $attempt->attempt > 1 and $quiz->attemptonlast and !$attempt->preview) {
+        // Find the previous attempt
+        if (!$lastattemptid = get_field('quiz_attempts', 'uniqueid', 'quiz', $attempt->quiz, 'userid', $attempt->userid, 'attempt', $attempt->attempt-1)) {
+            error('Could not find previous attempt to build on');
+        }
+    }
+
     // Restore the question sessions to their most recent states
     // creating new sessions where required
-    if (!$states = quiz_restore_question_sessions($questions, $quiz, $attempt)) {
+    if (!$states = get_question_states($questions, $quiz, $attempt, $lastattemptid)) {
         error('Could not restore question sessions');
     }
 
     // Save all the newly created states
     if ($newattempt) {
         foreach ($questions as $i => $question) {
-            quiz_save_question_session($questions[$i], $states[$i]);
+            save_question_session($questions[$i], $states[$i]);
         }
     }
 
-
 /// Process form data /////////////////////////////////////////////////
 
     if ($responses = data_submitted() and empty($_POST['quizpassword'])) {
 
         // set the default event. This can be overruled by individual buttons.
-        $event = (array_key_exists('markall', $responses)) ? QUIZ_EVENTGRADE :
-         ($finishattempt ? QUIZ_EVENTCLOSE : QUIZ_EVENTSAVE);
+        $event = (array_key_exists('markall', $responses)) ? QUESTION_EVENTSUBMIT :
+         ($finishattempt ? QUESTION_EVENTCLOSE : QUESTION_EVENTSAVE);
 
         // Unset any variables we know are not responses
         unset($responses->id);
@@ -289,7 +329,7 @@
 
         // extract responses
         // $actions is an array indexed by the questions ids
-        $actions = quiz_extract_responses($questions, $responses, $event);
+        $actions = question_extract_responses($questions, $responses, $event);
 
         // Process each question in turn
 
@@ -297,10 +337,11 @@
         foreach($questionidarray as $i) {
             if (!isset($actions[$i])) {
                 $actions[$i]->responses = array('' => '');
+                $actions[$i]->event = QUESTION_EVENTSAVE;
             }
             $actions[$i]->timestamp = $timestamp;
-            quiz_process_responses($questions[$i], $states[$i], $actions[$i], $quiz, $attempt);
-            quiz_save_question_session($questions[$i], $states[$i]);
+            question_process_responses($questions[$i], $states[$i], $actions[$i], $quiz, $attempt);
+            save_question_session($questions[$i], $states[$i]);
         }
 
         $attempt->timemodified = $timestamp;
@@ -308,7 +349,6 @@
     // We have now finished processing form data
     }
 
-
 /// Finish attempt if requested
     if ($finishattempt) {
 
@@ -317,13 +357,13 @@
 
         // Find all the questions for this attempt for which the newest
         // state is not also the newest graded state
-        if ($closequestions = get_records_select('quiz_newest_states',
-         "attemptid = $attempt->id AND newest != newgraded", '', 'questionid, questionid')) {
+        if ($closequestions = get_records_select('question_sessions',
+         "attemptid = $attempt->uniqueid AND newest != newgraded", '', 'questionid, questionid')) {
 
             // load all the questions
             $closequestionlist = implode(',', array_keys($closequestions));
             $sql = "SELECT q.*, i.grade AS maxgrade, i.id AS instance".
-                   "  FROM {$CFG->prefix}quiz_questions q,".
+                   "  FROM {$CFG->prefix}question q,".
                    "       {$CFG->prefix}quiz_question_instances i".
                    " WHERE i.quiz = '$quiz->id' AND q.id = i.question".
                    "   AND q.id IN ($closequestionlist)";
@@ -332,21 +372,21 @@
             }
 
             // Load the question type specific information
-            if (!quiz_get_question_options($closequestions)) {
+            if (!get_question_options($closequestions)) {
                 error('Could not load question options');
             }
 
             // Restore the question sessions
-            if (!$closestates = quiz_restore_question_sessions($closequestions, $quiz, $attempt)) {
+            if (!$closestates = get_question_states($closequestions, $quiz, $attempt)) {
                 error('Could not restore question sessions');
             }
 
             foreach($closequestions as $key => $question) {
-                $action->event = QUIZ_EVENTCLOSE;
+                $action->event = QUESTION_EVENTCLOSE;
                 $action->responses = $closestates[$key]->responses;
                 $action->timestamp = $closestates[$key]->timestamp;
-                quiz_process_responses($question, $closestates[$key], $action, $quiz, $attempt);
-                            quiz_save_question_session($question, $closestates[$key]);
+                question_process_responses($question, $closestates[$key], $action, $quiz, $attempt);
+                save_question_session($question, $closestates[$key]);
             }
         }
         add_to_log($course->id, 'quiz', 'close attempt',
@@ -367,11 +407,11 @@
 /// Check access to quiz page
 
     // check the quiz times
-    if (($timestamp < $quiz->timeopen || $timestamp > $quiz->timeclose)) {
+    if ($timestamp < $quiz->timeopen || ($quiz->timeclose and $timestamp > $quiz->timeclose)) {
         if ($isteacher) {
             notify(get_string('notavailabletostudents', 'quiz'));
         } else {
-            print_continue(get_string('notavailable', 'quiz'), "view.php?id={$cm->id}");
+            notice(get_string('notavailable', 'quiz'), "view.php?id={$cm->id}");
         }
     }
 
@@ -382,51 +422,57 @@
 /// Print the quiz page ////////////////////////////////////////////////////////
 
 /// Print the preview heading
-    if ($isteacher) {
+    if (has_capability('mod/quiz:preview', $context)) {
         print_heading(get_string('previewquiz', 'quiz', format_string($quiz->name)));
         unset($buttonoptions);
         $buttonoptions['q'] = $quiz->id;
         $buttonoptions['forcenew'] = true;
-        echo '<center>';
+        echo '<div class="boxaligncenter">';
         print_single_button($CFG->wwwroot.'/mod/quiz/attempt.php', $buttonoptions, get_string('startagain', 'quiz'));
-        echo '</center>';
+        echo '</div>';
         if ($quiz->popup) {
             notify(get_string('popupnotice', 'quiz'));
         }
     }
 
 /// Start the form
+    echo "<form id=\"responseform\" method=\"post\" action=\"attempt.php\" onclick=\"this.autocomplete='off'\">\n";
     if($quiz->timelimit > 0) {
         // Make sure javascript is enabled for time limited quizzes
         ?>
-        <script language="javascript" type="text/javascript">
-        <!--
-            document.write("<form name=\"responseform\" method=\"post\" action=\"attempt.php\" autocomplete=\"off\">\n");
-        // -->
+        <script type="text/javascript">
+            // Do nothing.
         </script>
         <noscript>
-        <center><p><strong><?php print_string('noscript', 'quiz'); ?></strong></p></center>
+        <div>
+        <?php print_heading(get_string('noscript', 'quiz')); ?>
+        </div>
         </noscript>
         <?php
-    } else {
-        echo "<form name=\"responseform\" method=\"post\" action=\"attempt.php\" autocomplete=\"off\">\n";
     }
 
     // Add a hidden field with the quiz id
+    echo '<div>';
     echo '<input type="hidden" name="q" value="' . s($quiz->id) . "\" />\n";
 
 /// Print the navigation panel if required
     $numpages = quiz_number_of_pages($attempt->layout);
     if ($numpages > 1) {
         ?>
-        <script language="javascript" type="text/javascript">
+        <script type="text/javascript">
+        //<![CDATA[
         function navigate(page) {
-            document.responseform.page.value=page;
-            document.responseform.submit();
+            var ourForm = document.getElementById('responseform'); 
+            ourForm.page.value=page;
+            if (ourForm.onsubmit) {
+                ourForm.onsubmit();
+            }
+            ourForm.submit();
         }
+        //]]>
         </script>
         <?php
-        echo '<input type="hidden" id="page" name="page" value="'.$page."\" />\n";
+        echo '<input type="hidden" name="page" value="'.$page."\" />\n";
         quiz_print_navigation_panel($page, $numpages);
         echo "<br />\n";
     }
@@ -439,13 +485,13 @@
     $pagequestions = explode(',', $pagelist);
     $number = quiz_first_questionnumber($attempt->layout, $pagelist);
     foreach ($pagequestions as $i) {
-        $options = quiz_get_renderoptions($quiz, $states[$i]);
+        $options = quiz_get_renderoptions($quiz->review, $states[$i]);
         // Print the question
         if ($i > 0) {
             echo "<br />\n";
         }
-        quiz_print_quiz_question($questions[$i], $states[$i], $number, $quiz, $options);
-        quiz_save_question_session($questions[$i], $states[$i]);
+        print_question($questions[$i], $states[$i], $number, $quiz, $options);
+        save_question_session($questions[$i], $states[$i]);
         $number += $questions[$i]->length;
     }
 
@@ -453,16 +499,16 @@
 
     $strconfirmattempt = addslashes(get_string("confirmclose", "quiz"));
     $onclick = "return confirm('$strconfirmattempt')";
-    echo "<center>\n";
+    echo "<div class=\"submitbtns mdl-align\">\n";
 
     echo "<input type=\"submit\" name=\"saveattempt\" value=\"".get_string("savenosubmit", "quiz")."\" />\n";
-    if ($quiz->optionflags & QUIZ_ADAPTIVE) {
+    if ($quiz->optionflags & QUESTION_ADAPTIVE) {
         echo "<input type=\"submit\" name=\"markall\" value=\"".get_string("markall", "quiz")."\" />\n";
     }
     echo "<input type=\"submit\" name=\"finishattempt\" value=\"".get_string("finishattempt", "quiz")."\" onclick=\"$onclick\" />\n";
-    echo '<input type="hidden" name="timeup" value="0" />';
+    echo '<input type="hidden" name="timeup" id="timeup" value="0" />';
 
-    echo "</center>";
+    echo "</div>";
 
     // Print the navigation panel if required
     if ($numpages > 1) {
@@ -472,13 +518,18 @@
     }
 
     // Finish the form
+    echo '</div>';
     echo "</form>\n";
 
-
-    $secondsleft = $quiz->timeclose - time();
+    $secondsleft = ($quiz->timeclose ? $quiz->timeclose : 999999999999) - time();
+    if ($isteacher) {
+        // For teachers ignore the quiz closing time
+        $secondsleft = 999999999999;
+    }
+    
     // If time limit is set include floating timer.
-    if ($quiz->timelimit > 0) {
-
+    // MDL-7495, no timer for users with disability
+    if ($quiz->timelimit > 0 && !has_capability('mod/quiz:ignoretimelimits', $context, NULL, false)) {
         $timesincestart = time() - $attempt->timestart;
         $timerstartvalue = min($quiz->timelimit*60 - $timesincestart, $secondsleft);
         if ($timerstartvalue <= 0) {
