@@ -1,4 +1,4 @@
-<?php // $Id: edit.php,v 1.64.2.5 2005/07/06 07:32:47 gustav_delius Exp $
+<?php // $Id: edit.php,v 1.90.2.3 2007/03/29 23:11:47 tjhunt Exp $
 /**
 * Page to edit quizzes
 *
@@ -7,7 +7,6 @@
 * allows them to be edited or more to be added. This column is only there if
 * the quiz does not already have student attempts
 * The left column lists all questions that have been added to the current quiz.
-* This column is only there if this page has been called in the context of a quiz.
 * The lecturer can add questions from the right hand list to the quiz or remove them
 *
 * The script also processes a number of actions:
@@ -16,17 +15,11 @@
 * addquestion  Adds a single question to the quiz
 * add          Adds several selected questions to the quiz
 * addrandom    Adds a certain number of random questions to the quiz
-* delete       Removes a question from the quiz
-* setgrades    Changes the maximum grades for questions in the quiz
 * repaginate   Re-paginates the quiz
-* Actions affecting the question pool:
-* move         Moves a question to a different category
-* deleteselected Deletes the selected questions from the category
-* Other actions:
-* cat          Chooses the category
-* displayoptions Sets display options
+* delete       Removes a question from the quiz
+* savechanges  Saves the order and grades for questions in the quiz
 *
-* @version $Id: edit.php,v 1.64.2.5 2005/07/06 07:32:47 gustav_delius Exp $
+* @version $Id: edit.php,v 1.90.2.3 2007/03/29 23:11:47 tjhunt Exp $
 * @author Martin Dougiamas and many others. This has recently been extensively
 *         rewritten by Gustav Delius and other members of the Serving Mathematics project
 *         {@link http://maths.york.ac.uk/serving_maths}
@@ -34,14 +27,11 @@
 * @package quiz
 */
     require_once("../../config.php");
-    require_once("editlib.php");
+    require_once($CFG->dirroot.'/mod/quiz/editlib.php');
 
     require_login();
 
-    $courseid = optional_param('courseid');
-    $quizid   = optional_param('quizid');
-    $page     = optional_param('page', -1);
-    $perpage  = optional_param('perpage', 20);
+    $quizid    = optional_param('quizid', 0, PARAM_INT);
 
     $strquizzes = get_string('modulenameplural', 'quiz');
     $strquiz = get_string('modulename', 'quiz');
@@ -63,54 +53,42 @@
             }
             $modform->instance = $modform->id;
             $SESSION->modform = $modform;    // Save the form in the current session
-
-            $cm = get_coursemodule_from_instance('quiz', $modform->instance);
-            $modform->cmid = $cm->id;
-            // We don't log all visits to this page but only those that recreate modform
-            add_to_log($cm->course, 'quiz', 'editquestions',
-                               "view.php?id=$cm->id",
-                               "$quizid", $cm->id);
         }
 
-    } else if ($courseid) { // Page retrieve through "Edit Questions" link - no quiz selected
-        $modform->course = $courseid;
-        unset($modform->instance);
-        $SESSION->modform = $modform;    // Save the form in the current session
-
-        add_to_log($courseid, 'quiz', 'editquestions', "index.php?id=$courseid");
-
-    } else {
-        // we might get here after editing a question in
-        // a popup window. So close window automatically.
-?>
-<script type="text/javascript">
-<!--
-if (self.name == 'editquestion') {
-    self.close();
-}
--->
-</script>
-<noscript>
-<?php notify(get_string('pleaseclose', 'quiz')); ?>
-</noscript>
-<?php
+    } else if (!empty($sortorder)) {
         // no quiz or course was specified so we need to use the stored modform
-        if (isset($SESSION->modform)) { 
+        if (isset($SESSION->modform)) {
             $modform = $SESSION->modform;
         } else {
-            exit;
+            error('cmunknown');
+        }
+    } else {
+        // no quiz or course was specified so we need to use the stored modform
+        if (isset($SESSION->modform)) {
+            $modform = $SESSION->modform;
+        } else {
+            print_error('cmunknown');
         }
     }
 
+    // Get the course object and related bits.
     if (! $course = get_record("course", "id", $modform->course)) {
         error("This course doesn't exist");
     }
+    $coursecontext = get_context_instance(CONTEXT_COURSE, $modform->course);
 
     require_login($course->id, false);
+    
+    // Get the module and related bits.
+    $cm = get_coursemodule_from_instance('quiz', $modform->instance);
+    $modform->cmid = $cm->id;
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
 
-    if (!isteacheredit($course->id)) {
-        error("You can't modify this course!");
-    }
+    // Log this visit.
+    add_to_log($cm->course, 'quiz', 'editquestions',
+            "view.php?id=$cm->id", "$quizid", $cm->id);
+
+    require_capability('mod/quiz:manage', $context);
 
     if (isset($modform->instance)
         && empty($modform->grades))  // Construct an array to hold all the grades.
@@ -118,15 +96,12 @@ if (self.name == 'editquestion') {
         $modform->grades = quiz_get_all_question_grades($modform);
     }
 
-    if ($page > -1) {
-        $modform->page = $page;
-    } else {
-        $page = isset($modform->page) ? $modform->page : 0;
-    }
+    $SESSION->returnurl = $FULLME;
 
 /// Now, check for commands on this page and modify variables as necessary
 
     if (isset($_REQUEST['up']) and confirm_sesskey()) { /// Move the given question up a slot
+        $up = optional_param('up', 0, PARAM_INT);
         $questions = explode(",", $modform->questions);
         if ($up > 0 and isset($questions[$up])) {
             $prevkey = ($questions[$up-1] == 0) ? $up-2 : $up-1;
@@ -145,6 +120,7 @@ if (self.name == 'editquestion') {
     }
 
     if (isset($_REQUEST['down']) and confirm_sesskey()) { /// Move the given question down a slot
+        $down = optional_param('down', 0, PARAM_INT);
         $questions = explode(",", $modform->questions);
         if ($down < count($questions)) {
             $nextkey = ($questions[$down+1] == 0) ? $down+2 : $down+1;
@@ -177,12 +153,13 @@ if (self.name == 'editquestion') {
         $categoryid = required_param('categoryid', PARAM_INT);
         $randomcount = required_param('randomcount', PARAM_INT);
         // load category
-        if (! $category = get_record('quiz_categories', 'id', $categoryid)) {
+        if (! $category = get_record('question_categories', 'id', $categoryid)) {
             error('Category ID is incorrect');
         }
+        $category->name = addslashes($category->name);
         // find existing random questions in this category
         $random = RANDOM;
-        if ($existingquestions = get_records_select('quiz_questions', "qtype = '$random' AND category = '$category->id'")) {
+        if ($existingquestions = get_records_select('question', "qtype = '$random' AND category = '$category->id'")) {
             // now remove the ones that are already used in this quiz
             if ($questionids = explode(',', $modform->questions)) {
                 foreach ($questionids as $questionid) {
@@ -206,6 +183,7 @@ if (self.name == 'editquestion') {
         if ($randomcreate > 0) {
 
             $form->name = get_string('random', 'quiz') .' ('. $category->name .')';
+            $form->category = $category->id;
             $form->questiontext = $recurse; // we use the questiontext field to store the info
                                             // on whether to include questions in subcategories
             $form->questiontextformat = 0;
@@ -215,9 +193,8 @@ if (self.name == 'editquestion') {
             for ($i=0; $i<$randomcreate; $i++) {
                 $form->stamp = make_unique_id_code();  // Set the unique code (not to be changed)
                 $question = new stdClass;
-                $question->category = $category->id;
                 $question->qtype = RANDOM;
-                $question = $QUIZ_QTYPES[RANDOM]->save_question($question, $form, $course);
+                $question = $QTYPES[RANDOM]->save_question($question, $form, $course);
                 if(!isset($question->id)) {
                     error('Could not insert new random question!');
                 }
@@ -228,7 +205,7 @@ if (self.name == 'editquestion') {
 
     if (isset($_REQUEST['repaginate']) and confirm_sesskey()) { /// Re-paginate the quiz
         if (isset($_REQUEST['questionsperpage'])) {
-            $modform->questionsperpage = required_param('questionsperpage', 1, PARAM_INT);
+            $modform->questionsperpage = required_param('questionsperpage', PARAM_INT);
             if (!set_field('quiz', 'questionsperpage', $modform->questionsperpage, 'id', $modform->id)) {
                 error('Could not save number of questions per page');
             }
@@ -239,89 +216,18 @@ if (self.name == 'editquestion') {
         }
     }
 
-    if (isset($_REQUEST['move']) and confirm_sesskey()) { /// Move selected questions to new category
-        if (!$tocategory = get_record('quiz_categories', 'id', $_REQUEST['category'])) {
-            error('Invalid category');
-        }
-        if (!isteacheredit($tocategory->course)) {
-            error(get_string('categorynoedit', 'quiz', $tocategory->name), 'edit.php');
-        }
-        foreach ($_POST as $key => $value) {    // Parse input for question ids
-            if (substr($key, 0, 1) == "q") {
-                $key = substr($key,1);
-                if (!set_field('quiz_questions', 'category', $tocategory->id, 'id', $key)) {
-                    error('Could not update category field');
-                }
-            }
-        }
-    }
-
     if (isset($_REQUEST['delete']) and confirm_sesskey()) { /// Remove a question from the quiz
         quiz_delete_quiz_question($_REQUEST['delete'], $modform);
     }
 
-    if (isset($_REQUEST['deleteselected'])) { // delete selected questions from the category
-
-        if (isset($confirm) and confirm_sesskey()) { // teacher has already confirmed the action
-            if ($confirm == md5($deleteselected)) {
-                if ($questionlist = explode(',', $deleteselected)) {
-                    // for each question either hide it if it is in use or delete it
-                    foreach ($questionlist as $questionid) {
-                        if (record_exists('quiz_question_instances', 'question', $questionid) or
-                            record_exists('quiz_states', 'originalquestion', $questionid)) {
-                            if (!set_field('quiz_questions', 'hidden', 1, 'id', $questionid)) {
-                               error('Was not able to hide question');
-                            }
-                        } else {
-                            delete_records("quiz_questions", "id", $questionid);
-                        }
-                    }
-                }
-                redirect("edit.php");
-            } else {
-                error("Confirmation string was incorrect");
-            }
-
-        } else { // teacher still has to confirm
-            // make a list of all the questions that are selected
-            $rawquestions = $_POST;
-            $questionlist = '';  // comma separated list of ids of questions to be deleted
-            $questionnames = ''; // string with names of questions separated by <br /> with
-                                 // an asterix in front of those that are in use
-            $inuse = false;      // set to true if at least one of the questions is in use
-            foreach ($rawquestions as $key => $value) {    // Parse input for question ids
-                if (substr($key, 0, 1) == "q") {
-                    $key = substr($key,1);
-                    $questionlist .= $key.',';
-                    if (record_exists('quiz_question_instances', 'question', $key) or
-                        record_exists('quiz_states', 'originalquestion', $key)) {
-                        $questionnames .= '* ';
-                        $inuse = true;
-                    }
-                    $questionnames .= get_field('quiz_questions', 'name', 'id', $key).'<br />';
-                }
-            }
-            if (!$questionlist) { // no questions were selected
-                redirect('edit.php');
-            }
-            $questionlist = rtrim($questionlist, ',');
-
-            // Add an explanation about questions in use
-            if ($inuse) {
-                $questionnames .= get_string('questionsinuse', 'quiz');
-            }
-            print_header_simple($streditingquestions, '',
-                 "<a href=\"index.php?id=$course->id\">$strquizzes</a>".
-                 " -> $streditingquestions");
-            notice_yesno(get_string("deletequestionscheck", "quiz", $questionnames),
-                        "edit.php?sesskey=$USER->sesskey&amp;deleteselected=$questionlist&amp;confirm=".md5($questionlist), "edit.php");
-            print_footer($course);
-            exit;
+    if (isset($_REQUEST['savechanges']) and confirm_sesskey()) {
+        $savequizid = required_param('savequizid', PARAM_INT);
+        if ($modform->id != $savequizid) {
+            error("Error saving quiz settings, please do not change two quizes from the same browser", $CFG->wwwroot.'/mod/quiz/edit.php?quizid='.$savequizid);
         }
-    }
-
-    if (isset($_REQUEST['setgrades']) and confirm_sesskey()) {
-    /// The grades have been updated, so update our internal list
+    /// We need to save the new ordering (if given) and the new grades
+        $oldquestions = explode(",", $modform->questions); // the questions in the old order
+        $questions = array(); // for questions in the new order
         $rawgrades = $_POST;
         unset($modform->grades);
         foreach ($rawgrades as $key => $value) {    // Parse input for question -> grades
@@ -329,62 +235,65 @@ if (self.name == 'editquestion') {
                 $key = substr($key,1);
                 $modform->grades[$key] = $value;
                 quiz_update_question_instance($modform->grades[$key], $key, $modform->instance);
+            } elseif (substr($key, 0, 1) == "o") {   // Parse input for ordering info
+                $key = substr($key,1);
+                $questions[$value] = $oldquestions[$key];
+            }
+        }
+        
+        // If ordering info was given, reorder the questions
+        if ($questions) {
+            ksort($questions);
+            $modform->questions = implode(",", $questions);
+            // Always have a page break at the end
+            $modform->questions = $modform->questions . ',0';
+            // Avoid duplicate page breaks
+            while (strpos($modform->questions, ',0,0')) {
+                $modform->questions = str_replace(',0,0', ',0', $modform->questions);
+            }
+            if (!set_field('quiz', 'questions', $modform->questions, 'id', $modform->instance)) {
+                error('Could not save question list');
             }
         }
 
         // If rescaling is required save the new maximum
         if (isset($_REQUEST['maxgrade'])) {
-            $modform->grade = optional_param('maxgrade', 0);
-            if (!set_field('quiz', 'grade', $modform->grade, 'id', $modform->instance)) {
-                error('Could not set new maximal grade for quiz');
+            if (!quiz_set_grade(optional_param('maxgrade', 0), $modform)) {
+                error('Could not set a new maximum grade for the quiz');
             }
         }
     }
 
-    if (isset($_REQUEST['cat'])) { /// coming from category selection drop-down menu
-        $modform->category = $cat;
-        $page = 0;
-        $modform->page = 0;
-    }
-
-    if(isset($_REQUEST['recurse'])) {
-        $SESSION->quiz_recurse = optional_param('recurse', 0, PARAM_BOOL);
-    }
     if(isset($_REQUEST['showbreaks'])) {
         $SESSION->quiz_showbreaks = optional_param('showbreaks', 0, PARAM_BOOL);
-    }
-    if(isset($_REQUEST['showhidden'])) {
-        $SESSION->quiz_showhidden = optional_param('showhidden', 0, PARAM_BOOL);
+        $SESSION->quiz_reordertool = optional_param('reordertool', 0, PARAM_BOOL);
     }
 
 /// Delete any teacher preview attempts if the quiz has been modified
-    if (isset($_REQUEST['setgrades']) or isset($_REQUEST['delete']) or isset($_REQUEST['repaginate']) or isset($_REQUEST['addrandom']) or isset($_REQUEST['addquestion']) or isset($_REQUEST['up']) or isset($_REQUEST['down']) or isset($_REQUEST['add'])) {
+    if (isset($_REQUEST['savechanges']) or isset($_REQUEST['delete']) or isset($_REQUEST['repaginate']) or isset($_REQUEST['addrandom']) or isset($_REQUEST['addquestion']) or isset($_REQUEST['up']) or isset($_REQUEST['down']) or isset($_REQUEST['add'])) {
         delete_records('quiz_attempts', 'preview', '1', 'quiz', $modform->id);
     }
 
 /// all commands have been dealt with, now print the page
 
-    if (empty($modform->category) or !record_exists('quiz_categories', 'id', $modform->category)) {
-        $category = quiz_get_default_category($course->id);
+    if (empty($modform->category) or !record_exists('question_categories', 'id', $modform->category)) {
+        $category = get_default_question_category($course->id);
         $modform->category = $category->id;
     }
-    if (!isset($SESSION->quiz_recurse)) {
-        $SESSION->quiz_recurse = 1;
-    }
-    if (!isset($SESSION->quiz_showhidden)) {
-        $SESSION->quiz_showhidden = false;
-    }
     if (!isset($SESSION->quiz_showbreaks)) {
         $SESSION->quiz_showbreaks = ($CFG->quiz_questionsperpage < 2) ? 0 : 1;
     }
+    if (!isset($SESSION->quiz_reordertool)) {
+        $SESSION->quiz_reordertool = 0;
+    }
 
     $SESSION->modform = $modform;
 
     // Print basic page layout.
 
-    if (isset($modform->instance) and record_exists_sql("SELECT * FROM {$CFG->prefix}quiz_attempts WHERE quiz = '$modform->instance' AND preview = '0' LIMIT 1")){
+    if (isset($modform->instance) and record_exists_select('quiz_attempts', "quiz = '$modform->instance' AND preview = '0'")){
         // one column layout with table of questions used in this quiz
-        $strupdatemodule = isteacheredit($course->id)
+        $strupdatemodule = has_capability('moodle/course:manageactivities', $coursecontext)
                     ? update_module_button($modform->cmid, $course->id, get_string('modulename', 'quiz'))
                     : "";
         print_header_simple($streditingquiz, '',
@@ -394,93 +303,65 @@ if (self.name == 'editquestion') {
                  true, $strupdatemodule);
 
         $currenttab = 'edit';
+        $mode = 'editq';
         $quiz = &$modform;
         include('tabs.php');
 
-        print_simple_box_start("center");
+        print_box_start();
 
-        $attemptcount = count_records('quiz_attempts', 'quiz', $modform->instance, 'preview', 0);
-
-        $strviewallanswers  = get_string("viewallanswers","quiz",$attemptcount);
-        $strattemptsexist  = get_string("attemptsexist","quiz");
-        $usercount = count_records_select('quiz_attempts', "quiz = '$modform->id' AND preview = '0'", 'COUNT(DISTINCT userid)');
-        $strusers  = $course->students;
+        $a->attemptnum = count_records('quiz_attempts', 'quiz', $quiz->id, 'preview', 0);
+        $a->studentnum = count_records_select('quiz_attempts', "quiz = '$quiz->id' AND preview = '0'", 'COUNT(DISTINCT userid)');
+        $a->studentstring  = $course->students;
         if (! $cm = get_coursemodule_from_instance("quiz", $modform->instance, $course->id)) {
             error("Course Module ID was incorrect");
         }
-        echo "<center>\n";
-        echo "$strattemptsexist<br /><a href=\"report.php?mode=overview&amp;id=$cm->id\">$strviewallanswers ($usercount $strusers)</a>";
-        echo "<form target=\"_parent\" method=\"get\" action=\"$CFG->wwwroot/mod/quiz/edit.php\">\n";
-        echo "    <input type=\"hidden\" name=\"courseid\" value=\"$course->id\" />\n";
-        echo "    <input type=\"submit\" value=\"".get_string("editcatquestions", "quiz")."\" />\n";
-        echo "</form>";
-        echo "</center><br/ >\n";
+        echo "<div class=\"attemptsnotice\">\n";
+        echo "<a href=\"report.php?mode=overview&amp;id=$cm->id\">".get_string('numattempts', 'quiz', $a)."</a><br />".get_string("attemptsexist","quiz");
+        echo "</div><br />\n";
 
-        $sumgrades = quiz_print_question_list($modform, false, $SESSION->quiz_showbreaks);
+        $sumgrades = quiz_print_question_list($modform, false, $SESSION->quiz_showbreaks, $SESSION->quiz_reordertool);
         if (!set_field('quiz', 'sumgrades', $sumgrades, 'id', $modform->instance)) {
             error('Failed to set sumgrades');
         }
 
-        print_simple_box_end();
+        print_box_end();
         print_footer($course);
         exit;
     }
 
-    if (!isset($modform->instance)) {
-        // one column layout for non-quiz-specific editing page
-        print_header_simple($streditingquestions, '',
-                 "<a href=\"index.php?id=$course->id\">$strquizzes</a>".
-                 " -> $streditingquestions");
-        echo '<table align="center" border="0" cellpadding="2" cellspacing="0">';
-        echo '<tr><td valign="top">';
+    // two column layout with quiz info in left column
+    $strupdatemodule = has_capability('moodle/course:manageactivities', $coursecontext)
+        ? update_module_button($modform->cmid, $course->id, get_string('modulename', 'quiz'))
+        : "";
+    print_header_simple($streditingquiz, '',
+             "<a href=\"index.php?id=$course->id\">$strquizzes</a>".
+             " -> <a href=\"view.php?q=$modform->instance\">".format_string($modform->name).'</a>'.
+             " -> $streditingquiz",
+             "", "", true, $strupdatemodule);
 
-    } else {
-        // two column layout with quiz info in left column
-        $strupdatemodule = isteacheredit($course->id)
-            ? update_module_button($modform->cmid, $course->id, get_string('modulename', 'quiz'))
-            : "";
-        print_header_simple($streditingquiz, '',
-                 "<a href=\"index.php?id=$course->id\">$strquizzes</a>".
-                 " -> <a href=\"view.php?q=$modform->instance\">".format_string($modform->name).'</a>'.
-                 " -> $streditingquiz",
-                 "", "", true, $strupdatemodule);
+    $currenttab = 'edit';
+    $mode = 'editq';
+    $quiz = &$modform;
+    include('tabs.php');
 
-        $currenttab = 'edit';
-        $quiz = &$modform;
-        include('tabs.php');
+    echo '<table border="0" style="width:100%" cellpadding="2" cellspacing="0">';
+    echo '<tr><td style="width:50%" valign="top">';
+    print_box_start('generalbox quizquestions');
+    print_heading(get_string('questionsinthisquiz', 'quiz'), '', 2);
 
-        echo '<table border="0" width="100%" cellpadding="2" cellspacing="0">';
-        echo '<tr><td width="50%" valign="top">';
-        print_simple_box_start("center", "100%");
-
-        $sumgrades = quiz_print_question_list($modform, true, $SESSION->quiz_showbreaks);
-        if (!set_field('quiz', 'sumgrades', $sumgrades, 'id', $modform->instance)) {
-            error('Failed to set sumgrades');
-        }
-
-        print_simple_box_end();
-
-        echo '</td><td valign="top" width="50%">';
+    $sumgrades = quiz_print_question_list($modform, true, $SESSION->quiz_showbreaks, $SESSION->quiz_reordertool);
+    if (!set_field('quiz', 'sumgrades', $sumgrades, 'id', $modform->instance)) {
+        error('Failed to set sumgrades');
     }
-    // non-quiz-specific column
-    print_simple_box_start("center", "100%");
-    // starts with category selection form
-    quiz_print_category_form($course, $modform->category, $SESSION->quiz_recurse, $SESSION->quiz_showhidden);
-    print_simple_box_end();
 
-    print_spacer(5,1);
-    // continues with list of questions
-    print_simple_box_start("center", "100%");
-    quiz_print_cat_question_list($course, $modform->category,
-                                 isset($modform->instance) ? $modform->instance : 0, $SESSION->quiz_recurse, $page, $perpage, $SESSION->quiz_showhidden);
-    print_simple_box_end();
-    if (!isset($modform->instance)) {
-        print_continue("index.php?id=$modform->course");
-    }
+    print_box_end();
+
+    echo '</td><td style="width:50%" valign="top">';
+
+    require($CFG->dirroot.'/question/showbank.php');
+
     echo '</td></tr>';
     echo '</table>';
 
-
-
     print_footer($course);
 ?>
