@@ -1,15 +1,15 @@
-<?php // $Id: jsclock.php,v 1.1.10.1 2005/01/29 14:06:59 skodak Exp $
+<?php // $Id: jsclock.php,v 1.5 2007/01/03 14:44:54 moodler Exp $
 defined('MOODLE_INTERNAL') or die('Direct access to this script is forbidden.');
 ?>
 
-<script language="javascript">
-<!--
+<script text="text/javascript">
+//<![CDATA[
 /// This Javascript clock provides a little countdown in the title bar
 
 var timerID = null;
 var timerRunning = false;
 var secondsleft = <?php echo $secondsleft ?>;
-var titleafter  = '<?php echo $quiz->name ?>';
+var titleafter  = '<?php echo format_string($quiz->name) ?>';
 var titlebefore = '<?php echo get_string("countdown", "quiz").": " ?>';
 var alertmessage  = '<?php print_string("countdownfinished", "quiz") ?>';
 var alertmessage10  = '<?php print_string("countdowntenminutes", "quiz") ?>';
@@ -44,16 +44,16 @@ function showtime() {
 
         var hours = Math.floor( current / 3600 );
         current = current - (hours*3600);
-    
+
         var minutes =   Math.floor( current / 60 );
         current = current - (minutes*60);
-    
+
         var seconds = current;
-    
+
         var timeValue = "" + hours;
         timeValue  += ((minutes < 10) ? ":0" : ":") + minutes;
         timeValue  += ((seconds < 10) ? ":0" : ":") + seconds;
-    
+
         document.title = titlebefore+timeValue+' '+titleafter;
         timerID = setTimeout("showtime()",1000);
         timerRunning = true;
@@ -63,5 +63,5 @@ function showtime() {
 document.onLoad = startclock();
 
 
-// -- End of JavaScript code -------------- -->
+//]]>
 </script>
