@@ -1,4 +1,4 @@
-<?php  // $Id: lib.php,v 1.44.2.1 2005/12/05 23:59:24 stronk7 Exp $
+<?php  // $Id: lib.php,v 1.63.2.2 2007/06/04 22:23:01 poltawski Exp $
 
 if (!isset($CFG->resource_framesize)) {
     set_config("resource_framesize", 130);
@@ -36,10 +36,22 @@ if (!isset($CFG->resource_allowlocalfiles)) {
     set_config("resource_allowlocalfiles", "0");
 }
 
+if (!isset($CFG->resource_hide_repository)) {
+    set_config("resource_hide_repository", "1");
+}
+
+if (!isset($CFG->resource_autofilerename)) {
+    set_config("resource_autofilerename", "1");
+}
+
+if (!isset($CFG->resource_blockdeletingfile)) {
+    set_config("resource_blockdeletingfile", "1");
+}
+
 define('RESOURCE_LOCALPATH', 'LOCALPATH');
 
 $RESOURCE_WINDOW_OPTIONS = array('resizable', 'scrollbars', 'directories', 'location',
-                                 'menubar', 'toolbar', 'status', 'height', 'width');
+                                 'menubar', 'toolbar', 'status', 'width', 'height');
 
 foreach ($RESOURCE_WINDOW_OPTIONS as $popupoption) {
     $popupoption = "resource_popup$popupoption";
@@ -78,11 +90,10 @@ var $resource;
 */
 function resource_base($cmid=0) {
 
-    global $CFG;
-    global $course;   // Ugly hack, needed for course language ugly hack
+    global $CFG, $COURSE;
 
     if ($cmid) {
-        if (! $this->cm = get_record("course_modules", "id", $cmid)) {
+        if (! $this->cm = get_coursemodule_from_id('resource', $cmid)) {
             error("Course Module ID was incorrect");
         }
 
@@ -90,10 +101,6 @@ function resource_base($cmid=0) {
             error("Course is misconfigured");
         }
 
-        $course = $this->course;  // Make it a global so we can see it later
-
-        require_course_login($this->course, true, $this->cm);
-
         if (! $this->resource = get_record("resource", "id", $this->cm->instance)) {
             error("Resource ID was incorrect");
         }
@@ -101,18 +108,20 @@ function resource_base($cmid=0) {
         $this->strresource  = get_string("modulename", "resource");
         $this->strresources = get_string("modulenameplural", "resource");
 
-        if ($this->course->category) {
-            $this->navigation = "<a target=\"{$CFG->framename}\" href=\"$CFG->wwwroot/course/view.php?id={$this->course->id}\">{$this->course->shortname}</a> -> ".
-                                "<a target=\"{$CFG->framename}\" href=\"index.php?id={$this->course->id}\">$this->strresources</a> ->";
+        if ($this->course->id != SITEID) {
+            $this->navigation = "<a $CFG->frametarget onclick=\"this.target='$CFG->framename'\" href=\"$CFG->wwwroot/course/view.php?id={$this->course->id}\">{$this->course->shortname}</a> -> ".
+                                "<a $CFG->frametarget onclick=\"this.target='$CFG->framename'\" href=\"index.php?id={$this->course->id}\">$this->strresources</a> ->";
         } else {
-            $this->navigation = "<a target=\"{$CFG->framename}\" href=\"index.php?id={$this->course->id}\">$this->strresources</a> ->";
+            $this->navigation = "<a $CFG->frametarget onclick=\"this.target='$CFG->framename'\" href=\"index.php?id={$this->course->id}\">$this->strresources</a> ->";
         }
 
-        if (!$this->cm->visible and !isteacher($this->course->id)) {
+        if (!$this->cm->visible and !has_capability('moodle/course:viewhiddenactivities', get_context_instance(CONTEXT_MODULE, $this->cm->id))) {
             $pagetitle = strip_tags($this->course->shortname.': '.$this->strresource);
             print_header($pagetitle, $this->course->fullname, "$this->navigation $this->strresource", "", "", true, '', navmenu($this->course, $this->cm));
             notice(get_string("activityiscurrentlyhidden"), "$CFG->wwwroot/course/view.php?id={$this->course->id}");
         }
+    } else {
+        $this->course = $COURSE;
     }
 }
 
@@ -125,45 +134,75 @@ function display() {
 }
 
 
-function setup(&$form) {
-    global $CFG, $usehtmleditor;
+/**
+* Display the resource with the course blocks.
+*/
+function display_course_blocks_start() {
 
-    if (! empty($form->course)) {
-        if (! $this->course = get_record("course", "id", $form->course)) {
-            error("Course is misconfigured");
-        }
+    global $CFG;
+    global $USER;
+
+    require_once($CFG->libdir.'/blocklib.php');
+    require_once($CFG->libdir.'/pagelib.php');
+    require_once($CFG->dirroot.'/course/lib.php'); //required by some blocks
+
+    $PAGE = page_create_object(PAGE_COURSE_VIEW, $this->course->id);
+    $this->PAGE = $PAGE;
+    $pageblocks = blocks_setup($PAGE);
+
+    $blocks_preferred_width = bounded_number(180, blocks_preferred_width($pageblocks[BLOCK_POS_LEFT]), 210);
+
+/// Print the page header
+
+    $edit = optional_param('edit', -1, PARAM_BOOL);
+
+    if (($edit != -1) and $PAGE->user_allowed_editing()) {
+        $USER->editing = $edit;
     }
 
-    if (empty($form->name)) {
-        $form->name = "";
-    }
-    if (empty($form->type)) {
-        $form->type = "";
-    }
-    if (empty($form->summary)) {
-        $form->summary = "";
-    }
-    if (empty($form->reference)) {
-        $form->reference = "";
-    }
-    if (empty($form->alltext)) {
-        $form->alltext = "";
-    }
-    if (empty($form->options)) {
-        $form->options = "";
-    }
-    $nohtmleditorneeded = true;
+    $morebreadcrumbs = array($this->strresources   => 'index.php?id='.$this->course->id,
+                             $this->resource->name => '');
 
-    print_heading_with_help(get_string("resourcetype$form->type", 'resource'), $form->type, 'resource/type');
+    $PAGE->print_header($this->course->shortname.': %fullname%', $morebreadcrumbs);
+
+    echo '<table id="layout-table"><tr>';
+
+    if((blocks_have_content($pageblocks, BLOCK_POS_LEFT) || $PAGE->user_is_editing())) {
+        echo '<td style="width: '.$blocks_preferred_width.'px;" id="left-column">';
+        blocks_print_group($PAGE, $pageblocks, BLOCK_POS_LEFT);
+        echo '</td>';
+    }
+
+    echo '<td id="middle-column">';
+    echo '<div id="resource">';
 
-    include("$CFG->dirroot/mod/resource/type/common.html");
 }
 
 
-function setup_end() {
+/**
+ * Finish displaying the resource with the course blocks
+ */
+function display_course_blocks_end() {
+
     global $CFG;
 
-    include("$CFG->dirroot/mod/resource/type/common_end.html");
+    $PAGE = $this->PAGE;
+    $pageblocks = blocks_setup($PAGE);
+    $blocks_preferred_width = bounded_number(180, blocks_preferred_width($pageblocks[BLOCK_POS_RIGHT]), 210);
+
+    echo '</div>';
+    echo '</td>';
+
+    if((blocks_have_content($pageblocks, BLOCK_POS_RIGHT) || $PAGE->user_is_editing())) {
+        echo '<td style="width: '.$blocks_preferred_width.'px;" id="right-column">';
+        blocks_print_group($PAGE, $pageblocks, BLOCK_POS_RIGHT);
+        echo '</td>';
+    }
+
+    echo '</tr></table>';
+
+    print_footer($this->course);
+
 }
 
 
@@ -173,37 +212,8 @@ function add_instance($resource) {
 // will create a new instance and return the id number
 // of the new instance.
 
-    global $RESOURCE_WINDOW_OPTIONS;
-
     $resource->timemodified = time();
 
-    if (isset($resource->windowpopup)) {
-        if ($resource->windowpopup) {
-            $optionlist = array();
-            foreach ($RESOURCE_WINDOW_OPTIONS as $option) {
-                if (isset($resource->$option)) {
-                    $optionlist[] = $option."=".$resource->$option;
-                }
-            }
-            $resource->popup = implode(',', $optionlist);
-            $resource->options = "";
-        } else {
-            if (isset($resource->framepage)) {
-                $resource->options = "frame";
-            } else {
-                $resource->options = "";
-            }
-            $resource->popup = "";
-        }
-    }
-
-    if (isset($resource->parametersettingspref)) {
-        set_user_preference('resource_parametersettingspref', $resource->parametersettingspref);
-    }
-    if (isset($resource->windowsettingspref)) {
-        set_user_preference('resource_windowsettingspref', $resource->windowsettingspref);
-    }
-
     return insert_record("resource", $resource);
 }
 
@@ -213,38 +223,9 @@ function update_instance($resource) {
 // (defined by the form in mod.html) this function
 // will update an existing instance with new data.
 
-    global $RESOURCE_WINDOW_OPTIONS;
-
     $resource->id = $resource->instance;
     $resource->timemodified = time();
 
-    if (isset($resource->windowpopup)) {
-        if ($resource->windowpopup) {
-            $optionlist = array();
-            foreach ($RESOURCE_WINDOW_OPTIONS as $option) {
-                if (isset($resource->$option)) {
-                    $optionlist[] = $option."=".$resource->$option;
-                }
-            }
-            $resource->popup = implode(',', $optionlist);
-            $resource->options = "";
-        } else {
-            if (isset($resource->framepage)) {
-                $resource->options = "frame";
-            } else {
-                $resource->options = "";
-            }
-            $resource->popup = "";
-        }
-    }
-
-    if (isset($resource->parametersettingspref)) {
-        set_user_preference('resource_parametersettingspref', $resource->parametersettingspref);
-    }
-    if (isset($resource->windowsettingspref)) {
-        set_user_preference('resource_windowsettingspref', $resource->windowsettingspref);
-    }
-
     return update_record("resource", $resource);
 }
 
@@ -263,7 +244,13 @@ function delete_instance($resource) {
     return $result;
 }
 
+function setup_elements(&$mform) {
+    //override to add your own options
+}
 
+function setup_preprocessing(&$default_values){
+    //override to add your own options
+}
 
 } /// end of class definition
 
@@ -272,7 +259,7 @@ function delete_instance($resource) {
 function resource_add_instance($resource) {
     global $CFG;
 
-    $resource->type = clean_filename($resource->type);   // Just to be safe
+    $resource->type = clean_param($resource->type, PARAM_SAFEDIR);   // Just to be safe
 
     require_once("$CFG->dirroot/mod/resource/type/$resource->type/resource.class.php");
     $resourceclass = "resource_$resource->type";
@@ -284,7 +271,7 @@ function resource_add_instance($resource) {
 function resource_update_instance($resource) {
     global $CFG;
 
-    $resource->type = clean_filename($resource->type);   // Just to be safe
+    $resource->type = clean_param($resource->type, PARAM_SAFEDIR);   // Just to be safe
 
     require_once("$CFG->dirroot/mod/resource/type/$resource->type/resource.class.php");
     $resourceclass = "resource_$resource->type";
@@ -300,7 +287,7 @@ function resource_delete_instance($id) {
         return false;
     }
 
-    $resource->type = clean_filename($resource->type);   // Just to be safe
+    $resource->type = clean_param($resource->type, PARAM_SAFEDIR);   // Just to be safe
 
     require_once("$CFG->dirroot/mod/resource/type/$resource->type/resource.class.php");
     $resourceclass = "resource_$resource->type";
@@ -317,6 +304,7 @@ function resource_user_outline($course, $user, $mod, $resource) {
         $numviews = count($logs);
         $lastlog = array_pop($logs);
 
+        $result = new object();
         $result->info = get_string("numviews", "", $numviews);
         $result->time = $lastlog->time;
 
@@ -365,7 +353,7 @@ function resource_get_coursemodule_info($coursemodule) {
 
    if ($resource = get_record("resource", "id", $coursemodule->instance)) {
        if (!empty($resource->popup)) {
-           $info->extra =  urlencode("target=\"resource$resource->id\" onclick=\"return ".
+           $info->extra =  urlencode("onclick=\"this.target='resource$resource->id'; return ".
                             "openpopup('/mod/resource/view.php?inpopup=true&amp;id=".
                             $coursemodule->id.
                             "','resource$resource->id','$resource->popup');\"");
@@ -536,25 +524,144 @@ function resource_is_url($path) {
     return false;
 }
 
-function resource_get_resource_types() {
-/// Returns a menu of current resource types, in standard order
-    global $resource_standard_order;
+function resource_get_types() {
+    global $CFG;
 
-    $resources = array();
+    $types = array();
 
-    /// Standard resource types
     $standardresources = array('text','html','file','directory');
     foreach ($standardresources as $resourcetype) {
-        $resources[$resourcetype] = get_string("resourcetype$resourcetype", 'resource');
+        $type = new object();
+        $type->modclass = MOD_CLASS_RESOURCE;
+        $type->type = "resource&amp;type=$resourcetype";
+        $type->typestr = get_string("resourcetype$resourcetype", 'resource');
+        $types[] = $type;
     }
 
     /// Drop-in extra resource types
     $resourcetypes = get_list_of_plugins('mod/resource/type');
     foreach ($resourcetypes as $resourcetype) {
-        if (!in_array($resourcetype, $resources)) {
-            $resources[$resourcetype] = get_string("resourcetype$resourcetype", 'resource');
+        if (!empty($CFG->{'resource_hide_'.$resourcetype})) {  // Not wanted
+            continue;
+        }
+        if (!in_array($resourcetype, $standardresources)) {
+            $type = new object();
+            $type->modclass = MOD_CLASS_RESOURCE;
+            $type->type = "resource&amp;type=$resourcetype";
+            $type->typestr = get_string("resourcetype$resourcetype", 'resource');
+            $types[] = $type;
         }
     }
-    return $resources;
+
+    return $types;
 }
+
+function resource_get_view_actions() {
+    return array('view','view all');
+}
+
+function resource_get_post_actions() {
+    return array();
+}
+
+function resource_renamefiles($course, $wdir, $oldname, $name) {
+    global $CFG;
+
+    $status = '<p align=\"center\"><strong>'.get_string('affectedresources', 'resource').':</strong><ul>';
+    $updates = false;
+
+    $old = trim($wdir.'/'.$oldname, '/');
+    $new = trim($wdir.'/'.$name, '/');
+
+    $sql = "SELECT r.id, r.reference, r.name, cm.id AS cmid
+             FROM {$CFG->prefix}resource r,
+                  {$CFG->prefix}course_modules cm,
+                  {$CFG->prefix}modules m
+             WHERE r.course    = '{$course->id}'
+               AND m.name      = 'resource'
+               AND cm.module   = m.id
+               AND cm.instance = r.id
+               AND (r.type = 'file' OR r.type = 'directory')
+               AND (r.reference LIKE '{$old}/%' OR r.reference = '{$old}')";
+    if ($resources = get_records_sql($sql)) {
+        foreach ($resources as $resource) {
+            $r = new object();
+            $r->id = $resource->id;
+            $r->reference = '';
+            if ($resource->reference == $old) {
+                $r->reference = addslashes($new);
+            } else {
+                $r->reference = addslashes(preg_replace('|^'.preg_quote($old, '|').'/|', $new.'/', $resource->reference));
+            }
+            if ($r->reference !== '') {
+                $updates = true;
+                $status .= "<li><a href=\"$CFG->wwwroot/mod/resource/view.php?id=$resource->cmid\" target=\"_blank\">$resource->name</a>: $resource->reference ==> $r->reference</li>";
+                if (!empty($CFG->resource_autofilerename)) {
+                    if (!update_record('resource', $r)) {
+                        error("Error updating resource with ID $r->id.");
+                    }
+                }
+            }
+        }
+    }
+    $status .= '</ul></p>';
+
+    if ($updates) {
+        echo $status;
+        if (empty($CFG->resource_autofilerename)) {
+            notify(get_string('warningdisabledrename', 'resource'));
+        }
+    }
+}
+
+function resource_delete_warning($course, $files) {
+    global $CFG;
+
+    $found = array();
+
+    foreach($files as $key=>$file) {
+        $files[$key] = trim($file, '/');
+    }
+    $sql = "SELECT r.id, r.reference, r.name, cm.id AS cmid
+             FROM {$CFG->prefix}resource r,
+                  {$CFG->prefix}course_modules cm,
+                  {$CFG->prefix}modules m
+             WHERE r.course    = '{$course->id}'
+               AND m.name      = 'resource'
+               AND cm.module   = m.id
+               AND cm.instance = r.id
+               AND (r.type = 'file' OR r.type = 'directory')";
+    if ($resources = get_records_sql($sql)) {
+        foreach ($resources as $resource) {
+            if ($resource->reference == '') {
+                continue; // top shared directory does not prevent anything
+            }
+            if (in_array($resource->reference, $files)) {
+                $found[$resource->id] = $resource;
+            } else {
+                foreach($files as $file) {
+                    if (preg_match('|^'.preg_quote($file, '|').'/|', $resource->reference)) {
+                        $found[$resource->id] = $resource;
+                    }
+                }
+            }
+        }
+    }
+
+    if (!empty($found)) {
+
+        print_simple_box_start("center");
+        echo '<p><strong>'.get_string('affectedresources', 'resource').':</strong><ul>';
+        foreach($found as $resource) {
+            echo "<li><a href=\"$CFG->wwwroot/mod/resource/view.php?id=$resource->cmid\" target=\"_blank\">$resource->name</a>: $resource->reference</li>";
+        }
+        echo '</ul></p>';
+        print_simple_box_end();
+
+        return true;
+    } else {
+        return false;
+    }
+}
+
 ?>
