@@ -1,57 +1,4 @@
-<?php  // $Id: lib.php,v 1.65.2.5 2006/08/11 12:21:23 bobopinna Exp $
-
-/// Library of functions and constants for module scorm
-
-define('GRADESCOES', '0');
-define('GRADEHIGHEST', '1');
-define('GRADEAVERAGE', '2');
-define('GRADESUM', '3');
-$SCORM_GRADE_METHOD = array (GRADESCOES => get_string('gradescoes', 'scorm'),
-                             GRADEHIGHEST => get_string('gradehighest', 'scorm'),
-                             GRADEAVERAGE => get_string('gradeaverage', 'scorm'),
-                             GRADESUM => get_string('gradesum', 'scorm'));
-
-define('VALUEHIGHEST', '0');
-define('VALUEAVERAGE', '1');
-define('VALUEFIRST', '2');
-define('VALUELAST', '3');
-$SCORM_WHAT_GRADE = array (VALUEHIGHEST => get_string('highestattempt', 'scorm'),
-                           VALUEAVERAGE => get_string('averageattempt', 'scorm'),
-                           VALUEFIRST => get_string('firstattempt', 'scorm'),
-                           VALUELAST => get_string('lastattempt', 'scorm'));
-
-$SCORM_POPUP_OPTIONS = array('resizable'=>1, 
-                             'scrollbars'=>1, 
-                             'directories'=>0, 
-                             'location'=>0,
-                             'menubar'=>0, 
-                             'toolbar'=>0, 
-                             'status'=>0);
-$stdoptions = '';
-foreach ($SCORM_POPUP_OPTIONS as $popupopt => $value) {
-    $stdoptions .= $popupopt.'='.$value;
-    if ($popupopt != 'status') {
-        $stdoptions .= ',';
-    }
-}
-
-if (!isset($CFG->scorm_maxattempts)) {
-    set_config('scorm_maxattempts','6');
-}
-
-if (!isset($CFG->scorm_frameheight)) {
-    set_config('scorm_frameheight','500');
-}
-
-if (!isset($CFG->scorm_framewidth)) {
-    set_config('scorm_framewidth','100%');
-}
-
-//
-// Repository configurations
-//
-$repositoryconfigfile = $CFG->dirroot.'/mod/resource/type/ims/repository_config.php';
-$repositorybrowser = '/mod/resource/type/ims/finder.php';
+<?php  // $Id: lib.php,v 1.83.2.2 2007/04/10 14:21:29 csantossaenz Exp $
 
 /**
 * Given an object containing all the necessary data,
@@ -62,12 +9,25 @@ $repositorybrowser = '/mod/resource/type/ims/finder.php';
 * @param mixed $scorm Form data
 * @return int
 */
+require_once('locallib.php');
 function scorm_add_instance($scorm) {
-    if(empty($scorm->datadir)) { //check to make sure scorm object is valid BEFORE entering it in the database.
-        error(get_string('nomanifest', 'scorm'));
-    } else {
-        global $CFG;
+    global $CFG;
+
+    require_once('locallib.php');
+
+    if (($packagedata = scorm_check_package($scorm)) != null) {
+        $scorm->pkgtype = $packagedata->pkgtype;
+        $scorm->datadir = $packagedata->datadir;
+        $scorm->launch = $packagedata->launch;
+        $scorm->parse = 1;
+
         $scorm->timemodified = time();
+        if (!scorm_external_link($scorm->reference)) {
+            $scorm->md5hash = md5_file($CFG->dataroot.'/'.$scorm->course.'/'.$scorm->reference);
+        } else {
+            $scorm->dir = $CFG->dataroot.'/'.$scorm->course.'/moddata/scorm';
+            $scorm->md5hash = md5_file($scorm->dir.$scorm->datadir.'/'.basename($scorm->reference));
+        }
 
         $scorm = scorm_option2text($scorm);
         $scorm->width = str_replace('%','',$scorm->width);
@@ -77,9 +37,14 @@ function scorm_add_instance($scorm) {
         $scorm->width = clean_param($scorm->width, PARAM_INT);
         $scorm->height = clean_param($scorm->height, PARAM_INT);
 
+        if (!isset($scorm->whatgrade)) {
+            $scorm->whatgrade = 0;
+        }
+        $scorm->grademethod = ($scorm->whatgrade * 10) + $scorm->grademethod;
+
         $id = insert_record('scorm', $scorm);
 
-        if ((basename($scorm->reference) != 'imsmanifest.xml') && ($scorm->reference[0] != '#')) {
+        if (scorm_external_link($scorm->reference) || ((basename($scorm->reference) != 'imsmanifest.xml') && ($scorm->reference[0] != '#'))) {
             // Rename temp scorm dir to scorm id
             $scorm->dir = $CFG->dataroot.'/'.$scorm->course.'/moddata/scorm';
             rename($scorm->dir.$scorm->datadir,$scorm->dir.'/'.$id);
@@ -87,13 +52,14 @@ function scorm_add_instance($scorm) {
 
         // Parse scorm manifest
         if ($scorm->parse == 1) {
-            require_once('locallib.php');
             $scorm->id = $id;
             $scorm->launch = scorm_parse($scorm);
             set_field('scorm','launch',$scorm->launch,'id',$scorm->id);
         }
 
         return $id;
+    } else {
+        error(get_string('badpackage','scorm'));
     }
 }
 
@@ -106,9 +72,27 @@ function scorm_add_instance($scorm) {
 * @return int
 */
 function scorm_update_instance($scorm) {
-
     global $CFG;
 
+    require_once('locallib.php');
+
+    if (($packagedata = scorm_check_package($scorm)) != null) {
+        $scorm->pkgtype = $packagedata->pkgtype;
+        if ($packagedata->launch == 0) {
+            $scorm->launch = $packagedata->launch;
+            $scorm->datadir = $packagedata->datadir;
+            $scorm->parse = 1;
+            if (!scorm_external_link($scorm->reference)) {
+                $scorm->md5hash = md5_file($CFG->dataroot.'/'.$scorm->course.'/'.$scorm->reference);
+            } else {
+                $scorm->dir = $CFG->dataroot.'/'.$scorm->course.'/moddata/scorm';
+                $scorm->md5hash = md5_file($scorm->dir.$scorm->datadir.'/'.basename($scorm->reference));
+            }
+        } else {
+            $scorm->parse = 0;
+        }
+    }
+
     $scorm->timemodified = time();
     $scorm->id = $scorm->instance;
 
@@ -116,20 +100,28 @@ function scorm_update_instance($scorm) {
     $scorm->width = str_replace('%','',$scorm->width);
     $scorm->height = str_replace('%','',$scorm->height);
 
+    if (!isset($scorm->whatgrade)) {
+        $scorm->whatgrade = 0;
+    }
+    $scorm->grademethod = ($scorm->whatgrade * 10) + $scorm->grademethod;
+
     // Check if scorm manifest needs to be reparsed
     if ($scorm->parse == 1) {
-        require_once('locallib.php');
         $scorm->dir = $CFG->dataroot.'/'.$scorm->course.'/moddata/scorm';
         if (is_dir($scorm->dir.'/'.$scorm->id)) {
             scorm_delete_files($scorm->dir.'/'.$scorm->id);
         }
         if (isset($scorm->datadir) && ($scorm->datadir != $scorm->id) && 
-           (basename($scorm->reference) != 'imsmanifest.xml') && ($scorm->reference[0] != '#')) {
+           (scorm_external_link($scorm->reference) || ((basename($scorm->reference) != 'imsmanifest.xml') && ($scorm->reference[0] != '#')))) {
             rename($scorm->dir.$scorm->datadir,$scorm->dir.'/'.$scorm->id);
         }
-        
+
         $scorm->launch = scorm_parse($scorm);
+    } else {
+        $oldscorm = get_record('scorm','id',$scorm->id);
+        $scorm->reference = $oldscorm->reference; // This fix a problem with Firefox when the teacher choose Cancel on overwrite question
     }
+    
     return update_record('scorm', $scorm);
 }
 
@@ -151,21 +143,52 @@ function scorm_delete_instance($id) {
 
     $result = true;
 
-    // Delete any dependent files
-    require_once('locallib.php');
-    scorm_delete_files($CFG->dataroot.'/'.$scorm->course.'/moddata/scorm/'.$scorm->id);
+    $scorm->dir = $CFG->dataroot.'/'.$scorm->course.'/moddata/scorm';
+    if (is_dir($scorm->dir.'/'.$scorm->id)) {
+        // Delete any dependent files
+        require_once('locallib.php');
+        scorm_delete_files($scorm->dir.'/'.$scorm->id);
+    }
 
     // Delete any dependent records
     if (! delete_records('scorm_scoes_track', 'scormid', $scorm->id)) {
         $result = false;
     }
-    if (! delete_records('scorm_scoes', 'scorm', $scorm->id)) {
+    if ($scoes = get_records('scorm_scoes','scorm',$scorm->id)) {
+        foreach ($scoes as $sco) {
+            if (! delete_records('scorm_scoes_data', 'scoid', $sco->id)) {
+                $result = false;
+            }
+        } 
+        delete_records('scorm_scoes', 'scorm', $scorm->id);
+    } else {
         $result = false;
     }
     if (! delete_records('scorm', 'id', $scorm->id)) {
         $result = false;
     }
 
+    /*if (! delete_records('scorm_sequencing_controlmode', 'scormid', $scorm->id)) {
+        $result = false;
+    }
+    if (! delete_records('scorm_sequencing_rolluprules', 'scormid', $scorm->id)) {
+        $result = false;
+    }
+    if (! delete_records('scorm_sequencing_rolluprule', 'scormid', $scorm->id)) {
+        $result = false;
+    }
+    if (! delete_records('scorm_sequencing_rollupruleconditions', 'scormid', $scorm->id)) {
+        $result = false;
+    }
+    if (! delete_records('scorm_sequencing_rolluprulecondition', 'scormid', $scorm->id)) {
+        $result = false;
+    }
+    if (! delete_records('scorm_sequencing_rulecondition', 'scormid', $scorm->id)) {
+        $result = false;
+    }
+    if (! delete_records('scorm_sequencing_ruleconditions', 'scormid', $scorm->id)) {
+        $result = false;
+    }*/       
     return $result;
 }
 
@@ -183,84 +206,11 @@ function scorm_delete_instance($id) {
 function scorm_user_outline($course, $user, $mod, $scorm) { 
 
     $return = NULL;
-    $scores->values = 0;
-    $scores->sum = 0;
-    $scores->max = 0;
-    $scores->lastmodify = 0;
-    $scores->count = 0;
-    if ($scoes = get_records_select("scorm_scoes","scorm='$scorm->id' ORDER BY id")) {
-        require_once('locallib.php');
-        foreach ($scoes as $sco) {
-            if ($sco->launch!='') {
-                $scores->count++;
-                if ($userdata = scorm_get_tracks($sco->id, $user->id)) {
-                    if (!isset($scores->{$userdata->status})) {
-                        $scores->{$userdata->status} = 1;
-                    } else {    
-                        $scores->{$userdata->status}++;
-                    }
-                    if (!empty($userdata->score_raw)) {
-                        $scores->values++;
-                        $scores->sum += $userdata->score_raw;
-                        $scores->max = ($userdata->score_raw > $scores->max)?$userdata->score_raw:$scores->max;
-                    }
-                    if (isset($userdata->timemodified) && ($userdata->timemodified > $scores->lastmodify)) {
-                        $scores->lastmodify = $userdata->timemodified;
-                    }
-                }
-            }
-        }
-        switch ($scorm->grademethod) {
-            case GRADEHIGHEST:
-                if ($scores->values > 0) {
-                    $return->info = get_string('score','scorm').':&nbsp;'.$scores->max;
-                    $return->time = $scores->lastmodify;
-                }
-            break;
-            case GRADEAVERAGE:
-                if ($scores->values > 0) {
-                    $return->info = get_string('score','scorm').':&nbsp;'.$scores->sum/$scores->values;
-                    $return->time = $scores->lastmodify;
-                }
-            break;
-            case GRADESUM:
-                if ($scores->values > 0) {
-                    $return->info = get_string('score','scorm').':&nbsp;'.$scores->sum;
-                    $return->time = $scores->lastmodify;
-                }
-            break;
-            case GRADESCOES:
-                $return->info = '';
-                $scores->notattempted = $scores->count;
-                if (isset($scores->completed)) {
-                    $return->info .= get_string('completed','scorm').':&nbsp;'.$scores->completed.'<br />';
-                    $scores->notattempted -= $scores->completed;
-                }
-                if (isset($scores->passed)) {
-                    $return->info .= get_string('passed','scorm').':&nbsp;'.$scores->passed.'<br />';
-                    $scores->notattempted -= $scores->passed;
-                }
-                if (isset($scores->failed)) {
-                    $return->info .= get_string('failed','scorm').':&nbsp;'.$scores->failed.'<br />';
-                    $scores->notattempted -= $scores->failed;
-                }
-                if (isset($scores->incomplete)) {
-                    $return->info .= get_string('incomplete','scorm').':&nbsp;'.$scores->incomplete.'<br />';
-                    $scores->notattempted -= $scores->incomplete;
-                }
-                if (isset($scores->browsed)) {
-                    $return->info .= get_string('browsed','scorm').':&nbsp;'.$scores->browsed.'<br />';
-                    $scores->notattempted -= $scores->browsed;
-                }
-                $return->time = $scores->lastmodify;
-                if ($return->info == '') {
-                    $return = NULL;
-                } else {
-                    $return->info .= get_string('notattempted','scorm').':&nbsp;'.$scores->notattempted.'<br />';
-                }
-            break;
-        }
-    }
+
+    require_once('locallib.php');
+
+    $return = scorm_grade_user($scorm, $user->id, true);
+
     return $return;
 }
 
@@ -331,7 +281,7 @@ function scorm_user_complete($course, $user, $mod, $scorm) {
                     if (($nextsco !== false) && ($sco->parent != $nextsco->parent) && (($level==0) || (($level>0) && ($nextsco->parent == $sco->identifier)))) {
                         $sublist++;
                     } else {
-                        $report .= '<img src="'.$scormpixdir.'/spacer.gif" />';
+                        $report .= '<img src="'.$scormpixdir.'/spacer.gif" alt="" />';
                     }
 
                     if ($sco->launch) {
@@ -425,6 +375,32 @@ function scorm_cron () {
 
     global $CFG;
 
+    require_once('locallib.php');
+
+    $sitetimezone = $CFG->timezone;
+    /// Now see if there are any digest mails waiting to be sent, and if we should send them
+    if (!isset($CFG->scorm_updatetimelast)) {    // To catch the first time
+        set_config('scorm_updatetimelast', 0);
+    }
+
+    $timenow = time();
+    $updatetime = usergetmidnight($timenow, $sitetimezone) + ($CFG->scorm_updatetime * 3600);
+
+    if ($CFG->scorm_updatetimelast < $updatetime and $timenow > $updatetime) {
+
+        set_config('scorm_updatetimelast', $timenow);
+
+        mtrace('Updating scorm packages which require daily update');//We are updating
+
+        $scormsupdate = get_records('scorm','updatefreq',UPDATE_EVERYDAY);
+        if (!empty($scormsupdate)) {
+            foreach($scormsupdate as $scormupdate) {
+                $scormupdate->instance = $scormupdate->id;
+                $id = scorm_update_instance($scormupdate);
+            }
+        }
+    }
+
     return true;
 }
 
@@ -441,11 +417,8 @@ function scorm_grades($scormid) {
     if (!$scorm = get_record('scorm', 'id', $scormid)) {
         return NULL;
     }
-    if (!$scoes = get_records('scorm_scoes','scorm',$scormid)) {
-        return NULL;
-    }
 
-    if ($scorm->grademethod == GRADESCOES) {
+    if (($scorm->grademethod % 10) == 0) { // GRADESCOES
         if (!$return->maxgrade = count_records_select('scorm_scoes',"scorm='$scormid' AND launch<>''")) {
             return NULL;
         }
@@ -457,7 +430,7 @@ function scorm_grades($scormid) {
     if ($scousers=get_records_select('scorm_scoes_track', "scormid='$scormid' GROUP BY userid", "", "userid,null")) {
         require_once('locallib.php');
         foreach ($scousers as $scouser) {
-            $return->grades[$scouser->userid] = scorm_grade_user($scoes, $scouser->userid, $scorm->grademethod);
+            $return->grades[$scouser->userid] = scorm_grade_user($scorm, $scouser->userid);
         }
     }
     return $return;
@@ -473,9 +446,8 @@ function scorm_get_post_actions() {
 
 function scorm_option2text($scorm) {
     global $SCORM_POPUP_OPTIONS;
-
     if (isset($scorm->popup)) {
-        if ($scorm->popup) {
+        if ($scorm->popup == 1) {
             $optionlist = array();
             foreach ($SCORM_POPUP_OPTIONS as $name => $option) {
                 if (isset($scorm->$name)) {
