@@ -1,15 +1,16 @@
-<?PHP // $Id: graph.php,v 1.18 2004/03/13 14:24:34 moodler Exp $
+<?php // $Id: graph.php,v 1.28 2006/08/30 08:43:19 toyomoyo Exp $
 
     require_once("../../config.php");
     require_once("$CFG->libdir/graphlib.php");
     require_once("lib.php");
 
-    require_variable($id);    // Course Module ID
-    require_variable($type);  // Graph Type
-    optional_variable($group, "0");  // Group ID
-    optional_variable($sid);  // Student ID
+    $id    = required_param('id', PARAM_INT);    // Course Module ID
+    $type  = required_param('type', PARAM_FILE);  // Graph Type
+    $group = optional_param('group', 0, PARAM_INT);  // Group ID
+    $sid   = optional_param('sid', false, PARAM_INT);  // Student ID
+    $qid   = optional_param('qid', 0, PARAM_INT);  // Group ID
 
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('survey', $id)) {
         error("Course Module ID was incorrect");
     }
 
@@ -17,11 +18,12 @@
         error("Course is misconfigured");
     }
 
-    require_login($course->id);
+    require_login($course->id, false, $cm);
 
     $groupmode = groupmode($course, $cm);   // Groups are being used
+    $context = get_context_instance(CONTEXT_MODULE, $cm->id);
 
-    if (!isteacher($course->id)) {
+    if (!has_capability('mod/survey:readresponses', $context)) {
         if ($type != "student.png" or $sid != $USER->id ) {
             error("Sorry, you aren't allowed to see this.");
         } else if ($groupmode and !ismember($group)) {
@@ -49,6 +51,8 @@
     $strpreferredclass = get_string("preferredclass", "survey");
     $strpreferredstudent = get_string("preferredstudent", "survey", $course->student);
 
+    $virtualscales = false; //set default value for case clauses
+
     switch ($type) {
 
      case "question.png":
@@ -56,7 +60,7 @@
        $question = get_record("survey_questions", "id", $qid);
        $question->text = get_string($question->text, "survey");
        $question->options = get_string($question->options, "survey");
-  
+
        $options = explode(",",$question->options);
 
        while (list($key,) = each($options)) {
@@ -77,7 +81,7 @@
            }
        }
 
-       
+
        $maxbuckets1 = max($buckets1);
        $maxbuckets2 = max($buckets2);
        $maxbuckets = ($maxbuckets1 > $maxbuckets2) ? $maxbuckets1 : $maxbuckets2;
@@ -103,13 +107,16 @@
        } else {
            $graph->y_order = array('answers2');
        }
-       
+
        $graph->parameter['y_axis_gridlines']= $maxbuckets + 1;
        $graph->parameter['y_resolution_left']= 1;
        $graph->parameter['y_decimal_left']  = 0;
-       $graph->parameter['x_axis_angle']    = 0;
+       $graph->parameter['x_axis_angle']    = 20;
        $graph->parameter['shadow']          = 'none';
 
+       $graph->y_tick_labels = null;
+       $graph->offset_relation = null;
+
        $graph->draw_stack();
 
        break;
@@ -192,7 +199,7 @@
            $buckets2[$i] = $buckets2[$i] - 1;
        }
 
-       
+
 
        $maxbuckets1 = max($buckets1);
        $maxbuckets2 = max($buckets2);
@@ -203,16 +210,16 @@
 
        $graph->x_data               = $names;
        $graph->y_data['answers1']   = $buckets1;
-       $graph->y_format['answers1'] = array('colour' => 'ltblue', 'line' => 'line',  'point' => 'square', 
+       $graph->y_format['answers1'] = array('colour' => 'ltblue', 'line' => 'line',  'point' => 'square',
                                             'shadow_offset' => 4, 'legend' => $stractual);
        $graph->y_data['answers2']   = $buckets2;
-       $graph->y_format['answers2'] = array('colour' => 'ltorange', 'line' => 'line', 'point' => 'square', 
+       $graph->y_format['answers2'] = array('colour' => 'ltorange', 'line' => 'line', 'point' => 'square',
                                                 'shadow_offset' => 4, 'legend' => $strpreferred);
        $graph->y_data['stdev1']   = $stdev1;
-       $graph->y_format['stdev1'] = array('colour' => 'ltltblue', 'bar' => 'fill', 
+       $graph->y_format['stdev1'] = array('colour' => 'ltltblue', 'bar' => 'fill',
                                             'shadow_offset' => '4', 'legend' => 'none', 'bar_size' => 0.3);
        $graph->y_data['stdev2']   = $stdev2;
-       $graph->y_format['stdev2'] = array('colour' => 'ltltorange', 'bar' => 'fill', 
+       $graph->y_format['stdev2'] = array('colour' => 'ltltorange', 'bar' => 'fill',
                                             'shadow_offset' => '4', 'legend' => 'none', 'bar_size' => 0.2);
        $graph->offset_relation['stdev1'] = 'answers1';
        $graph->offset_relation['stdev2'] = 'answers2';
@@ -232,23 +239,24 @@
        } else {
            $graph->y_order = array('stdev2', 'answers2');
        }
-       
+
        $graph->parameter['y_max_left']= count($options) - 1;
        $graph->parameter['y_axis_gridlines']= count($options);
        $graph->parameter['y_resolution_left']= 1;
        $graph->parameter['y_decimal_left']= 1;
-       $graph->parameter['x_axis_angle']  = 0;
+       $graph->parameter['x_axis_angle']  = 20;
 
        $graph->draw();
 
        break;
 
 
-    
+
      case "overall.png":
 
        $qqq = get_records_list("survey_questions", "id", $survey->questions);
 
+
        foreach ($qqq as $key => $qq) {
            if ($qq->multi) {
                $qqq[$key]->text = get_string($qq->text, "survey");
@@ -330,7 +338,7 @@
 
            $buckets1[$i] = $buckets1[$i] - 1;         // Hack because there should not be ANY 0 values in the data.
            $buckets2[$i] = $buckets2[$i] - 1;
-           
+
        }
 
        $maxbuckets1 = max($buckets1);
@@ -338,22 +346,22 @@
 
 
        $graph = new graph($SURVEY_GWIDTH,$SURVEY_GHEIGHT);
-       $graph->parameter['title'] = "$survey->name";
+       $graph->parameter['title'] = strip_tags(format_string($survey->name,true));
 
        $graph->x_data               = $names;
 
        $graph->y_data['answers1']   = $buckets1;
-       $graph->y_format['answers1'] = array('colour' => 'ltblue', 'line' => 'line',  'point' => 'square', 
+       $graph->y_format['answers1'] = array('colour' => 'ltblue', 'line' => 'line',  'point' => 'square',
                                             'shadow_offset' => 4, 'legend' => $stractual);
        $graph->y_data['answers2']   = $buckets2;
-       $graph->y_format['answers2'] = array('colour' => 'ltorange', 'line' => 'line', 'point' => 'square', 
+       $graph->y_format['answers2'] = array('colour' => 'ltorange', 'line' => 'line', 'point' => 'square',
                                                 'shadow_offset' => 4, 'legend' => $strpreferred);
 
        $graph->y_data['stdev1']   = $stdev1;
-       $graph->y_format['stdev1'] = array('colour' => 'ltltblue', 'bar' => 'fill', 
+       $graph->y_format['stdev1'] = array('colour' => 'ltltblue', 'bar' => 'fill',
                                             'shadow_offset' => '4', 'legend' => 'none', 'bar_size' => 0.3);
        $graph->y_data['stdev2']   = $stdev2;
-       $graph->y_format['stdev2'] = array('colour' => 'ltltorange', 'bar' => 'fill', 
+       $graph->y_format['stdev2'] = array('colour' => 'ltltorange', 'bar' => 'fill',
                                             'shadow_offset' => '4', 'legend' => 'none', 'bar_size' => 0.2);
        $graph->offset_relation['stdev1'] = 'answers1';
        $graph->offset_relation['stdev2'] = 'answers2';
@@ -371,12 +379,13 @@
        } else {
            $graph->y_order = array('stdev2', 'answers2');
        }
-       
+
        $graph->parameter['y_max_left']= $numoptions - 1;
        $graph->parameter['y_axis_gridlines']= $numoptions;
        $graph->parameter['y_resolution_left']= 1;
        $graph->parameter['y_decimal_left']= 1;
        $graph->parameter['x_axis_angle']  = 0;
+       $graph->parameter['x_inner_padding']  = 6;
 
        $graph->draw();
 
@@ -498,27 +507,27 @@
 
 
        $graph = new graph($SURVEY_GWIDTH,$SURVEY_GHEIGHT);
-       $graph->parameter['title'] = "$survey->name";
+       $graph->parameter['title'] = strip_tags(format_string($survey->name,true));
 
        $graph->x_data               = $names;
 
        $graph->y_data['answers1']   = $buckets1;
-       $graph->y_format['answers1'] = array('colour' => 'ltblue', 'line' => 'line',  'point' => 'square', 
+       $graph->y_format['answers1'] = array('colour' => 'ltblue', 'line' => 'line',  'point' => 'square',
                                             'shadow_offset' => 0.1, 'legend' => $stractualclass);
        $graph->y_data['answers2']   = $buckets2;
-       $graph->y_format['answers2'] = array('colour' => 'ltorange', 'line' => 'line', 'point' => 'square', 
+       $graph->y_format['answers2'] = array('colour' => 'ltorange', 'line' => 'line', 'point' => 'square',
                                                 'shadow_offset' => 0.1, 'legend' => $strpreferredclass);
        $graph->y_data['studanswers1']   = $studbuckets1;
-       $graph->y_format['studanswers1'] = array('colour' => 'blue', 'line' => 'line',  'point' => 'square', 
+       $graph->y_format['studanswers1'] = array('colour' => 'blue', 'line' => 'line',  'point' => 'square',
                                             'shadow_offset' => 4, 'legend' => $stractualstudent);
        $graph->y_data['studanswers2']   = $studbuckets2;
-       $graph->y_format['studanswers2'] = array('colour' => 'orange', 'line' => 'line', 'point' => 'square', 
+       $graph->y_format['studanswers2'] = array('colour' => 'orange', 'line' => 'line', 'point' => 'square',
                                                 'shadow_offset' => 4, 'legend' => $strpreferredstudent);
        $graph->y_data['stdev1']   = $stdev1;
-       $graph->y_format['stdev1'] = array('colour' => 'ltltblue', 'bar' => 'fill', 
+       $graph->y_format['stdev1'] = array('colour' => 'ltltblue', 'bar' => 'fill',
                                             'shadow_offset' => 0.1, 'legend' => 'none', 'bar_size' => 0.3);
        $graph->y_data['stdev2']   = $stdev2;
-       $graph->y_format['stdev2'] = array('colour' => 'ltltorange', 'bar' => 'fill', 
+       $graph->y_format['stdev2'] = array('colour' => 'ltltorange', 'bar' => 'fill',
                                             'shadow_offset' => 0.1, 'legend' => 'none', 'bar_size' => 0.2);
        $graph->offset_relation['stdev1'] = 'answers1';
        $graph->offset_relation['stdev2'] = 'answers2';
@@ -538,12 +547,12 @@
        } else {
            $graph->y_order = array('stdev2', 'answers2', 'studanswers2');
        }
-       
+
        $graph->parameter['y_max_left']= $numoptions - 1;
        $graph->parameter['y_axis_gridlines']= $numoptions;
        $graph->parameter['y_resolution_left']= 1;
        $graph->parameter['y_decimal_left']= 1;
-       $graph->parameter['x_axis_angle']  = 0;
+       $graph->parameter['x_axis_angle']  = 20;
 
        $graph->draw();
        break;
@@ -646,7 +655,7 @@
            $studbuckets2[$i] = $studbuckets2[$i] - 1;
        }
 
-       
+
 
        $maxbuckets1 = max($buckets1);
        $maxbuckets2 = max($buckets2);
@@ -657,22 +666,22 @@
 
        $graph->x_data               = $names;
        $graph->y_data['answers1']   = $buckets1;
-       $graph->y_format['answers1'] = array('colour' => 'ltblue', 'line' => 'line',  'point' => 'square', 
+       $graph->y_format['answers1'] = array('colour' => 'ltblue', 'line' => 'line',  'point' => 'square',
                                             'shadow_offset' => 0.1, 'legend' => $stractualclass);
        $graph->y_data['answers2']   = $buckets2;
-       $graph->y_format['answers2'] = array('colour' => 'ltorange', 'line' => 'line', 'point' => 'square', 
+       $graph->y_format['answers2'] = array('colour' => 'ltorange', 'line' => 'line', 'point' => 'square',
                                                 'shadow_offset' => 0.1, 'legend' => $strpreferredclass);
        $graph->y_data['studanswers1']   = $studbuckets1;
-       $graph->y_format['studanswers1'] = array('colour' => 'blue', 'line' => 'line',  'point' => 'square', 
+       $graph->y_format['studanswers1'] = array('colour' => 'blue', 'line' => 'line',  'point' => 'square',
                                             'shadow_offset' => 4, 'legend' => $stractualstudent);
        $graph->y_data['studanswers2']   = $studbuckets2;
-       $graph->y_format['studanswers2'] = array('colour' => 'orange', 'line' => 'line', 'point' => 'square', 
+       $graph->y_format['studanswers2'] = array('colour' => 'orange', 'line' => 'line', 'point' => 'square',
                                                 'shadow_offset' => 4, 'legend' => $strpreferredstudent);
        $graph->y_data['stdev1']   = $stdev1;
-       $graph->y_format['stdev1'] = array('colour' => 'ltltblue', 'bar' => 'fill', 
+       $graph->y_format['stdev1'] = array('colour' => 'ltltblue', 'bar' => 'fill',
                                             'shadow_offset' => 0.1, 'legend' => 'none', 'bar_size' => 0.3);
        $graph->y_data['stdev2']   = $stdev2;
-       $graph->y_format['stdev2'] = array('colour' => 'ltltorange', 'bar' => 'fill', 
+       $graph->y_format['stdev2'] = array('colour' => 'ltltorange', 'bar' => 'fill',
                                             'shadow_offset' => 0.1, 'legend' => 'none', 'bar_size' => 0.2);
        $graph->offset_relation['stdev1'] = 'answers1';
        $graph->offset_relation['stdev2'] = 'answers2';
@@ -692,12 +701,12 @@
        } else {
            $graph->y_order = array('stdev2', 'answers2', 'studanswers2');
        }
-       
+
        $graph->parameter['y_max_left']= count($options)-1;
        $graph->parameter['y_axis_gridlines']= count($options);
        $graph->parameter['y_resolution_left']= 1;
        $graph->parameter['y_decimal_left']= 1;
-       $graph->parameter['x_axis_angle']  = 0;
+       $graph->parameter['x_axis_angle']  = 20;
 
        $graph->draw();
 
@@ -709,5 +718,5 @@
 
    exit;
 
-         
+
 ?>
