@@ -1,9 +1,9 @@
-<?PHP // $Id: index.php,v 1.15 2004/08/22 14:38:45 gustav_delius Exp $
+<?php // $Id: index.php,v 1.20 2006/09/02 11:44:08 skodak Exp $
 
     require_once("../../config.php");
     require_once("lib.php");
 
-    require_variable($id);   // course
+    $id = required_param('id', PARAM_INT);    // Course Module ID
 
     if (! $course = get_record("course", "id", $id)) {
         error("Course ID is incorrect");
@@ -42,7 +42,7 @@
     $currentsection = '';
 
     foreach ($surveys as $survey) {
-        if (isset($USER->id) and survey_already_done($survey->id, $USER->id)) {
+        if (!empty($USER->id) and survey_already_done($survey->id, $USER->id)) {
             $ss = $strdone;
         } else {
             $ss = $strnotdone;
@@ -60,20 +60,20 @@
         //Calculate the href
         if (!$survey->visible) {
             //Show dimmed if the mod is hidden
-            $tt_href = "<A class=\"dimmed\" HREF=\"view.php?id=$survey->coursemodule\">$survey->name</A>";
+            $tt_href = "<a class=\"dimmed\" href=\"view.php?id=$survey->coursemodule\">".format_string($survey->name,true)."</a>";
         } else {
             //Show normal if the mod is visible
-            $tt_href = "<A HREF=\"view.php?id=$survey->coursemodule\">$survey->name</A>";
+            $tt_href = "<a href=\"view.php?id=$survey->coursemodule\">".format_string($survey->name,true)."</a>";
         }
 
         if ($course->format == "weeks" or $course->format == "topics") {
-            $table->data[] = array ($printsection, $tt_href, "<A HREF=\"view.php?id=$survey->coursemodule\">$ss</A>");
+            $table->data[] = array ($printsection, $tt_href, "<a href=\"view.php?id=$survey->coursemodule\">$ss</a>");
         } else {
-            $table->data[] = array ($tt_href, "<A HREF=\"view.php?id=$survey->coursemodule\">$ss</A>");
+            $table->data[] = array ($tt_href, "<a href=\"view.php?id=$survey->coursemodule\">$ss</a>");
         }
     }
 
-    echo "<BR>";
+    echo "<br />";
     print_table($table);
     print_footer($course);
 
