@@ -1,12 +1,14 @@
-<?php  // $Id: view.php,v 1.44.2.2 2005/12/21 03:24:26 toyomoyo Exp $
+<?php  // $Id: view.php,v 1.66.2.3 2007/03/02 01:29:10 toyomoyo Exp $
 /// Extended by Michael Schneider
 /// This page prints a particular instance of wiki
 
-    global $CFG;
+    global $CFG,$USER;
 
     require_once("../../config.php");
     require_once("lib.php");
-    #require_once("$CFG->dirroot/course/lib.php"); // For side-blocks
+    #require_once("$CFG->dirroot/course/lib.php"); // For side-blocks    
+    require_once($CFG->libdir . '/ajax/ajaxlib.php');
+    require_js(array('yui_yahoo','yui_connection'));
 
     $ewiki_action = optional_param('ewiki_action', '', PARAM_ALPHA);     // Action on Wiki-Page
     $id           = optional_param('id', 0, PARAM_INT);                  // Course Module ID, or
@@ -16,14 +18,26 @@
     $userid       = optional_param('userid', 0, PARAM_INT);              // User wiki.
     $groupid      = optional_param('groupid', 0, PARAM_INT);             // Group wiki.
     $canceledit   = optional_param('canceledit','', PARAM_ALPHA);          // Editing has been cancelled
-
+    $cacheme      = optional_param('allowcache', 1, PARAM_INT);   // Set this to 0 to try and disable page caching.
+    
     // Only want to add edit log entries if we have made some changes ie submitted a form
     $editsave = optional_param('thankyou', '');
     
-
-
+    if($page) {
+        // Split page command into action and page
+        $actions = explode('/', $page,2);
+        if(count($actions)==2) {
+            $pagename=$actions[1];
+        } else {
+        	    $pagename=$actions[0];
+        }
+    } else {
+        $actions=array('');
+        $pagename='';
+    }
+    
     if ($id) {
-        if (! $cm = get_record("course_modules", "id", $id)) {
+        if (! $cm = get_coursemodule_from_id('wiki', $id)) {
             error("Course Module ID was incorrect");
         }
 
@@ -50,7 +64,7 @@
     }
 
     require_course_login($course, true, $cm);
-
+    
     /// Add the course module 'groupmode' to the wiki object, for easy access.
     $wiki->groupmode = $cm->groupmode;
 
@@ -62,9 +76,33 @@
 
 /// Globally disable CamelCase, if the option is selected for this wiki.
     $moodle_disable_camel_case = ($wiki->disablecamelcase == 1);
-
+    
     if (($wiki_entry = wiki_get_default_entry($wiki, $course, $userid, $groupid))) {
+        // OK, now we know the entry ID, we can do lock etc.
+        
+        // If true, we are 'really' on an editing page, not just on edit/something
+        $reallyedit=$actions[0]=='edit' && !$canceledit && !$editsave;
 
+        // Remove lock when we go to another wiki page (such as the cancel page)
+        if(!$reallyedit) {
+            wiki_release_lock($wiki_entry->id,$pagename);
+        } else if(array_key_exists('content',$_POST)) {
+            // Do not allow blank content because it causes problems (the wiki decides
+            // the page should automatically go into edit mode, but Moodle doesn't realise
+            // this and filters out the JS)
+            if($_POST['content']=='') {
+                $_POST['content']="\n";
+                $_REQUEST['content']="\n";
+            }
+    
+            // We must have the edit lock in order to be permitted to save    
+            list($ok,$lock)=wiki_obtain_lock($wiki_entry->id,$pagename);
+            if(!$ok) {
+                $strsavenolock=get_string('savenolock','wiki');
+                error($strsavenolock,$CFG->wwwroot.'/mod/wiki/view.php?id='.$cm->id.'&page=view/'.urlencode($pagename));
+            }
+        }
+        
 ///     ################# EWIKI Part ###########################
 ///     The wiki_entry->pagename is set to the specified value of the wiki,
 ///     or the default value in the 'lang' file if the specified value was empty.
@@ -112,10 +150,12 @@
 
         define("EWIKI_INIT_PAGES", wiki_content_dir($wiki));
 
-///     # fix broken PHP setup
-        if (!function_exists("get_magic_quotes_gpc") || get_magic_quotes_gpc()) {
-            include($CFG->dirroot."/mod/wiki/ewiki/fragments/strip_wonderful_slashes.php");
-        }
+///     # Moodle always addslashes to everything so we are going to strip them always
+///     # to allow wiki itself to add them again. It's a triple add-strip-add but
+///     # was the only way to solve the problem without modifying how the rest of
+///     # the module works.
+        include($CFG->dirroot."/mod/wiki/ewiki/fragments/strip_wonderful_slashes.php");
+
         if (ini_get("register_globals")) {
             #    include($CFG->dirroot."/mod/wiki/ewiki/fragments/strike_register_globals.php");
         }
@@ -214,7 +254,8 @@
     }
     else {
         $content = '';
-        $content2 = '<div align="center">'.get_string('nowikicreated', 'wiki').'</div>';
+        $content2 = '<div class="boxaligncenter">'.get_string('nowikicreated', 'wiki').'</div>';
+        
     }
 
     # Group wiki, ...: No page and no ewiki_title
@@ -242,34 +283,37 @@
 
 
     print_header_simple($ewiki_title?$ewiki_title:format_string($wiki->name), "",
-                "<a href=\"index.php?id=$course->id\">$strwikis</a> -> <a href=\"view.php?id=$moodleID\">".format_string($wiki->name,true)."</a>".($ewiki_title?" -> $ewiki_title":""),
-                "", "", true, update_module_button($cm->id, $course->id, $strwiki),
+                "<a href=\"index.php?id=$course->id\">$strwikis</a>".
+                    (($ewiki_title!=$wiki->name) ? " -> <a href=\"view.php?id=$moodleID\">".format_string($wiki->name,true)."</a>":"").
+                    ($ewiki_title?" -> $ewiki_title":""),
+                "", "", $cacheme, update_module_button($cm->id, $course->id, $strwiki),
                 navmenu($course, $cm));
 
 
     /// Print Page
     echo '    <div id="wikiPageActions">
     ';
-
     /// The top row contains links to other wikis, if applicable.
-    if ($wiki_list = wiki_get_other_wikis($wiki, $USER, $course, $wiki_entry->id)) {
+    if ($wiki_entry && $wiki_list = wiki_get_other_wikis($wiki, $USER, $course, $wiki_entry->id)) {
+        //echo "wiki list ";print_r($wiki_list);
         $selected="";
+        
         if (isset($wiki_list['selected'])) {
             $selected = $wiki_list['selected'];
             unset($wiki_list['selected']);
         }
         echo '<tr><td colspan="2">';
 
-        echo '<form name="otherwikis" action="'.$CFG->wwwroot.'/mod/wiki/view.php">';
+        echo '<form id="otherwikis" action="'.$CFG->wwwroot.'/mod/wiki/view.php">';
         echo '<table border="0" cellpadding="0" cellspacing="0" width="100%"><tr>';
         echo '<td class="sideblockheading">&nbsp;'
             .$WIKI_TYPES[$wiki->wtype].' '
             .get_string('modulename', 'wiki')." ".get_string('for',"wiki")." "
             .wiki_get_owner($wiki_entry).':</td>';
 
-        echo '<td class="sideblockheading" align="right">'
+        echo '<td class="sideblockheading">'
             .get_string('otherwikis', 'wiki').':&nbsp;&nbsp;';
-        $script = 'self.location=document.otherwikis.wikiselect.options[document.otherwikis.wikiselect.selectedIndex].value';
+        $script = 'self.location=getElementById(\'otherwikis\').wikiselect.options[getElementById(\'otherwikis\').wikiselect.selectedIndex].value';
         choose_from_menu($wiki_list, "wikiselect", $selected, "choose", $script);
         echo '</td>';
         echo '</tr></table>';
@@ -286,24 +330,24 @@
         echo '<tr>';
 
         /// Searchform
-        echo '<td align="center">';
+        echo '<td class="wikisearchform">';
         wiki_print_search_form($cm->id, $q, $userid, $groupid, false);
         echo '</td>';
 
         /// Internal Wikilinks
-        echo '<td align="center">';
+        echo '<td class="wikilinksblock">';
         wiki_print_wikilinks_block($cm->id,  $wiki->ewikiacceptbinary);
         echo '</td>';
 
         /// Administrative Links
         if($canedit) {
-          echo '<td align="center">';
+          echo '<td class="wikiadminactions">';
           wiki_print_administration_actions($wiki, $cm->id, $userid, $groupid, $ewiki_title, $wiki->htmlmode!=2, $course);
           echo '</td>';
         }
 
         /// Formatting Rules
-        echo '<td align="right">';
+        echo '<td class="howtowiki">';
         helpbutton('howtowiki', get_string('howtowiki', 'wiki'), 'wiki');
         echo '</td>';
 
@@ -314,9 +358,9 @@
     <div id="wiki-view" class="mwiki">
     ';
 
-    if($ewiki_title==$wiki_entry->pagename && !empty($wiki->summary)) {
+    if($wiki_entry && $ewiki_title==$wiki_entry->pagename && !empty($wiki->summary)) {
       if (trim(strip_tags($wiki->summary))) {
-          print_simple_box(format_text($wiki->summary, FORMAT_MOODLE), 'center', '70%', '', 5, 'generalbox', 'intro');
+          print_box(format_text($wiki->summary, FORMAT_MOODLE), 'generalbox', 'intro');
       }
     }
 
@@ -343,23 +387,104 @@
         print_tabs($tabrows, $currenttab);
     }
 
+    /// Insert a link to force page refresh if new content isn't showing.
     
+    // build new URL + query string
+    $queries = preg_split('/[?&]/', me());  
+    $nqueries = count($queries);
+    $me = $queries[0] . '?';
+    for($i=1; $i < $nqueries; $i++)
+    {
+        if( !strstr($queries[$i], 'allowcache') )
+            $me .= $queries[$i] . '&amp;'; 
+    }
+    $me .= 'allowcache=0';
+
+    // Insert the link
+    $linkdesc = get_string('reloadlinkdescription', 'wiki');
+    $linktext = get_string('reloadlinktext', 'wiki');
+    echo "<div class='wikilinkright'><a href='$me' title='$linkdesc'><input type='button' value='$linktext' /></a></div>";
+
     print_simple_box_start('center', '100%', '', '20');
 
     /// Don't filter any pages containing wiki actions (except view). A wiki page containing
-    /// actions will have the form [action]/[pagename]. If the '/' isn't there, or the action
-    /// is 'view', filter it. Also, if the page doesn't exist, it will default to 'edit'.
-    $actions = explode('/', $page);
-    if ($ewiki_action == "edit" || ($actions !== false && count($actions) > 1 && $actions[0] != 'view') ||
-        (count($actions) == 1 && !record_exists('wiki_pages', 'pagename', addslashes($page), 'wiki', $wiki_entry->id))) {
-        print $content;
+    /// actions will have the form [action]/[pagename]. If the action is 'view' or the  '/'
+    /// isn't there (so the action defaults to 'view'), filter it.
+    /// If the page does not yet exist, the display will default to 'edit'.
+    if((count($actions) < 2 || $actions[0] == "view") && $wiki_entry && 
+        record_exists('wiki_pages', 'pagename', addslashes($page), 'wiki', $wiki_entry->id)) {
+        print(format_text($content, $moodle_format));
+    } else if($actions[0]=='edit' && $reallyedit) {
+        // Check the page isn't locked before printing out standard wiki content. (Locking
+        // is implemented as a wrapper over the existing wiki.)
+        list($gotlock,$lock)=wiki_obtain_lock($wiki_entry->id,$pagename);
+        if(!$gotlock) {
+            $modcontext = get_context_instance(CONTEXT_MODULE, $cm->id);
+            $canoverridelock = has_capability('mod/wiki:overridelock', $modcontext);
+            
+            $a=new stdClass;
+            $a->since=userdate($lock->lockedsince);
+            $a->seen=userdate($lock->lockedseen);
+            $user=get_record('user','id',$lock->lockedby);
+            $a->name=fullname($user, 
+              has_capability('moodle/site:viewfullnames', $modcontext));
+                
+            print_string('pagelocked','wiki',$a);
+            
+            if($canoverridelock) {
+                $pageesc=htmlspecialchars($page);
+                $stroverrideinfo=get_string('overrideinfo','wiki');
+                $stroverridebutton=get_string('overridebutton','wiki');
+                $sesskey=sesskey();
+                print "
+<form id='overridelock' method='post' action='overridelock.php'>
+  <div>
+  <input type='hidden' name='sesskey' value='$sesskey' />
+  <input type='hidden' name='id' value='$id' />
+  <input type='hidden' name='page' value='$pageesc' />
+  $stroverrideinfo
+  <input type='submit' value='$stroverridebutton' />
+  </div>
+</form>
+";
+            }
+        } else {
+       		// OK, the page is now locked to us. Put in the AJAX for keeping the lock
+            $strlockcancelled=get_string('lockcancelled','wiki');
+            $strnojslockwarning=get_string('nojslockwarning','wiki');
+            $intervalms=WIKI_LOCK_RECONFIRM*1000;
+            print "
+<script type='text/javascript'>
+var intervalID;
+function handleResponse(o) {
+    if(o.responseText=='cancel') {
+        document.forms['ewiki'].elements['preview'].disabled=true;
+        document.forms['ewiki'].elements['save'].disabled=true;
+        clearInterval(intervalID);
+        alert('$strlockcancelled');
     }
-    else {
-        print(format_text($content, $moodle_format));    /// DISABLED UNTIL IT CAN BE FIXED
+}
+function handleFailure(o) {
+    // Ignore for now
+}
+intervalID=setInterval(function() {
+    YAHOO.util.Connect.asyncRequest('POST','confirmlock.php',
+        {success:handleResponse,failure:handleFailure},'lockid={$lock->id}');    
+    },$intervalms);
+</script>
+<noscript><p>
+$strnojslockwarning
+</p></noscript>
+";
+            // Print editor etc
+            print $content;
+        }
+    } else {
+        print $content;
     }
     print $content2;
     print_simple_box_end();
-    echo "<br clear=\"all\" />";
+    echo "<br />";
 
 /// Finish the page
     echo '
