@@ -1,11 +1,11 @@
-<?php // $Id: editlib.php,v 1.19.2.6 2006/08/18 21:22:00 tjhunt Exp $
+<?php // $Id: editlib.php,v 1.41.2.12 2007/05/22 13:24:47 tjhunt Exp $
 /**
 * Functions used by showbank.php to show question editing interface
 *
 * TODO: currently the function question_list still provides controls specific
 *       to the quiz module. This needs to be generalised.
 *
-* @version $Id: editlib.php,v 1.19.2.6 2006/08/18 21:22:00 tjhunt Exp $
+* @version $Id: editlib.php,v 1.41.2.12 2007/05/22 13:24:47 tjhunt Exp $
 * @author Martin Dougiamas and many others. This has recently been extensively
 *         rewritten by members of the Serving Mathematics project
 *         {@link http://maths.york.ac.uk/serving_maths}
@@ -25,7 +25,7 @@ define('DEFAULT_QUESTIONS_PER_PAGE', 20);
 * @param bool $recurse include subdirectories
 * @author added by Howard Miller June 2004
 */
-function get_questions_category( $category, $noparent=false, $recurse=true ) {
+function get_questions_category( $category, $noparent=false, $recurse=true, $export=true ) {
 
     global $QTYPES;
 
@@ -52,6 +52,7 @@ function get_questions_category( $category, $noparent=false, $recurse=true ) {
         // iterate through questions, getting stuff we need
         foreach($questions as $question) {
             $questiontype = $QTYPES[$question->qtype];
+            $question->export_process = $export;
             $questiontype->get_question_options( $question );
             $qresults[] = $question;
         }
@@ -69,20 +70,18 @@ function get_questions_category( $category, $noparent=false, $recurse=true ) {
 * @param integer $courseid  The id of the course whose default category is wanted
 */
 function get_default_question_category($courseid) {
-
-    if ($categories = get_records_select("question_categories", "course = '$courseid' AND parent = '0'", "id")) {
-        foreach ($categories as $category) {
-            return $category;   // Return the first one (lowest id)
-        }
+    // If it already exists, just return it.
+    if ($category = get_records_select("question_categories", "course = '$courseid' AND parent = '0'", 'id', '*', '', 1)) {
+        return reset($category);
     }
 
     // Otherwise, we need to make one
+    $category = new stdClass;
     $category->name = get_string("default", "quiz");
     $category->info = get_string("defaultinfo", "quiz");
     $category->course = $courseid;
     $category->parent = 0;
-    // TODO: Figure out why we use 999 below
-    $category->sortorder = 999;
+    $category->sortorder = 999; // By default, all categories get this number, and are sorted alphabetically.
     $category->publish = 0;
     $category->stamp = make_unique_id_code();
 
@@ -93,106 +92,59 @@ function get_default_question_category($courseid) {
     return $category;
 }
 
-/**
- * Return a list of categories nicely formatted
- * @param int courseid id of course 
- * @param bool published true=include all published categories
- * @return array formatted category names
- */
-function question_category_menu($courseid, $published=false) {
-/// Returns the list of categories
-    $publish = "";
-    if ($published) {
-        $publish = "OR publish = '1'";
-    }
-
-    if (!isadmin()) {
-        $categories = get_records_select("question_categories", "course = '$courseid' $publish", 'parent, sortorder, name ASC');
-    } else {
-        $categories = get_records_select("question_categories", '', 'parent, sortorder, name ASC');
-    }
-    if (!$categories) {
-        return false;
-    }
-    $categories = add_indented_names($categories);
-
-    foreach ($categories as $category) {
-       if ($catcourse = get_record("course", "id", $category->course)) {
-           if ($category->publish && ($category->course != $courseid)) {
-               $category->indentedname .= " ($catcourse->shortname)";
-           }
-           $catmenu[$category->id] = $category->indentedname;
-       }
-    }
-    return $catmenu;
-}
-
 /**
  * prints a form to choose categories
  */
-function question_category_form($course, $current, $recurse=1, $showhidden=false) {
+function question_category_form($course, $current, $recurse=1, $showhidden=false, $showquestiontext=false) {
     global $CFG;
 
 /// Make sure the default category exists for this course
-    if (!$categories = get_records("question_categories", "course", $course->id, "id ASC")) {
-        if (!$category = get_default_question_category($course->id)) {
-            notify("Error creating a default category!");
-        }
-    }
+    get_default_question_category($course->id);
 
 /// Get all the existing categories now
-    if (!$categories = get_records_select("question_categories", "course = '{$course->id}' OR publish = '1'", "parent, sortorder, name ASC")) {
-        notify("Could not find any question categories!");
-        return false;    // Something is really wrong
-    }
+    $catmenu = question_category_options($course->id, true);
 
-    $categories = add_indented_names( $categories );
-    foreach ($categories as $key => $category) {
-       if ($catcourse = get_record("course", "id", $category->course)) {
-           if ($category->publish && $category->course != $course->id) {
-               $category->indentedname .= " ($catcourse->shortname)";
-           }
-           $catmenu[$category->id] = $category->indentedname;
-       }
-    }
     $strcategory = get_string("category", "quiz");
     $strshow = get_string("show", "quiz");
     $streditcats = get_string("editcategories", "quiz");
 
-    echo "<table width=\"100%\"><tr><td width=\"20\" nowrap=\"nowrap\">";
-    echo "<b>$strcategory:</b>&nbsp;";
+    echo "<table><tr><td style=\"white-space:nowrap;\">";
+    echo "<strong>$strcategory:</strong>&nbsp;";
     echo "</td><td>";
     popup_form ("edit.php?courseid=$course->id&amp;cat=", $catmenu, "catmenu", $current, "", "", "", false, "self");
     echo "</td><td align=\"right\">";
     echo "<form method=\"get\" action=\"$CFG->wwwroot/question/category.php\">";
+    echo "<div>";
     echo "<input type=\"hidden\" name=\"id\" value=\"$course->id\" />";
     echo "<input type=\"submit\" value=\"$streditcats\" />";
+    echo '</div>';
     echo "</form>";
     echo '</td></tr></table>';
-    echo '<form method="post" action="edit.php" name="displayoptions">';
-    echo '<table><tr><td>';
-    echo "<input type=\"hidden\" name=\"courseid\" value=\"{$course->id}\" />";
-    echo '<input type="hidden" name="recurse" value="0" />';
-    echo '<input type="checkbox" name="recurse" value="1"';
-    if ($recurse) {
-        echo ' checked="checked"';
-    }
-    echo ' onchange="document.displayoptions.submit(); return true;" />';
-    print_string('recurse', 'quiz');
-    // hide-feature
-    echo '<br />';
-    echo '<input type="hidden" name="showhidden" value="0" />';
-    echo '<input type="checkbox" name="showhidden"';
-    if ($showhidden) {
-        echo ' checked="checked"';
-    }
-    echo ' onchange="document.displayoptions.submit(); return true;" />';
-    print_string('showhidden', 'quiz');
-    echo '</td><noscript><td valign="center">';
-    echo ' <input type="submit" value="'. get_string('go') .'" />';
-    echo '</td></noscript></tr></table></form>';
+
+    echo '<form method="get" action="edit.php" id="displayoptions">';
+    echo "<fieldset class='invisiblefieldset'>";
+    echo "<input type=\"hidden\" name=\"courseid\" value=\"{$course->id}\" />\n";
+    question_category_form_checkbox('recurse', $recurse);
+    question_category_form_checkbox('showhidden', $showhidden);
+    question_category_form_checkbox('showquestiontext', $showquestiontext);
+    echo '<noscript><div class="centerpara"><input type="submit" value="'. get_string('go') .'" />';
+    echo '</div></noscript></fieldset></form>';
 }
 
+/**
+ * Private funciton to help the preceeding function.
+ */
+function question_category_form_checkbox($name, $checked) {
+    echo '<div><input type="hidden" id="' . $name . '_off" name="' . $name . '" value="0" />';
+    echo '<input type="checkbox" id="' . $name . '_on" name="' . $name . '" value="1"';
+    if ($checked) {
+        echo ' checked="checked"';
+    }
+    echo ' onchange="getElementById(\'displayoptions\').submit(); return true;" />';
+    echo '<label for="' . $name . '_on">';
+    print_string($name, 'quiz');
+    echo "</label></div>\n";
+}
 
 /**
 * Prints the table of questions in a category with interactions
@@ -204,11 +156,13 @@ function question_category_form($course, $current, $recurse=1, $showhidden=false
 * @param int $page        The number of the page to be displayed
 * @param int $perpage     Number of questions to show per page
 * @param boolean $showhidden   True if also hidden questions should be displayed
+* @param boolean $showquestiontext whether the text of each question should be shown in the list
 */
 function question_list($course, $categoryid, $quizid=0,
- $recurse=1, $page=0, $perpage=100, $showhidden=false, $sortorder='qtype, name ASC') {
-    global $QTYPE_MENU, $USER, $CFG;
-
+        $recurse=1, $page=0, $perpage=100, $showhidden=false, $sortorder='qtype, name ASC',
+        $showquestiontext = false) {
+    global $QTYPE_MENU, $USER, $CFG, $THEME;
+    
     $qtypemenu = $QTYPE_MENU;
     if ($rqp_types = get_records('question_rqp_types')) {
         foreach($rqp_types as $type) {
@@ -238,7 +192,7 @@ function question_list($course, $categoryid, $quizid=0,
     $strpreview = get_string("preview","quiz");
 
     if (!$categoryid) {
-        echo "<p align=\"center\"><b>";
+        echo "<p style=\"text-align:center;\"><b>";
         print_string("selectcategoryabove", "quiz");
         echo "</b></p>";
         if ($quizid) {
@@ -249,46 +203,42 @@ function question_list($course, $categoryid, $quizid=0,
         return;
     }
 
-    if (!$category = get_record("question_categories", "id", "$categoryid")) {
-        notify("Category not found!");
+    if (!$category = get_record('question_categories', 'id', $categoryid)) {
+        notify('Category not found!');
         return;
     }
-    echo "<center>";
+    $canedit = has_capability('moodle/question:manage', get_context_instance(CONTEXT_COURSE, $category->course));
+    $editingquiz = false;
+    if ($quizid) {
+        $cm = get_coursemodule_from_instance('quiz', $quizid);
+        $editingquiz = has_capability('mod/quiz:manage', get_context_instance(CONTEXT_MODULE, $cm->id));
+    }
+    
+    echo '<div class="boxaligncenter">';
     $formatoptions = new stdClass;
     $formatoptions->noclean = true;
     echo format_text($category->info, FORMAT_MOODLE, $formatoptions, $course->id);
 
     echo '<table><tr>';
 
-    // check if editing of this category is allowed
-    if (isteacheredit($category->course)) {
+    // check if editing questions in this category is allowed
+    if ($canedit) {
         echo "<td valign=\"top\"><b>$strcreatenewquestion:</b></td>";
         echo '<td valign="top" align="right">';
         popup_form ("$CFG->wwwroot/question/question.php?category=$category->id&amp;qtype=", $qtypemenu, "addquestion",
                     "", "choose", "", "", false, "self");
-        echo '</td><td width="10" valign="top" align="right">';
+        echo '</td><td valign="top" align="right">';
         helpbutton("questiontypes", $strcreatenewquestion, "quiz");
-        echo '</td></tr>';
+        echo '</td>';
     }
     else {
-        echo '<tr><td>';
+        echo '<td>';
         print_string("publishedit","quiz");
-        echo '</td></tr>';
+        echo '</td>';
     }
 
-    echo '<tr><td colspan="3" align="right"><font size="2">';
-    if (isteacheredit($category->course)) {
-        echo '<a href="'.$CFG->wwwroot.'/question/import.php?category='.$category->id.'">'.$strimportquestions.'</a>';
-        helpbutton("import", $strimportquestions, "quiz");
-        echo ' | ';
-    }
-    echo "<a href=\"$CFG->wwwroot/question/export.php?category={$category->id}&amp;courseid={$course->id}\">$strexportquestions</a>";
-    helpbutton("export", $strexportquestions, "quiz");
-    echo '</font></td></tr>';
-
-    echo '</table>';
-
-    echo '</center>';
+    echo '</tr></table>';
+    echo '</div>';
 
     $categorylist = ($recurse) ? question_categorylist($category->id) : $category->id;
 
@@ -296,7 +246,7 @@ function question_list($course, $categoryid, $quizid=0,
     $showhidden = $showhidden ? '' : " AND hidden = '0'";
 
     if (!$totalnumber = count_records_select('question', "category IN ($categorylist) AND parent = '0' $showhidden")) {
-        echo "<p align=\"center\">";
+        echo "<p style=\"text-align:center;\">";
         print_string("noquestions", "quiz");
         echo "</p>";
         return;
@@ -307,7 +257,7 @@ function question_list($course, $categoryid, $quizid=0,
         $page = 0;
         if (!$questions = get_records_select('question', "category IN ($categorylist) AND parent = '0' $showhidden", $sortorder, '*', 0, $perpage)) {
             // There are no questions at all
-            echo "<p align=\"center\">";
+            echo "<p style=\"text-align:center;\">";
             print_string("noquestions", "quiz");
             echo "</p>";
             return;
@@ -317,76 +267,112 @@ function question_list($course, $categoryid, $quizid=0,
     print_paging_bar($totalnumber, $page, $perpage,
                 "edit.php?courseid={$course->id}&amp;perpage=$perpage&amp;");
 
-    $canedit = isteacheredit($category->course);
-
     echo '<form method="post" action="edit.php?courseid='.$course->id.'">';
+    echo '<fieldset class="invisiblefieldset" style="display: block;">';
     echo '<input type="hidden" name="sesskey" value="'.$USER->sesskey.'" />';
-    print_simple_box_start('center', '100%', '#ffffff', 0);
-    echo '<table id="categoryquestions" cellspacing="0"><tr>';
-    $actionwidth = $canedit ? 95 : 70;
-    echo "<th width=\"$actionwidth\" nowrap=\"nowrap\" class=\"header\">$straction</th>";
+
+    echo '<table id="categoryquestions" style="width: 100%"><tr>';
+    echo "<th style=\"white-space:nowrap;\" class=\"header\" scope=\"col\">$straction</th>";
     
     $sortoptions = array('name, qtype ASC' => get_string("sortalpha", "quiz"),
                          'qtype, name ASC' => get_string("sorttypealpha", "quiz"),
                          'id ASC' => get_string("sortage", "quiz"));
     $orderselect  = choose_from_menu ($sortoptions, 'sortorder', $sortorder, false, 'this.form.submit();', '0', true);
-    $orderselect .= '<noscript><input type="submit" value="'.get_string("sortsubmit", "quiz").'" /></noscript>';
-    echo "<th width=\"100%\" align=\"left\" nowrap=\"nowrap\" class=\"header\">$strquestionname $orderselect</th>
-    <th nowrap=\"nowrap\" class=\"header\">$strtype</th>";
+    $orderselect .= '<noscript><div><input type="submit" value="'.get_string("sortsubmit", "quiz").'" /></div></noscript>';
+    echo "<th style=\"white-space:nowrap; text-align: left;\" class=\"header\" scope=\"col\">$strquestionname $orderselect</th>
+    <th style=\"white-space:nowrap; text-align: right;\" class=\"header\" scope=\"col\">$strtype</th>";
     echo "</tr>\n";
     foreach ($questions as $question) {
-        echo "<tr>\n<td nowrap=\"nowrap\">\n";
-        if ($quizid) {
-            echo "<a title=\"$straddtoquiz\" href=\"edit.php?addquestion=$question->id&amp;quizid=$quizid&amp;sesskey=$USER->sesskey\"><img
-                  src=\"$CFG->pixpath/t/moveleft.gif\" border=\"0\" alt=\"$straddtoquiz\" /></a>&nbsp;";
+        $nameclass = '';
+        $textclass = '';
+        if ($question->hidden) {
+            $nameclass = 'dimmed_text';
+            $textclass = 'dimmed_text';
         }
-        echo "<a title=\"$strpreview\" href=\"javascript:void();\" onClick=\"openpopup('/question/preview.php?id=$question->id&quizid=$quizid','$strpreview','scrollbars=yes,resizable=yes,width=700,height=480', false)\"><img
-              src=\"$CFG->pixpath/t/preview.gif\" border=\"0\" alt=\"$strpreview\" /></a>&nbsp;";
+        if ($showquestiontext) {
+            $nameclass .= ' header';
+        }
+        if ($nameclass) {
+            $nameclass = 'class="' . $nameclass . '"';
+        }
+        if ($textclass) {
+            $textclass = 'class="' . $textclass . '"';
+        }
+        
+        echo "<tr>\n<td style=\"white-space:nowrap;\" $nameclass>\n";
+        
+        // add to quiz
+        if ($editingquiz) {
+            echo "<a title=\"$straddtoquiz\" href=\"edit.php?addquestion=$question->id&amp;quizid=$quizid&amp;sesskey=$USER->sesskey\"><img
+                  src=\"$CFG->pixpath/t/moveleft.gif\" alt=\"$straddtoquiz\" /></a>&nbsp;";
+        }
+        
+        // preview
+        link_to_popup_window('/question/preview.php?id=' . $question->id . '&amp;quizid=' . $quizid, 'questionpreview',
+                "<img src=\"$CFG->pixpath/t/preview.gif\" class=\"iconsmall\" alt=\"$strpreview\" />",
+                0, 0, $strpreview, QUESTION_PREVIEW_POPUP_OPTIONS);
+        
+        // edit, hide, delete question, using question capabilities, not quiz capabilieies
         if ($canedit) {
             echo "<a title=\"$stredit\" href=\"$CFG->wwwroot/question/question.php?id=$question->id\"><img
-                 src=\"$CFG->pixpath/t/edit.gif\" border=\"0\" alt=\"$stredit\" /></a>&nbsp;";
+                    src=\"$CFG->pixpath/t/edit.gif\" alt=\"$stredit\" /></a>&nbsp;";
             // hide-feature
             if($question->hidden) {
                 echo "<a title=\"$strrestore\" href=\"edit.php?courseid=$course->id&amp;unhide=$question->id&amp;sesskey=$USER->sesskey\"><img
-                     src=\"$CFG->pixpath/t/restore.gif\" border=\"0\" alt=\"$strrestore\" /></a>";
+                        src=\"$CFG->pixpath/t/restore.gif\" alt=\"$strrestore\" /></a>";
             } else {
                 echo "<a title=\"$strdelete\" href=\"edit.php?courseid=$course->id&amp;deleteselected=$question->id&amp;q$question->id=1\"><img
-                     src=\"$CFG->pixpath/t/delete.gif\" border=\"0\" alt=\"$strdelete\" /></a>";
+                        src=\"$CFG->pixpath/t/delete.gif\" alt=\"$strdelete\" /></a>";
             }
         }
         echo "&nbsp;<input title=\"$strselect\" type=\"checkbox\" name=\"q$question->id\" value=\"1\" />";
         echo "</td>\n";
 
-        if ($question->hidden) {
-            echo '<td class="dimmed_text">'.$question->name."</td>\n";
-        } else {
-            echo "<td>".$question->name."</td>\n";
-        }
-        echo "<td align=\"center\">\n";
-        print_question_icon($question, $canedit);
+        echo "<td $nameclass>" . format_string($question->name) . "</td>\n";
+        echo "<td $nameclass style='text-align: right'>\n";
+        print_question_icon($question);
         echo "</td>\n";
         echo "</tr>\n";
-    }
-    echo '<tr><td align="center" colspan="3">';
-    print_paging_bar($totalnumber, $page, $perpage, "edit.php?courseid={$course->id}&amp;perpage=$perpage&amp;");
-    if ($totalnumber > DEFAULT_QUESTIONS_PER_PAGE) {
-        if ($perpage == DEFAULT_QUESTIONS_PER_PAGE) {
-            echo '<a href="edit.php?courseid='.$course->id.'&amp;perpage=1000">'.get_string('showall', 'moodle', $totalnumber).'</a>';
-        } else {
-            echo '<a href="edit.php?courseid='.$course->id.'&amp;perpage=' . DEFAULT_QUESTIONS_PER_PAGE . '">'.get_string('showperpage', 'moodle', DEFAULT_QUESTIONS_PER_PAGE).'</a>';
+        if($showquestiontext){
+            echo '<tr><td colspan="3" ' . $textclass . '>';
+            $formatoptions = new stdClass;
+            $formatoptions->noclean = true;
+            $formatoptions->para = false;
+            echo format_text($question->questiontext, $question->questiontextformat,
+                    $formatoptions, $course->id);
+            echo "</td></tr>\n";
         }
     }
-    echo "</td></tr></table>\n";
-    print_simple_box_end();
+    echo "</table>\n";
+
+    $paging = print_paging_bar($totalnumber, $page, $perpage,
+            "edit.php?courseid={$course->id}&amp;perpage=$perpage&amp;", 'page',
+            false, true);
+    if ($totalnumber > DEFAULT_QUESTIONS_PER_PAGE) {
+        if ($perpage == DEFAULT_QUESTIONS_PER_PAGE) {
+            $showall = '<a href="edit.php?courseid='.$course->id.'&amp;perpage=1000">'.get_string('showall', 'moodle', $totalnumber).'</a>';
+        } else {
+            $showall = '<a href="edit.php?courseid='.$course->id.'&amp;perpage=' . DEFAULT_QUESTIONS_PER_PAGE . '">'.get_string('showperpage', 'moodle', DEFAULT_QUESTIONS_PER_PAGE).'</a>';
+        }
+        if ($paging) {
+            $paging = substr($paging, 0, strrpos($paging, '</div>'));
+            $paging .= "<br />$showall</div>";
+        } else {
+            $paging = "<div class='paging'>$showall</div>"; 
+        }
+    }
+    echo $paging;
 
     echo '<table class="quiz-edit-selected"><tr><td colspan="2">';
     echo '<a href="javascript:select_all_in(\'TABLE\', null, \'categoryquestions\');">'.$strselectall.'</a> /'.
      ' <a href="javascript:deselect_all_in(\'TABLE\', null, \'categoryquestions\');">'.$strselectnone.'</a>'.
      '</td><td align="right"><b>&nbsp;'.get_string('withselected', 'quiz').':</b></td></tr><tr><td>';
-    if ($quizid) {
-        echo "<input type=\"submit\" name=\"add\" value=\"<< $straddtoquiz\" />\n";
+
+    if ($editingquiz) {
+        echo "<input type=\"submit\" name=\"add\" value=\"{$THEME->larrow} $straddtoquiz\" />\n";
         echo '</td><td>';
     }
+    // print delete and move selected question
     if ($canedit) {
         echo '<input type="submit" name="deleteselected" value="'.$strdelete."\" /></td><td>\n";
         echo '<input type="submit" name="move" value="'.get_string('moveto', 'quiz')."\" />\n";
@@ -394,8 +380,12 @@ function question_list($course, $categoryid, $quizid=0,
     }
     echo "</td></tr></table>";
 
-    if ($quizid) {
-        for ($i=1;$i<=10; $i++) {
+    // add random question
+    if ($editingquiz) {
+        for ($i = 1;$i <= min(10, $totalnumber); $i++) {
+            $randomcount[$i] = $i;
+        }
+        for ($i = 20;$i <= min(100, $totalnumber); $i += 10) {
             $randomcount[$i] = $i;
         }
         echo '<br />';
@@ -406,8 +396,8 @@ function question_list($course, $categoryid, $quizid=0,
         echo ' <input type="submit" name="addrandom" value="'. get_string('add') .'" />';
         helpbutton('random', get_string('random', 'quiz'), 'quiz');
     }
-
-     echo "</form>\n";
+    echo '</fieldset>';
+    echo "</form>\n";
 }
 
-?>
+?>
\ No newline at end of file
