@@ -1,4 +1,4 @@
-<?php // $Id: format.php,v 1.2.2.2 2006/08/15 14:38:38 thepurpleblob Exp $
+<?php // $Id: format.php,v 1.15.2.3 2007/03/14 14:10:51 thepurpleblob Exp $
 //
 ///////////////////////////////////////////////////////////////
 // The GIFT import filter was designed as an easy to use method 
@@ -35,11 +35,11 @@
 class qformat_gift extends qformat_default {
 
     function provide_import() {
-      return true;
+        return true;
     }
 
     function provide_export() {
-      return true;
+        return true;
     }
 
     function answerweightparser(&$answer) {
@@ -65,25 +65,23 @@ class qformat_gift extends qformat_default {
     }
 
     function split_truefalse_comment($comment){
-      // splits up comment around # marks
-      // returns an array of true/false feedback
-      $feedback = explode('#',$comment);
-      if (count($feedback)>=2) {
-        $true_feedback = $feedback[0];
-        $false_feedback = $feedback[1];
-      }
-      else {
-        $true_feedback = $feedback[0];
-        $false_feedback = '';
-      }
-      return array( 'true'=>$true_feedback, 'false'=>$false_feedback );
+        // splits up comment around # marks
+        // returns an array of true/false feedback
+        $bits = explode('#',$comment);
+        $feedback = array('wrong' => $bits[0]);
+        if (count($bits) >= 2) {
+            $feedback['right'] = $bits[1];
+        } else {
+            $feedback['right'] = '';
+        }
+        return $feedback;
     }
     
     function escapedchar_pre($string) {
         //Replaces escaped control characters with a placeholder BEFORE processing
         
-        $escapedcharacters = array("\\#",    "\\=",    "\\{",    "\\}",    "\\~",    "\\n"   );  //dlnsk
-        $placeholders      = array("&&035;", "&&061;", "&&123;", "&&125;", "&&126;", "&&010" );  //dlnsk
+        $escapedcharacters = array("\\:",    "\\#",    "\\=",    "\\{",    "\\}",    "\\~",    "\\n"   );  //dlnsk
+        $placeholders      = array("&&058;", "&&035;", "&&061;", "&&123;", "&&125;", "&&126;", "&&010" );  //dlnsk
 
         $string = str_replace("\\\\", "&&092;", $string);
         $string = str_replace($escapedcharacters, $placeholders, $string);
@@ -93,24 +91,21 @@ class qformat_gift extends qformat_default {
 
     function escapedchar_post($string) {
         //Replaces placeholders with corresponding character AFTER processing is done
-        $placeholders = array("&&035;", "&&061;", "&&123;", "&&125;", "&&126;", "&&010"); //dlnsk
-        $characters   = array("#",      "=",      "{",      "}",      "~",      "\n"   ); //dlnsk
+        $placeholders = array("&&058;", "&&035;", "&&061;", "&&123;", "&&125;", "&&126;", "&&010"); //dlnsk
+        $characters   = array(":",     "#",      "=",      "{",      "}",      "~",      "\n"   ); //dlnsk
         $string = str_replace($placeholders, $characters, $string);
         return $string;
     }
 
     function check_answer_count( $min, $answers, $text ) {
-      $countanswers = count($answers);
-      if ($countanswers < $min) {
-        if ($this->displayerrors) {
-          $errormessage = get_string( 'importminerror', 'quiz' );
-            echo "<p>$text</p>\n"; 
-            echo "<p>$errormessage</p>\n"; 
-         }
-         return false;
-       }
+        $countanswers = count($answers);
+        if ($countanswers < $min) {
+            $importminerror = get_string( 'importminerror', 'quiz' );
+            $this->error( $importminerror, $text );
+            return false;
+        }
 
-       return true;
+        return true;
     }
 
 
@@ -125,23 +120,32 @@ class qformat_gift extends qformat_default {
 
         // REMOVED COMMENTED LINES and IMPLODE
         foreach ($lines as $key => $line) {
-           $line = trim($line);
-           if (substr($line, 0, 2) == "//") {
-                // echo "Commented line removed.<br />";
+            $line = trim($line);
+            if (substr($line, 0, 2) == "//") {
                 $lines[$key] = " ";
-                }
+            }
         }
 
         $text = trim(implode(" ", $lines));
 
         if ($text == "") {
-            // echo "<p>Empty line.</p>";
             return false;
         }
 
         // Substitute escaped control characters with placeholders
         $text = $this->escapedchar_pre($text);
 
+        // Look for category modifier
+        if (ereg( '^\$CATEGORY:', $text)) {
+            // $newcategory = $matches[1];
+            $newcategory = trim(substr( $text, 10 ));
+
+            // build fake question to contain category
+            $question->qtype = 'category';
+            $question->category = $newcategory;
+            return $question;
+        }
+        
         // QUESTION NAME parser
         if (substr($text, 0, 2) == "::") {
             $text = substr($text, 2);
@@ -150,7 +154,7 @@ class qformat_gift extends qformat_default {
             if ($namefinish === false) {
                 $question->name = false;
                 // name will be assigned after processing question text below
-             } else {
+            } else {
                 $questionname = substr($text, 0, $namefinish);
                 $question->name = addslashes(trim($this->escapedchar_post($questionname)));
                 $text = trim(substr($text, $namefinish+2)); // Remove name from text
@@ -163,17 +167,15 @@ class qformat_gift extends qformat_default {
         // FIND ANSWER section
         $answerstart = strpos($text, "{");
         if ($answerstart === false) {
-            if ($this->displayerrors) {
-                echo "<p>$text<p>Could not find a {";
-            }
+            $giftleftbraceerror = get_string( 'giftleftbraceerror', 'quiz' );
+            $this->error( $giftleftbraceerror, $text );
             return false;
         }
 
         $answerfinish = strpos($text, "}");
         if ($answerfinish === false) {
-            if ($this->displayerrors) {
-                echo "<p>$text<p>Could not find a }";
-            }
+            $giftrightbraceerror = get_string( 'giftrightbraceerror', 'quiz' );
+            $this->error( $giftrightbraceerror, $text );
             return false;
         }
 
@@ -193,13 +195,13 @@ class qformat_gift extends qformat_default {
         $oldquestiontext = $questiontext;
         $questiontextformat = 0;
         if (substr($questiontext,0,1)=='[') {
-          $questiontext = substr( $questiontext,1 );
-          $rh_brace = strpos( $questiontext, ']' );
-          $qtformat= substr( $questiontext, 0, $rh_brace );
-          $questiontext = substr( $questiontext, $rh_brace+1 );
-          if (!$questiontextformat = text_format_name( $qtformat )) {
-            $questiontext = $oldquestiontext;
-          }          
+            $questiontext = substr( $questiontext,1 );
+            $rh_brace = strpos( $questiontext, ']' );
+            $qtformat= substr( $questiontext, 0, $rh_brace );
+            $questiontext = substr( $questiontext, $rh_brace+1 );
+            if (!$questiontextformat = text_format_name( $qtformat )) {
+                $questiontext = $oldquestiontext;
+            }          
         }
         $question->questiontextformat = $questiontextformat;
         $question->questiontext = addslashes(trim($this->escapedchar_post($questiontext)));
@@ -212,7 +214,7 @@ class qformat_gift extends qformat_default {
         // ensure name is not longer than 250 characters
         $question->name = shorten_text( $question->name, 250 );
 
-         // determine QUESTION TYPE
+        // determine QUESTION TYPE
         $question->qtype = NULL;
 
         if ($answertext{0} == "#"){
@@ -223,8 +225,8 @@ class qformat_gift extends qformat_default {
             $question->qtype = MULTICHOICE;
     
         } elseif (strpos($answertext, "=")  !== false 
-              AND strpos($answertext, "->") !== false) {
-              // only Matching contains both = and ->
+                && strpos($answertext, "->") !== false) {
+            // only Matching contains both = and ->
             $question->qtype = MATCH;
 
         } else { // either TRUEFALSE or SHORTANSWER
@@ -246,9 +248,8 @@ class qformat_gift extends qformat_default {
         }
 
         if (!isset($question->qtype)) {
-            if ($this->displayerrors) {
-                echo "<p>$text<p>Question type not set.";
-                }
+            $giftqtypenotset = get_string('giftqtypenotset','quiz');
+            $this->error( $giftqtypenotset, $text );
             return false;
         }
 
@@ -271,9 +272,9 @@ class qformat_gift extends qformat_default {
     
                 $countanswers = count($answers);
                 
-		if (!$this->check_answer_count( 2,$answers,$text )) {
-  		  return false;
- 		  break;
+                if (!$this->check_answer_count( 2,$answers,$text )) {
+                    return false;
+                    break;
                 }
 
                 foreach ($answers as $key => $answer) {
@@ -292,7 +293,10 @@ class qformat_gift extends qformat_default {
                     }
                     $question->fraction[$key] = $answer_weight;
                     $question->feedback[$key] = $this->commentparser($answer); // commentparser also removes comment from $answer
-                    $question->answer[$key]   = addslashes($this->escapedchar_post($answer));    
+                    $question->answer[$key]   = addslashes($this->escapedchar_post($answer));
+                    $question->correctfeedback = '';
+                    $question->partiallycorrectfeedback = '';
+                    $question->incorrectfeedback = '';
                 }  // end foreach answer
     
                 //$question->defaultgrade = 1;
@@ -309,18 +313,16 @@ class qformat_gift extends qformat_default {
                     array_shift($answers);
                 }
     
-		if (!$this->check_answer_count( 2,$answers,$text )) {
-  		  return false;
- 		  break;
+                if (!$this->check_answer_count( 2,$answers,$text )) {
+                    return false;
+                    break;
                 }
     
                 foreach ($answers as $key => $answer) {
                     $answer = trim($answer);
-                    if (strpos($answer, "->") <= 0) {
-                        if ($this->displayerrors) {
-                        echo "<p>$text<p>Error processing Matching question.<br />
-                            Improperly formatted answer: $answer";
-                        }
+                    if (strpos($answer, "->") === false) {
+                        $giftmatchingformat = get_string('giftmatchingformat','quiz');
+                        $this->error($giftmatchingformat, $answer );
                         return false;
                         break 2;
                     }
@@ -331,28 +333,26 @@ class qformat_gift extends qformat_default {
 
                 }  // end foreach answer
     
-                //$question->defaultgrade = 1;
-                //$question->image = "";   // No images with this format
                 return $question;
                 break;
             
             case TRUEFALSE:
                 $answer = $answertext;
                 $comment = $this->commentparser($answer); // commentparser also removes comment from $answer
-                $feedback = $this->split_truefalse_comment( $comment );
+                $feedback = $this->split_truefalse_comment($comment);
 
                 if ($answer == "T" OR $answer == "TRUE") {
                     $question->answer = 1;
-                    $question->feedbackfalse = $feedback['true'];; //feedback if answer is wrong
-                    $question->feedbacktrue = $feedback['false']; // make sure this exists to stop notifications
+                    $question->feedbacktrue = $feedback['right'];
+                    $question->feedbackfalse = $feedback['wrong'];
                 } else {
                     $question->answer = 0;
-                    $question->feedbacktrue = $feedback['true']; //feedback if answer is wrong
-                    $question->feedbackfalse = $feedback['false']; // make sure this exists to stop notifications
+                    $question->feedbackfalse = $feedback['right'];
+                    $question->feedbacktrue = $feedback['wrong'];
                 }
 
-                //$question->defaultgrade = 1;
-                //$question->image = "";   // No images with this format
+                $question->correctanswer = $question->answer;
+
                 return $question;
                 break;
                 
@@ -366,9 +366,9 @@ class qformat_gift extends qformat_default {
                     array_shift($answers);
                 }
     
-		if (!$this->check_answer_count( 1,$answers,$text )) {
-  		  return false;
- 		  break;
+                if (!$this->check_answer_count( 1,$answers,$text )) {
+                    return false;
+                    break;
                 }
 
                 foreach ($answers as $key => $answer) {
@@ -395,6 +395,14 @@ class qformat_gift extends qformat_default {
                 // Note similarities to ShortAnswer
                 $answertext = substr($answertext, 1); // remove leading "#"
 
+                // If there is feedback for a wrong answer, store it for now.
+                if (($pos = strpos($answertext, '~')) !== false) {
+                    $wrongfeedback = substr($answertext, $pos);
+                    $answertext = substr($answertext, 0, $pos);
+                } else {
+                    $wrongfeedback = '';
+                }
+
                 $answers = explode("=", $answertext);
                 if (isset($answers[0])) {
                     $answers[0] = trim($answers[0]);
@@ -405,9 +413,8 @@ class qformat_gift extends qformat_default {
     
                 if (count($answers) == 0) {
                     // invalid question
-                    if ($this->displayerrors) {
-                        echo "<p>$text<p>No answers found in answertext (Numerical answer)";
-                    }
+                    $giftnonumericalanswers = get_string('giftnonumericalanswers','quiz');
+                    $this->error( $giftnonumericalanswers, $text );
                     return false;
                     break;
                 }
@@ -440,13 +447,9 @@ class qformat_gift extends qformat_default {
                         $ans = trim($answer);
                     }
     
-                    if (!is_numeric($ans) 
-                     OR !is_numeric($tol)) {
-                        if ($this->displayerrors) {
-                            $err = get_string( 'errornotnumbers' );
-                            echo "<p>$text</p><p>$err</p>
-                                <p>Answer: <u>$answer</u></p><p>Tolerance: <u>$tol</u></p> ";
-                        }
+                    if (!(is_numeric($ans) || $ans = '*') || !is_numeric($tol)) {
+                            $errornotnumbers = get_string( 'errornotnumbers' );
+                            $this->error( $errornotnumbers, $text );
                         return false;
                         break;
                     }
@@ -456,16 +459,20 @@ class qformat_gift extends qformat_default {
                     $question->tolerance[$key] = $tol;
                 } // end foreach
 
-                //$question->defaultgrade = 1;
-                //$question->image = "";   // No images with this format
-                //$question->multiplier = array(); // no numeric multipliers with GIFT
+                if ($wrongfeedback) {
+                    $key += 1;
+                    $question->fraction[$key] = 0;
+                    $question->feedback[$key] = $this->commentparser($wrongfeedback);
+                    $question->answer[$key] = '';
+                    $question->tolerance[$key] = '';
+                }
+
                 return $question;
                 break;
 
                 default:
-                if ($this->displayerrors) {
-                    echo "<p>$text<p> No valid question type. Error in switch(question->qtype)";
-                }
+                    $giftnovalidquestion = get_string('giftnovalidquestion','quiz');
+                    $this->error( $giftnovalidquestion, $text );
                 return false;
                 break;                
         
@@ -474,15 +481,15 @@ class qformat_gift extends qformat_default {
     }    // end function readquestion($lines)
 
 function repchar( $text, $format=0 ) {
-    // escapes 'reserved' characters # = ~ { ) and removes new lines
+    // escapes 'reserved' characters # = ~ { ) : and removes new lines
     // also pushes text through format routine
-    $reserved = array( '#', '=', '~', '{', '}', "\n","\r");
-    $escaped =  array( '\#','\=','\~','\{','\}','\n',''  ); //dlnsk
+    $reserved = array( '#', '=', '~', '{', '}', ':', "\n","\r");
+    $escaped =  array( '\#','\=','\~','\{','\}','\:','\n',''  ); //dlnsk
 
     $newtext = str_replace( $reserved, $escaped, $text ); 
     $format = 0; // turn this off for now
     if ($format) {
-      $newtext = format_text( $format );
+        $newtext = format_text( $format );
     }
     return $newtext;
     }
@@ -501,50 +508,44 @@ function writequestion( $question ) {
     $textformat = $question->questiontextformat;
     $tfname = "";
     if ($textformat!=FORMAT_MOODLE) {
-      $tfname = text_format_name( (int)$textformat );
-      $tfname = "[$tfname]";
+        $tfname = text_format_name( (int)$textformat );
+        $tfname = "[$tfname]";
     }
 
     // output depends on question type
     switch($question->qtype) {
+    case 'category':
+        // not a real question, used to insert category switch
+        $expout .= "\$CATEGORY: $question->category\n";    
+        break;
     case TRUEFALSE:
-        $answers = $question->options->answers;
-        foreach ($answers as $answer) {
-            if (trim($answer->answer)=='True') {
-                if ($answer->fraction==1) {
-                    $answertext = 'TRUE';
-                    $right_feedback = $answer->feedback;
-                }
-                else {
-                    $answertext = 'FALSE';
-                    $wrong_feedback = $answer->feedback;
-                }
-            }
-            else {
-                if ($answer->fraction==1) {
-                    $answertext = 'FALSE';
-                    $right_feedback = $answer->feedback;
-                }
-                else {
-                    $answertext = 'TRUE';
-                    $wrong_feedback = $answer->feedback;
-                }
-            }
+        $trueanswer = $question->options->answers[$question->options->trueanswer];
+        $falseanswer = $question->options->answers[$question->options->falseanswer];
+        if ($trueanswer->fraction == 1) {
+            $answertext = 'TRUE';
+            $right_feedback = $trueanswer->feedback;
+            $wrong_feedback = $falseanswer->feedback;
+        } else {
+            $answertext = 'FALSE';
+            $right_feedback = $falseanswer->feedback;
+            $wrong_feedback = $trueanswer->feedback;
         }
 
-        $wrong_feedback = $this->repchar( $wrong_feedback );
-        $right_feedback = $this->repchar( $right_feedback );
-        $expout .= "::".$question->name."::".$tfname.$this->repchar( $question->questiontext,$textformat )."{".$this->repchar( $answertext );
-        if ($wrong_feedback!="") {
-            $expout .= "#".$wrong_feedback;
+        $wrong_feedback = $this->repchar($wrong_feedback);
+        $right_feedback = $this->repchar($right_feedback);
+        $expout .= "::".$this->repchar($question->name)."::".$tfname.$this->repchar( $question->questiontext,$textformat )."{".$this->repchar( $answertext );
+        if ($wrong_feedback) {
+            $expout .= "#" . $wrong_feedback;
+        } else if ($right_feedback) {
+            $expout .= "#";
         }
-        if ($right_feedback!="") {
-            $expout .= "#".$right_feedback;
+        if ($right_feedback) {
+            $expout .= "#" . $right_feedback;
         }
         $expout .= "}\n";
         break;
     case MULTICHOICE:
-        $expout .= "::".$question->name."::".$tfname.$this->repchar( $question->questiontext, $textformat )."{\n";
+        $expout .= "::".$this->repchar($question->name)."::".$tfname.$this->repchar( $question->questiontext, $textformat )."{\n";
         foreach($question->options->answers as $answer) {
             if ($answer->fraction==1) {
                 $answertext = '=';
@@ -553,8 +554,8 @@ function writequestion( $question ) {
                 $answertext = '~';
             }
             else {
-              $export_weight = $answer->fraction*100;
-              $answertext = "~%$export_weight%";
+                $export_weight = $answer->fraction*100;
+                $answertext = "~%$export_weight%";
             }
             $expout .= "\t".$answertext.$this->repchar( $answer->answer );
             if ($answer->feedback!="") {
@@ -565,7 +566,7 @@ function writequestion( $question ) {
         $expout .= "}\n";
         break;
     case SHORTANSWER:
-        $expout .= "::".$question->name."::".$tfname.$this->repchar( $question->questiontext, $textformat )."{\n";
+        $expout .= "::".$this->repchar($question->name)."::".$tfname.$this->repchar( $question->questiontext, $textformat )."{\n";
         foreach($question->options->answers as $answer) {
             $weight = 100 * $answer->fraction;
             $expout .= "\t=%".$weight."%".$this->repchar( $answer->answer )."#".$this->repchar( $answer->feedback )."\n";
@@ -573,16 +574,18 @@ function writequestion( $question ) {
         $expout .= "}\n";
         break;
     case NUMERICAL:
-        $answer = array_pop( $question->options->answers );
-        $tolerance = $answer->tolerance;
-        $min = $answer->answer - $tolerance;
-        $max = $answer->answer + $tolerance;
-        $expout .= "::".$question->name."::".$tfname.$this->repchar( $question->questiontext, $textformat )."{\n";
-        $expout .= "\t#".$min."..".$max."#".$this->repchar( $answer->feedback )."\n";
+        $expout .= "::".$this->repchar($question->name)."::".$tfname.$this->repchar( $question->questiontext, $textformat )."{#\n";
+        foreach ($question->options->answers as $answer) {
+            if ($answer->answer != '') {
+                $expout .= "\t=".$answer->answer.":".(float)$answer->tolerance."#".$this->repchar( $answer->feedback )."\n";
+            } else {
+                $expout .= "\t~#".$this->repchar( $answer->feedback )."\n";
+            }
+        }
         $expout .= "}\n";
         break;
     case MATCH:
-        $expout .= "::".$question->name."::".$tfname.$this->repchar( $question->questiontext, $textformat )."{\n";
+        $expout .= "::".$this->repchar($question->name)."::".$tfname.$this->repchar( $question->questiontext, $textformat )."{\n";
         foreach($question->options->subquestions as $subquestion) {
             $expout .= "\t=".$this->repchar( $subquestion->questiontext )." -> ".$this->repchar( $subquestion->answertext )."\n";
         }
