@@ -1,36 +1,36 @@
-<?php // $Id: question.php,v 1.19.2.3 2006/10/01 20:31:47 tjhunt Exp $
-/*
-* Page for editing questions
-*
-* This page shows the question editing form or processes the following actions:
-* - create new question (category, qtype)
-* - edit question (id, contextquiz (optional))
-* - cancel (cancel)
-*
-* TODO: currently this still treats the quiz as special
-* TODO: question versioning is not currently enabled
-*
-* @version $Id: question.php,v 1.19.2.3 2006/10/01 20:31:47 tjhunt Exp $
-* @author Martin Dougiamas and many others. This has recently been extensively
-*         rewritten by members of the Serving Mathematics project
-*         {@link http://maths.york.ac.uk/serving_maths}
-* @license http://www.gnu.org/copyleft/gpl.html GNU Public License
-* @package question
-*/
+<?php
+/**
+ * Page for editing questions
+ *
+ * This page shows the question editing form or processes the following actions:
+ * - create new question (category, qtype)
+ * - edit question (id, contextquiz (optional))
+ * - cancel (cancel)
+ *
+ * TODO: currently this still treats the quiz as special
+ * TODO: question versioning is not currently enabled
+ *
+ * @version $Id: question.php,v 1.31.2.2 2007/04/23 13:55:01 tjhunt Exp $
+ * @author Martin Dougiamas and many others. This has recently been extensively
+ *         rewritten by members of the Serving Mathematics project
+ *         {@link http://maths.york.ac.uk/serving_maths}
+ * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
+ * @package question
+ *//** */
 
-    require_once("../config.php");
-    // NOTE - is this correct? This is just about editing screens?
-    require_once( "editlib.php" );
-    require_once($CFG->libdir.'/filelib.php');
+    require_once(dirname(__FILE__) . '/../config.php');
+    require_once('editlib.php'); // NOTE - is this correct? This is just about editing screens?
+    require_once($CFG->libdir . '/filelib.php');
+    require_once($CFG->libdir . '/formslib.php');
 
-    $id = optional_param('id', 0, PARAM_INT);        // question id
+    $id = optional_param('id', 0, PARAM_INT); // question id
 
     $qtype = optional_param('qtype', '', PARAM_FILE);
     $category = optional_param('category', 0, PARAM_INT);
-    
-    
+    $inpopup = optional_param('inpopup', 0, PARAM_BOOL);
+
     $CFG->pagepath = 'question/type/'.$qtype;
-    
+
 
     // rqp questions set the type to rqp_nn where nn is the rqp_type id
     if (substr($qtype, 0, 4) == 'rqp_') {
@@ -91,21 +91,12 @@
 
     require_login($course->id, false);
 
-    if (!isteacheredit($course->id)) {
-        error("You can't modify these questions!");
+    if ($QTYPES[$question->qtype]->create_editing_form('question2.php', $question) !== null) {
+        redirect(str_ireplace('question.php', 'question2.php', me()));
     }
 
-    // TODO: remove restriction to quiz
-    $streditingquestion = get_string('editingquestion', 'quiz');
-    if (isset($SESSION->modform->instance)) {
-        $strediting = '<a href="'.$SESSION->returnurl.'">'.get_string('editingquiz', 'quiz').'</a> -> '.
-            $streditingquestion;
-    } else {
-        $strediting = '<a href="edit.php?courseid='.$course->id.'">'.
-            get_string("editquestions", "quiz").'</a> -> '.$streditingquestion;
-    }
-
-    print_header_simple("$streditingquestion", "", $strediting);
+    $coursecontext = get_context_instance(CONTEXT_COURSE, $course->id);
+    require_capability('moodle/question:manage', $coursecontext);
 
     if ($form = data_submitted() and confirm_sesskey()) {
 
@@ -252,23 +243,34 @@
             //    $QTYPES[$question->qtype]->get_question_options($question);
             //    quiz_regrade_question_in_quizzes($question, $replaceinquiz);
             //}
-            redirect($SESSION->returnurl);
+
+            $strsaved = get_string('changessaved');
+            if ($inpopup) {
+                notify($strsaved, '');
+                close_window(3);
+            } else {
+                echo '</div>';
+                redirect($SESSION->returnurl);
+            }
         }
     }
+    // TODO: remove restriction to quiz
+    $streditingquestion = get_string('editingquestion', 'quiz');
+    if (isset($SESSION->modform->instance)) {
+        $strediting = '<a href="'.$SESSION->returnurl.'">'.get_string('editingquiz', 'quiz').'</a> -> '.
+            $streditingquestion;
+    } else {
+        $strediting = '<a href="edit.php?courseid='.$course->id.'">'.
+            get_string("editquestions", "quiz").'</a> -> '.$streditingquestion;
+    }
+
+    print_header_simple($streditingquestion, '', $strediting);
 
     // prepare the grades selector drop-down used by many question types
     $creategrades = get_grade_options();
     $gradeoptions = $creategrades->gradeoptions;
     $gradeoptionsfull = $creategrades->gradeoptionsfull;
 
-    make_upload_directory("$course->id");    // Just in case
-    $coursefiles = get_directory_list("$CFG->dataroot/$course->id", $CFG->moddata);
-    foreach ($coursefiles as $filename) {
-        if (mimeinfo("icon", $filename) == "image.gif") {
-            $images["$filename"] = $filename;
-        }
-    }
-
     // Initialise defaults if necessary.
     if (empty($question->id)) {
         $question->id = "";
@@ -288,6 +290,9 @@
     if (!isset($question->defaultgrade)) {
         $question->defaultgrade = 1;
     }
+    if (empty($question->generalfeedback)) {
+        $question->generalfeedback = "";
+    }
 
     // Set up some richtext editing if necessary
     if ($usehtmleditor = can_use_richtext_editor()) {
