@@ -1,4 +1,4 @@
-<?php  // $Id: questiontype.php,v 1.7.2.5 2006/08/18 10:28:15 tjhunt Exp $
+<?php  // $Id: questiontype.php,v 1.26.2.5 2007/04/04 18:01:28 tjhunt Exp $
 
 ///////////////////
 /// MULTIANSWER /// (Embedded - cloze)
@@ -28,7 +28,7 @@ class embedded_cloze_qtype extends default_questiontype {
             return false;
         }
 
-        $wrappedquestions = get_records_list('question', 'id', $sequence);
+        $wrappedquestions = get_records_list('question', 'id', $sequence, 'id ASC');
 
         // We want an array with question ids as index and the positions as values
         $sequence = array_flip(explode(',', $sequence));
@@ -71,11 +71,11 @@ class embedded_cloze_qtype extends default_questiontype {
             if ($oldwrappedid = array_shift($oldwrappedids)) {
                 $wrapped->id = $oldwrappedid;
             }
-            $wrapped->name     = $question->name;
-            $wrapped->parent   = $question->id;
+            $wrapped->name = $question->name;
+            $wrapped->parent = $question->id;
             $wrapped->category = $question->category;
             $wrapped = $QTYPES[$wrapped->qtype]->save_question($wrapped,
-             $wrapped, $question->course);
+                    $wrapped, $question->course);
             $sequence[] = $wrapped->id;
         }
 
@@ -87,12 +87,11 @@ class embedded_cloze_qtype extends default_questiontype {
             $multianswer = new stdClass;
             $multianswer->question = $question->id;
             $multianswer->sequence = implode(',', $sequence);
-            if ($oldid =
-             get_field('question_multianswer', 'id', 'question', $question->id)) {
+            if ($oldid = get_field('question_multianswer', 'id', 'question', $question->id)) {
                 $multianswer->id = $oldid;
                 if (!update_record("question_multianswer", $multianswer)) {
                     $result->error = "Could not update cloze question options! " .
-                     "(id=$multianswer->id)";
+                            "(id=$multianswer->id)";
                     return $result;
                 }
             } else {
@@ -105,7 +104,7 @@ class embedded_cloze_qtype extends default_questiontype {
     }
 
     function save_question($authorizedquestion, $form, $course) {
-        $question = qtype_multianswer_extract_question ($form->questiontext);
+        $question = qtype_multianswer_extract_question($form->questiontext);
         if (isset($authorizedquestion->id)) {
             $question->id = $authorizedquestion->id;
         }
@@ -119,7 +118,7 @@ class embedded_cloze_qtype extends default_questiontype {
         $form->defaultgrade = $question->defaultgrade;
         $form->questiontext = $question->questiontext;
         $form->questiontextformat = 0;
-        $form->options      = clone($question->options);
+        $form->options = clone($question->options);
         unset($question->options);
         return parent::save_question($question, $form, $course);
     }
@@ -138,24 +137,23 @@ class embedded_cloze_qtype extends default_questiontype {
         foreach ($responses as $response) {
             $tmp = explode("-", $response);
             // restore encoded characters
-            $state->responses[$tmp[0]] =
-             str_replace(array("&#0044;", "&#0045;"), array(",", "-"), $tmp[1]);
+            $state->responses[$tmp[0]] = str_replace(array("&#0044;", "&#0045;"),
+                    array(",", "-"), $tmp[1]);
         }
         return true;
     }
 
     function save_session_and_responses(&$question, &$state) {
         $responses = $state->responses;
+        // encode - (hyphen) and , (comma) to &#0045; because they are used as
+        // delimiters
         array_walk($responses, create_function('&$val, $key',
-         // encode - (hyphen) and , (comma) to &#0045; because they are used as
-         // delimiters
-         '$val = str_replace(array(",", "-"), array("&#0044;", "&#0045;"), $val);
-          $val = "$key-$val";'));
+                '$val = str_replace(array(",", "-"), array("&#0044;", "&#0045;"), $val);
+                $val = "$key-$val";'));
         $responses = implode(',', $responses);
 
         // Set the legacy answer field
-        if (!set_field('question_states', 'answer', $responses, 'id',
-         $state->id)) {
+        if (!set_field('question_states', 'answer', $responses, 'id', $state->id)) {
             return false;
         }
         return true;
@@ -189,22 +187,28 @@ class embedded_cloze_qtype extends default_questiontype {
     }
 
     function print_question_formulation_and_controls(&$question, &$state, $cmoptions, $options) {
-        global $QTYPES;
+        
+        global $QTYPES, $CFG, $USER;
         $readonly = empty($options->readonly) ? '' : 'readonly="readonly"';
         $disabled = empty($options->readonly) ? '' : 'disabled="disabled"';
         $formatoptions = new stdClass;
         $formatoptions->noclean = true;
         $formatoptions->para = false;
         $nameprefix = $question->name_prefix;
-
+        
+        // adding an icon with alt to warn user this is a fill in the gap question
+        // MDL-7497
+        if (!empty($USER->screenreader)) {
+            echo "<img src=\"$CFG->wwwroot/question/type/$question->qtype/icon.gif\" ".
+                "class=\"icon\" alt=\"".get_string('clozeaid','qtype_multichoice')."\" />  ";
+        }
         // For this question type, we better print the image on top:
         if ($image = get_question_image($question, $cmoptions->course)) {
             echo('<img class="qimage" src="' . $image . '" alt="" /><br />');
         }
-
+        
         $qtextremaining = format_text($question->questiontext,
-                                      $question->questiontextformat,
-                                      $formatoptions, $cmoptions->course);
+                $question->questiontextformat, $formatoptions, $cmoptions->course);
 
         $strfeedback = get_string('feedback', 'quiz');
 
@@ -213,27 +217,31 @@ class embedded_cloze_qtype extends default_questiontype {
 
         while (ereg('\{#([^[:space:]}]*)}', $qtextremaining, $regs)) {
             $qtextsplits = explode($regs[0], $qtextremaining, 2);
+            echo "<label>"; // MDL-7497
             echo $qtextsplits[0];
             $qtextremaining = $qtextsplits[1];
 
             $positionkey = $regs[1];
             $wrapped = &$question->options->questions[$positionkey];
             $answers = &$wrapped->options->answers;
-            $correctanswers = $QTYPES[$wrapped->qtype]
-             ->get_correct_responses($wrapped, $state);
+            $correctanswers = $QTYPES[$wrapped->qtype]->get_correct_responses($wrapped, $state);
 
             $inputname = $nameprefix.$positionkey;
-            $response = isset($state->responses[$positionkey])
-                    ? $state->responses[$positionkey] : null;
-
+            if (isset($state->responses[$positionkey])) {
+                $response = $state->responses[$positionkey];
+            } else {
+                $response = null;
+            }
 
             // Determine feedback popup if any
             $popup = '';
             $style = '';
+            $feedbackimg = '';
             if ($options->feedback) {
                 $chosenanswer = null;
                 switch ($wrapped->qtype) {
                     case 'numerical':
+                    case 'shortanswer':
                         $testedstate = clone($state);
                         $testedstate->responses[''] = $response;
                         foreach ($answers as $answer) {
@@ -244,19 +252,6 @@ class embedded_cloze_qtype extends default_questiontype {
                             }
                         }
                         break;
-                    case 'shortanswer':
-                        $testedstate = clone($state);
-                        $testedstate->responses[''] = $response;
-                        $teststate   = clone($state);
-                        foreach ($answers as $answer) {
-                            $teststate->responses[''] = trim($answer->answer);
-                            if($QTYPES[$wrapped->qtype]
-                                    ->compare_responses($wrapped, $testedstate, $teststate)) {
-                                $chosenanswer = clone($answer);
-                                break;
-                            }
-                        }
-                        break;
                     case 'multichoice':
                         if (isset($answers[$response])) {
                             $chosenanswer = clone($answers[$response]);
@@ -274,28 +269,18 @@ class embedded_cloze_qtype extends default_questiontype {
                 }
 
                 if (!empty($chosenanswer->feedback)) {
-                    $feedback = str_replace("'", "\\'", $chosenanswer->feedback);
+                    $feedback = s(str_replace(array("\\", "'"), array("\\\\", "\\'"), $chosenanswer->feedback));
                     $popup = " onmouseover=\"return overlib('$feedback', STICKY, MOUSEOFF, CAPTION, '$strfeedback', FGCOLOR, '#FFFFFF');\" ".
                              " onmouseout=\"return nd();\" ";
                 }
 
                 /// Determine style
-                if (!empty($chosenanswer) && $options->correct_responses) {
-                    if (!isset($chosenanswer->fraction)
-                            || $chosenanswer->fraction <= 0.0) {
-                        // The response must have been totally wrong:
-                        $style = 'class="incorrect"';
-
-                    } else if ($chosenanswer->fraction >= 1.0) {
-                        // The response was correct!!
-                        $style = 'class="correct"';
-
-                    } else {
-                        // This response did at least give some credit:
-                        $style = 'class="partialcorrect"';
-                    }
+                if ($options->feedback && !empty($response)) {
+                    $style = 'class = "'.question_get_feedback_class($chosenanswer->fraction).'"';
+                    $feedbackimg = question_get_feedback_image($chosenanswer->fraction);
                 } else {
                     $style = '';
+                    $feedbackimg = '';
                 }
             }
 
@@ -304,24 +289,44 @@ class embedded_cloze_qtype extends default_questiontype {
                 case 'shortanswer':
                 case 'numerical':
                     echo " <input $style $readonly $popup name=\"$inputname\"
-                            type=\"text\" value=\"$response\" size=\"12\" /> ";
+                            type=\"text\" value=\"".s($response, true)."\" size=\"12\" /> ";
+                    if (!empty($feedback) && !empty($USER->screenreader)) {
+                        echo "<img src=\"$CFG->pixpath/i/feedback.gif\" alt=\"$feedback\" />";
+                    }
+                    echo $feedbackimg;
                     break;
                 case 'multichoice':
                     $outputoptions = '<option></option>'; // Default empty option
                     foreach ($answers as $mcanswer) {
-                        $selected = $response == $mcanswer->id
-                                ? ' selected="selected" ' : '';
-                        $outputoptions .= "<option value=\"$mcanswer->id\" $selected>$mcanswer->answer</option>";
+                        $selected = '';
+                        if ($response == $mcanswer->id) {
+                            $selected = ' selected="selected"';
+                        }
+                        $outputoptions .= "<option value=\"$mcanswer->id\"$selected>" .
+                                s($mcanswer->answer, true) . '</option>';
                     }
-                   echo "<select $popup $readonly $style name=\"$inputname\">";
-                   echo $outputoptions;
-                   echo '</select>';
-                   break;
-               default:
-                   error("Unable to recognize questiontype ($wrapped->qtype) of
-                          question part $positionkey.");
-                   break;
+                    // In the next line, $readonly is invalid HTML, but it works in
+                    // all browsers. $disabled would be valid, but then the JS for
+                    // displaying the feedback does not work. Of course, we should
+                    // not be relying on JS (for accessibility reasons), but that is
+                    // a bigger problem.
+                    //
+                    // The span is used for safari, which does not allow styling of
+                    // selects.
+                    echo "<span $style><select $popup $readonly $style name=\"$inputname\">";
+                    echo $outputoptions;
+                    echo '</select></span>';
+                    if (!empty($feedback) && !empty($USER->screenreader)) {
+                        echo "<img src=\"$CFG->pixpath/i/feedback.gif\" alt=\"$feedback\" />";
+                    }
+                    echo $feedbackimg;
+                    break;
+                default:
+                    error("Unable to recognize questiontype ($wrapped->qtype) of
+                           question part $positionkey.");
+                    break;
            }
+           echo "</label>"; // MDL-7497
         }
 
         // Print the final piece of question text:
@@ -334,7 +339,7 @@ class embedded_cloze_qtype extends default_questiontype {
         $teststate = clone($state);
         $state->raw_grade = 0;
         foreach($question->options->questions as $key => $wrapped) {
-            $state->responses[$key] = html_entity_decode($state->responses[$key]);
+            $state->responses[$key] = $state->responses[$key];
             $teststate->responses = array('' => $state->responses[$key]);
             $teststate->raw_grade = 0;
             if (false === $QTYPES[$wrapped->qtype]
@@ -547,7 +552,7 @@ class embedded_cloze_qtype extends default_questiontype {
             $wrappedquestionid = $sequence[$seqnum-1];
             // now we can find the question
             if (!$wrappedquestion = get_record('question', 'id', $wrappedquestionid)) {
-                error("Can't find the subquestion $wrappedquestionid that is used as part $seqnum in cloze question $state->question");
+                notify("Can't find the subquestion $wrappedquestionid that is used as part $seqnum in cloze question $state->question");
             }
             // For multichoice question we need to recode the answer
             if ($answer and $wrappedquestion->qtype == 'multichoice') {
@@ -578,9 +583,7 @@ class embedded_cloze_qtype extends default_questiontype {
 //////////////////////////////////////////////////////////////////////////
 //// INITIATION - Without this line the question type is not in use... ///
 //////////////////////////////////////////////////////////////////////////
-$QTYPES['multianswer']= new embedded_cloze_qtype();
-// The following adds the questiontype to the menu of types shown to teachers
-$QTYPE_MENU['multianswer'] = get_string("multianswer", "quiz");
+question_register_questiontype(new embedded_cloze_qtype());
 
 /////////////////////////////////////////////////////////////
 //// ADDITIONAL FUNCTIONS
@@ -596,15 +599,13 @@ define("ANSWER_ALTERNATIVE_FRACTION_REGEX",
        '=|%(-?[0-9]+)%');
 // for the syntax '(?<!' see http://www.perl.com/doc/manual/html/pod/perlre.html#item_C
 define("ANSWER_ALTERNATIVE_ANSWER_REGEX",
-        '.+?(?<!\\\\|&)(?=[~#}]|$)');
-        //'[^~#}]+');
+        '.+?(?<!\\\\|&|&amp;)(?=[~#}]|$)');
 define("ANSWER_ALTERNATIVE_FEEDBACK_REGEX",
         '.*?(?<!\\\\)(?=[~}]|$)');
-        //'[//^~}]*');
 define("ANSWER_ALTERNATIVE_REGEX",
-       '(' . ANSWER_ALTERNATIVE_FRACTION_REGEX .')?'
-       . '(' . ANSWER_ALTERNATIVE_ANSWER_REGEX . ')'
-       . '(#(' . ANSWER_ALTERNATIVE_FEEDBACK_REGEX .'))?');
+       '(' . ANSWER_ALTERNATIVE_FRACTION_REGEX .')?' .
+       '(' . ANSWER_ALTERNATIVE_ANSWER_REGEX . ')' .
+       '(#(' . ANSWER_ALTERNATIVE_FEEDBACK_REGEX .'))?');
 
 // Parenthesis positions for ANSWER_ALTERNATIVE_REGEX
 define("ANSWER_ALTERNATIVE_REGEX_PERCENTILE_FRACTION", 2);
@@ -644,42 +645,6 @@ define("ANSWER_REGEX_ANSWER_TYPE_SHORTANSWER", 5);
 define("ANSWER_REGEX_ALTERNATIVES", 6);
 
 function qtype_multianswer_extract_question($text) {
-
-////////////////////////////////////////////////
-//// Define some constants first. It is not the
-//// pattern commonly used in questiontypes.
-//// The reason is that it has been moved here from
-//// question/format/multianswer/format.php
-////////////////////////////////////////////////
-
-
-    // Undo the automatic addslashes, because we want to analyze the text - we need to remember this later and addslashes again!
-    $text = stripslashes($text);
-
-    // We need to allow entities (e.g. &#1085;) in answers. This is difficulty,
-    // because the '#' character is used as delimiter between answer and
-    // feedback as well as inside entities. The HTML editor automatically
-    // replaces '&' with '&amp;', so we undo this to get back the entities we
-    // originally wanted. However, this code leaves all &amp; alone, if they
-    // are not followed by 2 to 9 characters and a final semicolon. This allows
-    // to have an answer end on '&' with the feedback (e.g. answer&amp;#feedback).
-    // When the plain text editor is used, the &amp; needs to be typed out
-    // explicitly in this case.
-    $text = preg_replace('/&amp;(#[0-9a-fx]{2,6}?);/', '&$1;', $text);
-
-    // REGULAR EXPRESSION CONSTANTS
-    // I do not know any way to make this easier
-    // Regexes are always awkard when defined but more comprehensible
-    // when used as constants in the executive code
-
-    // Handle the entity encoded ampersand in entities (e.g. &amp;lt; -> &lt;)
-    $text = preg_replace('/&amp;(.{2,9}?;)/', '&${1}', $text);
-    $text = stripslashes($text);
-
-////////////////////////////////////////
-//// Start of the actual function
-////////////////////////////////////////
-
     $question = new stdClass;
     $question->qtype = 'multianswer';
     $question->questiontext = $text;
@@ -702,6 +667,9 @@ function qtype_multianswer_extract_question($text) {
         } else if(!empty($answerregs[ANSWER_REGEX_ANSWER_TYPE_MULTICHOICE])) {
             $wrapped->qtype = 'multichoice';
             $wrapped->single = 1;
+            $wrapped->correctfeedback = '';
+            $wrapped->partiallycorrectfeedback = '';
+            $wrapped->incorrectfeedback = '';
         } else {
             error("Cannot identify qtype $answerregs[2]");
             return false;
@@ -714,38 +682,35 @@ function qtype_multianswer_extract_question($text) {
         $wrapped->fraction = array();
         $wrapped->feedback = array();
         $wrapped->shuffleanswers = 1;
-        $wrapped->questiontext = addslashes($answerregs[0]); // here we don't want multianswer_escape, because this is editing time information
+        $wrapped->questiontext = $answerregs[0];
         $wrapped->questiontextformat = 0;
 
         $remainingalts = $answerregs[ANSWER_REGEX_ALTERNATIVES];
         while (preg_match('/~?'.ANSWER_ALTERNATIVE_REGEX.'/', $remainingalts, $altregs)) {
             if ('=' == $altregs[ANSWER_ALTERNATIVE_REGEX_FRACTION]) {
                 $wrapped->fraction[] = '1';
-            } else if ($percentile =
-             $altregs[ANSWER_ALTERNATIVE_REGEX_PERCENTILE_FRACTION]){
+            } else if ($percentile = $altregs[ANSWER_ALTERNATIVE_REGEX_PERCENTILE_FRACTION]){
                 $wrapped->fraction[] = .01 * $percentile;
             } else {
                 $wrapped->fraction[] = '0';
             }
-            $wrapped->feedback[] = multianswer_escape(
-             isset($altregs[ANSWER_ALTERNATIVE_REGEX_FEEDBACK])
-             ? $altregs[ANSWER_ALTERNATIVE_REGEX_FEEDBACK] : '');
+            if (isset($altregs[ANSWER_ALTERNATIVE_REGEX_FEEDBACK])) {
+                $wrapped->feedback[] = html_entity_decode($altregs[ANSWER_ALTERNATIVE_REGEX_FEEDBACK], ENT_QUOTES, 'UTF-8');
+            } else {
+                $wrapped->feedback[] = '';
+            }
             if (!empty($answerregs[ANSWER_REGEX_ANSWER_TYPE_NUMERICAL])
-                    && ereg(NUMERICAL_ALTERNATIVE_REGEX,
-                            $altregs[ANSWER_ALTERNATIVE_REGEX_ANSWER],
-                            $numregs) )
-            {
-                $wrapped->answer[] =
-                 multianswer_escape($numregs[NUMERICAL_CORRECT_ANSWER]);
+                    && ereg(NUMERICAL_ALTERNATIVE_REGEX, $altregs[ANSWER_ALTERNATIVE_REGEX_ANSWER], $numregs)) {
+                $wrapped->answer[] = $numregs[NUMERICAL_CORRECT_ANSWER];
                 if ($numregs[NUMERICAL_ABS_ERROR_MARGIN]) {
                     $wrapped->tolerance[] =
-                     $numregs[NUMERICAL_ABS_ERROR_MARGIN];
+                    $numregs[NUMERICAL_ABS_ERROR_MARGIN];
                 } else {
                     $wrapped->tolerance[] = 0;
                 }
             } else { // Tolerance can stay undefined for non numerical questions
-                $wrapped->answer[] = multianswer_escape(
-                 $altregs[ANSWER_ALTERNATIVE_REGEX_ANSWER]);
+                // Undo quoting done by the HTML editor.
+                $wrapped->answer[] = html_entity_decode($altregs[ANSWER_ALTERNATIVE_REGEX_ANSWER], ENT_QUOTES, 'UTF-8');
             }
             $tmp = explode($altregs[0], $remainingalts, 2);
             $remainingalts = $tmp[1];
@@ -756,15 +721,7 @@ function qtype_multianswer_extract_question($text) {
         $question->questiontext = implode("{#$positionkey}",
                     explode($answerregs[0], $question->questiontext, 2));
     }
-    $question->questiontext = multianswer_escape($question->questiontext);
+    $question->questiontext = $question->questiontext;
     return $question;
 }
-
-function multianswer_escape($text) {
-    $text = str_replace("&amp;", "&", $text);
-    $text = str_replace('\#', '#', $text);
-    $text = html_entity_decode($text);
-    return addslashes($text);
-}
-
 ?>
