@@ -1,21 +1,22 @@
-<?php  // $Id: questiontype.php,v 1.3 2006/03/28 07:39:36 gustav_delius Exp $
-
-/////////////////
-/// NUMERICAL ///
-/////////////////
-
-/// QUESTION TYPE CLASS //////////////////
-
-///
-/// This class contains some special features in order to make the
-/// question type embeddable within a multianswer (cloze) question
-///
-
-/// This question type behaves like shortanswer in most cases.
-/// Therefore, it extends the shortanswer question type...
+<?php
+/**
+ * @version $Id: questiontype.php,v 1.10.2.2 2007/03/03 04:38:38 pichetp Exp $
+ * @author Martin Dougiamas and many others. Tim Hunt.
+ * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
+ * @package question
+ *//** */
 
 require_once("$CFG->dirroot/question/type/shortanswer/questiontype.php");
 
+/**
+ * NUMERICAL QUESTION TYPE CLASS
+ *
+ * This class contains some special features in order to make the
+ * question type embeddable within a multianswer (cloze) question
+ *
+ * This question type behaves like shortanswer in most cases.
+ * Therefore, it extends the shortanswer question type...
+ */
 class question_numerical_qtype extends question_shortanswer_qtype {
 
     function name() {
@@ -33,21 +34,22 @@ class question_numerical_qtype extends question_shortanswer_qtype {
                                 "FROM {$CFG->prefix}question_answers a, " .
                                 "     {$CFG->prefix}question_numerical n " .
                                 "WHERE a.question = $question->id " .
-                                "AND   a.id = n.answer;")) {
+                                "    AND   a.id = n.answer " .
+                                "ORDER BY a.id ASC")) {
             notify('Error: Missing question answer!');
             return false;
         }
         $this->get_numerical_units($question);
 
-        // If units are defined we strip off the defaultunit from the answer, if
+        // If units are defined we strip off the default unit from the answer, if
         // it is present. (Required for compatibility with the old code and DB).
         if ($defaultunit = $this->get_default_numerical_unit($question)) {
             foreach($question->options->answers as $key => $val) {
                 $answer = trim($val->answer);
                 $length = strlen($defaultunit->unit);
-                if (substr($answer, -$length) == $defaultunit->unit) {
+                if ($length && substr($answer, -$length) == $defaultunit->unit) {
                     $question->options->answers[$key]->answer =
-                     substr($answer, 0, strlen($answer)-$length);
+                            substr($answer, 0, strlen($answer)-$length);
                 }
             }
         }
@@ -88,20 +90,21 @@ class question_numerical_qtype extends question_shortanswer_qtype {
         return $unit;
     }
 
+    /**
+     * Save the units and the answers associated with this question.
+     */
     function save_question_options($question) {
-        // save_question_options supports the definition of multiple answers
-        // for numerical questions. This is not currently used by the editing
-        // interface, but the GIFT format supports it. The multianswer qtype,
-        // for example can make use of this feature.
+        
         // Get old versions of the objects
-        if (!$oldanswers = get_records("question_answers", "question", $question->id)) {
+        if (!$oldanswers = get_records('question_answers', 'question', $question->id, 'id ASC')) {
             $oldanswers = array();
         }
 
-        if (!$oldoptions = get_records("question_numerical", "question", $question->id)) {
+        if (!$oldoptions = get_records('question_numerical', 'question', $question->id, 'answer ASC')) {
             $oldoptions = array();
         }
 
+        // Save the units.
         $result = $this->save_numerical_units($question);
         if (isset($result->error)) {
             return $result;
@@ -111,10 +114,17 @@ class question_numerical_qtype extends question_shortanswer_qtype {
 
         // Insert all the new answers
         foreach ($question->answer as $key => $dataanswer) {
-            if ($dataanswer != "") {
+            if (!isset( $question->deleteanswer[$key] ) && !( trim($dataanswer) == 0 && $question->fraction[$key]== 0 &&trim($question->feedback[$key])=='')) { 
                 $answer = new stdClass;
                 $answer->question = $question->id;
-                $answer->answer   = trim($dataanswer);
+                if (trim($dataanswer) == '*') {
+                    $answer->answer = '*';
+                } else {
+                    $answer->answer = $this->apply_unit($dataanswer, $units);
+                    if ($answer->answer === false) {
+                        $result->notice = get_string('invalidnumericanswer', 'quiz');
+                    }
+                }
                 $answer->fraction = $question->fraction[$key];
                 $answer->feedback = trim($question->feedback[$key]);
 
@@ -124,7 +134,7 @@ class question_numerical_qtype extends question_shortanswer_qtype {
                         $result->error = "Could not update quiz answer! (id=$answer->id)";
                         return $result;
                     }
-                } else {    // This is a completely new answer
+                } else { // This is a completely new answer
                     if (! $answer->id = insert_record("question_answers", $answer)) {
                         $result->error = "Could not insert quiz answer!";
                         return $result;
@@ -137,8 +147,15 @@ class question_numerical_qtype extends question_shortanswer_qtype {
                 }
                 $options->question  = $question->id;
                 $options->answer    = $answer->id;
-                $options->tolerance = $this->apply_unit($question->tolerance[$key], $units);
-
+                if (trim($question->tolerance[$key]) == '') {
+                    $options->tolerance = '';
+                } else {
+                    $options->tolerance = $this->apply_unit($question->tolerance[$key], $units);
+                    if ($options->tolerance === false) {
+                        $result->notice = get_string('invalidnumerictolerance', 'quiz');
+                    }
+                }
+                
                 // Save options
                 if (isset($options->id)) { // reusing existing record
                     if (! update_record('question_numerical', $options)) {
@@ -151,27 +168,32 @@ class question_numerical_qtype extends question_shortanswer_qtype {
                         return $result;
                     }
                 }
-
-                // delete old answer records
-                if (!empty($oldanswers)) {
-                    foreach($oldanswers as $oa) {
-                        delete_records('question_answers', 'id', $oa->id);
-                    }
-                }
-
-                // delete old answer records
-                if (!empty($oldoptions)) {
-                    foreach($oldoptions as $oo) {
-                        delete_records('question_numerical', 'id', $oo->id);
-                    }
-                }
-
             }
         }
+        // delete old answer records
+        if (!empty($oldanswers)) {
+            foreach($oldanswers as $oa) {
+                delete_records('question_answers', 'id', $oa->id);
+            }
+        }
+
+        // delete old answer records
+        if (!empty($oldoptions)) {
+            foreach($oldoptions as $oo) {
+                delete_records('question_numerical', 'id', $oo->id);
+            }
+        }
+
+        // Report any problems.
+        if (!empty($result->notice)) {
+            return $result;
+        }
+        
+        return true;
     }
 
     function save_numerical_units($question) {
-        if (!$oldunits = get_records("question_numerical_units", "question", $question->id)) {
+        if (!$oldunits = get_records('question_numerical_units', 'question', $question->id, 'id ASC')) {
             $oldunits = array();
         }
 
@@ -180,8 +202,8 @@ class question_numerical_qtype extends question_shortanswer_qtype {
         $keys  = array();
         $oldunits = array_values($oldunits);
         usort($oldunits, create_function('$a, $b', // make sure the default unit is at index 0
-         'if (1.0 === (float)$a->multiplier) { return -1; } else '.
-         'if (1.0 === (float)$b->multiplier) { return 1; } else { return 0; }'));
+                'if (1.0 === (float)$a->multiplier) { return -1; } else '.
+                'if (1.0 === (float)$b->multiplier) { return 1; } else { return 0; }'));
         foreach ($oldunits as $unit) {
             $units[] = clone($unit);
         }
@@ -190,8 +212,7 @@ class question_numerical_qtype extends question_shortanswer_qtype {
             // Discard any unit which doesn't specify the unit or the multiplier
             if (!empty($question->multiplier[$i]) && !empty($question->unit[$i])) {
                 $units[$i]->question = $question->id;
-                $units[$i]->multiplier =
-                 $this->apply_unit($question->multiplier[$i], array());
+                $units[$i]->multiplier = $this->apply_unit($question->multiplier[$i], array());
                 $units[$i]->unit = $question->unit[$i];
             } else {
                 unset($units[$i]);
@@ -200,6 +221,7 @@ class question_numerical_qtype extends question_shortanswer_qtype {
         unset($question->multiplier, $question->unit);
 
         /// Save units
+        $result = new stdClass;
         for ($i = 0; $i < $n; $i++) {
             if (!isset($units[$i]) && isset($oldunits[$i])) { // Delete if it hasn't been resubmitted
                 delete_records('question_numerical_units', 'id', $oldunits[$i]->id);
@@ -223,43 +245,44 @@ class question_numerical_qtype extends question_shortanswer_qtype {
     }
 
     /**
-    * Deletes question from the question-type specific tables
-    *
-    * @return boolean Success/Failure
-    * @param object $question  The question being deleted
-    */
+     * Deletes question from the question-type specific tables
+     *
+     * @return boolean Success/Failure
+     * @param object $question  The question being deleted
+     */
     function delete_question($questionid) {
         delete_records("question_numerical", "question", $questionid);
         delete_records("question_numerical_units", "question", $questionid);
         return true;
     }
 
-    function compare_responses(&$question, &$state, &$teststate) {
-        $response = isset($state->responses['']) ? $state->responses[''] : '';
-        $testresponse = isset($teststate->responses[''])
-         ? $teststate->responses[''] : '';
-        return ($response == $testresponse);
+    function compare_responses(&$question, $state, $teststate) {
+        if (isset($state->responses['']) && isset($teststate->responses[''])) {
+            return $state->responses[''] == $teststate->responses[''];
+        }
+        return false;
     }
 
-
-
-    // Checks whether a response matches a given answer, taking the tolerance
-    // into account. Returns a true for if a response matches the answer, false
-    // if it doesn't.
+    /**
+     * Checks whether a response matches a given answer, taking the tolerance
+     * and units into account. Returns a true for if a response matches the
+     * answer, false if it doesn't.
+     */
     function test_response(&$question, &$state, $answer) {
-        if (isset($state->responses[''])) {
-            $response = $this->apply_unit(stripslashes($state->responses['']),
-             $question->options->units);
-        } else {
-            $response = '';
+        // Deal with the match anything answer.
+        if ($answer->answer == '*') {
+            return true;
         }
 
-        if (is_numeric($response) && is_numeric($answer->answer)) {
-            $this->get_tolerance_interval($answer);
-            return ($answer->min <= $response && $answer->max >= $response);
-        } else {
-            return ($response == $answer->answer);
+        $response = $this->apply_unit(stripslashes($state->responses['']), $question->options->units);
+
+        if ($response === false) {
+            return false; // The student did not type a number.
         }
+
+        // The student did type a number, so check it with tolerances.
+        $this->get_tolerance_interval($answer);
+        return ($answer->min <= $response && $response <= $answer->max);
     }
 
     // ULPGC ecastro
@@ -273,34 +296,9 @@ class question_numerical_qtype extends question_shortanswer_qtype {
         return false;
     }
 
-    function grade_responses(&$question, &$state, $cmoptions) {
-        $answers     = &$question->options->answers;
-        $state->raw_grade = 0;
-        foreach($answers as $answer) {
-            if($this->test_response($question, $state, $answer)) {
-                if ($state->raw_grade < $answer->fraction) {
-                    $state->raw_grade = $answer->fraction;
-                }
-            }
-        }
-        if (empty($state->raw_grade)) {
-            $state->raw_grade = 0;
-        }
-
-        // Make sure we don't assign negative or too high marks
-        $state->raw_grade = min(max((float) $state->raw_grade,
-                            0.0), 1.0) * $question->maxgrade;
-        $state->penalty = $question->penalty * $question->maxgrade;
-
-        // mark the state as graded
-        $state->event = ($state->event ==  QUESTION_EVENTCLOSE) ? QUESTION_EVENTCLOSEANDGRADE : QUESTION_EVENTGRADE;
-
-        return true;
-    }
-
     function get_correct_responses(&$question, &$state) {
         $correct = parent::get_correct_responses($question, $state);
-        if ($unit = $this->get_default_numerical_unit($question)) {
+        if ($correct[''] != '*' && $unit = $this->get_default_numerical_unit($question)) {
             $correct[''] .= ' '.$unit->unit;
         }
         return $correct;
@@ -308,16 +306,17 @@ class question_numerical_qtype extends question_shortanswer_qtype {
 
     // ULPGC ecastro
     function get_all_responses(&$question, &$state) {
-        unset($answers);
+        $result = new stdClass;
+        $answers = array();
         $unit = $this->get_default_numerical_unit($question);
         if (is_array($question->options->answers)) {
             foreach ($question->options->answers as $aid=>$answer) {
-                unset ($r);
+                $r = new stdClass;
                 $r->answer = $answer->answer;
                 $r->credit = $answer->fraction;
                 $this->get_tolerance_interval($answer);
-                if ($unit) {
-                    $r->answer .= ' '.$unit->unit;
+                if ($r->answer != '*' && $unit) {
+                    $r->answer .= ' ' . $unit->unit;
                 }
                 if ($answer->max != $answer->min) {
                     $max = "$answer->max"; //format_float($answer->max, 2);
@@ -326,8 +325,6 @@ class question_numerical_qtype extends question_shortanswer_qtype {
                 }
                 $answers[$aid] = $r;
             }
-        } else {
-            $answers[]="error"; // just for debugging, eliminate
         }
         $result->id = $question->id;
         $result->responses = $answers;
@@ -337,8 +334,7 @@ class question_numerical_qtype extends question_shortanswer_qtype {
     function get_tolerance_interval(&$answer) {
         // No tolerance
         if (empty($answer->tolerance)) {
-            $answer->min = $answer->max = $answer->answer;
-            return true;
+            $answer->tolerance = 0;
         }
 
         // Calculate the interval of correct responses (min/max)
@@ -355,13 +351,24 @@ class question_numerical_qtype extends question_shortanswer_qtype {
                 /// Recalculate the tolerance and fall through
                 /// to the nominal case:
                 $tolerance = $answer->answer * $tolerance;
-                // Falls through to the nominal case -
-            case '2': case 'nominal':
-                $tolerance = abs($tolerance); // important - otherwise min and max are swapped
+                // Do not fall through to the nominal case because the tiny fraction is a factor of the answer
+                 $tolerance = abs($tolerance); // important - otherwise min and max are swapped
                 $max = $answer->answer + $tolerance;
                 $min = $answer->answer - $tolerance;
                 break;
-            case '3': case 'geometric':
+            case '2': case 'nominal':
+                $tolerance = abs($tolerance); // important - otherwise min and max are swapped
+                // $answer->tolerance 0 or something else
+                if ((float)$answer->tolerance == 0.0  &&  abs((float)$answer->answer) <= $tolerance ){
+                    $tolerance = (float) ("1.0e-".ini_get('precision')) * abs((float)$answer->answer) ; //tiny fraction 
+                } else if ((float)$answer->tolerance != 0.0 && abs((float)$answer->tolerance) < abs((float)$answer->answer) &&  abs((float)$answer->answer) <= $tolerance){
+                    $tolerance = (1+("1.0e-".ini_get('precision')) )* abs((float) $answer->tolerance) ;//tiny fraction 
+               }     
+               
+                $max = $answer->answer + $tolerance;
+                $min = $answer->answer - $tolerance;
+                break;
+           case '3': case 'geometric':
                 $quotient = 1 + abs($tolerance);
                 $max = $answer->answer * $quotient;
                 $min = $answer->answer / $quotient;
@@ -376,40 +383,51 @@ class question_numerical_qtype extends question_shortanswer_qtype {
     }
 
     /**
-    * Checks if the $rawresponse has a unit and applys it if appropriate.
-    *
-    * @param string $rawresponse  The response string to be converted to a float.
-    * @param array $units         An array with the defined units, where the
-    *                             unit is the key and the multiplier the value.
-    * @return float               The rawresponse with the unit taken into
-    *                             account as a float.
-    */
+     * Checks if the $rawresponse has a unit and applys it if appropriate.
+     *
+     * @param string $rawresponse  The response string to be converted to a float.
+     * @param array $units         An array with the defined units, where the
+     *                             unit is the key and the multiplier the value.
+     * @return float               The rawresponse with the unit taken into
+     *                             account as a float.
+     */
     function apply_unit($rawresponse, $units) {
         // Make units more useful
         $tmpunits = array();
         foreach ($units as $unit) {
             $tmpunits[$unit->unit] = $unit->multiplier;
         }
-
+        // remove spaces and normalise decimal places.
         $search  = array(' ', ',');
         $replace = array('', '.');
-        $rawresponse = str_replace($search, $replace, $rawresponse); // remove spaces
-        if (ereg(
-         '^([+-]?([0-9]+(\\.[0-9]*)?|[.][0-9]+)([eE][-+]?[0-9]+)?)([^0-9].*)?$',
-         $rawresponse, $responseparts)) {
-            $responsenum  = (float)$responseparts[1];
-            if (isset($tmpunits[$responseparts[5]])) {
-                return (float)$responseparts[1] / $tmpunits[$responseparts[5]];
+        $rawresponse = str_replace($search, $replace, trim($rawresponse));
+        
+        // Apply any unit that is present.
+        if (ereg('^([+-]?([0-9]+(\\.[0-9]*)?|\\.[0-9]+)([eE][-+]?[0-9]+)?)([^0-9].*)?$',
+                $rawresponse, $responseparts)) {
+                    
+            if (!empty($responseparts[5])) {
+                
+                if (isset($tmpunits[$responseparts[5]])) {
+                    // Valid number with unit.
+                    return (float)$responseparts[1] / $tmpunits[$responseparts[5]];
+                } else {
+                    // Valid number with invalid unit. Must be wrong.
+                    return false;
+                }
+
             } else {
+                // Valid number without unit.
                 return (float)$responseparts[1];
             }
         }
-        return $rawresponse;
+        // Invalid number. Must be wrong.
+        return false;
     }
     
-/// BACKUP FUNCTIONS ////////////////////////////
+    /// BACKUP FUNCTIONS ////////////////////////////
 
-    /*
+    /**
      * Backup the data in the question
      *
      * This is used in question/backuplib.php
@@ -418,7 +436,7 @@ class question_numerical_qtype extends question_shortanswer_qtype {
 
         $status = true;
 
-        $numericals = get_records("question_numerical","question",$question,"id");
+        $numericals = get_records('question_numerical', 'question', $question, 'id ASC');
         //If there are numericals
         if ($numericals) {
             //Iterate over each numerical
@@ -437,9 +455,9 @@ class question_numerical_qtype extends question_shortanswer_qtype {
         return $status;
     }
 
-/// RESTORE FUNCTIONS /////////////////
+    /// RESTORE FUNCTIONS /////////////////
 
-    /*
+    /**
      * Restores the data in the question
      *
      * This is used in question/restorelib.php
@@ -456,18 +474,19 @@ class question_numerical_qtype extends question_shortanswer_qtype {
             $num_info = $numericals[$i];
 
             //Now, build the question_numerical record structure
+            $numerical = new stdClass;
             $numerical->question = $new_question_id;
             $numerical->answer = backup_todb($num_info['#']['ANSWER']['0']['#']);
             $numerical->tolerance = backup_todb($num_info['#']['TOLERANCE']['0']['#']);
 
-            ////We have to recode the answer field
+            //We have to recode the answer field
             $answer = backup_getid($restore->backup_unique_code,"question_answers",$numerical->answer);
             if ($answer) {
                 $numerical->answer = $answer->new_id;
             }
 
             //The structure is equal to the db, so insert the question_numerical
-            $newid = insert_record ("question_numerical",$numerical);
+            $newid = insert_record ("question_numerical", $numerical);
 
             //Do some output
             if (($i+1) % 50 == 0) {
@@ -492,13 +511,7 @@ class question_numerical_qtype extends question_shortanswer_qtype {
     }
 
 }
-//// END OF CLASS ////
-
-//////////////////////////////////////////////////////////////////////////
-//// INITIATION - Without this line the question type is not in use... ///
-//////////////////////////////////////////////////////////////////////////
-$QTYPES['numerical']= new question_numerical_qtype();
-// The following adds the questiontype to the menu of types shown to teachers
-$QTYPE_MENU['numerical'] = get_string("numerical", "quiz");
 
+// INITIATION - Without this line the question type is not in use.
+question_register_questiontype(new question_numerical_qtype());
 ?>
